declare module 'websql-autocomplete-2/index' {
  import { AbstractParseTreeVisitor, Lexer as LexerType, Parser as ParserType } from 'antlr4ng';
  import { CursorPosition } from 'websql-autocomplete-2/lib/cursor.js/index';
  import { TokenDictionary } from 'websql-autocomplete-2/lib/tables.js/index';
  import { AutocompleteParseResult, GenerateSuggestionsFromRules, GetParseTree, ISymbolTableVisitor, LexerConstructor, ParserConstructor, SymbolTableVisitorConstructor, TableSuggestion } from 'websql-autocomplete-2/types.js/index';
  export { AutocompleteParseResult, TableSuggestion };
  export function parseQuery<L extends LexerType, P extends ParserType, V extends AbstractParseTreeVisitor<{}>, S extends ISymbolTableVisitor & V>(Lexer: LexerConstructor<L>, Parser: ParserConstructor<P>, SymbolTableVisitor: SymbolTableVisitorConstructor<S>, tokenDictionary: TokenDictionary, ignoredTokens: Set<number>, preferredRules: Set<number>, explicitlyParseJoin: boolean, getParseTree: GetParseTree<P>, generateSuggestionsFromRules: GenerateSuggestionsFromRules, query: string, cursor: CursorPosition): AutocompleteParseResult;
  export function parseMySqlQueryWithoutCursor(query: string): Pick<AutocompleteParseResult, 'errors'>;
  export function parseMySqlQuery(query: string, cursor: CursorPosition): AutocompleteParseResult;
  export function parsePostgreSqlQueryWithoutCursor(query: string): Pick<AutocompleteParseResult, 'errors'>;
  export function parsePostgreSqlQuery(query: string, cursor: CursorPosition): AutocompleteParseResult;
  export function parseClickHouseQueryWithoutCursor(query: string): Pick<AutocompleteParseResult, 'errors'>;
  export function parseClickHouseQuery(query: string, cursor: CursorPosition): AutocompleteParseResult;

}
declare module 'websql-autocomplete-2/lib/cursor' {
  import { Token, TokenStream } from 'antlr4ng';
  export interface CursorPosition {
      line: number;
      column: number;
  }
  export interface TokenPosition {
      startLine: number;
      startColumn: number;
      endLine: number;
      endColumn: number;
  }
  export function getTokenPosition(token: Token, whitespaceToken: number): TokenPosition;
  export function findCursorTokenIndex(tokenStream: TokenStream, cursor: CursorPosition, whitespaceToken: number, realIndex?: boolean): number | undefined;
  export function getCursorIndex(query: string, cursor: CursorPosition): number;

}
declare module 'websql-autocomplete-2/lib/query' {
  export function getCurrentStatement(query: string, cursorIndex: number): {
      statement: string;
      cursorIndex: number;
  };
  export function shouldSuggestTemplates(statement: string, cursorIndex: number): boolean;

}
declare module 'websql-autocomplete-2/lib/sqlErrorListener' {
  import { ANTLRErrorListener, ATNSimulator, Recognizer, Token } from 'antlr4ng';
  import { TokenPosition } from 'websql-autocomplete-2/lib/cursor.js/index';
  interface ParserSyntaxError extends TokenPosition {
      message: string;
  }
  export class SqlErrorListener implements ANTLRErrorListener {
      errors: ParserSyntaxError[];
      whitespaceToken: number;
      constructor(whitespaceToken: number);
      syntaxError<S extends Token, T extends ATNSimulator>(_recognizer: Recognizer<T>, token: S | null, startLine: number, startColumn: number, message: string): void;
      reportAmbiguity(): void;
      reportAttemptingFullContext(): void;
      reportContextSensitivity(): void;
  }
  export {};

}
declare module 'websql-autocomplete-2/lib/symbolTable' {
  import * as c3 from 'antlr4-c3';
  export class TableSymbol extends c3.TypedSymbol {
      name: string;
      alias: string | undefined;
      constructor(name: string, alias?: string, type?: c3.IType);
  }

}
declare module 'websql-autocomplete-2/lib/tables' {
  import { TokenStream } from 'antlr4ng';
  export interface TableQueryPosition {
      start: number;
      end: number;
      type: 'from' | 'alter' | 'insert' | 'update';
      joinTableQueryPosition?: Omit<TableQueryPosition, 'joinTableQueryPosition' | 'type'>;
  }
  export interface TokenDictionary {
      SPACE: number;
      FROM: number;
      OPENING_BRACKET: number;
      CLOSING_BRACKET: number;
      ALTER: number;
      INSERT: number;
      UPDATE: number;
      JOIN: number;
  }
  export function getTableQueryPosition(tokenStream: TokenStream, tokenIndex: number, dictionary: TokenDictionary): TableQueryPosition | undefined;

}
declare module 'websql-autocomplete-2/parsers/clickhouse/clickHouseParserData' {
  import { ParseTree, Token } from 'antlr4ng';
  import * as c3 from 'antlr4-c3';
  import { AutocompleteParseResult, ISymbolTableVisitor } from 'websql-autocomplete-2/types.js/index';
  import { ClickHouseLexer } from 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseLexer.js/index';
  import { ClickHouseParser, TableExprAliasContext, TableIdentifierContext } from 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index';
  import { ClickHouseParserVisitor } from 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParserVisitor.js/index';
  import { TableQueryPosition, TokenDictionary } from 'websql-autocomplete-2/lib/tables.js/index';
  class ClickHouseSymbolTableVisitor extends ClickHouseParserVisitor<{}> implements ISymbolTableVisitor {
      symbolTable: c3.SymbolTable;
      scope: c3.ScopedSymbol;
      constructor();
      visitTableIdentifier: (context: TableIdentifierContext) => {};
      visitTableExprAlias: (context: TableExprAliasContext) => {};
  }
  function generateSuggestionsFromRules(rules: c3.CandidatesCollection['rules'], cursorTokenIndex: number, previousToken?: Token): Partial<AutocompleteParseResult> & {
      suggestColumns?: boolean;
  };
  function getParseTree(parser: ClickHouseParser, type?: TableQueryPosition['type']): ParseTree;
  export const clickHouseParserData: {
      Lexer: typeof ClickHouseLexer;
      Parser: typeof ClickHouseParser;
      SymbolTableVisitor: typeof ClickHouseSymbolTableVisitor;
      tokenDictionary: TokenDictionary;
      ignoredTokens: Set<number>;
      preferredRules: Set<number>;
      explicitlyParseJoin: boolean;
      getParseTree: typeof getParseTree;
      generateSuggestionsFromRules: typeof generateSuggestionsFromRules;
  };
  export {};

}
declare module 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseLexer' {
  import * as antlr from 'antlr4ng';
  export class ClickHouseLexer extends antlr.Lexer {
      static readonly ADD = 1;
      static readonly AFTER = 2;
      static readonly ALIAS = 3;
      static readonly ALL = 4;
      static readonly ALTER = 5;
      static readonly AND = 6;
      static readonly ANTI = 7;
      static readonly ANY = 8;
      static readonly ARRAY = 9;
      static readonly AS = 10;
      static readonly ASCENDING = 11;
      static readonly ASOF = 12;
      static readonly AST = 13;
      static readonly ASYNC = 14;
      static readonly ATTACH = 15;
      static readonly BETWEEN = 16;
      static readonly BOTH = 17;
      static readonly BY = 18;
      static readonly CASE = 19;
      static readonly CAST = 20;
      static readonly CHECK = 21;
      static readonly CLEAR = 22;
      static readonly CLUSTER = 23;
      static readonly CODEC = 24;
      static readonly COLLATE = 25;
      static readonly COLUMN = 26;
      static readonly COMMENT = 27;
      static readonly CONSTRAINT = 28;
      static readonly CREATE = 29;
      static readonly CROSS = 30;
      static readonly CUBE = 31;
      static readonly CURRENT = 32;
      static readonly DATABASE = 33;
      static readonly DATABASES = 34;
      static readonly DATE = 35;
      static readonly DAY = 36;
      static readonly DEDUPLICATE = 37;
      static readonly DEFAULT = 38;
      static readonly DELAY = 39;
      static readonly DELETE = 40;
      static readonly DESC = 41;
      static readonly DESCENDING = 42;
      static readonly DESCRIBE = 43;
      static readonly DETACH = 44;
      static readonly DICTIONARIES = 45;
      static readonly DICTIONARY = 46;
      static readonly DISK = 47;
      static readonly DISTINCT = 48;
      static readonly DISTRIBUTED = 49;
      static readonly DROP = 50;
      static readonly ELSE = 51;
      static readonly END = 52;
      static readonly ENGINE = 53;
      static readonly EVENTS = 54;
      static readonly EXISTS = 55;
      static readonly EXPLAIN = 56;
      static readonly EXPRESSION = 57;
      static readonly EXTRACT = 58;
      static readonly FETCHES = 59;
      static readonly FINAL = 60;
      static readonly FIRST = 61;
      static readonly FLUSH = 62;
      static readonly FOLLOWING = 63;
      static readonly FOR = 64;
      static readonly FORMAT = 65;
      static readonly FREEZE = 66;
      static readonly FROM = 67;
      static readonly FULL = 68;
      static readonly FUNCTION = 69;
      static readonly GLOBAL = 70;
      static readonly GRANULARITY = 71;
      static readonly GROUP = 72;
      static readonly HAVING = 73;
      static readonly HIERARCHICAL = 74;
      static readonly HOUR = 75;
      static readonly ID = 76;
      static readonly IF = 77;
      static readonly ILIKE = 78;
      static readonly IN = 79;
      static readonly INDEX = 80;
      static readonly INF = 81;
      static readonly INJECTIVE = 82;
      static readonly INNER = 83;
      static readonly INSERT = 84;
      static readonly INTERVAL = 85;
      static readonly INTO = 86;
      static readonly IS = 87;
      static readonly IS_OBJECT_ID = 88;
      static readonly JOIN = 89;
      static readonly KEY = 90;
      static readonly KILL = 91;
      static readonly LAST = 92;
      static readonly LAYOUT = 93;
      static readonly LEADING = 94;
      static readonly LEFT = 95;
      static readonly LIFETIME = 96;
      static readonly LIKE = 97;
      static readonly LIMIT = 98;
      static readonly LIVE = 99;
      static readonly LOCAL = 100;
      static readonly LOGS = 101;
      static readonly MATERIALIZE = 102;
      static readonly MATERIALIZED = 103;
      static readonly MAX = 104;
      static readonly MERGES = 105;
      static readonly MIN = 106;
      static readonly MINUTE = 107;
      static readonly MODIFY = 108;
      static readonly MONTH = 109;
      static readonly MOVE = 110;
      static readonly MUTATION = 111;
      static readonly NAN_SQL = 112;
      static readonly NO = 113;
      static readonly NOT = 114;
      static readonly NULL_SQL = 115;
      static readonly NULLS = 116;
      static readonly OFFSET = 117;
      static readonly ON = 118;
      static readonly OPTIMIZE = 119;
      static readonly OR = 120;
      static readonly ORDER = 121;
      static readonly OUTER = 122;
      static readonly OUTFILE = 123;
      static readonly OVER = 124;
      static readonly PARTITION = 125;
      static readonly POPULATE = 126;
      static readonly PRECEDING = 127;
      static readonly PREWHERE = 128;
      static readonly PRIMARY = 129;
      static readonly PROJECTION = 130;
      static readonly QUARTER = 131;
      static readonly RANGE = 132;
      static readonly RELOAD = 133;
      static readonly REMOVE = 134;
      static readonly RENAME = 135;
      static readonly REPLACE = 136;
      static readonly REPLICA = 137;
      static readonly REPLICATED = 138;
      static readonly RIGHT = 139;
      static readonly ROLLUP = 140;
      static readonly ROW = 141;
      static readonly ROWS = 142;
      static readonly SAMPLE = 143;
      static readonly SECOND = 144;
      static readonly SELECT = 145;
      static readonly SEMI = 146;
      static readonly SENDS = 147;
      static readonly SET = 148;
      static readonly SETTINGS = 149;
      static readonly SHOW = 150;
      static readonly SOURCE = 151;
      static readonly START = 152;
      static readonly STOP = 153;
      static readonly SUBSTRING = 154;
      static readonly SYNC = 155;
      static readonly SYNTAX = 156;
      static readonly SYSTEM = 157;
      static readonly TABLE = 158;
      static readonly TABLES = 159;
      static readonly TEMPORARY = 160;
      static readonly TEST = 161;
      static readonly THEN = 162;
      static readonly TIES = 163;
      static readonly TIMEOUT = 164;
      static readonly TIMESTAMP = 165;
      static readonly TO = 166;
      static readonly TOP = 167;
      static readonly TOTALS = 168;
      static readonly TRAILING = 169;
      static readonly TRIM = 170;
      static readonly TRUNCATE = 171;
      static readonly TTL = 172;
      static readonly TYPE = 173;
      static readonly UNBOUNDED = 174;
      static readonly UNION = 175;
      static readonly UPDATE = 176;
      static readonly USE = 177;
      static readonly USING = 178;
      static readonly UUID = 179;
      static readonly VALUES = 180;
      static readonly VIEW = 181;
      static readonly VOLUME = 182;
      static readonly WATCH = 183;
      static readonly WEEK = 184;
      static readonly WHEN = 185;
      static readonly WHERE = 186;
      static readonly WINDOW = 187;
      static readonly WITH = 188;
      static readonly YEAR = 189;
      static readonly JSON_FALSE = 190;
      static readonly JSON_TRUE = 191;
      static readonly IDENTIFIER = 192;
      static readonly FLOATING_LITERAL = 193;
      static readonly OCTAL_LITERAL = 194;
      static readonly DECIMAL_LITERAL = 195;
      static readonly HEXADECIMAL_LITERAL = 196;
      static readonly STRING_LITERAL = 197;
      static readonly ARROW = 198;
      static readonly ASTERISK = 199;
      static readonly BACKQUOTE = 200;
      static readonly BACKSLASH = 201;
      static readonly COLON = 202;
      static readonly COMMA = 203;
      static readonly CONCAT = 204;
      static readonly DASH = 205;
      static readonly DOT = 206;
      static readonly EQ_DOUBLE = 207;
      static readonly EQ_SINGLE = 208;
      static readonly GE = 209;
      static readonly GT = 210;
      static readonly LBRACE = 211;
      static readonly LBRACKET = 212;
      static readonly LE = 213;
      static readonly LPAREN = 214;
      static readonly LT = 215;
      static readonly NOT_EQ = 216;
      static readonly PERCENT = 217;
      static readonly PLUS = 218;
      static readonly QUERY = 219;
      static readonly QUOTE_DOUBLE = 220;
      static readonly QUOTE_SINGLE = 221;
      static readonly RBRACE = 222;
      static readonly RBRACKET = 223;
      static readonly RPAREN = 224;
      static readonly SEMICOLON = 225;
      static readonly SLASH = 226;
      static readonly UNDERSCORE = 227;
      static readonly MULTI_LINE_COMMENT = 228;
      static readonly SINGLE_LINE_COMMENT = 229;
      static readonly WHITESPACE = 230;
      static readonly channelNames: string[];
      static readonly literalNames: (string | null)[];
      static readonly symbolicNames: (string | null)[];
      static readonly modeNames: string[];
      static readonly ruleNames: string[];
      constructor(input: antlr.CharStream);
      get grammarFileName(): string;
      get literalNames(): (string | null)[];
      get symbolicNames(): (string | null)[];
      get ruleNames(): string[];
      get serializedATN(): number[];
      get channelNames(): string[];
      get modeNames(): string[];
      static readonly _serializedATN: number[];
      private static __ATN;
      static get _ATN(): antlr.ATN;
      private static readonly vocabulary;
      get vocabulary(): antlr.Vocabulary;
      private static readonly decisionsToDFA;
  }

}
declare module 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser' {
  import * as antlr from 'antlr4ng';
  import { ClickHouseParserVisitor } from 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParserVisitor.js/index';
  export class ClickHouseParser extends antlr.Parser {
      static readonly ADD = 1;
      static readonly AFTER = 2;
      static readonly ALIAS = 3;
      static readonly ALL = 4;
      static readonly ALTER = 5;
      static readonly AND = 6;
      static readonly ANTI = 7;
      static readonly ANY = 8;
      static readonly ARRAY = 9;
      static readonly AS = 10;
      static readonly ASCENDING = 11;
      static readonly ASOF = 12;
      static readonly AST = 13;
      static readonly ASYNC = 14;
      static readonly ATTACH = 15;
      static readonly BETWEEN = 16;
      static readonly BOTH = 17;
      static readonly BY = 18;
      static readonly CASE = 19;
      static readonly CAST = 20;
      static readonly CHECK = 21;
      static readonly CLEAR = 22;
      static readonly CLUSTER = 23;
      static readonly CODEC = 24;
      static readonly COLLATE = 25;
      static readonly COLUMN = 26;
      static readonly COMMENT = 27;
      static readonly CONSTRAINT = 28;
      static readonly CREATE = 29;
      static readonly CROSS = 30;
      static readonly CUBE = 31;
      static readonly CURRENT = 32;
      static readonly DATABASE = 33;
      static readonly DATABASES = 34;
      static readonly DATE = 35;
      static readonly DAY = 36;
      static readonly DEDUPLICATE = 37;
      static readonly DEFAULT = 38;
      static readonly DELAY = 39;
      static readonly DELETE = 40;
      static readonly DESC = 41;
      static readonly DESCENDING = 42;
      static readonly DESCRIBE = 43;
      static readonly DETACH = 44;
      static readonly DICTIONARIES = 45;
      static readonly DICTIONARY = 46;
      static readonly DISK = 47;
      static readonly DISTINCT = 48;
      static readonly DISTRIBUTED = 49;
      static readonly DROP = 50;
      static readonly ELSE = 51;
      static readonly END = 52;
      static readonly ENGINE = 53;
      static readonly EVENTS = 54;
      static readonly EXISTS = 55;
      static readonly EXPLAIN = 56;
      static readonly EXPRESSION = 57;
      static readonly EXTRACT = 58;
      static readonly FETCHES = 59;
      static readonly FINAL = 60;
      static readonly FIRST = 61;
      static readonly FLUSH = 62;
      static readonly FOLLOWING = 63;
      static readonly FOR = 64;
      static readonly FORMAT = 65;
      static readonly FREEZE = 66;
      static readonly FROM = 67;
      static readonly FULL = 68;
      static readonly FUNCTION = 69;
      static readonly GLOBAL = 70;
      static readonly GRANULARITY = 71;
      static readonly GROUP = 72;
      static readonly HAVING = 73;
      static readonly HIERARCHICAL = 74;
      static readonly HOUR = 75;
      static readonly ID = 76;
      static readonly IF = 77;
      static readonly ILIKE = 78;
      static readonly IN = 79;
      static readonly INDEX = 80;
      static readonly INF = 81;
      static readonly INJECTIVE = 82;
      static readonly INNER = 83;
      static readonly INSERT = 84;
      static readonly INTERVAL = 85;
      static readonly INTO = 86;
      static readonly IS = 87;
      static readonly IS_OBJECT_ID = 88;
      static readonly JOIN = 89;
      static readonly KEY = 90;
      static readonly KILL = 91;
      static readonly LAST = 92;
      static readonly LAYOUT = 93;
      static readonly LEADING = 94;
      static readonly LEFT = 95;
      static readonly LIFETIME = 96;
      static readonly LIKE = 97;
      static readonly LIMIT = 98;
      static readonly LIVE = 99;
      static readonly LOCAL = 100;
      static readonly LOGS = 101;
      static readonly MATERIALIZE = 102;
      static readonly MATERIALIZED = 103;
      static readonly MAX = 104;
      static readonly MERGES = 105;
      static readonly MIN = 106;
      static readonly MINUTE = 107;
      static readonly MODIFY = 108;
      static readonly MONTH = 109;
      static readonly MOVE = 110;
      static readonly MUTATION = 111;
      static readonly NAN_SQL = 112;
      static readonly NO = 113;
      static readonly NOT = 114;
      static readonly NULL_SQL = 115;
      static readonly NULLS = 116;
      static readonly OFFSET = 117;
      static readonly ON = 118;
      static readonly OPTIMIZE = 119;
      static readonly OR = 120;
      static readonly ORDER = 121;
      static readonly OUTER = 122;
      static readonly OUTFILE = 123;
      static readonly OVER = 124;
      static readonly PARTITION = 125;
      static readonly POPULATE = 126;
      static readonly PRECEDING = 127;
      static readonly PREWHERE = 128;
      static readonly PRIMARY = 129;
      static readonly PROJECTION = 130;
      static readonly QUARTER = 131;
      static readonly RANGE = 132;
      static readonly RELOAD = 133;
      static readonly REMOVE = 134;
      static readonly RENAME = 135;
      static readonly REPLACE = 136;
      static readonly REPLICA = 137;
      static readonly REPLICATED = 138;
      static readonly RIGHT = 139;
      static readonly ROLLUP = 140;
      static readonly ROW = 141;
      static readonly ROWS = 142;
      static readonly SAMPLE = 143;
      static readonly SECOND = 144;
      static readonly SELECT = 145;
      static readonly SEMI = 146;
      static readonly SENDS = 147;
      static readonly SET = 148;
      static readonly SETTINGS = 149;
      static readonly SHOW = 150;
      static readonly SOURCE = 151;
      static readonly START = 152;
      static readonly STOP = 153;
      static readonly SUBSTRING = 154;
      static readonly SYNC = 155;
      static readonly SYNTAX = 156;
      static readonly SYSTEM = 157;
      static readonly TABLE = 158;
      static readonly TABLES = 159;
      static readonly TEMPORARY = 160;
      static readonly TEST = 161;
      static readonly THEN = 162;
      static readonly TIES = 163;
      static readonly TIMEOUT = 164;
      static readonly TIMESTAMP = 165;
      static readonly TO = 166;
      static readonly TOP = 167;
      static readonly TOTALS = 168;
      static readonly TRAILING = 169;
      static readonly TRIM = 170;
      static readonly TRUNCATE = 171;
      static readonly TTL = 172;
      static readonly TYPE = 173;
      static readonly UNBOUNDED = 174;
      static readonly UNION = 175;
      static readonly UPDATE = 176;
      static readonly USE = 177;
      static readonly USING = 178;
      static readonly UUID = 179;
      static readonly VALUES = 180;
      static readonly VIEW = 181;
      static readonly VOLUME = 182;
      static readonly WATCH = 183;
      static readonly WEEK = 184;
      static readonly WHEN = 185;
      static readonly WHERE = 186;
      static readonly WINDOW = 187;
      static readonly WITH = 188;
      static readonly YEAR = 189;
      static readonly JSON_FALSE = 190;
      static readonly JSON_TRUE = 191;
      static readonly IDENTIFIER = 192;
      static readonly FLOATING_LITERAL = 193;
      static readonly OCTAL_LITERAL = 194;
      static readonly DECIMAL_LITERAL = 195;
      static readonly HEXADECIMAL_LITERAL = 196;
      static readonly STRING_LITERAL = 197;
      static readonly ARROW = 198;
      static readonly ASTERISK = 199;
      static readonly BACKQUOTE = 200;
      static readonly BACKSLASH = 201;
      static readonly COLON = 202;
      static readonly COMMA = 203;
      static readonly CONCAT = 204;
      static readonly DASH = 205;
      static readonly DOT = 206;
      static readonly EQ_DOUBLE = 207;
      static readonly EQ_SINGLE = 208;
      static readonly GE = 209;
      static readonly GT = 210;
      static readonly LBRACE = 211;
      static readonly LBRACKET = 212;
      static readonly LE = 213;
      static readonly LPAREN = 214;
      static readonly LT = 215;
      static readonly NOT_EQ = 216;
      static readonly PERCENT = 217;
      static readonly PLUS = 218;
      static readonly QUERY = 219;
      static readonly QUOTE_DOUBLE = 220;
      static readonly QUOTE_SINGLE = 221;
      static readonly RBRACE = 222;
      static readonly RBRACKET = 223;
      static readonly RPAREN = 224;
      static readonly SEMICOLON = 225;
      static readonly SLASH = 226;
      static readonly UNDERSCORE = 227;
      static readonly MULTI_LINE_COMMENT = 228;
      static readonly SINGLE_LINE_COMMENT = 229;
      static readonly WHITESPACE = 230;
      static readonly RULE_root = 0;
      static readonly RULE_queryStmt = 1;
      static readonly RULE_query = 2;
      static readonly RULE_ctes = 3;
      static readonly RULE_namedQuery = 4;
      static readonly RULE_columnAliases = 5;
      static readonly RULE_alterStmt = 6;
      static readonly RULE_alterTableClause = 7;
      static readonly RULE_assignmentExprList = 8;
      static readonly RULE_assignmentExpr = 9;
      static readonly RULE_tableColumnPropertyType = 10;
      static readonly RULE_partitionClause = 11;
      static readonly RULE_attachStmt = 12;
      static readonly RULE_checkStmt = 13;
      static readonly RULE_createStmt = 14;
      static readonly RULE_dictionarySchemaClause = 15;
      static readonly RULE_dictionaryAttrDfnt = 16;
      static readonly RULE_dictionaryEngineClause = 17;
      static readonly RULE_dictionaryPrimaryKeyClause = 18;
      static readonly RULE_dictionaryArgExpr = 19;
      static readonly RULE_sourceClause = 20;
      static readonly RULE_lifetimeClause = 21;
      static readonly RULE_layoutClause = 22;
      static readonly RULE_rangeClause = 23;
      static readonly RULE_dictionarySettingsClause = 24;
      static readonly RULE_clusterClause = 25;
      static readonly RULE_uuidClause = 26;
      static readonly RULE_destinationClause = 27;
      static readonly RULE_subqueryClause = 28;
      static readonly RULE_tableSchemaClause = 29;
      static readonly RULE_engineClause = 30;
      static readonly RULE_partitionByClause = 31;
      static readonly RULE_primaryKeyClause = 32;
      static readonly RULE_sampleByClause = 33;
      static readonly RULE_ttlClause = 34;
      static readonly RULE_engineExpr = 35;
      static readonly RULE_tableElementExpr = 36;
      static readonly RULE_tableColumnDfnt = 37;
      static readonly RULE_tableColumnPropertyExpr = 38;
      static readonly RULE_tableIndexDfnt = 39;
      static readonly RULE_tableProjectionDfnt = 40;
      static readonly RULE_codecExpr = 41;
      static readonly RULE_codecArgExpr = 42;
      static readonly RULE_ttlExpr = 43;
      static readonly RULE_describeStmt = 44;
      static readonly RULE_dropStmt = 45;
      static readonly RULE_existsStmt = 46;
      static readonly RULE_explainStmt = 47;
      static readonly RULE_insertStmt = 48;
      static readonly RULE_columnsClause = 49;
      static readonly RULE_dataClause = 50;
      static readonly RULE_killStmt = 51;
      static readonly RULE_optimizeStmt = 52;
      static readonly RULE_renameStmt = 53;
      static readonly RULE_projectionSelectStmt = 54;
      static readonly RULE_selectUnionStmt = 55;
      static readonly RULE_selectStmtWithParens = 56;
      static readonly RULE_selectStmt = 57;
      static readonly RULE_withClause = 58;
      static readonly RULE_topClause = 59;
      static readonly RULE_fromClause = 60;
      static readonly RULE_arrayJoinClause = 61;
      static readonly RULE_windowClause = 62;
      static readonly RULE_prewhereClause = 63;
      static readonly RULE_whereClause = 64;
      static readonly RULE_groupByClause = 65;
      static readonly RULE_havingClause = 66;
      static readonly RULE_orderByClause = 67;
      static readonly RULE_projectionOrderByClause = 68;
      static readonly RULE_limitByClause = 69;
      static readonly RULE_limitClause = 70;
      static readonly RULE_settingsClause = 71;
      static readonly RULE_joinExpr = 72;
      static readonly RULE_joinOp = 73;
      static readonly RULE_joinOpCross = 74;
      static readonly RULE_joinConstraintClause = 75;
      static readonly RULE_sampleClause = 76;
      static readonly RULE_limitExpr = 77;
      static readonly RULE_orderExprList = 78;
      static readonly RULE_orderExpr = 79;
      static readonly RULE_ratioExpr = 80;
      static readonly RULE_settingExprList = 81;
      static readonly RULE_settingExpr = 82;
      static readonly RULE_windowExpr = 83;
      static readonly RULE_winPartitionByClause = 84;
      static readonly RULE_winOrderByClause = 85;
      static readonly RULE_winFrameClause = 86;
      static readonly RULE_winFrameExtend = 87;
      static readonly RULE_winFrameBound = 88;
      static readonly RULE_setStmt = 89;
      static readonly RULE_showStmt = 90;
      static readonly RULE_systemStmt = 91;
      static readonly RULE_truncateStmt = 92;
      static readonly RULE_useStmt = 93;
      static readonly RULE_watchStmt = 94;
      static readonly RULE_columnTypeExpr = 95;
      static readonly RULE_columnExprList = 96;
      static readonly RULE_columnsExpr = 97;
      static readonly RULE_columnExpr = 98;
      static readonly RULE_columnArgList = 99;
      static readonly RULE_columnArgExpr = 100;
      static readonly RULE_columnLambdaExpr = 101;
      static readonly RULE_columnIdentifier = 102;
      static readonly RULE_nestedIdentifier = 103;
      static readonly RULE_tableExpr = 104;
      static readonly RULE_tableFunctionExpr = 105;
      static readonly RULE_tableIdentifier = 106;
      static readonly RULE_tableArgList = 107;
      static readonly RULE_tableArgExpr = 108;
      static readonly RULE_databaseIdentifier = 109;
      static readonly RULE_floatingLiteral = 110;
      static readonly RULE_numberLiteral = 111;
      static readonly RULE_literal = 112;
      static readonly RULE_interval = 113;
      static readonly RULE_keyword = 114;
      static readonly RULE_keywordForAlias = 115;
      static readonly RULE_alias = 116;
      static readonly RULE_identifier = 117;
      static readonly RULE_identifierOrNull = 118;
      static readonly RULE_enumValue = 119;
      static readonly literalNames: (string | null)[];
      static readonly symbolicNames: (string | null)[];
      static readonly ruleNames: string[];
      get grammarFileName(): string;
      get literalNames(): (string | null)[];
      get symbolicNames(): (string | null)[];
      get ruleNames(): string[];
      get serializedATN(): number[];
      protected createFailedPredicateException(predicate?: string, message?: string): antlr.FailedPredicateException;
      constructor(input: antlr.TokenStream);
      root(): RootContext;
      queryStmt(): QueryStmtContext;
      query(): QueryContext;
      ctes(): CtesContext;
      namedQuery(): NamedQueryContext;
      columnAliases(): ColumnAliasesContext;
      alterStmt(): AlterStmtContext;
      alterTableClause(): AlterTableClauseContext;
      assignmentExprList(): AssignmentExprListContext;
      assignmentExpr(): AssignmentExprContext;
      tableColumnPropertyType(): TableColumnPropertyTypeContext;
      partitionClause(): PartitionClauseContext;
      attachStmt(): AttachStmtContext;
      checkStmt(): CheckStmtContext;
      createStmt(): CreateStmtContext;
      dictionarySchemaClause(): DictionarySchemaClauseContext;
      dictionaryAttrDfnt(): DictionaryAttrDfntContext;
      dictionaryEngineClause(): DictionaryEngineClauseContext;
      dictionaryPrimaryKeyClause(): DictionaryPrimaryKeyClauseContext;
      dictionaryArgExpr(): DictionaryArgExprContext;
      sourceClause(): SourceClauseContext;
      lifetimeClause(): LifetimeClauseContext;
      layoutClause(): LayoutClauseContext;
      rangeClause(): RangeClauseContext;
      dictionarySettingsClause(): DictionarySettingsClauseContext;
      clusterClause(): ClusterClauseContext;
      uuidClause(): UuidClauseContext;
      destinationClause(): DestinationClauseContext;
      subqueryClause(): SubqueryClauseContext;
      tableSchemaClause(): TableSchemaClauseContext;
      engineClause(): EngineClauseContext;
      partitionByClause(): PartitionByClauseContext;
      primaryKeyClause(): PrimaryKeyClauseContext;
      sampleByClause(): SampleByClauseContext;
      ttlClause(): TtlClauseContext;
      engineExpr(): EngineExprContext;
      tableElementExpr(): TableElementExprContext;
      tableColumnDfnt(): TableColumnDfntContext;
      tableColumnPropertyExpr(): TableColumnPropertyExprContext;
      tableIndexDfnt(): TableIndexDfntContext;
      tableProjectionDfnt(): TableProjectionDfntContext;
      codecExpr(): CodecExprContext;
      codecArgExpr(): CodecArgExprContext;
      ttlExpr(): TtlExprContext;
      describeStmt(): DescribeStmtContext;
      dropStmt(): DropStmtContext;
      existsStmt(): ExistsStmtContext;
      explainStmt(): ExplainStmtContext;
      insertStmt(): InsertStmtContext;
      columnsClause(): ColumnsClauseContext;
      dataClause(): DataClauseContext;
      killStmt(): KillStmtContext;
      optimizeStmt(): OptimizeStmtContext;
      renameStmt(): RenameStmtContext;
      projectionSelectStmt(): ProjectionSelectStmtContext;
      selectUnionStmt(): SelectUnionStmtContext;
      selectStmtWithParens(): SelectStmtWithParensContext;
      selectStmt(): SelectStmtContext;
      withClause(): WithClauseContext;
      topClause(): TopClauseContext;
      fromClause(): FromClauseContext;
      arrayJoinClause(): ArrayJoinClauseContext;
      windowClause(): WindowClauseContext;
      prewhereClause(): PrewhereClauseContext;
      whereClause(): WhereClauseContext;
      groupByClause(): GroupByClauseContext;
      havingClause(): HavingClauseContext;
      orderByClause(): OrderByClauseContext;
      projectionOrderByClause(): ProjectionOrderByClauseContext;
      limitByClause(): LimitByClauseContext;
      limitClause(): LimitClauseContext;
      settingsClause(): SettingsClauseContext;
      joinExpr(): JoinExprContext;
      joinExpr(_p: number): JoinExprContext;
      joinOp(): JoinOpContext;
      joinOpCross(): JoinOpCrossContext;
      joinConstraintClause(): JoinConstraintClauseContext;
      sampleClause(): SampleClauseContext;
      limitExpr(): LimitExprContext;
      orderExprList(): OrderExprListContext;
      orderExpr(): OrderExprContext;
      ratioExpr(): RatioExprContext;
      settingExprList(): SettingExprListContext;
      settingExpr(): SettingExprContext;
      windowExpr(): WindowExprContext;
      winPartitionByClause(): WinPartitionByClauseContext;
      winOrderByClause(): WinOrderByClauseContext;
      winFrameClause(): WinFrameClauseContext;
      winFrameExtend(): WinFrameExtendContext;
      winFrameBound(): WinFrameBoundContext;
      setStmt(): SetStmtContext;
      showStmt(): ShowStmtContext;
      systemStmt(): SystemStmtContext;
      truncateStmt(): TruncateStmtContext;
      useStmt(): UseStmtContext;
      watchStmt(): WatchStmtContext;
      columnTypeExpr(): ColumnTypeExprContext;
      columnExprList(): ColumnExprListContext;
      columnsExpr(): ColumnsExprContext;
      columnExpr(): ColumnExprContext;
      columnExpr(_p: number): ColumnExprContext;
      columnArgList(): ColumnArgListContext;
      columnArgExpr(): ColumnArgExprContext;
      columnLambdaExpr(): ColumnLambdaExprContext;
      columnIdentifier(): ColumnIdentifierContext;
      nestedIdentifier(): NestedIdentifierContext;
      tableExpr(): TableExprContext;
      tableExpr(_p: number): TableExprContext;
      tableFunctionExpr(): TableFunctionExprContext;
      tableIdentifier(): TableIdentifierContext;
      tableArgList(): TableArgListContext;
      tableArgExpr(): TableArgExprContext;
      databaseIdentifier(): DatabaseIdentifierContext;
      floatingLiteral(): FloatingLiteralContext;
      numberLiteral(): NumberLiteralContext;
      literal(): LiteralContext;
      interval(): IntervalContext;
      keyword(): KeywordContext;
      keywordForAlias(): KeywordForAliasContext;
      alias(): AliasContext;
      identifier(): IdentifierContext;
      identifierOrNull(): IdentifierOrNullContext;
      enumValue(): EnumValueContext;
      sempred(localContext: antlr.RuleContext | null, ruleIndex: number, predIndex: number): boolean;
      private dictionaryAttrDfnt_sempred;
      private dictionaryEngineClause_sempred;
      private engineClause_sempred;
      private joinExpr_sempred;
      private columnExpr_sempred;
      private tableExpr_sempred;
      static readonly _serializedATN: number[];
      private static __ATN;
      static get _ATN(): antlr.ATN;
      private static readonly vocabulary;
      get vocabulary(): antlr.Vocabulary;
      private static readonly decisionsToDFA;
  }
  export class RootContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      queryStmt(): QueryStmtContext[];
      queryStmt(i: number): QueryStmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class QueryStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      query(): QueryContext | null;
      INTO(): antlr.TerminalNode | null;
      OUTFILE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      FORMAT(): antlr.TerminalNode | null;
      identifierOrNull(): IdentifierOrNullContext | null;
      SEMICOLON(): antlr.TerminalNode | null;
      insertStmt(): InsertStmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class QueryContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alterStmt(): AlterStmtContext | null;
      attachStmt(): AttachStmtContext | null;
      checkStmt(): CheckStmtContext | null;
      createStmt(): CreateStmtContext | null;
      describeStmt(): DescribeStmtContext | null;
      dropStmt(): DropStmtContext | null;
      existsStmt(): ExistsStmtContext | null;
      explainStmt(): ExplainStmtContext | null;
      killStmt(): KillStmtContext | null;
      optimizeStmt(): OptimizeStmtContext | null;
      renameStmt(): RenameStmtContext | null;
      selectUnionStmt(): SelectUnionStmtContext | null;
      setStmt(): SetStmtContext | null;
      showStmt(): ShowStmtContext | null;
      systemStmt(): SystemStmtContext | null;
      truncateStmt(): TruncateStmtContext | null;
      useStmt(): UseStmtContext | null;
      watchStmt(): WatchStmtContext | null;
      selectStmt(): SelectStmtContext | null;
      ctes(): CtesContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CtesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode;
      namedQuery(): NamedQueryContext[];
      namedQuery(i: number): NamedQueryContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class NamedQueryContext extends antlr.ParserRuleContext {
      _name?: IdentifierContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      query(): QueryContext;
      RPAREN(): antlr.TerminalNode;
      identifier(): IdentifierContext;
      columnAliases(): ColumnAliasesContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnAliasesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LPAREN(): antlr.TerminalNode;
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AlterStmtContext): void;
  }
  export class AlterTableStmtContext extends AlterStmtContext {
      constructor(ctx: AlterStmtContext);
      ALTER(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      alterTableClause(): AlterTableClauseContext[];
      alterTableClause(i: number): AlterTableClauseContext | null;
      clusterClause(): ClusterClauseContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AlterTableClauseContext): void;
  }
  export class AlterTableClauseReplaceContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      REPLACE(): antlr.TerminalNode;
      partitionClause(): PartitionClauseContext;
      FROM(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseModifyOrderByContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MODIFY(): antlr.TerminalNode;
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseUpdateContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      UPDATE(): antlr.TerminalNode;
      assignmentExprList(): AssignmentExprListContext;
      whereClause(): WhereClauseContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseClearProjectionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      CLEAR(): antlr.TerminalNode;
      PROJECTION(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      partitionClause(): PartitionClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseModifyRemoveContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MODIFY(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      REMOVE(): antlr.TerminalNode;
      tableColumnPropertyType(): TableColumnPropertyTypeContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseDeleteContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      DELETE(): antlr.TerminalNode;
      WHERE(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseCommentContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      COMMENT(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      STRING_LITERAL(): antlr.TerminalNode;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseDropColumnContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      DROP(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseDetachContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      DETACH(): antlr.TerminalNode;
      partitionClause(): PartitionClauseContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseAddIndexContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      ADD(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      tableIndexDfnt(): TableIndexDfntContext;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      nestedIdentifier(): NestedIdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseDropPartitionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      DROP(): antlr.TerminalNode;
      partitionClause(): PartitionClauseContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseMaterializeIndexContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MATERIALIZE(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      partitionClause(): PartitionClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseMaterializeProjectionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MATERIALIZE(): antlr.TerminalNode;
      PROJECTION(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      partitionClause(): PartitionClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseMovePartitionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MOVE(): antlr.TerminalNode;
      partitionClause(): PartitionClauseContext;
      TO(): antlr.TerminalNode | null;
      DISK(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      VOLUME(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      tableIdentifier(): TableIdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseRenameContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      RENAME(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext[];
      nestedIdentifier(i: number): NestedIdentifierContext | null;
      TO(): antlr.TerminalNode;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseFreezePartitionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      FREEZE(): antlr.TerminalNode;
      partitionClause(): PartitionClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseClearColumnContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      CLEAR(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      partitionClause(): PartitionClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseModifyContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MODIFY(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      tableColumnDfnt(): TableColumnDfntContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseClearIndexContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      CLEAR(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      partitionClause(): PartitionClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseRemoveTTLContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      REMOVE(): antlr.TerminalNode;
      TTL(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseModifyCodecContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MODIFY(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      codecExpr(): CodecExprContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseAttachContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      ATTACH(): antlr.TerminalNode;
      partitionClause(): PartitionClauseContext;
      FROM(): antlr.TerminalNode | null;
      tableIdentifier(): TableIdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseDropProjectionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      DROP(): antlr.TerminalNode;
      PROJECTION(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseDropIndexContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      DROP(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseModifyCommentContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MODIFY(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext;
      COMMENT(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseModifyTTLContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      MODIFY(): antlr.TerminalNode;
      ttlClause(): TtlClauseContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseAddProjectionContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      ADD(): antlr.TerminalNode;
      PROJECTION(): antlr.TerminalNode;
      tableProjectionDfnt(): TableProjectionDfntContext;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      nestedIdentifier(): NestedIdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AlterTableClauseAddColumnContext extends AlterTableClauseContext {
      constructor(ctx: AlterTableClauseContext);
      ADD(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      tableColumnDfnt(): TableColumnDfntContext;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      nestedIdentifier(): NestedIdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AssignmentExprListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      assignmentExpr(): AssignmentExprContext[];
      assignmentExpr(i: number): AssignmentExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AssignmentExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nestedIdentifier(): NestedIdentifierContext;
      EQ_SINGLE(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableColumnPropertyTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALIAS(): antlr.TerminalNode | null;
      CODEC(): antlr.TerminalNode | null;
      COMMENT(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      TTL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class PartitionClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext | null;
      ID(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AttachStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AttachStmtContext): void;
  }
  export class AttachDictionaryStmtContext extends AttachStmtContext {
      constructor(ctx: AttachStmtContext);
      ATTACH(): antlr.TerminalNode;
      DICTIONARY(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      clusterClause(): ClusterClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CheckStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHECK(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      partitionClause(): PartitionClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CreateStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: CreateStmtContext): void;
  }
  export class CreateViewStmtContext extends CreateStmtContext {
      constructor(ctx: CreateStmtContext);
      VIEW(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      subqueryClause(): SubqueryClauseContext;
      ATTACH(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      OR(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      uuidClause(): UuidClauseContext | null;
      clusterClause(): ClusterClauseContext | null;
      tableSchemaClause(): TableSchemaClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CreateDictionaryStmtContext extends CreateStmtContext {
      constructor(ctx: CreateStmtContext);
      DICTIONARY(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      dictionarySchemaClause(): DictionarySchemaClauseContext;
      dictionaryEngineClause(): DictionaryEngineClauseContext;
      ATTACH(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      uuidClause(): UuidClauseContext | null;
      clusterClause(): ClusterClauseContext | null;
      OR(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CreateDatabaseStmtContext extends CreateStmtContext {
      constructor(ctx: CreateStmtContext);
      DATABASE(): antlr.TerminalNode;
      databaseIdentifier(): DatabaseIdentifierContext;
      ATTACH(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      clusterClause(): ClusterClauseContext | null;
      engineExpr(): EngineExprContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CreateLiveViewStmtContext extends CreateStmtContext {
      constructor(ctx: CreateStmtContext);
      LIVE(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      subqueryClause(): SubqueryClauseContext;
      ATTACH(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      uuidClause(): UuidClauseContext | null;
      clusterClause(): ClusterClauseContext | null;
      WITH(): antlr.TerminalNode | null;
      TIMEOUT(): antlr.TerminalNode | null;
      destinationClause(): DestinationClauseContext | null;
      tableSchemaClause(): TableSchemaClauseContext | null;
      DECIMAL_LITERAL(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CreateMaterializedViewStmtContext extends CreateStmtContext {
      constructor(ctx: CreateStmtContext);
      MATERIALIZED(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      subqueryClause(): SubqueryClauseContext;
      ATTACH(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      destinationClause(): DestinationClauseContext | null;
      engineClause(): EngineClauseContext | null;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      uuidClause(): UuidClauseContext | null;
      clusterClause(): ClusterClauseContext | null;
      tableSchemaClause(): TableSchemaClauseContext | null;
      POPULATE(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CreateTableStmtContext extends CreateStmtContext {
      constructor(ctx: CreateStmtContext);
      TABLE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      ATTACH(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      uuidClause(): UuidClauseContext | null;
      clusterClause(): ClusterClauseContext | null;
      tableSchemaClause(): TableSchemaClauseContext | null;
      engineClause(): EngineClauseContext | null;
      subqueryClause(): SubqueryClauseContext | null;
      OR(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DictionarySchemaClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LPAREN(): antlr.TerminalNode;
      dictionaryAttrDfnt(): DictionaryAttrDfntContext[];
      dictionaryAttrDfnt(i: number): DictionaryAttrDfntContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DictionaryAttrDfntContext extends antlr.ParserRuleContext {
      attrs: Set<string>;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      columnTypeExpr(): ColumnTypeExprContext;
      DEFAULT(): antlr.TerminalNode[];
      DEFAULT(i: number): antlr.TerminalNode | null;
      literal(): LiteralContext[];
      literal(i: number): LiteralContext | null;
      EXPRESSION(): antlr.TerminalNode[];
      EXPRESSION(i: number): antlr.TerminalNode | null;
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      HIERARCHICAL(): antlr.TerminalNode[];
      HIERARCHICAL(i: number): antlr.TerminalNode | null;
      INJECTIVE(): antlr.TerminalNode[];
      INJECTIVE(i: number): antlr.TerminalNode | null;
      IS_OBJECT_ID(): antlr.TerminalNode[];
      IS_OBJECT_ID(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DictionaryEngineClauseContext extends antlr.ParserRuleContext {
      clauses: Set<string>;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      dictionaryPrimaryKeyClause(): DictionaryPrimaryKeyClauseContext | null;
      sourceClause(): SourceClauseContext[];
      sourceClause(i: number): SourceClauseContext | null;
      lifetimeClause(): LifetimeClauseContext[];
      lifetimeClause(i: number): LifetimeClauseContext | null;
      layoutClause(): LayoutClauseContext[];
      layoutClause(i: number): LayoutClauseContext | null;
      rangeClause(): RangeClauseContext[];
      rangeClause(i: number): RangeClauseContext | null;
      dictionarySettingsClause(): DictionarySettingsClauseContext[];
      dictionarySettingsClause(i: number): DictionarySettingsClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DictionaryPrimaryKeyClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PRIMARY(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DictionaryArgExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      literal(): LiteralContext | null;
      LPAREN(): antlr.TerminalNode | null;
      RPAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SourceClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SOURCE(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode[];
      LPAREN(i: number): antlr.TerminalNode | null;
      identifier(): IdentifierContext;
      RPAREN(): antlr.TerminalNode[];
      RPAREN(i: number): antlr.TerminalNode | null;
      dictionaryArgExpr(): DictionaryArgExprContext[];
      dictionaryArgExpr(i: number): DictionaryArgExprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class LifetimeClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIFETIME(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      RPAREN(): antlr.TerminalNode;
      DECIMAL_LITERAL(): antlr.TerminalNode[];
      DECIMAL_LITERAL(i: number): antlr.TerminalNode | null;
      MIN(): antlr.TerminalNode | null;
      MAX(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class LayoutClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LAYOUT(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode[];
      LPAREN(i: number): antlr.TerminalNode | null;
      identifier(): IdentifierContext;
      RPAREN(): antlr.TerminalNode[];
      RPAREN(i: number): antlr.TerminalNode | null;
      dictionaryArgExpr(): DictionaryArgExprContext[];
      dictionaryArgExpr(i: number): DictionaryArgExprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class RangeClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RANGE(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      RPAREN(): antlr.TerminalNode;
      MIN(): antlr.TerminalNode | null;
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      MAX(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DictionarySettingsClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SETTINGS(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      settingExprList(): SettingExprListContext;
      RPAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ClusterClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode;
      CLUSTER(): antlr.TerminalNode;
      identifier(): IdentifierContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class UuidClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UUID(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DestinationClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TO(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SubqueryClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode;
      selectUnionStmt(): SelectUnionStmtContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableSchemaClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableSchemaClauseContext): void;
  }
  export class SchemaAsTableClauseContext extends TableSchemaClauseContext {
      constructor(ctx: TableSchemaClauseContext);
      AS(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SchemaAsFunctionClauseContext extends TableSchemaClauseContext {
      constructor(ctx: TableSchemaClauseContext);
      AS(): antlr.TerminalNode;
      tableFunctionExpr(): TableFunctionExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SchemaDescriptionClauseContext extends TableSchemaClauseContext {
      constructor(ctx: TableSchemaClauseContext);
      LPAREN(): antlr.TerminalNode;
      tableElementExpr(): TableElementExprContext[];
      tableElementExpr(i: number): TableElementExprContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class EngineClauseContext extends antlr.ParserRuleContext {
      clauses: Set<string>;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      engineExpr(): EngineExprContext;
      orderByClause(): OrderByClauseContext[];
      orderByClause(i: number): OrderByClauseContext | null;
      partitionByClause(): PartitionByClauseContext[];
      partitionByClause(i: number): PartitionByClauseContext | null;
      primaryKeyClause(): PrimaryKeyClauseContext[];
      primaryKeyClause(i: number): PrimaryKeyClauseContext | null;
      sampleByClause(): SampleByClauseContext[];
      sampleByClause(i: number): SampleByClauseContext | null;
      ttlClause(): TtlClauseContext[];
      ttlClause(i: number): TtlClauseContext | null;
      settingsClause(): SettingsClauseContext[];
      settingsClause(i: number): SettingsClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class PartitionByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class PrimaryKeyClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PRIMARY(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SampleByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SAMPLE(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TtlClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TTL(): antlr.TerminalNode;
      ttlExpr(): TtlExprContext[];
      ttlExpr(i: number): TtlExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class EngineExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ENGINE(): antlr.TerminalNode;
      identifierOrNull(): IdentifierOrNullContext;
      EQ_SINGLE(): antlr.TerminalNode | null;
      LPAREN(): antlr.TerminalNode | null;
      RPAREN(): antlr.TerminalNode | null;
      columnExprList(): ColumnExprListContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableElementExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableElementExprContext): void;
  }
  export class TableElementExprProjectionContext extends TableElementExprContext {
      constructor(ctx: TableElementExprContext);
      PROJECTION(): antlr.TerminalNode;
      tableProjectionDfnt(): TableProjectionDfntContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableElementExprConstraintContext extends TableElementExprContext {
      constructor(ctx: TableElementExprContext);
      CONSTRAINT(): antlr.TerminalNode;
      identifier(): IdentifierContext;
      CHECK(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableElementExprColumnContext extends TableElementExprContext {
      constructor(ctx: TableElementExprContext);
      tableColumnDfnt(): TableColumnDfntContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableElementExprIndexContext extends TableElementExprContext {
      constructor(ctx: TableElementExprContext);
      INDEX(): antlr.TerminalNode;
      tableIndexDfnt(): TableIndexDfntContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableColumnDfntContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nestedIdentifier(): NestedIdentifierContext;
      columnTypeExpr(): ColumnTypeExprContext | null;
      tableColumnPropertyExpr(): TableColumnPropertyExprContext | null;
      COMMENT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      codecExpr(): CodecExprContext | null;
      TTL(): antlr.TerminalNode | null;
      columnExpr(): ColumnExprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableColumnPropertyExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnExpr(): ColumnExprContext;
      DEFAULT(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      ALIAS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableIndexDfntContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nestedIdentifier(): NestedIdentifierContext;
      columnExpr(): ColumnExprContext;
      TYPE(): antlr.TerminalNode;
      columnTypeExpr(): ColumnTypeExprContext;
      GRANULARITY(): antlr.TerminalNode;
      DECIMAL_LITERAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableProjectionDfntContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nestedIdentifier(): NestedIdentifierContext;
      projectionSelectStmt(): ProjectionSelectStmtContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CodecExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CODEC(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      codecArgExpr(): CodecArgExprContext[];
      codecArgExpr(i: number): CodecArgExprContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class CodecArgExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      LPAREN(): antlr.TerminalNode | null;
      RPAREN(): antlr.TerminalNode | null;
      columnExprList(): ColumnExprListContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TtlExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnExpr(): ColumnExprContext;
      DELETE(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      DISK(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      VOLUME(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DescribeStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableExpr(): TableExprContext;
      DESCRIBE(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DropStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: DropStmtContext): void;
  }
  export class DropDatabaseStmtContext extends DropStmtContext {
      constructor(ctx: DropStmtContext);
      DATABASE(): antlr.TerminalNode;
      databaseIdentifier(): DatabaseIdentifierContext;
      DETACH(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      clusterClause(): ClusterClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DropTableStmtContext extends DropStmtContext {
      constructor(ctx: DropStmtContext);
      tableIdentifier(): TableIdentifierContext;
      DETACH(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      clusterClause(): ClusterClauseContext | null;
      NO(): antlr.TerminalNode | null;
      DELAY(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ExistsStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ExistsStmtContext): void;
  }
  export class ExistsTableStmtContext extends ExistsStmtContext {
      constructor(ctx: ExistsStmtContext);
      EXISTS(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      DICTIONARY(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ExistsDatabaseStmtContext extends ExistsStmtContext {
      constructor(ctx: ExistsStmtContext);
      EXISTS(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode;
      databaseIdentifier(): DatabaseIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ExplainStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ExplainStmtContext): void;
  }
  export class ExplainSyntaxStmtContext extends ExplainStmtContext {
      constructor(ctx: ExplainStmtContext);
      EXPLAIN(): antlr.TerminalNode;
      SYNTAX(): antlr.TerminalNode;
      query(): QueryContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ExplainASTStmtContext extends ExplainStmtContext {
      constructor(ctx: ExplainStmtContext);
      EXPLAIN(): antlr.TerminalNode;
      AST(): antlr.TerminalNode;
      query(): QueryContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class InsertStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INSERT(): antlr.TerminalNode;
      INTO(): antlr.TerminalNode;
      dataClause(): DataClauseContext;
      tableIdentifier(): TableIdentifierContext | null;
      FUNCTION(): antlr.TerminalNode | null;
      tableFunctionExpr(): TableFunctionExprContext | null;
      TABLE(): antlr.TerminalNode | null;
      columnsClause(): ColumnsClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnsClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LPAREN(): antlr.TerminalNode;
      nestedIdentifier(): NestedIdentifierContext[];
      nestedIdentifier(i: number): NestedIdentifierContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DataClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: DataClauseContext): void;
  }
  export class DataClauseValuesContext extends DataClauseContext {
      constructor(ctx: DataClauseContext);
      VALUES(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DataClauseFormatContext extends DataClauseContext {
      constructor(ctx: DataClauseContext);
      FORMAT(): antlr.TerminalNode;
      identifier(): IdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DataClauseSelectContext extends DataClauseContext {
      constructor(ctx: DataClauseContext);
      selectUnionStmt(): SelectUnionStmtContext;
      EOF(): antlr.TerminalNode;
      SEMICOLON(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class KillStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: KillStmtContext): void;
  }
  export class KillMutationStmtContext extends KillStmtContext {
      constructor(ctx: KillStmtContext);
      KILL(): antlr.TerminalNode;
      MUTATION(): antlr.TerminalNode;
      whereClause(): WhereClauseContext;
      clusterClause(): ClusterClauseContext | null;
      SYNC(): antlr.TerminalNode | null;
      ASYNC(): antlr.TerminalNode | null;
      TEST(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class OptimizeStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPTIMIZE(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      clusterClause(): ClusterClauseContext | null;
      partitionClause(): PartitionClauseContext | null;
      FINAL(): antlr.TerminalNode | null;
      DEDUPLICATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class RenameStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RENAME(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext[];
      tableIdentifier(i: number): TableIdentifierContext | null;
      TO(): antlr.TerminalNode[];
      TO(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      clusterClause(): ClusterClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ProjectionSelectStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LPAREN(): antlr.TerminalNode;
      SELECT(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      RPAREN(): antlr.TerminalNode;
      withClause(): WithClauseContext | null;
      groupByClause(): GroupByClauseContext | null;
      projectionOrderByClause(): ProjectionOrderByClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SelectUnionStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectStmtWithParens(): SelectStmtWithParensContext[];
      selectStmtWithParens(i: number): SelectStmtWithParensContext | null;
      UNION(): antlr.TerminalNode[];
      UNION(i: number): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode[];
      ALL(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SelectStmtWithParensContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectStmt(): SelectStmtContext | null;
      LPAREN(): antlr.TerminalNode | null;
      selectUnionStmt(): SelectUnionStmtContext | null;
      RPAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SelectStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SELECT(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      withClause(): WithClauseContext | null;
      DISTINCT(): antlr.TerminalNode | null;
      topClause(): TopClauseContext | null;
      fromClause(): FromClauseContext | null;
      arrayJoinClause(): ArrayJoinClauseContext | null;
      windowClause(): WindowClauseContext | null;
      prewhereClause(): PrewhereClauseContext | null;
      whereClause(): WhereClauseContext | null;
      groupByClause(): GroupByClauseContext | null;
      WITH(): antlr.TerminalNode[];
      WITH(i: number): antlr.TerminalNode | null;
      TOTALS(): antlr.TerminalNode | null;
      havingClause(): HavingClauseContext | null;
      orderByClause(): OrderByClauseContext | null;
      limitByClause(): LimitByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      settingsClause(): SettingsClauseContext | null;
      CUBE(): antlr.TerminalNode | null;
      ROLLUP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WithClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TopClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TOP(): antlr.TerminalNode;
      DECIMAL_LITERAL(): antlr.TerminalNode;
      WITH(): antlr.TerminalNode | null;
      TIES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class FromClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode;
      joinExpr(): JoinExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ArrayJoinClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ARRAY(): antlr.TerminalNode;
      JOIN(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      LEFT(): antlr.TerminalNode | null;
      INNER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WindowClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WINDOW(): antlr.TerminalNode;
      identifier(): IdentifierContext;
      AS(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      windowExpr(): WindowExprContext;
      RPAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class PrewhereClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PREWHERE(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WhereClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHERE(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class GroupByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GROUP(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode | null;
      columnExprList(): ColumnExprListContext | null;
      RPAREN(): antlr.TerminalNode | null;
      CUBE(): antlr.TerminalNode | null;
      ROLLUP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class HavingClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HAVING(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class OrderByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      orderExprList(): OrderExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ProjectionOrderByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class LimitByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIMIT(): antlr.TerminalNode;
      limitExpr(): LimitExprContext;
      BY(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class LimitClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIMIT(): antlr.TerminalNode;
      limitExpr(): LimitExprContext;
      WITH(): antlr.TerminalNode | null;
      TIES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SettingsClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SETTINGS(): antlr.TerminalNode;
      settingExprList(): SettingExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: JoinExprContext): void;
  }
  export class JoinExprOpContext extends JoinExprContext {
      constructor(ctx: JoinExprContext);
      joinExpr(): JoinExprContext[];
      joinExpr(i: number): JoinExprContext | null;
      JOIN(): antlr.TerminalNode;
      joinConstraintClause(): JoinConstraintClauseContext;
      joinOp(): JoinOpContext | null;
      GLOBAL(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinExprTableContext extends JoinExprContext {
      constructor(ctx: JoinExprContext);
      tableExpr(): TableExprContext;
      FINAL(): antlr.TerminalNode | null;
      sampleClause(): SampleClauseContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinExprParensContext extends JoinExprContext {
      constructor(ctx: JoinExprContext);
      LPAREN(): antlr.TerminalNode;
      joinExpr(): JoinExprContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinExprCrossOpContext extends JoinExprContext {
      constructor(ctx: JoinExprContext);
      joinExpr(): JoinExprContext[];
      joinExpr(i: number): JoinExprContext | null;
      joinOpCross(): JoinOpCrossContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinOpContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: JoinOpContext): void;
  }
  export class JoinOpFullContext extends JoinOpContext {
      constructor(ctx: JoinOpContext);
      FULL(): antlr.TerminalNode | null;
      OUTER(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinOpInnerContext extends JoinOpContext {
      constructor(ctx: JoinOpContext);
      INNER(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      ASOF(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinOpLeftRightContext extends JoinOpContext {
      constructor(ctx: JoinOpContext);
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      OUTER(): antlr.TerminalNode | null;
      SEMI(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      ANTI(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      ASOF(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinOpCrossContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CROSS(): antlr.TerminalNode | null;
      JOIN(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class JoinConstraintClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode | null;
      columnExprList(): ColumnExprListContext;
      USING(): antlr.TerminalNode | null;
      LPAREN(): antlr.TerminalNode | null;
      RPAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SampleClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SAMPLE(): antlr.TerminalNode;
      ratioExpr(): RatioExprContext[];
      ratioExpr(i: number): RatioExprContext | null;
      OFFSET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class LimitExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      COMMA(): antlr.TerminalNode | null;
      OFFSET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class OrderExprListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      orderExpr(): OrderExprContext[];
      orderExpr(i: number): OrderExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class OrderExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnExpr(): ColumnExprContext;
      NULLS(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      ASCENDING(): antlr.TerminalNode | null;
      DESCENDING(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      LAST(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class RatioExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      numberLiteral(): NumberLiteralContext[];
      numberLiteral(i: number): NumberLiteralContext | null;
      SLASH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SettingExprListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      settingExpr(): SettingExprContext[];
      settingExpr(i: number): SettingExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SettingExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      EQ_SINGLE(): antlr.TerminalNode;
      literal(): LiteralContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WindowExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      winPartitionByClause(): WinPartitionByClauseContext | null;
      winOrderByClause(): WinOrderByClauseContext | null;
      winFrameClause(): WinFrameClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WinPartitionByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WinOrderByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      orderExprList(): OrderExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WinFrameClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      winFrameExtend(): WinFrameExtendContext;
      ROWS(): antlr.TerminalNode | null;
      RANGE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WinFrameExtendContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: WinFrameExtendContext): void;
  }
  export class FrameStartContext extends WinFrameExtendContext {
      constructor(ctx: WinFrameExtendContext);
      winFrameBound(): WinFrameBoundContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class FrameBetweenContext extends WinFrameExtendContext {
      constructor(ctx: WinFrameExtendContext);
      BETWEEN(): antlr.TerminalNode;
      winFrameBound(): WinFrameBoundContext[];
      winFrameBound(i: number): WinFrameBoundContext | null;
      AND(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WinFrameBoundContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CURRENT(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      UNBOUNDED(): antlr.TerminalNode | null;
      PRECEDING(): antlr.TerminalNode | null;
      FOLLOWING(): antlr.TerminalNode | null;
      numberLiteral(): NumberLiteralContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SetStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      settingExprList(): SettingExprListContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ShowStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ShowStmtContext): void;
  }
  export class ShowCreateDatabaseStmtContext extends ShowStmtContext {
      constructor(ctx: ShowStmtContext);
      SHOW(): antlr.TerminalNode;
      CREATE(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode;
      databaseIdentifier(): DatabaseIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ShowDatabasesStmtContext extends ShowStmtContext {
      constructor(ctx: ShowStmtContext);
      SHOW(): antlr.TerminalNode;
      DATABASES(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ShowCreateTableStmtContext extends ShowStmtContext {
      constructor(ctx: ShowStmtContext);
      SHOW(): antlr.TerminalNode;
      CREATE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      TEMPORARY(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ShowTablesStmtContext extends ShowStmtContext {
      constructor(ctx: ShowStmtContext);
      SHOW(): antlr.TerminalNode;
      TABLES(): antlr.TerminalNode;
      TEMPORARY(): antlr.TerminalNode | null;
      databaseIdentifier(): DatabaseIdentifierContext | null;
      LIKE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      whereClause(): WhereClauseContext | null;
      limitClause(): LimitClauseContext | null;
      FROM(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ShowDictionariesStmtContext extends ShowStmtContext {
      constructor(ctx: ShowStmtContext);
      SHOW(): antlr.TerminalNode;
      DICTIONARIES(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode | null;
      databaseIdentifier(): DatabaseIdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ShowCreateDictionaryStmtContext extends ShowStmtContext {
      constructor(ctx: ShowStmtContext);
      SHOW(): antlr.TerminalNode;
      CREATE(): antlr.TerminalNode;
      DICTIONARY(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class SystemStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SYSTEM(): antlr.TerminalNode;
      FLUSH(): antlr.TerminalNode | null;
      DISTRIBUTED(): antlr.TerminalNode | null;
      tableIdentifier(): TableIdentifierContext | null;
      LOGS(): antlr.TerminalNode | null;
      RELOAD(): antlr.TerminalNode | null;
      DICTIONARIES(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      START(): antlr.TerminalNode | null;
      STOP(): antlr.TerminalNode | null;
      SENDS(): antlr.TerminalNode | null;
      FETCHES(): antlr.TerminalNode | null;
      MERGES(): antlr.TerminalNode | null;
      TTL(): antlr.TerminalNode | null;
      REPLICATED(): antlr.TerminalNode | null;
      SYNC(): antlr.TerminalNode | null;
      REPLICA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TruncateStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRUNCATE(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      TEMPORARY(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      clusterClause(): ClusterClauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class UseStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USE(): antlr.TerminalNode;
      databaseIdentifier(): DatabaseIdentifierContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class WatchStmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WATCH(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext;
      EVENTS(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      DECIMAL_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnTypeExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ColumnTypeExprContext): void;
  }
  export class ColumnTypeExprNestedContext extends ColumnTypeExprContext {
      constructor(ctx: ColumnTypeExprContext);
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      LPAREN(): antlr.TerminalNode;
      columnTypeExpr(): ColumnTypeExprContext[];
      columnTypeExpr(i: number): ColumnTypeExprContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnTypeExprParamContext extends ColumnTypeExprContext {
      constructor(ctx: ColumnTypeExprContext);
      identifier(): IdentifierContext;
      LPAREN(): antlr.TerminalNode;
      RPAREN(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnTypeExprSimpleContext extends ColumnTypeExprContext {
      constructor(ctx: ColumnTypeExprContext);
      identifier(): IdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnTypeExprComplexContext extends ColumnTypeExprContext {
      constructor(ctx: ColumnTypeExprContext);
      identifier(): IdentifierContext;
      LPAREN(): antlr.TerminalNode;
      columnTypeExpr(): ColumnTypeExprContext[];
      columnTypeExpr(i: number): ColumnTypeExprContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnTypeExprEnumContext extends ColumnTypeExprContext {
      constructor(ctx: ColumnTypeExprContext);
      identifier(): IdentifierContext;
      LPAREN(): antlr.TerminalNode;
      enumValue(): EnumValueContext[];
      enumValue(i: number): EnumValueContext | null;
      RPAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnsExpr(): ColumnsExprContext[];
      columnsExpr(i: number): ColumnsExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnsExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ColumnsExprContext): void;
  }
  export class ColumnsExprColumnContext extends ColumnsExprContext {
      constructor(ctx: ColumnsExprContext);
      columnExpr(): ColumnExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnsExprAsteriskContext extends ColumnsExprContext {
      constructor(ctx: ColumnsExprContext);
      ASTERISK(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext | null;
      DOT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnsExprSubqueryContext extends ColumnsExprContext {
      constructor(ctx: ColumnsExprContext);
      LPAREN(): antlr.TerminalNode;
      selectUnionStmt(): SelectUnionStmtContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ColumnExprContext): void;
  }
  export class ColumnExprTernaryOpContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      QUERY(): antlr.TerminalNode;
      COLON(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprAliasContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext;
      alias(): AliasContext | null;
      AS(): antlr.TerminalNode | null;
      identifier(): IdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprExtractContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      EXTRACT(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      interval(): IntervalContext;
      FROM(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprNegateContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      DASH(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprSubqueryContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      LPAREN(): antlr.TerminalNode;
      selectUnionStmt(): SelectUnionStmtContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprLiteralContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      literal(): LiteralContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprArrayContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      LBRACKET(): antlr.TerminalNode;
      RBRACKET(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprSubstringContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      SUBSTRING(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      FROM(): antlr.TerminalNode;
      RPAREN(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprCastContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      CAST(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      AS(): antlr.TerminalNode;
      columnTypeExpr(): ColumnTypeExprContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprOrContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      OR(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprPrecedence1Context extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      ASTERISK(): antlr.TerminalNode | null;
      SLASH(): antlr.TerminalNode | null;
      PERCENT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprPrecedence2Context extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      PLUS(): antlr.TerminalNode | null;
      DASH(): antlr.TerminalNode | null;
      CONCAT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprPrecedence3Context extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      EQ_DOUBLE(): antlr.TerminalNode | null;
      EQ_SINGLE(): antlr.TerminalNode | null;
      NOT_EQ(): antlr.TerminalNode | null;
      LE(): antlr.TerminalNode | null;
      GE(): antlr.TerminalNode | null;
      LT(): antlr.TerminalNode | null;
      GT(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      LIKE(): antlr.TerminalNode | null;
      ILIKE(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprIntervalContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      INTERVAL(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      interval(): IntervalContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprIsNullContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext;
      IS(): antlr.TerminalNode;
      NULL_SQL(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprWinFunctionTargetContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      OVER(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode | null;
      RPAREN(): antlr.TerminalNode | null;
      columnExprList(): ColumnExprListContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprTrimContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      TRIM(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      RPAREN(): antlr.TerminalNode;
      BOTH(): antlr.TerminalNode | null;
      LEADING(): antlr.TerminalNode | null;
      TRAILING(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprTupleContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      LPAREN(): antlr.TerminalNode;
      columnExprList(): ColumnExprListContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprArrayAccessContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      LBRACKET(): antlr.TerminalNode;
      RBRACKET(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprBetweenContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      BETWEEN(): antlr.TerminalNode;
      AND(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprParensContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      LPAREN(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprTimestampContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      TIMESTAMP(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprAndContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      AND(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprTupleAccessContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnExpr(): ColumnExprContext;
      DOT(): antlr.TerminalNode;
      DECIMAL_LITERAL(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprCaseContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      CASE(): antlr.TerminalNode;
      END(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext[];
      columnExpr(i: number): ColumnExprContext | null;
      WHEN(): antlr.TerminalNode[];
      WHEN(i: number): antlr.TerminalNode | null;
      THEN(): antlr.TerminalNode[];
      THEN(i: number): antlr.TerminalNode | null;
      ELSE(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprDateContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      DATE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprNotContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      NOT(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprWinFunctionContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      identifier(): IdentifierContext;
      OVER(): antlr.TerminalNode;
      LPAREN(): antlr.TerminalNode[];
      LPAREN(i: number): antlr.TerminalNode | null;
      windowExpr(): WindowExprContext;
      RPAREN(): antlr.TerminalNode[];
      RPAREN(i: number): antlr.TerminalNode | null;
      columnExprList(): ColumnExprListContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprIdentifierContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      columnIdentifier(): ColumnIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprFunctionContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      identifier(): IdentifierContext;
      LPAREN(): antlr.TerminalNode[];
      LPAREN(i: number): antlr.TerminalNode | null;
      RPAREN(): antlr.TerminalNode[];
      RPAREN(i: number): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      columnArgList(): ColumnArgListContext | null;
      columnExprList(): ColumnExprListContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnExprAsteriskContext extends ColumnExprContext {
      constructor(ctx: ColumnExprContext);
      ASTERISK(): antlr.TerminalNode;
      tableIdentifier(): TableIdentifierContext | null;
      DOT(): antlr.TerminalNode | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnArgListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnArgExpr(): ColumnArgExprContext[];
      columnArgExpr(i: number): ColumnArgExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnArgExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnLambdaExpr(): ColumnLambdaExprContext | null;
      columnExpr(): ColumnExprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnLambdaExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ARROW(): antlr.TerminalNode;
      columnExpr(): ColumnExprContext;
      LPAREN(): antlr.TerminalNode | null;
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      RPAREN(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class ColumnIdentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nestedIdentifier(): NestedIdentifierContext;
      tableIdentifier(): TableIdentifierContext | null;
      DOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class NestedIdentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext[];
      identifier(i: number): IdentifierContext | null;
      DOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableExprContext): void;
  }
  export class TableExprIdentifierContext extends TableExprContext {
      constructor(ctx: TableExprContext);
      tableIdentifier(): TableIdentifierContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableExprSubqueryContext extends TableExprContext {
      constructor(ctx: TableExprContext);
      LPAREN(): antlr.TerminalNode;
      selectUnionStmt(): SelectUnionStmtContext;
      RPAREN(): antlr.TerminalNode;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableExprAliasContext extends TableExprContext {
      constructor(ctx: TableExprContext);
      tableExpr(): TableExprContext;
      alias(): AliasContext | null;
      AS(): antlr.TerminalNode | null;
      identifier(): IdentifierContext | null;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableExprFunctionContext extends TableExprContext {
      constructor(ctx: TableExprContext);
      tableFunctionExpr(): TableFunctionExprContext;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableFunctionExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      LPAREN(): antlr.TerminalNode;
      RPAREN(): antlr.TerminalNode;
      tableArgList(): TableArgListContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableIdentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      databaseIdentifier(): DatabaseIdentifierContext | null;
      DOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableArgListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableArgExpr(): TableArgExprContext[];
      tableArgExpr(i: number): TableArgExprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class TableArgExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nestedIdentifier(): NestedIdentifierContext | null;
      tableFunctionExpr(): TableFunctionExprContext | null;
      literal(): LiteralContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class DatabaseIdentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class FloatingLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FLOATING_LITERAL(): antlr.TerminalNode | null;
      DOT(): antlr.TerminalNode | null;
      DECIMAL_LITERAL(): antlr.TerminalNode[];
      DECIMAL_LITERAL(i: number): antlr.TerminalNode | null;
      OCTAL_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class NumberLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      floatingLiteral(): FloatingLiteralContext | null;
      OCTAL_LITERAL(): antlr.TerminalNode | null;
      DECIMAL_LITERAL(): antlr.TerminalNode | null;
      HEXADECIMAL_LITERAL(): antlr.TerminalNode | null;
      INF(): antlr.TerminalNode | null;
      NAN_SQL(): antlr.TerminalNode | null;
      PLUS(): antlr.TerminalNode | null;
      DASH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class LiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      numberLiteral(): NumberLiteralContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      NULL_SQL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class IntervalContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SECOND(): antlr.TerminalNode | null;
      MINUTE(): antlr.TerminalNode | null;
      HOUR(): antlr.TerminalNode | null;
      DAY(): antlr.TerminalNode | null;
      WEEK(): antlr.TerminalNode | null;
      MONTH(): antlr.TerminalNode | null;
      QUARTER(): antlr.TerminalNode | null;
      YEAR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class KeywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AFTER(): antlr.TerminalNode | null;
      ALIAS(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      ALTER(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      ANTI(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      ARRAY(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      ASCENDING(): antlr.TerminalNode | null;
      ASOF(): antlr.TerminalNode | null;
      AST(): antlr.TerminalNode | null;
      ASYNC(): antlr.TerminalNode | null;
      ATTACH(): antlr.TerminalNode | null;
      BETWEEN(): antlr.TerminalNode | null;
      BOTH(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      CASE(): antlr.TerminalNode | null;
      CAST(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      CLEAR(): antlr.TerminalNode | null;
      CLUSTER(): antlr.TerminalNode | null;
      CODEC(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      COLUMN(): antlr.TerminalNode | null;
      COMMENT(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      CROSS(): antlr.TerminalNode | null;
      CUBE(): antlr.TerminalNode | null;
      CURRENT(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      DATABASES(): antlr.TerminalNode | null;
      DATE(): antlr.TerminalNode | null;
      DEDUPLICATE(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      DELAY(): antlr.TerminalNode | null;
      DELETE(): antlr.TerminalNode | null;
      DESCRIBE(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      DESCENDING(): antlr.TerminalNode | null;
      DETACH(): antlr.TerminalNode | null;
      DICTIONARIES(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      DISK(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      DISTRIBUTED(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      ELSE(): antlr.TerminalNode | null;
      END(): antlr.TerminalNode | null;
      ENGINE(): antlr.TerminalNode | null;
      EVENTS(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      EXPLAIN(): antlr.TerminalNode | null;
      EXPRESSION(): antlr.TerminalNode | null;
      EXTRACT(): antlr.TerminalNode | null;
      FETCHES(): antlr.TerminalNode | null;
      FINAL(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      FLUSH(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      FOLLOWING(): antlr.TerminalNode | null;
      FORMAT(): antlr.TerminalNode | null;
      FREEZE(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      GRANULARITY(): antlr.TerminalNode | null;
      GROUP(): antlr.TerminalNode | null;
      HAVING(): antlr.TerminalNode | null;
      HIERARCHICAL(): antlr.TerminalNode | null;
      ID(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      ILIKE(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      INJECTIVE(): antlr.TerminalNode | null;
      INNER(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      INTERVAL(): antlr.TerminalNode | null;
      INTO(): antlr.TerminalNode | null;
      IS(): antlr.TerminalNode | null;
      IS_OBJECT_ID(): antlr.TerminalNode | null;
      JOIN(): antlr.TerminalNode | null;
      JSON_FALSE(): antlr.TerminalNode | null;
      JSON_TRUE(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      KILL(): antlr.TerminalNode | null;
      LAST(): antlr.TerminalNode | null;
      LAYOUT(): antlr.TerminalNode | null;
      LEADING(): antlr.TerminalNode | null;
      LEFT(): antlr.TerminalNode | null;
      LIFETIME(): antlr.TerminalNode | null;
      LIKE(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      LIVE(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      LOGS(): antlr.TerminalNode | null;
      MATERIALIZE(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      MAX(): antlr.TerminalNode | null;
      MERGES(): antlr.TerminalNode | null;
      MIN(): antlr.TerminalNode | null;
      MODIFY(): antlr.TerminalNode | null;
      MOVE(): antlr.TerminalNode | null;
      MUTATION(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      NULLS(): antlr.TerminalNode | null;
      OFFSET(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      OPTIMIZE(): antlr.TerminalNode | null;
      OR(): antlr.TerminalNode | null;
      ORDER(): antlr.TerminalNode | null;
      OUTER(): antlr.TerminalNode | null;
      OUTFILE(): antlr.TerminalNode | null;
      OVER(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      POPULATE(): antlr.TerminalNode | null;
      PRECEDING(): antlr.TerminalNode | null;
      PREWHERE(): antlr.TerminalNode | null;
      PRIMARY(): antlr.TerminalNode | null;
      RANGE(): antlr.TerminalNode | null;
      RELOAD(): antlr.TerminalNode | null;
      REMOVE(): antlr.TerminalNode | null;
      RENAME(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      REPLICA(): antlr.TerminalNode | null;
      REPLICATED(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      ROLLUP(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode | null;
      SAMPLE(): antlr.TerminalNode | null;
      SELECT(): antlr.TerminalNode | null;
      SEMI(): antlr.TerminalNode | null;
      SENDS(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      SETTINGS(): antlr.TerminalNode | null;
      SHOW(): antlr.TerminalNode | null;
      SOURCE(): antlr.TerminalNode | null;
      START(): antlr.TerminalNode | null;
      STOP(): antlr.TerminalNode | null;
      SUBSTRING(): antlr.TerminalNode | null;
      SYNC(): antlr.TerminalNode | null;
      SYNTAX(): antlr.TerminalNode | null;
      SYSTEM(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      TEST(): antlr.TerminalNode | null;
      THEN(): antlr.TerminalNode | null;
      TIES(): antlr.TerminalNode | null;
      TIMEOUT(): antlr.TerminalNode | null;
      TIMESTAMP(): antlr.TerminalNode | null;
      TOTALS(): antlr.TerminalNode | null;
      TRAILING(): antlr.TerminalNode | null;
      TRIM(): antlr.TerminalNode | null;
      TRUNCATE(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      TOP(): antlr.TerminalNode | null;
      TTL(): antlr.TerminalNode | null;
      TYPE(): antlr.TerminalNode | null;
      UNBOUNDED(): antlr.TerminalNode | null;
      UNION(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      USE(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      UUID(): antlr.TerminalNode | null;
      VALUES(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      VOLUME(): antlr.TerminalNode | null;
      WATCH(): antlr.TerminalNode | null;
      WHEN(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      WINDOW(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class KeywordForAliasContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DATE(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      ID(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class AliasContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IDENTIFIER(): antlr.TerminalNode | null;
      keywordForAlias(): KeywordForAliasContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class IdentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IDENTIFIER(): antlr.TerminalNode | null;
      interval(): IntervalContext | null;
      keyword(): KeywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class IdentifierOrNullContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      NULL_SQL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }
  export class EnumValueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STRING_LITERAL(): antlr.TerminalNode;
      EQ_SINGLE(): antlr.TerminalNode;
      numberLiteral(): NumberLiteralContext;
      get ruleIndex(): number;
      accept<Result>(visitor: ClickHouseParserVisitor<Result>): Result | null;
  }

}
declare module 'websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParserVisitor' {
  import { AbstractParseTreeVisitor } from "antlr4ng";
  import { RootContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { QueryStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { QueryContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CtesContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { NamedQueryContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnAliasesContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseAddColumnContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseAddIndexContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseAddProjectionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseAttachContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseClearColumnContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseClearIndexContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseClearProjectionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseCommentContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseDeleteContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseDetachContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseDropColumnContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseDropIndexContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseDropProjectionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseDropPartitionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseFreezePartitionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseMaterializeIndexContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseMaterializeProjectionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseModifyCodecContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseModifyCommentContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseModifyRemoveContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseModifyContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseModifyOrderByContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseModifyTTLContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseMovePartitionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseRemoveTTLContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseRenameContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseReplaceContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AlterTableClauseUpdateContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AssignmentExprListContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AssignmentExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableColumnPropertyTypeContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { PartitionClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AttachDictionaryStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CheckStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CreateDatabaseStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CreateDictionaryStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CreateLiveViewStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CreateMaterializedViewStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CreateTableStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CreateViewStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DictionarySchemaClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DictionaryAttrDfntContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DictionaryEngineClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DictionaryPrimaryKeyClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DictionaryArgExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SourceClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { LifetimeClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { LayoutClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { RangeClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DictionarySettingsClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ClusterClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { UuidClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DestinationClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SubqueryClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SchemaDescriptionClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SchemaAsTableClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SchemaAsFunctionClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { EngineClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { PartitionByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { PrimaryKeyClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SampleByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TtlClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { EngineExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableElementExprColumnContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableElementExprConstraintContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableElementExprIndexContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableElementExprProjectionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableColumnDfntContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableColumnPropertyExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableIndexDfntContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableProjectionDfntContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CodecExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { CodecArgExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TtlExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DescribeStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DropDatabaseStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DropTableStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ExistsDatabaseStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ExistsTableStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ExplainASTStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ExplainSyntaxStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { InsertStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnsClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DataClauseFormatContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DataClauseValuesContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DataClauseSelectContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { KillMutationStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { OptimizeStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { RenameStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ProjectionSelectStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SelectUnionStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SelectStmtWithParensContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SelectStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WithClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TopClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { FromClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ArrayJoinClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WindowClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { PrewhereClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WhereClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { GroupByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { HavingClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { OrderByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ProjectionOrderByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { LimitByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { LimitClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SettingsClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinExprOpContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinExprTableContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinExprParensContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinExprCrossOpContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinOpInnerContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinOpLeftRightContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinOpFullContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinOpCrossContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { JoinConstraintClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SampleClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { LimitExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { OrderExprListContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { OrderExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { RatioExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SettingExprListContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SettingExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WindowExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WinPartitionByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WinOrderByClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WinFrameClauseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { FrameStartContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { FrameBetweenContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WinFrameBoundContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SetStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ShowCreateDatabaseStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ShowCreateDictionaryStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ShowCreateTableStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ShowDatabasesStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ShowDictionariesStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ShowTablesStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { SystemStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TruncateStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { UseStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { WatchStmtContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnTypeExprSimpleContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnTypeExprNestedContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnTypeExprEnumContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnTypeExprComplexContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnTypeExprParamContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprListContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnsExprAsteriskContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnsExprSubqueryContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnsExprColumnContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprTernaryOpContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprAliasContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprExtractContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprNegateContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprSubqueryContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprLiteralContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprArrayContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprSubstringContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprCastContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprOrContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprPrecedence1Context } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprPrecedence2Context } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprPrecedence3Context } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprIntervalContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprIsNullContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprWinFunctionTargetContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprTrimContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprTupleContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprArrayAccessContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprBetweenContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprParensContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprTimestampContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprAndContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprTupleAccessContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprCaseContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprDateContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprNotContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprWinFunctionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprIdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprFunctionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnExprAsteriskContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnArgListContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnArgExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnLambdaExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { ColumnIdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { NestedIdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableExprIdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableExprSubqueryContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableExprAliasContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableExprFunctionContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableFunctionExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableIdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableArgListContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { TableArgExprContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { DatabaseIdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { FloatingLiteralContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { NumberLiteralContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { LiteralContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { IntervalContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { KeywordContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { KeywordForAliasContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { AliasContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { IdentifierContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { IdentifierOrNullContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  import { EnumValueContext } from "websql-autocomplete-2/parsers/clickhouse/generated/ClickHouseParser.js/index";
  /**
   * This interface defines a complete generic visitor for a parse tree produced
   * by `ClickHouseParser`.
   *
   * @param <Result> The return type of the visit operation. Use `void` for
   * operations with no return type.
   */
  export class ClickHouseParserVisitor<Result> extends AbstractParseTreeVisitor<Result> {
      /**
       * Visit a parse tree produced by `ClickHouseParser.root`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoot?: (ctx: RootContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.queryStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQueryStmt?: (ctx: QueryStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.query`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQuery?: (ctx: QueryContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.ctes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCtes?: (ctx: CtesContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.namedQuery`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNamedQuery?: (ctx: NamedQueryContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnAliases`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnAliases?: (ctx: ColumnAliasesContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableStmt`
       * labeled alternative in `ClickHouseParser.alterStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableStmt?: (ctx: AlterTableStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseAddColumn`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseAddColumn?: (ctx: AlterTableClauseAddColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseAddIndex`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseAddIndex?: (ctx: AlterTableClauseAddIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseAddProjection`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseAddProjection?: (ctx: AlterTableClauseAddProjectionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseAttach`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseAttach?: (ctx: AlterTableClauseAttachContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseClearColumn`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseClearColumn?: (ctx: AlterTableClauseClearColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseClearIndex`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseClearIndex?: (ctx: AlterTableClauseClearIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseClearProjection`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseClearProjection?: (ctx: AlterTableClauseClearProjectionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseComment`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseComment?: (ctx: AlterTableClauseCommentContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseDelete`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseDelete?: (ctx: AlterTableClauseDeleteContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseDetach`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseDetach?: (ctx: AlterTableClauseDetachContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseDropColumn`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseDropColumn?: (ctx: AlterTableClauseDropColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseDropIndex`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseDropIndex?: (ctx: AlterTableClauseDropIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseDropProjection`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseDropProjection?: (ctx: AlterTableClauseDropProjectionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseDropPartition`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseDropPartition?: (ctx: AlterTableClauseDropPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseFreezePartition`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseFreezePartition?: (ctx: AlterTableClauseFreezePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseMaterializeIndex`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseMaterializeIndex?: (ctx: AlterTableClauseMaterializeIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseMaterializeProjection`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseMaterializeProjection?: (ctx: AlterTableClauseMaterializeProjectionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseModifyCodec`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseModifyCodec?: (ctx: AlterTableClauseModifyCodecContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseModifyComment`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseModifyComment?: (ctx: AlterTableClauseModifyCommentContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseModifyRemove`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseModifyRemove?: (ctx: AlterTableClauseModifyRemoveContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseModify`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseModify?: (ctx: AlterTableClauseModifyContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseModifyOrderBy`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseModifyOrderBy?: (ctx: AlterTableClauseModifyOrderByContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseModifyTTL`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseModifyTTL?: (ctx: AlterTableClauseModifyTTLContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseMovePartition`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseMovePartition?: (ctx: AlterTableClauseMovePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseRemoveTTL`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseRemoveTTL?: (ctx: AlterTableClauseRemoveTTLContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseRename`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseRename?: (ctx: AlterTableClauseRenameContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseReplace`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseReplace?: (ctx: AlterTableClauseReplaceContext) => Result;
      /**
       * Visit a parse tree produced by the `AlterTableClauseUpdate`
       * labeled alternative in `ClickHouseParser.alterTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTableClauseUpdate?: (ctx: AlterTableClauseUpdateContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.assignmentExprList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAssignmentExprList?: (ctx: AssignmentExprListContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.assignmentExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAssignmentExpr?: (ctx: AssignmentExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableColumnPropertyType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableColumnPropertyType?: (ctx: TableColumnPropertyTypeContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.partitionClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionClause?: (ctx: PartitionClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `AttachDictionaryStmt`
       * labeled alternative in `ClickHouseParser.attachStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAttachDictionaryStmt?: (ctx: AttachDictionaryStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.checkStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCheckStmt?: (ctx: CheckStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `CreateDatabaseStmt`
       * labeled alternative in `ClickHouseParser.createStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateDatabaseStmt?: (ctx: CreateDatabaseStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `CreateDictionaryStmt`
       * labeled alternative in `ClickHouseParser.createStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateDictionaryStmt?: (ctx: CreateDictionaryStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `CreateLiveViewStmt`
       * labeled alternative in `ClickHouseParser.createStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateLiveViewStmt?: (ctx: CreateLiveViewStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `CreateMaterializedViewStmt`
       * labeled alternative in `ClickHouseParser.createStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateMaterializedViewStmt?: (ctx: CreateMaterializedViewStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `CreateTableStmt`
       * labeled alternative in `ClickHouseParser.createStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateTableStmt?: (ctx: CreateTableStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `CreateViewStmt`
       * labeled alternative in `ClickHouseParser.createStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateViewStmt?: (ctx: CreateViewStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.dictionarySchemaClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDictionarySchemaClause?: (ctx: DictionarySchemaClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.dictionaryAttrDfnt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDictionaryAttrDfnt?: (ctx: DictionaryAttrDfntContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.dictionaryEngineClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDictionaryEngineClause?: (ctx: DictionaryEngineClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.dictionaryPrimaryKeyClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDictionaryPrimaryKeyClause?: (ctx: DictionaryPrimaryKeyClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.dictionaryArgExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDictionaryArgExpr?: (ctx: DictionaryArgExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.sourceClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSourceClause?: (ctx: SourceClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.lifetimeClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLifetimeClause?: (ctx: LifetimeClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.layoutClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLayoutClause?: (ctx: LayoutClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.rangeClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRangeClause?: (ctx: RangeClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.dictionarySettingsClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDictionarySettingsClause?: (ctx: DictionarySettingsClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.clusterClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitClusterClause?: (ctx: ClusterClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.uuidClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUuidClause?: (ctx: UuidClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.destinationClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDestinationClause?: (ctx: DestinationClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.subqueryClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubqueryClause?: (ctx: SubqueryClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `SchemaDescriptionClause`
       * labeled alternative in `ClickHouseParser.tableSchemaClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSchemaDescriptionClause?: (ctx: SchemaDescriptionClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `SchemaAsTableClause`
       * labeled alternative in `ClickHouseParser.tableSchemaClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSchemaAsTableClause?: (ctx: SchemaAsTableClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `SchemaAsFunctionClause`
       * labeled alternative in `ClickHouseParser.tableSchemaClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSchemaAsFunctionClause?: (ctx: SchemaAsFunctionClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.engineClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEngineClause?: (ctx: EngineClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.partitionByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionByClause?: (ctx: PartitionByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.primaryKeyClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrimaryKeyClause?: (ctx: PrimaryKeyClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.sampleByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSampleByClause?: (ctx: SampleByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.ttlClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTtlClause?: (ctx: TtlClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.engineExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEngineExpr?: (ctx: EngineExprContext) => Result;
      /**
       * Visit a parse tree produced by the `TableElementExprColumn`
       * labeled alternative in `ClickHouseParser.tableElementExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableElementExprColumn?: (ctx: TableElementExprColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `TableElementExprConstraint`
       * labeled alternative in `ClickHouseParser.tableElementExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableElementExprConstraint?: (ctx: TableElementExprConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `TableElementExprIndex`
       * labeled alternative in `ClickHouseParser.tableElementExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableElementExprIndex?: (ctx: TableElementExprIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `TableElementExprProjection`
       * labeled alternative in `ClickHouseParser.tableElementExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableElementExprProjection?: (ctx: TableElementExprProjectionContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableColumnDfnt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableColumnDfnt?: (ctx: TableColumnDfntContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableColumnPropertyExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableColumnPropertyExpr?: (ctx: TableColumnPropertyExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableIndexDfnt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableIndexDfnt?: (ctx: TableIndexDfntContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableProjectionDfnt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableProjectionDfnt?: (ctx: TableProjectionDfntContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.codecExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCodecExpr?: (ctx: CodecExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.codecArgExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCodecArgExpr?: (ctx: CodecArgExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.ttlExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTtlExpr?: (ctx: TtlExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.describeStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDescribeStmt?: (ctx: DescribeStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `DropDatabaseStmt`
       * labeled alternative in `ClickHouseParser.dropStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropDatabaseStmt?: (ctx: DropDatabaseStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `DropTableStmt`
       * labeled alternative in `ClickHouseParser.dropStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropTableStmt?: (ctx: DropTableStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `ExistsDatabaseStmt`
       * labeled alternative in `ClickHouseParser.existsStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExistsDatabaseStmt?: (ctx: ExistsDatabaseStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `ExistsTableStmt`
       * labeled alternative in `ClickHouseParser.existsStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExistsTableStmt?: (ctx: ExistsTableStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `ExplainASTStmt`
       * labeled alternative in `ClickHouseParser.explainStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplainASTStmt?: (ctx: ExplainASTStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `ExplainSyntaxStmt`
       * labeled alternative in `ClickHouseParser.explainStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplainSyntaxStmt?: (ctx: ExplainSyntaxStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.insertStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsertStmt?: (ctx: InsertStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnsClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnsClause?: (ctx: ColumnsClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `DataClauseFormat`
       * labeled alternative in `ClickHouseParser.dataClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDataClauseFormat?: (ctx: DataClauseFormatContext) => Result;
      /**
       * Visit a parse tree produced by the `DataClauseValues`
       * labeled alternative in `ClickHouseParser.dataClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDataClauseValues?: (ctx: DataClauseValuesContext) => Result;
      /**
       * Visit a parse tree produced by the `DataClauseSelect`
       * labeled alternative in `ClickHouseParser.dataClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDataClauseSelect?: (ctx: DataClauseSelectContext) => Result;
      /**
       * Visit a parse tree produced by the `KillMutationStmt`
       * labeled alternative in `ClickHouseParser.killStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKillMutationStmt?: (ctx: KillMutationStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.optimizeStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptimizeStmt?: (ctx: OptimizeStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.renameStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRenameStmt?: (ctx: RenameStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.projectionSelectStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProjectionSelectStmt?: (ctx: ProjectionSelectStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.selectUnionStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectUnionStmt?: (ctx: SelectUnionStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.selectStmtWithParens`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectStmtWithParens?: (ctx: SelectStmtWithParensContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.selectStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectStmt?: (ctx: SelectStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.withClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWithClause?: (ctx: WithClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.topClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTopClause?: (ctx: TopClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.fromClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFromClause?: (ctx: FromClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.arrayJoinClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitArrayJoinClause?: (ctx: ArrayJoinClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.windowClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindowClause?: (ctx: WindowClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.prewhereClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrewhereClause?: (ctx: PrewhereClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.whereClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWhereClause?: (ctx: WhereClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.groupByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGroupByClause?: (ctx: GroupByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.havingClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHavingClause?: (ctx: HavingClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.orderByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOrderByClause?: (ctx: OrderByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.projectionOrderByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProjectionOrderByClause?: (ctx: ProjectionOrderByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.limitByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLimitByClause?: (ctx: LimitByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.limitClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLimitClause?: (ctx: LimitClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.settingsClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSettingsClause?: (ctx: SettingsClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinExprOp`
       * labeled alternative in `ClickHouseParser.joinExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinExprOp?: (ctx: JoinExprOpContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinExprTable`
       * labeled alternative in `ClickHouseParser.joinExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinExprTable?: (ctx: JoinExprTableContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinExprParens`
       * labeled alternative in `ClickHouseParser.joinExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinExprParens?: (ctx: JoinExprParensContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinExprCrossOp`
       * labeled alternative in `ClickHouseParser.joinExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinExprCrossOp?: (ctx: JoinExprCrossOpContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinOpInner`
       * labeled alternative in `ClickHouseParser.joinOp`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinOpInner?: (ctx: JoinOpInnerContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinOpLeftRight`
       * labeled alternative in `ClickHouseParser.joinOp`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinOpLeftRight?: (ctx: JoinOpLeftRightContext) => Result;
      /**
       * Visit a parse tree produced by the `JoinOpFull`
       * labeled alternative in `ClickHouseParser.joinOp`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinOpFull?: (ctx: JoinOpFullContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.joinOpCross`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinOpCross?: (ctx: JoinOpCrossContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.joinConstraintClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinConstraintClause?: (ctx: JoinConstraintClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.sampleClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSampleClause?: (ctx: SampleClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.limitExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLimitExpr?: (ctx: LimitExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.orderExprList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOrderExprList?: (ctx: OrderExprListContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.orderExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOrderExpr?: (ctx: OrderExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.ratioExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRatioExpr?: (ctx: RatioExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.settingExprList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSettingExprList?: (ctx: SettingExprListContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.settingExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSettingExpr?: (ctx: SettingExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.windowExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindowExpr?: (ctx: WindowExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.winPartitionByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWinPartitionByClause?: (ctx: WinPartitionByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.winOrderByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWinOrderByClause?: (ctx: WinOrderByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.winFrameClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWinFrameClause?: (ctx: WinFrameClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `frameStart`
       * labeled alternative in `ClickHouseParser.winFrameExtend`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameStart?: (ctx: FrameStartContext) => Result;
      /**
       * Visit a parse tree produced by the `frameBetween`
       * labeled alternative in `ClickHouseParser.winFrameExtend`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameBetween?: (ctx: FrameBetweenContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.winFrameBound`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWinFrameBound?: (ctx: WinFrameBoundContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.setStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetStmt?: (ctx: SetStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `showCreateDatabaseStmt`
       * labeled alternative in `ClickHouseParser.showStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCreateDatabaseStmt?: (ctx: ShowCreateDatabaseStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `showCreateDictionaryStmt`
       * labeled alternative in `ClickHouseParser.showStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCreateDictionaryStmt?: (ctx: ShowCreateDictionaryStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `showCreateTableStmt`
       * labeled alternative in `ClickHouseParser.showStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCreateTableStmt?: (ctx: ShowCreateTableStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `showDatabasesStmt`
       * labeled alternative in `ClickHouseParser.showStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowDatabasesStmt?: (ctx: ShowDatabasesStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `showDictionariesStmt`
       * labeled alternative in `ClickHouseParser.showStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowDictionariesStmt?: (ctx: ShowDictionariesStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `showTablesStmt`
       * labeled alternative in `ClickHouseParser.showStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowTablesStmt?: (ctx: ShowTablesStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.systemStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSystemStmt?: (ctx: SystemStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.truncateStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTruncateStmt?: (ctx: TruncateStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.useStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUseStmt?: (ctx: UseStmtContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.watchStmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWatchStmt?: (ctx: WatchStmtContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnTypeExprSimple`
       * labeled alternative in `ClickHouseParser.columnTypeExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnTypeExprSimple?: (ctx: ColumnTypeExprSimpleContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnTypeExprNested`
       * labeled alternative in `ClickHouseParser.columnTypeExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnTypeExprNested?: (ctx: ColumnTypeExprNestedContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnTypeExprEnum`
       * labeled alternative in `ClickHouseParser.columnTypeExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnTypeExprEnum?: (ctx: ColumnTypeExprEnumContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnTypeExprComplex`
       * labeled alternative in `ClickHouseParser.columnTypeExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnTypeExprComplex?: (ctx: ColumnTypeExprComplexContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnTypeExprParam`
       * labeled alternative in `ClickHouseParser.columnTypeExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnTypeExprParam?: (ctx: ColumnTypeExprParamContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnExprList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprList?: (ctx: ColumnExprListContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnsExprAsterisk`
       * labeled alternative in `ClickHouseParser.columnsExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnsExprAsterisk?: (ctx: ColumnsExprAsteriskContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnsExprSubquery`
       * labeled alternative in `ClickHouseParser.columnsExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnsExprSubquery?: (ctx: ColumnsExprSubqueryContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnsExprColumn`
       * labeled alternative in `ClickHouseParser.columnsExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnsExprColumn?: (ctx: ColumnsExprColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprTernaryOp`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprTernaryOp?: (ctx: ColumnExprTernaryOpContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprAlias`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprAlias?: (ctx: ColumnExprAliasContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprExtract`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprExtract?: (ctx: ColumnExprExtractContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprNegate`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprNegate?: (ctx: ColumnExprNegateContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprSubquery`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprSubquery?: (ctx: ColumnExprSubqueryContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprLiteral`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprLiteral?: (ctx: ColumnExprLiteralContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprArray`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprArray?: (ctx: ColumnExprArrayContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprSubstring`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprSubstring?: (ctx: ColumnExprSubstringContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprCast`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprCast?: (ctx: ColumnExprCastContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprOr`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprOr?: (ctx: ColumnExprOrContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprPrecedence1`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprPrecedence1?: (ctx: ColumnExprPrecedence1Context) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprPrecedence2`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprPrecedence2?: (ctx: ColumnExprPrecedence2Context) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprPrecedence3`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprPrecedence3?: (ctx: ColumnExprPrecedence3Context) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprInterval`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprInterval?: (ctx: ColumnExprIntervalContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprIsNull`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprIsNull?: (ctx: ColumnExprIsNullContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprWinFunctionTarget`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprWinFunctionTarget?: (ctx: ColumnExprWinFunctionTargetContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprTrim`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprTrim?: (ctx: ColumnExprTrimContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprTuple`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprTuple?: (ctx: ColumnExprTupleContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprArrayAccess`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprArrayAccess?: (ctx: ColumnExprArrayAccessContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprBetween`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprBetween?: (ctx: ColumnExprBetweenContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprParens`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprParens?: (ctx: ColumnExprParensContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprTimestamp`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprTimestamp?: (ctx: ColumnExprTimestampContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprAnd`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprAnd?: (ctx: ColumnExprAndContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprTupleAccess`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprTupleAccess?: (ctx: ColumnExprTupleAccessContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprCase`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprCase?: (ctx: ColumnExprCaseContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprDate`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprDate?: (ctx: ColumnExprDateContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprNot`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprNot?: (ctx: ColumnExprNotContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprWinFunction`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprWinFunction?: (ctx: ColumnExprWinFunctionContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprIdentifier`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprIdentifier?: (ctx: ColumnExprIdentifierContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprFunction`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprFunction?: (ctx: ColumnExprFunctionContext) => Result;
      /**
       * Visit a parse tree produced by the `ColumnExprAsterisk`
       * labeled alternative in `ClickHouseParser.columnExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnExprAsterisk?: (ctx: ColumnExprAsteriskContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnArgList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnArgList?: (ctx: ColumnArgListContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnArgExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnArgExpr?: (ctx: ColumnArgExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnLambdaExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnLambdaExpr?: (ctx: ColumnLambdaExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.columnIdentifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnIdentifier?: (ctx: ColumnIdentifierContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.nestedIdentifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNestedIdentifier?: (ctx: NestedIdentifierContext) => Result;
      /**
       * Visit a parse tree produced by the `TableExprIdentifier`
       * labeled alternative in `ClickHouseParser.tableExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableExprIdentifier?: (ctx: TableExprIdentifierContext) => Result;
      /**
       * Visit a parse tree produced by the `TableExprSubquery`
       * labeled alternative in `ClickHouseParser.tableExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableExprSubquery?: (ctx: TableExprSubqueryContext) => Result;
      /**
       * Visit a parse tree produced by the `TableExprAlias`
       * labeled alternative in `ClickHouseParser.tableExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableExprAlias?: (ctx: TableExprAliasContext) => Result;
      /**
       * Visit a parse tree produced by the `TableExprFunction`
       * labeled alternative in `ClickHouseParser.tableExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableExprFunction?: (ctx: TableExprFunctionContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableFunctionExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableFunctionExpr?: (ctx: TableFunctionExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableIdentifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableIdentifier?: (ctx: TableIdentifierContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableArgList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableArgList?: (ctx: TableArgListContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.tableArgExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableArgExpr?: (ctx: TableArgExprContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.databaseIdentifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDatabaseIdentifier?: (ctx: DatabaseIdentifierContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.floatingLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFloatingLiteral?: (ctx: FloatingLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.numberLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNumberLiteral?: (ctx: NumberLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.literal`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLiteral?: (ctx: LiteralContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.interval`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInterval?: (ctx: IntervalContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKeyword?: (ctx: KeywordContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.keywordForAlias`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKeywordForAlias?: (ctx: KeywordForAliasContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.alias`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlias?: (ctx: AliasContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.identifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIdentifier?: (ctx: IdentifierContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.identifierOrNull`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIdentifierOrNull?: (ctx: IdentifierOrNullContext) => Result;
      /**
       * Visit a parse tree produced by `ClickHouseParser.enumValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEnumValue?: (ctx: EnumValueContext) => Result;
  }

}
declare module 'websql-autocomplete-2/parsers/mysql/generated/MySqlLexer' {
  import * as antlr from "antlr4ng";
  export class MySqlLexer extends antlr.Lexer {
      static readonly SPACE = 1;
      static readonly SPEC_MYSQL_COMMENT = 2;
      static readonly COMMENT_INPUT = 3;
      static readonly LINE_COMMENT = 4;
      static readonly ADD = 5;
      static readonly ALL = 6;
      static readonly ALTER = 7;
      static readonly ALWAYS = 8;
      static readonly ANALYZE = 9;
      static readonly AND = 10;
      static readonly ARRAY = 11;
      static readonly AS = 12;
      static readonly ASC = 13;
      static readonly ATTRIBUTE = 14;
      static readonly BEFORE = 15;
      static readonly BETWEEN = 16;
      static readonly BOTH = 17;
      static readonly BUCKETS = 18;
      static readonly BY = 19;
      static readonly CALL = 20;
      static readonly CASCADE = 21;
      static readonly CASE = 22;
      static readonly CAST = 23;
      static readonly CHANGE = 24;
      static readonly CHARACTER = 25;
      static readonly CHECK = 26;
      static readonly COLLATE = 27;
      static readonly COLUMN = 28;
      static readonly CONDITION = 29;
      static readonly CONSTRAINT = 30;
      static readonly CONTINUE = 31;
      static readonly CONVERT = 32;
      static readonly CREATE = 33;
      static readonly CROSS = 34;
      static readonly CURRENT = 35;
      static readonly CURRENT_ROLE = 36;
      static readonly CURRENT_USER = 37;
      static readonly CURSOR = 38;
      static readonly DATABASE = 39;
      static readonly DATABASES = 40;
      static readonly DECLARE = 41;
      static readonly DEFAULT = 42;
      static readonly DELAYED = 43;
      static readonly DELETE = 44;
      static readonly DESC = 45;
      static readonly DESCRIBE = 46;
      static readonly DETERMINISTIC = 47;
      static readonly DIAGNOSTICS = 48;
      static readonly DISTINCT = 49;
      static readonly DISTINCTROW = 50;
      static readonly DROP = 51;
      static readonly EACH = 52;
      static readonly ELSE = 53;
      static readonly ELSEIF = 54;
      static readonly EMPTY = 55;
      static readonly ENCLOSED = 56;
      static readonly ENFORCED = 57;
      static readonly ESCAPED = 58;
      static readonly EXCEPT = 59;
      static readonly EXISTS = 60;
      static readonly EXIT = 61;
      static readonly EXPLAIN = 62;
      static readonly FALSE = 63;
      static readonly FETCH = 64;
      static readonly FOR = 65;
      static readonly FORCE = 66;
      static readonly FOREIGN = 67;
      static readonly FROM = 68;
      static readonly FULLTEXT = 69;
      static readonly GENERATED = 70;
      static readonly GET = 71;
      static readonly GRANT = 72;
      static readonly GROUP = 73;
      static readonly HAVING = 74;
      static readonly HIGH_PRIORITY = 75;
      static readonly HISTOGRAM = 76;
      static readonly IF = 77;
      static readonly IGNORE = 78;
      static readonly IGNORED = 79;
      static readonly IN = 80;
      static readonly INDEX = 81;
      static readonly INFILE = 82;
      static readonly INNER = 83;
      static readonly INOUT = 84;
      static readonly INSERT = 85;
      static readonly INTERVAL = 86;
      static readonly INTO = 87;
      static readonly IS = 88;
      static readonly ITERATE = 89;
      static readonly JOIN = 90;
      static readonly KEY = 91;
      static readonly KEYS = 92;
      static readonly KILL = 93;
      static readonly LATERAL = 94;
      static readonly LEADING = 95;
      static readonly LEAVE = 96;
      static readonly LEFT = 97;
      static readonly LIKE = 98;
      static readonly LIMIT = 99;
      static readonly LINEAR = 100;
      static readonly LINES = 101;
      static readonly LOAD = 102;
      static readonly LOCK = 103;
      static readonly LOCKED = 104;
      static readonly LOOP = 105;
      static readonly LOW_PRIORITY = 106;
      static readonly MASTER_BIND = 107;
      static readonly MASTER_SSL_VERIFY_SERVER_CERT = 108;
      static readonly MATCH = 109;
      static readonly MAXVALUE = 110;
      static readonly MINVALUE = 111;
      static readonly MODIFIES = 112;
      static readonly NATURAL = 113;
      static readonly NOT = 114;
      static readonly NO_WRITE_TO_BINLOG = 115;
      static readonly NULL_LITERAL = 116;
      static readonly NUMBER = 117;
      static readonly ON = 118;
      static readonly OPTIMIZE = 119;
      static readonly OPTION = 120;
      static readonly OPTIONAL = 121;
      static readonly OPTIONALLY = 122;
      static readonly OR = 123;
      static readonly ORDER = 124;
      static readonly OUT = 125;
      static readonly OUTER = 126;
      static readonly OUTFILE = 127;
      static readonly OVER = 128;
      static readonly PARTITION = 129;
      static readonly PRIMARY = 130;
      static readonly PROCEDURE = 131;
      static readonly PURGE = 132;
      static readonly RANGE = 133;
      static readonly READ = 134;
      static readonly READS = 135;
      static readonly REFERENCES = 136;
      static readonly REGEXP = 137;
      static readonly RELEASE = 138;
      static readonly RENAME = 139;
      static readonly REPEAT = 140;
      static readonly REPLACE = 141;
      static readonly REQUIRE = 142;
      static readonly RESIGNAL = 143;
      static readonly RESTRICT = 144;
      static readonly RETAIN = 145;
      static readonly RETURN = 146;
      static readonly REVOKE = 147;
      static readonly RIGHT = 148;
      static readonly RLIKE = 149;
      static readonly SCHEMA = 150;
      static readonly SCHEMAS = 151;
      static readonly SELECT = 152;
      static readonly SET = 153;
      static readonly SEPARATOR = 154;
      static readonly SHOW = 155;
      static readonly SIGNAL = 156;
      static readonly SKIP_ = 157;
      static readonly SKIP_QUERY_REWRITE = 158;
      static readonly SPATIAL = 159;
      static readonly SQL = 160;
      static readonly SQLEXCEPTION = 161;
      static readonly SQLSTATE = 162;
      static readonly SQLWARNING = 163;
      static readonly SQL_BIG_RESULT = 164;
      static readonly SQL_CALC_FOUND_ROWS = 165;
      static readonly SQL_SMALL_RESULT = 166;
      static readonly SSL = 167;
      static readonly STACKED = 168;
      static readonly STARTING = 169;
      static readonly STATEMENT = 170;
      static readonly STRAIGHT_JOIN = 171;
      static readonly TABLE = 172;
      static readonly TERMINATED = 173;
      static readonly THEN = 174;
      static readonly TO = 175;
      static readonly TRAILING = 176;
      static readonly TRIGGER = 177;
      static readonly TRUE = 178;
      static readonly UNDO = 179;
      static readonly UNION = 180;
      static readonly UNIQUE = 181;
      static readonly UNLOCK = 182;
      static readonly UNSIGNED = 183;
      static readonly UPDATE = 184;
      static readonly USAGE = 185;
      static readonly USE = 186;
      static readonly USING = 187;
      static readonly VALUES = 188;
      static readonly WHEN = 189;
      static readonly WHERE = 190;
      static readonly WHILE = 191;
      static readonly WITH = 192;
      static readonly WRITE = 193;
      static readonly XOR = 194;
      static readonly ZEROFILL = 195;
      static readonly TINYINT = 196;
      static readonly SMALLINT = 197;
      static readonly MEDIUMINT = 198;
      static readonly MIDDLEINT = 199;
      static readonly INT = 200;
      static readonly INT1 = 201;
      static readonly INT2 = 202;
      static readonly INT3 = 203;
      static readonly INT4 = 204;
      static readonly INT8 = 205;
      static readonly INTEGER = 206;
      static readonly BIGINT = 207;
      static readonly REAL = 208;
      static readonly DOUBLE = 209;
      static readonly PRECISION = 210;
      static readonly FLOAT = 211;
      static readonly FLOAT4 = 212;
      static readonly FLOAT8 = 213;
      static readonly DECIMAL = 214;
      static readonly DEC = 215;
      static readonly NUMERIC = 216;
      static readonly DATE = 217;
      static readonly TIME = 218;
      static readonly TIMESTAMP = 219;
      static readonly DATETIME = 220;
      static readonly YEAR = 221;
      static readonly CHAR = 222;
      static readonly VARCHAR = 223;
      static readonly NVARCHAR = 224;
      static readonly NATIONAL = 225;
      static readonly BINARY = 226;
      static readonly VARBINARY = 227;
      static readonly TINYBLOB = 228;
      static readonly BLOB = 229;
      static readonly MEDIUMBLOB = 230;
      static readonly LONG = 231;
      static readonly LONGBLOB = 232;
      static readonly TINYTEXT = 233;
      static readonly TEXT = 234;
      static readonly MEDIUMTEXT = 235;
      static readonly LONGTEXT = 236;
      static readonly ENUM = 237;
      static readonly VARYING = 238;
      static readonly SERIAL = 239;
      static readonly YEAR_MONTH = 240;
      static readonly DAY_HOUR = 241;
      static readonly DAY_MINUTE = 242;
      static readonly DAY_SECOND = 243;
      static readonly HOUR_MINUTE = 244;
      static readonly HOUR_SECOND = 245;
      static readonly MINUTE_SECOND = 246;
      static readonly SECOND_MICROSECOND = 247;
      static readonly MINUTE_MICROSECOND = 248;
      static readonly HOUR_MICROSECOND = 249;
      static readonly DAY_MICROSECOND = 250;
      static readonly JSON_ARRAY = 251;
      static readonly JSON_ARRAYAGG = 252;
      static readonly JSON_ARRAY_APPEND = 253;
      static readonly JSON_ARRAY_INSERT = 254;
      static readonly JSON_CONTAINS = 255;
      static readonly JSON_CONTAINS_PATH = 256;
      static readonly JSON_DEPTH = 257;
      static readonly JSON_EXTRACT = 258;
      static readonly JSON_INSERT = 259;
      static readonly JSON_KEYS = 260;
      static readonly JSON_LENGTH = 261;
      static readonly JSON_MERGE = 262;
      static readonly JSON_MERGE_PATCH = 263;
      static readonly JSON_MERGE_PRESERVE = 264;
      static readonly JSON_OBJECT = 265;
      static readonly JSON_OBJECTAGG = 266;
      static readonly JSON_OVERLAPS = 267;
      static readonly JSON_PRETTY = 268;
      static readonly JSON_QUOTE = 269;
      static readonly JSON_REMOVE = 270;
      static readonly JSON_REPLACE = 271;
      static readonly JSON_SCHEMA_VALID = 272;
      static readonly JSON_SCHEMA_VALIDATION_REPORT = 273;
      static readonly JSON_SEARCH = 274;
      static readonly JSON_SET = 275;
      static readonly JSON_STORAGE_FREE = 276;
      static readonly JSON_STORAGE_SIZE = 277;
      static readonly JSON_TABLE = 278;
      static readonly JSON_TYPE = 279;
      static readonly JSON_UNQUOTE = 280;
      static readonly JSON_VALID = 281;
      static readonly JSON_VALUE = 282;
      static readonly NESTED = 283;
      static readonly ORDINALITY = 284;
      static readonly PATH = 285;
      static readonly AVG = 286;
      static readonly BIT_AND = 287;
      static readonly BIT_OR = 288;
      static readonly BIT_XOR = 289;
      static readonly COUNT = 290;
      static readonly CUME_DIST = 291;
      static readonly DENSE_RANK = 292;
      static readonly FIRST_VALUE = 293;
      static readonly GROUP_CONCAT = 294;
      static readonly LAG = 295;
      static readonly LAST_VALUE = 296;
      static readonly LEAD = 297;
      static readonly MAX = 298;
      static readonly MIN = 299;
      static readonly NTILE = 300;
      static readonly NTH_VALUE = 301;
      static readonly PERCENT_RANK = 302;
      static readonly RANK = 303;
      static readonly ROW_NUMBER = 304;
      static readonly STD = 305;
      static readonly STDDEV = 306;
      static readonly STDDEV_POP = 307;
      static readonly STDDEV_SAMP = 308;
      static readonly SUM = 309;
      static readonly VAR_POP = 310;
      static readonly VAR_SAMP = 311;
      static readonly VARIANCE = 312;
      static readonly CURRENT_DATE = 313;
      static readonly CURRENT_TIME = 314;
      static readonly CURRENT_TIMESTAMP = 315;
      static readonly LOCALTIME = 316;
      static readonly CURDATE = 317;
      static readonly CURTIME = 318;
      static readonly DATE_ADD = 319;
      static readonly DATE_SUB = 320;
      static readonly EXTRACT = 321;
      static readonly LOCALTIMESTAMP = 322;
      static readonly NOW = 323;
      static readonly POSITION = 324;
      static readonly SUBSTR = 325;
      static readonly SUBSTRING = 326;
      static readonly SYSDATE = 327;
      static readonly TRIM = 328;
      static readonly UTC_DATE = 329;
      static readonly UTC_TIME = 330;
      static readonly UTC_TIMESTAMP = 331;
      static readonly ACCOUNT = 332;
      static readonly ACTION = 333;
      static readonly AFTER = 334;
      static readonly AGGREGATE = 335;
      static readonly ALGORITHM = 336;
      static readonly ANY = 337;
      static readonly AT = 338;
      static readonly AUTHORS = 339;
      static readonly AUTOCOMMIT = 340;
      static readonly AUTOEXTEND_SIZE = 341;
      static readonly AUTO_INCREMENT = 342;
      static readonly AVG_ROW_LENGTH = 343;
      static readonly BEGIN = 344;
      static readonly BINLOG = 345;
      static readonly BIT = 346;
      static readonly BLOCK = 347;
      static readonly BOOL = 348;
      static readonly BOOLEAN = 349;
      static readonly BTREE = 350;
      static readonly CACHE = 351;
      static readonly CASCADED = 352;
      static readonly CHAIN = 353;
      static readonly CHANGED = 354;
      static readonly CHANNEL = 355;
      static readonly CHECKSUM = 356;
      static readonly PAGE_CHECKSUM = 357;
      static readonly CIPHER = 358;
      static readonly CLASS_ORIGIN = 359;
      static readonly CLIENT = 360;
      static readonly CLOSE = 361;
      static readonly CLUSTERING = 362;
      static readonly COALESCE = 363;
      static readonly CODE = 364;
      static readonly COLUMNS = 365;
      static readonly COLUMN_FORMAT = 366;
      static readonly COLUMN_NAME = 367;
      static readonly COMMENT = 368;
      static readonly COMMIT = 369;
      static readonly COMPACT = 370;
      static readonly COMPLETION = 371;
      static readonly COMPRESSED = 372;
      static readonly COMPRESSION = 373;
      static readonly CONCURRENT = 374;
      static readonly CONNECT = 375;
      static readonly CONNECTION = 376;
      static readonly CONSISTENT = 377;
      static readonly CONSTRAINT_CATALOG = 378;
      static readonly CONSTRAINT_SCHEMA = 379;
      static readonly CONSTRAINT_NAME = 380;
      static readonly CONTAINS = 381;
      static readonly CONTEXT = 382;
      static readonly CONTRIBUTORS = 383;
      static readonly COPY = 384;
      static readonly CPU = 385;
      static readonly CYCLE = 386;
      static readonly CURSOR_NAME = 387;
      static readonly DATA = 388;
      static readonly DATAFILE = 389;
      static readonly DEALLOCATE = 390;
      static readonly DEFAULT_AUTH = 391;
      static readonly DEFINER = 392;
      static readonly DELAY_KEY_WRITE = 393;
      static readonly DES_KEY_FILE = 394;
      static readonly DIRECTORY = 395;
      static readonly DISABLE = 396;
      static readonly DISCARD = 397;
      static readonly DISK = 398;
      static readonly DO = 399;
      static readonly DUMPFILE = 400;
      static readonly DUPLICATE = 401;
      static readonly DYNAMIC = 402;
      static readonly ENABLE = 403;
      static readonly ENCRYPTED = 404;
      static readonly ENCRYPTION = 405;
      static readonly ENCRYPTION_KEY_ID = 406;
      static readonly END = 407;
      static readonly ENDS = 408;
      static readonly ENGINE = 409;
      static readonly ENGINES = 410;
      static readonly ERROR = 411;
      static readonly ERRORS = 412;
      static readonly ESCAPE = 413;
      static readonly EVEN = 414;
      static readonly EVENT = 415;
      static readonly EVENTS = 416;
      static readonly EVERY = 417;
      static readonly EXCHANGE = 418;
      static readonly EXCLUSIVE = 419;
      static readonly EXPIRE = 420;
      static readonly EXPORT = 421;
      static readonly EXTENDED = 422;
      static readonly EXTENT_SIZE = 423;
      static readonly FAILED_LOGIN_ATTEMPTS = 424;
      static readonly FAST = 425;
      static readonly FAULTS = 426;
      static readonly FIELDS = 427;
      static readonly FILE_BLOCK_SIZE = 428;
      static readonly FILTER = 429;
      static readonly FIRST = 430;
      static readonly FIXED = 431;
      static readonly FLUSH = 432;
      static readonly FOLLOWING = 433;
      static readonly FOLLOWS = 434;
      static readonly FOUND = 435;
      static readonly FULL = 436;
      static readonly FUNCTION = 437;
      static readonly GENERAL = 438;
      static readonly GLOBAL = 439;
      static readonly GRANTS = 440;
      static readonly GROUP_REPLICATION = 441;
      static readonly HANDLER = 442;
      static readonly HASH = 443;
      static readonly HELP = 444;
      static readonly HISTORY = 445;
      static readonly HOST = 446;
      static readonly HOSTS = 447;
      static readonly IDENTIFIED = 448;
      static readonly IGNORE_SERVER_IDS = 449;
      static readonly IMPORT = 450;
      static readonly INCREMENT = 451;
      static readonly INDEXES = 452;
      static readonly INITIAL_SIZE = 453;
      static readonly INPLACE = 454;
      static readonly INSERT_METHOD = 455;
      static readonly INSTALL = 456;
      static readonly INSTANCE = 457;
      static readonly INSTANT = 458;
      static readonly INVISIBLE = 459;
      static readonly INVOKER = 460;
      static readonly IO = 461;
      static readonly IO_THREAD = 462;
      static readonly IPC = 463;
      static readonly ISOLATION = 464;
      static readonly ISSUER = 465;
      static readonly JSON = 466;
      static readonly KEY_BLOCK_SIZE = 467;
      static readonly LANGUAGE = 468;
      static readonly LAST = 469;
      static readonly LEAVES = 470;
      static readonly LESS = 471;
      static readonly LEVEL = 472;
      static readonly LIST = 473;
      static readonly LOCAL = 474;
      static readonly LOGFILE = 475;
      static readonly LOGS = 476;
      static readonly MASTER = 477;
      static readonly MASTER_AUTO_POSITION = 478;
      static readonly MASTER_CONNECT_RETRY = 479;
      static readonly MASTER_DELAY = 480;
      static readonly MASTER_HEARTBEAT_PERIOD = 481;
      static readonly MASTER_HOST = 482;
      static readonly MASTER_LOG_FILE = 483;
      static readonly MASTER_LOG_POS = 484;
      static readonly MASTER_PASSWORD = 485;
      static readonly MASTER_PORT = 486;
      static readonly MASTER_RETRY_COUNT = 487;
      static readonly MASTER_SSL = 488;
      static readonly MASTER_SSL_CA = 489;
      static readonly MASTER_SSL_CAPATH = 490;
      static readonly MASTER_SSL_CERT = 491;
      static readonly MASTER_SSL_CIPHER = 492;
      static readonly MASTER_SSL_CRL = 493;
      static readonly MASTER_SSL_CRLPATH = 494;
      static readonly MASTER_SSL_KEY = 495;
      static readonly MASTER_TLS_VERSION = 496;
      static readonly MASTER_USER = 497;
      static readonly MAX_CONNECTIONS_PER_HOUR = 498;
      static readonly MAX_QUERIES_PER_HOUR = 499;
      static readonly MAX_ROWS = 500;
      static readonly MAX_SIZE = 501;
      static readonly MAX_UPDATES_PER_HOUR = 502;
      static readonly MAX_USER_CONNECTIONS = 503;
      static readonly MEDIUM = 504;
      static readonly MEMBER = 505;
      static readonly MERGE = 506;
      static readonly MESSAGE_TEXT = 507;
      static readonly MID = 508;
      static readonly MIGRATE = 509;
      static readonly MIN_ROWS = 510;
      static readonly MODE = 511;
      static readonly MODIFY = 512;
      static readonly MUTEX = 513;
      static readonly MYSQL = 514;
      static readonly MYSQL_ERRNO = 515;
      static readonly NAME = 516;
      static readonly NAMES = 517;
      static readonly NCHAR = 518;
      static readonly NEVER = 519;
      static readonly NEXT = 520;
      static readonly NO = 521;
      static readonly NOCACHE = 522;
      static readonly NOCOPY = 523;
      static readonly NOCYCLE = 524;
      static readonly NOMAXVALUE = 525;
      static readonly NOMINVALUE = 526;
      static readonly NOWAIT = 527;
      static readonly NODEGROUP = 528;
      static readonly NONE = 529;
      static readonly ODBC = 530;
      static readonly OFFLINE = 531;
      static readonly OFFSET = 532;
      static readonly OF = 533;
      static readonly OJ = 534;
      static readonly OLD_PASSWORD = 535;
      static readonly ONE = 536;
      static readonly ONLINE = 537;
      static readonly ONLY = 538;
      static readonly OPEN = 539;
      static readonly OPTIMIZER_COSTS = 540;
      static readonly OPTIONS = 541;
      static readonly OWNER = 542;
      static readonly PACK_KEYS = 543;
      static readonly PAGE = 544;
      static readonly PAGE_COMPRESSED = 545;
      static readonly PAGE_COMPRESSION_LEVEL = 546;
      static readonly PARSER = 547;
      static readonly PARTIAL = 548;
      static readonly PARTITIONING = 549;
      static readonly PARTITIONS = 550;
      static readonly PASSWORD = 551;
      static readonly PASSWORD_LOCK_TIME = 552;
      static readonly PHASE = 553;
      static readonly PLUGIN = 554;
      static readonly PLUGIN_DIR = 555;
      static readonly PLUGINS = 556;
      static readonly PORT = 557;
      static readonly PRECEDES = 558;
      static readonly PRECEDING = 559;
      static readonly PREPARE = 560;
      static readonly PRESERVE = 561;
      static readonly PREV = 562;
      static readonly PROCESSLIST = 563;
      static readonly PROFILE = 564;
      static readonly PROFILES = 565;
      static readonly PROXY = 566;
      static readonly QUERY = 567;
      static readonly QUICK = 568;
      static readonly REBUILD = 569;
      static readonly RECOVER = 570;
      static readonly RECURSIVE = 571;
      static readonly REDO_BUFFER_SIZE = 572;
      static readonly REDUNDANT = 573;
      static readonly RELAY = 574;
      static readonly RELAY_LOG_FILE = 575;
      static readonly RELAY_LOG_POS = 576;
      static readonly RELAYLOG = 577;
      static readonly REMOVE = 578;
      static readonly REORGANIZE = 579;
      static readonly REPAIR = 580;
      static readonly REPLICATE_DO_DB = 581;
      static readonly REPLICATE_DO_TABLE = 582;
      static readonly REPLICATE_IGNORE_DB = 583;
      static readonly REPLICATE_IGNORE_TABLE = 584;
      static readonly REPLICATE_REWRITE_DB = 585;
      static readonly REPLICATE_WILD_DO_TABLE = 586;
      static readonly REPLICATE_WILD_IGNORE_TABLE = 587;
      static readonly REPLICATION = 588;
      static readonly RESET = 589;
      static readonly RESTART = 590;
      static readonly RESUME = 591;
      static readonly RETURNED_SQLSTATE = 592;
      static readonly RETURNING = 593;
      static readonly RETURNS = 594;
      static readonly REUSE = 595;
      static readonly ROLE = 596;
      static readonly ROLLBACK = 597;
      static readonly ROLLUP = 598;
      static readonly ROTATE = 599;
      static readonly ROW = 600;
      static readonly ROWS = 601;
      static readonly ROW_FORMAT = 602;
      static readonly RTREE = 603;
      static readonly SAVEPOINT = 604;
      static readonly SCHEDULE = 605;
      static readonly SECURITY = 606;
      static readonly SEQUENCE = 607;
      static readonly SERVER = 608;
      static readonly SESSION = 609;
      static readonly SHARE = 610;
      static readonly SHARED = 611;
      static readonly SIGNED = 612;
      static readonly SIMPLE = 613;
      static readonly SLAVE = 614;
      static readonly SLOW = 615;
      static readonly SNAPSHOT = 616;
      static readonly SOCKET = 617;
      static readonly SOME = 618;
      static readonly SONAME = 619;
      static readonly SOUNDS = 620;
      static readonly SOURCE = 621;
      static readonly SQL_AFTER_GTIDS = 622;
      static readonly SQL_AFTER_MTS_GAPS = 623;
      static readonly SQL_BEFORE_GTIDS = 624;
      static readonly SQL_BUFFER_RESULT = 625;
      static readonly SQL_CACHE = 626;
      static readonly SQL_NO_CACHE = 627;
      static readonly SQL_THREAD = 628;
      static readonly START = 629;
      static readonly STARTS = 630;
      static readonly STATS_AUTO_RECALC = 631;
      static readonly STATS_PERSISTENT = 632;
      static readonly STATS_SAMPLE_PAGES = 633;
      static readonly STATUS = 634;
      static readonly STOP = 635;
      static readonly STORAGE = 636;
      static readonly STORED = 637;
      static readonly STRING = 638;
      static readonly SUBCLASS_ORIGIN = 639;
      static readonly SUBJECT = 640;
      static readonly SUBPARTITION = 641;
      static readonly SUBPARTITIONS = 642;
      static readonly SUSPEND = 643;
      static readonly SWAPS = 644;
      static readonly SWITCHES = 645;
      static readonly TABLE_NAME = 646;
      static readonly TABLESPACE = 647;
      static readonly TABLE_TYPE = 648;
      static readonly TEMPORARY = 649;
      static readonly TEMPTABLE = 650;
      static readonly THAN = 651;
      static readonly TRADITIONAL = 652;
      static readonly TRANSACTION = 653;
      static readonly TRANSACTIONAL = 654;
      static readonly TRIGGERS = 655;
      static readonly TRUNCATE = 656;
      static readonly UNBOUNDED = 657;
      static readonly UNDEFINED = 658;
      static readonly UNDOFILE = 659;
      static readonly UNDO_BUFFER_SIZE = 660;
      static readonly UNINSTALL = 661;
      static readonly UNKNOWN = 662;
      static readonly UNTIL = 663;
      static readonly UPGRADE = 664;
      static readonly USER = 665;
      static readonly USE_FRM = 666;
      static readonly USER_RESOURCES = 667;
      static readonly VALIDATION = 668;
      static readonly VALUE = 669;
      static readonly VARIABLES = 670;
      static readonly VIEW = 671;
      static readonly VIRTUAL = 672;
      static readonly VISIBLE = 673;
      static readonly WAIT = 674;
      static readonly WARNINGS = 675;
      static readonly WINDOW = 676;
      static readonly WITHOUT = 677;
      static readonly WORK = 678;
      static readonly WRAPPER = 679;
      static readonly X509 = 680;
      static readonly XA = 681;
      static readonly XML = 682;
      static readonly YES = 683;
      static readonly EUR = 684;
      static readonly USA = 685;
      static readonly JIS = 686;
      static readonly ISO = 687;
      static readonly INTERNAL = 688;
      static readonly QUARTER = 689;
      static readonly MONTH = 690;
      static readonly DAY = 691;
      static readonly HOUR = 692;
      static readonly MINUTE = 693;
      static readonly WEEK = 694;
      static readonly SECOND = 695;
      static readonly MICROSECOND = 696;
      static readonly ADMIN = 697;
      static readonly APPLICATION_PASSWORD_ADMIN = 698;
      static readonly AUDIT_ABORT_EXEMPT = 699;
      static readonly AUDIT_ADMIN = 700;
      static readonly AUTHENTICATION_POLICY_ADMIN = 701;
      static readonly BACKUP_ADMIN = 702;
      static readonly BINLOG_ADMIN = 703;
      static readonly BINLOG_ENCRYPTION_ADMIN = 704;
      static readonly CLONE_ADMIN = 705;
      static readonly CONNECTION_ADMIN = 706;
      static readonly ENCRYPTION_KEY_ADMIN = 707;
      static readonly EXECUTE = 708;
      static readonly FILE = 709;
      static readonly FIREWALL_ADMIN = 710;
      static readonly FIREWALL_EXEMPT = 711;
      static readonly FIREWALL_USER = 712;
      static readonly FLUSH_OPTIMIZER_COSTS = 713;
      static readonly FLUSH_STATUS = 714;
      static readonly FLUSH_TABLES = 715;
      static readonly FLUSH_USER_RESOURCES = 716;
      static readonly GROUP_REPLICATION_ADMIN = 717;
      static readonly INNODB_REDO_LOG_ARCHIVE = 718;
      static readonly INNODB_REDO_LOG_ENABLE = 719;
      static readonly INVOKE = 720;
      static readonly LAMBDA = 721;
      static readonly NDB_STORED_USER = 722;
      static readonly PASSWORDLESS_USER_ADMIN = 723;
      static readonly PERSIST_RO_VARIABLES_ADMIN = 724;
      static readonly PRIVILEGES = 725;
      static readonly PROCESS = 726;
      static readonly RELOAD = 727;
      static readonly REPLICATION_APPLIER = 728;
      static readonly REPLICATION_SLAVE_ADMIN = 729;
      static readonly RESOURCE_GROUP_ADMIN = 730;
      static readonly RESOURCE_GROUP_USER = 731;
      static readonly ROLE_ADMIN = 732;
      static readonly ROUTINE = 733;
      static readonly S3 = 734;
      static readonly SERVICE_CONNECTION_ADMIN = 735;
      static readonly SESSION_VARIABLES_ADMIN = 736;
      static readonly SET_USER_ID = 737;
      static readonly SHOW_ROUTINE = 738;
      static readonly SHUTDOWN = 739;
      static readonly SUPER = 740;
      static readonly SYSTEM_VARIABLES_ADMIN = 741;
      static readonly TABLES = 742;
      static readonly TABLE_ENCRYPTION_ADMIN = 743;
      static readonly VERSION_TOKEN_ADMIN = 744;
      static readonly XA_RECOVER_ADMIN = 745;
      static readonly ARMSCII8 = 746;
      static readonly ASCII = 747;
      static readonly BIG5 = 748;
      static readonly CP1250 = 749;
      static readonly CP1251 = 750;
      static readonly CP1256 = 751;
      static readonly CP1257 = 752;
      static readonly CP850 = 753;
      static readonly CP852 = 754;
      static readonly CP866 = 755;
      static readonly CP932 = 756;
      static readonly DEC8 = 757;
      static readonly EUCJPMS = 758;
      static readonly EUCKR = 759;
      static readonly GB18030 = 760;
      static readonly GB2312 = 761;
      static readonly GBK = 762;
      static readonly GEOSTD8 = 763;
      static readonly GREEK = 764;
      static readonly HEBREW = 765;
      static readonly HP8 = 766;
      static readonly KEYBCS2 = 767;
      static readonly KOI8R = 768;
      static readonly KOI8U = 769;
      static readonly LATIN1 = 770;
      static readonly LATIN2 = 771;
      static readonly LATIN5 = 772;
      static readonly LATIN7 = 773;
      static readonly MACCE = 774;
      static readonly MACROMAN = 775;
      static readonly SJIS = 776;
      static readonly SWE7 = 777;
      static readonly TIS620 = 778;
      static readonly UCS2 = 779;
      static readonly UJIS = 780;
      static readonly UTF16 = 781;
      static readonly UTF16LE = 782;
      static readonly UTF32 = 783;
      static readonly UTF8 = 784;
      static readonly UTF8MB3 = 785;
      static readonly UTF8MB4 = 786;
      static readonly ARCHIVE = 787;
      static readonly BLACKHOLE = 788;
      static readonly CSV = 789;
      static readonly FEDERATED = 790;
      static readonly INNODB = 791;
      static readonly MEMORY = 792;
      static readonly MRG_MYISAM = 793;
      static readonly MYISAM = 794;
      static readonly NDB = 795;
      static readonly NDBCLUSTER = 796;
      static readonly PERFORMANCE_SCHEMA = 797;
      static readonly TOKUDB = 798;
      static readonly REPEATABLE = 799;
      static readonly COMMITTED = 800;
      static readonly UNCOMMITTED = 801;
      static readonly SERIALIZABLE = 802;
      static readonly GEOMETRYCOLLECTION = 803;
      static readonly GEOMCOLLECTION = 804;
      static readonly GEOMETRY = 805;
      static readonly LINESTRING = 806;
      static readonly MULTILINESTRING = 807;
      static readonly MULTIPOINT = 808;
      static readonly MULTIPOLYGON = 809;
      static readonly POINT = 810;
      static readonly POLYGON = 811;
      static readonly ABS = 812;
      static readonly ACOS = 813;
      static readonly ADDDATE = 814;
      static readonly ADDTIME = 815;
      static readonly AES_DECRYPT = 816;
      static readonly AES_ENCRYPT = 817;
      static readonly AREA = 818;
      static readonly ASBINARY = 819;
      static readonly ASIN = 820;
      static readonly ASTEXT = 821;
      static readonly ASWKB = 822;
      static readonly ASWKT = 823;
      static readonly ASYMMETRIC_DECRYPT = 824;
      static readonly ASYMMETRIC_DERIVE = 825;
      static readonly ASYMMETRIC_ENCRYPT = 826;
      static readonly ASYMMETRIC_SIGN = 827;
      static readonly ASYMMETRIC_VERIFY = 828;
      static readonly ATAN = 829;
      static readonly ATAN2 = 830;
      static readonly BENCHMARK = 831;
      static readonly BIN = 832;
      static readonly BIT_COUNT = 833;
      static readonly BIT_LENGTH = 834;
      static readonly BUFFER = 835;
      static readonly CATALOG_NAME = 836;
      static readonly CEIL = 837;
      static readonly CEILING = 838;
      static readonly CENTROID = 839;
      static readonly CHARACTER_LENGTH = 840;
      static readonly CHARSET = 841;
      static readonly CHAR_LENGTH = 842;
      static readonly COERCIBILITY = 843;
      static readonly COLLATION = 844;
      static readonly COMPRESS = 845;
      static readonly CONCAT = 846;
      static readonly CONCAT_WS = 847;
      static readonly CONNECTION_ID = 848;
      static readonly CONV = 849;
      static readonly CONVERT_TZ = 850;
      static readonly COS = 851;
      static readonly COT = 852;
      static readonly CRC32 = 853;
      static readonly CREATE_ASYMMETRIC_PRIV_KEY = 854;
      static readonly CREATE_ASYMMETRIC_PUB_KEY = 855;
      static readonly CREATE_DH_PARAMETERS = 856;
      static readonly CREATE_DIGEST = 857;
      static readonly CROSSES = 858;
      static readonly DATEDIFF = 859;
      static readonly DATE_FORMAT = 860;
      static readonly DAYNAME = 861;
      static readonly DAYOFMONTH = 862;
      static readonly DAYOFWEEK = 863;
      static readonly DAYOFYEAR = 864;
      static readonly DECODE = 865;
      static readonly DEGREES = 866;
      static readonly DES_DECRYPT = 867;
      static readonly DES_ENCRYPT = 868;
      static readonly DIMENSION = 869;
      static readonly DISJOINT = 870;
      static readonly ELT = 871;
      static readonly ENCODE = 872;
      static readonly ENCRYPT = 873;
      static readonly ENDPOINT = 874;
      static readonly ENGINE_ATTRIBUTE = 875;
      static readonly ENVELOPE = 876;
      static readonly EQUALS = 877;
      static readonly EXP = 878;
      static readonly EXPORT_SET = 879;
      static readonly EXTERIORRING = 880;
      static readonly EXTRACTVALUE = 881;
      static readonly FIELD = 882;
      static readonly FIND_IN_SET = 883;
      static readonly FLOOR = 884;
      static readonly FORMAT = 885;
      static readonly FOUND_ROWS = 886;
      static readonly FROM_BASE64 = 887;
      static readonly FROM_DAYS = 888;
      static readonly FROM_UNIXTIME = 889;
      static readonly GEOMCOLLFROMTEXT = 890;
      static readonly GEOMCOLLFROMWKB = 891;
      static readonly GEOMETRYCOLLECTIONFROMTEXT = 892;
      static readonly GEOMETRYCOLLECTIONFROMWKB = 893;
      static readonly GEOMETRYFROMTEXT = 894;
      static readonly GEOMETRYFROMWKB = 895;
      static readonly GEOMETRYN = 896;
      static readonly GEOMETRYTYPE = 897;
      static readonly GEOMFROMTEXT = 898;
      static readonly GEOMFROMWKB = 899;
      static readonly GET_FORMAT = 900;
      static readonly GET_LOCK = 901;
      static readonly GLENGTH = 902;
      static readonly GREATEST = 903;
      static readonly GTID_SUBSET = 904;
      static readonly GTID_SUBTRACT = 905;
      static readonly HEX = 906;
      static readonly IFNULL = 907;
      static readonly INET6_ATON = 908;
      static readonly INET6_NTOA = 909;
      static readonly INET_ATON = 910;
      static readonly INET_NTOA = 911;
      static readonly INSTR = 912;
      static readonly INTERIORRINGN = 913;
      static readonly INTERSECTS = 914;
      static readonly ISCLOSED = 915;
      static readonly ISEMPTY = 916;
      static readonly ISNULL = 917;
      static readonly ISSIMPLE = 918;
      static readonly IS_FREE_LOCK = 919;
      static readonly IS_IPV4 = 920;
      static readonly IS_IPV4_COMPAT = 921;
      static readonly IS_IPV4_MAPPED = 922;
      static readonly IS_IPV6 = 923;
      static readonly IS_USED_LOCK = 924;
      static readonly LAST_INSERT_ID = 925;
      static readonly LCASE = 926;
      static readonly LEAST = 927;
      static readonly LENGTH = 928;
      static readonly LINEFROMTEXT = 929;
      static readonly LINEFROMWKB = 930;
      static readonly LINESTRINGFROMTEXT = 931;
      static readonly LINESTRINGFROMWKB = 932;
      static readonly LN = 933;
      static readonly LOAD_FILE = 934;
      static readonly LOCATE = 935;
      static readonly LOG = 936;
      static readonly LOG10 = 937;
      static readonly LOG2 = 938;
      static readonly LOWER = 939;
      static readonly LPAD = 940;
      static readonly LTRIM = 941;
      static readonly MAKEDATE = 942;
      static readonly MAKETIME = 943;
      static readonly MAKE_SET = 944;
      static readonly MASTER_POS_WAIT = 945;
      static readonly MBRCONTAINS = 946;
      static readonly MBRDISJOINT = 947;
      static readonly MBREQUAL = 948;
      static readonly MBRINTERSECTS = 949;
      static readonly MBROVERLAPS = 950;
      static readonly MBRTOUCHES = 951;
      static readonly MBRWITHIN = 952;
      static readonly MD5 = 953;
      static readonly MLINEFROMTEXT = 954;
      static readonly MLINEFROMWKB = 955;
      static readonly MONTHNAME = 956;
      static readonly MPOINTFROMTEXT = 957;
      static readonly MPOINTFROMWKB = 958;
      static readonly MPOLYFROMTEXT = 959;
      static readonly MPOLYFROMWKB = 960;
      static readonly MULTILINESTRINGFROMTEXT = 961;
      static readonly MULTILINESTRINGFROMWKB = 962;
      static readonly MULTIPOINTFROMTEXT = 963;
      static readonly MULTIPOINTFROMWKB = 964;
      static readonly MULTIPOLYGONFROMTEXT = 965;
      static readonly MULTIPOLYGONFROMWKB = 966;
      static readonly NAME_CONST = 967;
      static readonly NULLIF = 968;
      static readonly NUMGEOMETRIES = 969;
      static readonly NUMINTERIORRINGS = 970;
      static readonly NUMPOINTS = 971;
      static readonly OCT = 972;
      static readonly OCTET_LENGTH = 973;
      static readonly ORD = 974;
      static readonly OVERLAPS = 975;
      static readonly PERIOD_ADD = 976;
      static readonly PERIOD_DIFF = 977;
      static readonly PI = 978;
      static readonly POINTFROMTEXT = 979;
      static readonly POINTFROMWKB = 980;
      static readonly POINTN = 981;
      static readonly POLYFROMTEXT = 982;
      static readonly POLYFROMWKB = 983;
      static readonly POLYGONFROMTEXT = 984;
      static readonly POLYGONFROMWKB = 985;
      static readonly POW = 986;
      static readonly POWER = 987;
      static readonly QUOTE = 988;
      static readonly RADIANS = 989;
      static readonly RAND = 990;
      static readonly RANDOM = 991;
      static readonly RANDOM_BYTES = 992;
      static readonly RELEASE_LOCK = 993;
      static readonly REVERSE = 994;
      static readonly ROUND = 995;
      static readonly ROW_COUNT = 996;
      static readonly RPAD = 997;
      static readonly RTRIM = 998;
      static readonly SEC_TO_TIME = 999;
      static readonly SECONDARY_ENGINE_ATTRIBUTE = 1000;
      static readonly SESSION_USER = 1001;
      static readonly SHA = 1002;
      static readonly SHA1 = 1003;
      static readonly SHA2 = 1004;
      static readonly SCHEMA_NAME = 1005;
      static readonly SIGN = 1006;
      static readonly SIN = 1007;
      static readonly SLEEP = 1008;
      static readonly SOUNDEX = 1009;
      static readonly SQL_THREAD_WAIT_AFTER_GTIDS = 1010;
      static readonly SQRT = 1011;
      static readonly SRID = 1012;
      static readonly STARTPOINT = 1013;
      static readonly STRCMP = 1014;
      static readonly STR_TO_DATE = 1015;
      static readonly ST_AREA = 1016;
      static readonly ST_ASBINARY = 1017;
      static readonly ST_ASTEXT = 1018;
      static readonly ST_ASWKB = 1019;
      static readonly ST_ASWKT = 1020;
      static readonly ST_BUFFER = 1021;
      static readonly ST_CENTROID = 1022;
      static readonly ST_CONTAINS = 1023;
      static readonly ST_CROSSES = 1024;
      static readonly ST_DIFFERENCE = 1025;
      static readonly ST_DIMENSION = 1026;
      static readonly ST_DISJOINT = 1027;
      static readonly ST_DISTANCE = 1028;
      static readonly ST_ENDPOINT = 1029;
      static readonly ST_ENVELOPE = 1030;
      static readonly ST_EQUALS = 1031;
      static readonly ST_EXTERIORRING = 1032;
      static readonly ST_GEOMCOLLFROMTEXT = 1033;
      static readonly ST_GEOMCOLLFROMTXT = 1034;
      static readonly ST_GEOMCOLLFROMWKB = 1035;
      static readonly ST_GEOMETRYCOLLECTIONFROMTEXT = 1036;
      static readonly ST_GEOMETRYCOLLECTIONFROMWKB = 1037;
      static readonly ST_GEOMETRYFROMTEXT = 1038;
      static readonly ST_GEOMETRYFROMWKB = 1039;
      static readonly ST_GEOMETRYN = 1040;
      static readonly ST_GEOMETRYTYPE = 1041;
      static readonly ST_GEOMFROMTEXT = 1042;
      static readonly ST_GEOMFROMWKB = 1043;
      static readonly ST_INTERIORRINGN = 1044;
      static readonly ST_INTERSECTION = 1045;
      static readonly ST_INTERSECTS = 1046;
      static readonly ST_ISCLOSED = 1047;
      static readonly ST_ISEMPTY = 1048;
      static readonly ST_ISSIMPLE = 1049;
      static readonly ST_LINEFROMTEXT = 1050;
      static readonly ST_LINEFROMWKB = 1051;
      static readonly ST_LINESTRINGFROMTEXT = 1052;
      static readonly ST_LINESTRINGFROMWKB = 1053;
      static readonly ST_NUMGEOMETRIES = 1054;
      static readonly ST_NUMINTERIORRING = 1055;
      static readonly ST_NUMINTERIORRINGS = 1056;
      static readonly ST_NUMPOINTS = 1057;
      static readonly ST_OVERLAPS = 1058;
      static readonly ST_POINTFROMTEXT = 1059;
      static readonly ST_POINTFROMWKB = 1060;
      static readonly ST_POINTN = 1061;
      static readonly ST_POLYFROMTEXT = 1062;
      static readonly ST_POLYFROMWKB = 1063;
      static readonly ST_POLYGONFROMTEXT = 1064;
      static readonly ST_POLYGONFROMWKB = 1065;
      static readonly ST_SRID = 1066;
      static readonly ST_STARTPOINT = 1067;
      static readonly ST_SYMDIFFERENCE = 1068;
      static readonly ST_TOUCHES = 1069;
      static readonly ST_UNION = 1070;
      static readonly ST_WITHIN = 1071;
      static readonly ST_X = 1072;
      static readonly ST_Y = 1073;
      static readonly SUBDATE = 1074;
      static readonly SUBSTRING_INDEX = 1075;
      static readonly SUBTIME = 1076;
      static readonly SYSTEM_USER = 1077;
      static readonly TAN = 1078;
      static readonly TIMEDIFF = 1079;
      static readonly TIMESTAMPADD = 1080;
      static readonly TIMESTAMPDIFF = 1081;
      static readonly TIME_FORMAT = 1082;
      static readonly TIME_TO_SEC = 1083;
      static readonly TOUCHES = 1084;
      static readonly TO_BASE64 = 1085;
      static readonly TO_DAYS = 1086;
      static readonly TO_SECONDS = 1087;
      static readonly TP_CONNECTION_ADMIN = 1088;
      static readonly UCASE = 1089;
      static readonly UNCOMPRESS = 1090;
      static readonly UNCOMPRESSED_LENGTH = 1091;
      static readonly UNHEX = 1092;
      static readonly UNIX_TIMESTAMP = 1093;
      static readonly UPDATEXML = 1094;
      static readonly UPPER = 1095;
      static readonly UUID = 1096;
      static readonly UUID_SHORT = 1097;
      static readonly VALIDATE_PASSWORD_STRENGTH = 1098;
      static readonly VERSION = 1099;
      static readonly WAIT_UNTIL_SQL_THREAD_AFTER_GTIDS = 1100;
      static readonly WEEKDAY = 1101;
      static readonly WEEKOFYEAR = 1102;
      static readonly WEIGHT_STRING = 1103;
      static readonly WITHIN = 1104;
      static readonly YEARWEEK = 1105;
      static readonly Y_FUNCTION = 1106;
      static readonly X_FUNCTION = 1107;
      static readonly VAR_ASSIGN = 1108;
      static readonly PLUS_ASSIGN = 1109;
      static readonly MINUS_ASSIGN = 1110;
      static readonly MULT_ASSIGN = 1111;
      static readonly DIV_ASSIGN = 1112;
      static readonly MOD_ASSIGN = 1113;
      static readonly AND_ASSIGN = 1114;
      static readonly XOR_ASSIGN = 1115;
      static readonly OR_ASSIGN = 1116;
      static readonly STAR = 1117;
      static readonly DIVIDE = 1118;
      static readonly MODULE = 1119;
      static readonly PLUS = 1120;
      static readonly MINUS = 1121;
      static readonly DIV = 1122;
      static readonly MOD = 1123;
      static readonly EQUAL_SYMBOL = 1124;
      static readonly GREATER_SYMBOL = 1125;
      static readonly LESS_SYMBOL = 1126;
      static readonly EXCLAMATION_SYMBOL = 1127;
      static readonly BIT_NOT_OP = 1128;
      static readonly BIT_OR_OP = 1129;
      static readonly BIT_AND_OP = 1130;
      static readonly BIT_XOR_OP = 1131;
      static readonly DOT = 1132;
      static readonly LR_BRACKET = 1133;
      static readonly RR_BRACKET = 1134;
      static readonly COMMA = 1135;
      static readonly SEMI = 1136;
      static readonly AT_SIGN = 1137;
      static readonly ZERO_DECIMAL = 1138;
      static readonly ONE_DECIMAL = 1139;
      static readonly TWO_DECIMAL = 1140;
      static readonly SINGLE_QUOTE_SYMB = 1141;
      static readonly DOUBLE_QUOTE_SYMB = 1142;
      static readonly REVERSE_QUOTE_SYMB = 1143;
      static readonly COLON_SYMB = 1144;
      static readonly CHARSET_REVERSE_QOUTE_STRING = 1145;
      static readonly FILESIZE_LITERAL = 1146;
      static readonly START_NATIONAL_STRING_LITERAL = 1147;
      static readonly STRING_LITERAL = 1148;
      static readonly DECIMAL_LITERAL = 1149;
      static readonly HEXADECIMAL_LITERAL = 1150;
      static readonly REAL_LITERAL = 1151;
      static readonly NULL_SPEC_LITERAL = 1152;
      static readonly BIT_STRING = 1153;
      static readonly STRING_CHARSET_NAME = 1154;
      static readonly DOT_ID = 1155;
      static readonly ID = 1156;
      static readonly REVERSE_QUOTE_ID = 1157;
      static readonly HOST_IP_ADDRESS = 1158;
      static readonly LOCAL_ID = 1159;
      static readonly GLOBAL_ID = 1160;
      static readonly ERROR_RECONGNIGION = 1161;
      static readonly channelNames: string[];
      static readonly literalNames: (string | null)[];
      static readonly symbolicNames: (string | null)[];
      static readonly modeNames: string[];
      static readonly ruleNames: string[];
      constructor(input: antlr.CharStream);
      get grammarFileName(): string;
      get literalNames(): (string | null)[];
      get symbolicNames(): (string | null)[];
      get ruleNames(): string[];
      get serializedATN(): number[];
      get channelNames(): string[];
      get modeNames(): string[];
      static readonly _serializedATN: number[];
      private static __ATN;
      static get _ATN(): antlr.ATN;
      private static readonly vocabulary;
      get vocabulary(): antlr.Vocabulary;
      private static readonly decisionsToDFA;
  }

}
declare module 'websql-autocomplete-2/parsers/mysql/generated/MySqlParser' {
  import * as antlr from "antlr4ng";
  import { Token } from "antlr4ng";
  import { MySqlParserListener } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParserListener.js/index";
  import { MySqlParserVisitor } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParserVisitor.js/index";
  export class MySqlParser extends antlr.Parser {
      static readonly SPACE = 1;
      static readonly SPEC_MYSQL_COMMENT = 2;
      static readonly COMMENT_INPUT = 3;
      static readonly LINE_COMMENT = 4;
      static readonly ADD = 5;
      static readonly ALL = 6;
      static readonly ALTER = 7;
      static readonly ALWAYS = 8;
      static readonly ANALYZE = 9;
      static readonly AND = 10;
      static readonly ARRAY = 11;
      static readonly AS = 12;
      static readonly ASC = 13;
      static readonly ATTRIBUTE = 14;
      static readonly BEFORE = 15;
      static readonly BETWEEN = 16;
      static readonly BOTH = 17;
      static readonly BUCKETS = 18;
      static readonly BY = 19;
      static readonly CALL = 20;
      static readonly CASCADE = 21;
      static readonly CASE = 22;
      static readonly CAST = 23;
      static readonly CHANGE = 24;
      static readonly CHARACTER = 25;
      static readonly CHECK = 26;
      static readonly COLLATE = 27;
      static readonly COLUMN = 28;
      static readonly CONDITION = 29;
      static readonly CONSTRAINT = 30;
      static readonly CONTINUE = 31;
      static readonly CONVERT = 32;
      static readonly CREATE = 33;
      static readonly CROSS = 34;
      static readonly CURRENT = 35;
      static readonly CURRENT_ROLE = 36;
      static readonly CURRENT_USER = 37;
      static readonly CURSOR = 38;
      static readonly DATABASE = 39;
      static readonly DATABASES = 40;
      static readonly DECLARE = 41;
      static readonly DEFAULT = 42;
      static readonly DELAYED = 43;
      static readonly DELETE = 44;
      static readonly DESC = 45;
      static readonly DESCRIBE = 46;
      static readonly DETERMINISTIC = 47;
      static readonly DIAGNOSTICS = 48;
      static readonly DISTINCT = 49;
      static readonly DISTINCTROW = 50;
      static readonly DROP = 51;
      static readonly EACH = 52;
      static readonly ELSE = 53;
      static readonly ELSEIF = 54;
      static readonly EMPTY = 55;
      static readonly ENCLOSED = 56;
      static readonly ENFORCED = 57;
      static readonly ESCAPED = 58;
      static readonly EXCEPT = 59;
      static readonly EXISTS = 60;
      static readonly EXIT = 61;
      static readonly EXPLAIN = 62;
      static readonly FALSE = 63;
      static readonly FETCH = 64;
      static readonly FOR = 65;
      static readonly FORCE = 66;
      static readonly FOREIGN = 67;
      static readonly FROM = 68;
      static readonly FULLTEXT = 69;
      static readonly GENERATED = 70;
      static readonly GET = 71;
      static readonly GRANT = 72;
      static readonly GROUP = 73;
      static readonly HAVING = 74;
      static readonly HIGH_PRIORITY = 75;
      static readonly HISTOGRAM = 76;
      static readonly IF = 77;
      static readonly IGNORE = 78;
      static readonly IGNORED = 79;
      static readonly IN = 80;
      static readonly INDEX = 81;
      static readonly INFILE = 82;
      static readonly INNER = 83;
      static readonly INOUT = 84;
      static readonly INSERT = 85;
      static readonly INTERVAL = 86;
      static readonly INTO = 87;
      static readonly IS = 88;
      static readonly ITERATE = 89;
      static readonly JOIN = 90;
      static readonly KEY = 91;
      static readonly KEYS = 92;
      static readonly KILL = 93;
      static readonly LATERAL = 94;
      static readonly LEADING = 95;
      static readonly LEAVE = 96;
      static readonly LEFT = 97;
      static readonly LIKE = 98;
      static readonly LIMIT = 99;
      static readonly LINEAR = 100;
      static readonly LINES = 101;
      static readonly LOAD = 102;
      static readonly LOCK = 103;
      static readonly LOCKED = 104;
      static readonly LOOP = 105;
      static readonly LOW_PRIORITY = 106;
      static readonly MASTER_BIND = 107;
      static readonly MASTER_SSL_VERIFY_SERVER_CERT = 108;
      static readonly MATCH = 109;
      static readonly MAXVALUE = 110;
      static readonly MINVALUE = 111;
      static readonly MODIFIES = 112;
      static readonly NATURAL = 113;
      static readonly NOT = 114;
      static readonly NO_WRITE_TO_BINLOG = 115;
      static readonly NULL_LITERAL = 116;
      static readonly NUMBER = 117;
      static readonly ON = 118;
      static readonly OPTIMIZE = 119;
      static readonly OPTION = 120;
      static readonly OPTIONAL = 121;
      static readonly OPTIONALLY = 122;
      static readonly OR = 123;
      static readonly ORDER = 124;
      static readonly OUT = 125;
      static readonly OUTER = 126;
      static readonly OUTFILE = 127;
      static readonly OVER = 128;
      static readonly PARTITION = 129;
      static readonly PRIMARY = 130;
      static readonly PROCEDURE = 131;
      static readonly PURGE = 132;
      static readonly RANGE = 133;
      static readonly READ = 134;
      static readonly READS = 135;
      static readonly REFERENCES = 136;
      static readonly REGEXP = 137;
      static readonly RELEASE = 138;
      static readonly RENAME = 139;
      static readonly REPEAT = 140;
      static readonly REPLACE = 141;
      static readonly REQUIRE = 142;
      static readonly RESIGNAL = 143;
      static readonly RESTRICT = 144;
      static readonly RETAIN = 145;
      static readonly RETURN = 146;
      static readonly REVOKE = 147;
      static readonly RIGHT = 148;
      static readonly RLIKE = 149;
      static readonly SCHEMA = 150;
      static readonly SCHEMAS = 151;
      static readonly SELECT = 152;
      static readonly SET = 153;
      static readonly SEPARATOR = 154;
      static readonly SHOW = 155;
      static readonly SIGNAL = 156;
      static readonly SKIP_ = 157;
      static readonly SKIP_QUERY_REWRITE = 158;
      static readonly SPATIAL = 159;
      static readonly SQL = 160;
      static readonly SQLEXCEPTION = 161;
      static readonly SQLSTATE = 162;
      static readonly SQLWARNING = 163;
      static readonly SQL_BIG_RESULT = 164;
      static readonly SQL_CALC_FOUND_ROWS = 165;
      static readonly SQL_SMALL_RESULT = 166;
      static readonly SSL = 167;
      static readonly STACKED = 168;
      static readonly STARTING = 169;
      static readonly STATEMENT = 170;
      static readonly STRAIGHT_JOIN = 171;
      static readonly TABLE = 172;
      static readonly TERMINATED = 173;
      static readonly THEN = 174;
      static readonly TO = 175;
      static readonly TRAILING = 176;
      static readonly TRIGGER = 177;
      static readonly TRUE = 178;
      static readonly UNDO = 179;
      static readonly UNION = 180;
      static readonly UNIQUE = 181;
      static readonly UNLOCK = 182;
      static readonly UNSIGNED = 183;
      static readonly UPDATE = 184;
      static readonly USAGE = 185;
      static readonly USE = 186;
      static readonly USING = 187;
      static readonly VALUES = 188;
      static readonly WHEN = 189;
      static readonly WHERE = 190;
      static readonly WHILE = 191;
      static readonly WITH = 192;
      static readonly WRITE = 193;
      static readonly XOR = 194;
      static readonly ZEROFILL = 195;
      static readonly TINYINT = 196;
      static readonly SMALLINT = 197;
      static readonly MEDIUMINT = 198;
      static readonly MIDDLEINT = 199;
      static readonly INT = 200;
      static readonly INT1 = 201;
      static readonly INT2 = 202;
      static readonly INT3 = 203;
      static readonly INT4 = 204;
      static readonly INT8 = 205;
      static readonly INTEGER = 206;
      static readonly BIGINT = 207;
      static readonly REAL = 208;
      static readonly DOUBLE = 209;
      static readonly PRECISION = 210;
      static readonly FLOAT = 211;
      static readonly FLOAT4 = 212;
      static readonly FLOAT8 = 213;
      static readonly DECIMAL = 214;
      static readonly DEC = 215;
      static readonly NUMERIC = 216;
      static readonly DATE = 217;
      static readonly TIME = 218;
      static readonly TIMESTAMP = 219;
      static readonly DATETIME = 220;
      static readonly YEAR = 221;
      static readonly CHAR = 222;
      static readonly VARCHAR = 223;
      static readonly NVARCHAR = 224;
      static readonly NATIONAL = 225;
      static readonly BINARY = 226;
      static readonly VARBINARY = 227;
      static readonly TINYBLOB = 228;
      static readonly BLOB = 229;
      static readonly MEDIUMBLOB = 230;
      static readonly LONG = 231;
      static readonly LONGBLOB = 232;
      static readonly TINYTEXT = 233;
      static readonly TEXT = 234;
      static readonly MEDIUMTEXT = 235;
      static readonly LONGTEXT = 236;
      static readonly ENUM = 237;
      static readonly VARYING = 238;
      static readonly SERIAL = 239;
      static readonly YEAR_MONTH = 240;
      static readonly DAY_HOUR = 241;
      static readonly DAY_MINUTE = 242;
      static readonly DAY_SECOND = 243;
      static readonly HOUR_MINUTE = 244;
      static readonly HOUR_SECOND = 245;
      static readonly MINUTE_SECOND = 246;
      static readonly SECOND_MICROSECOND = 247;
      static readonly MINUTE_MICROSECOND = 248;
      static readonly HOUR_MICROSECOND = 249;
      static readonly DAY_MICROSECOND = 250;
      static readonly JSON_ARRAY = 251;
      static readonly JSON_ARRAYAGG = 252;
      static readonly JSON_ARRAY_APPEND = 253;
      static readonly JSON_ARRAY_INSERT = 254;
      static readonly JSON_CONTAINS = 255;
      static readonly JSON_CONTAINS_PATH = 256;
      static readonly JSON_DEPTH = 257;
      static readonly JSON_EXTRACT = 258;
      static readonly JSON_INSERT = 259;
      static readonly JSON_KEYS = 260;
      static readonly JSON_LENGTH = 261;
      static readonly JSON_MERGE = 262;
      static readonly JSON_MERGE_PATCH = 263;
      static readonly JSON_MERGE_PRESERVE = 264;
      static readonly JSON_OBJECT = 265;
      static readonly JSON_OBJECTAGG = 266;
      static readonly JSON_OVERLAPS = 267;
      static readonly JSON_PRETTY = 268;
      static readonly JSON_QUOTE = 269;
      static readonly JSON_REMOVE = 270;
      static readonly JSON_REPLACE = 271;
      static readonly JSON_SCHEMA_VALID = 272;
      static readonly JSON_SCHEMA_VALIDATION_REPORT = 273;
      static readonly JSON_SEARCH = 274;
      static readonly JSON_SET = 275;
      static readonly JSON_STORAGE_FREE = 276;
      static readonly JSON_STORAGE_SIZE = 277;
      static readonly JSON_TABLE = 278;
      static readonly JSON_TYPE = 279;
      static readonly JSON_UNQUOTE = 280;
      static readonly JSON_VALID = 281;
      static readonly JSON_VALUE = 282;
      static readonly NESTED = 283;
      static readonly ORDINALITY = 284;
      static readonly PATH = 285;
      static readonly AVG = 286;
      static readonly BIT_AND = 287;
      static readonly BIT_OR = 288;
      static readonly BIT_XOR = 289;
      static readonly COUNT = 290;
      static readonly CUME_DIST = 291;
      static readonly DENSE_RANK = 292;
      static readonly FIRST_VALUE = 293;
      static readonly GROUP_CONCAT = 294;
      static readonly LAG = 295;
      static readonly LAST_VALUE = 296;
      static readonly LEAD = 297;
      static readonly MAX = 298;
      static readonly MIN = 299;
      static readonly NTILE = 300;
      static readonly NTH_VALUE = 301;
      static readonly PERCENT_RANK = 302;
      static readonly RANK = 303;
      static readonly ROW_NUMBER = 304;
      static readonly STD = 305;
      static readonly STDDEV = 306;
      static readonly STDDEV_POP = 307;
      static readonly STDDEV_SAMP = 308;
      static readonly SUM = 309;
      static readonly VAR_POP = 310;
      static readonly VAR_SAMP = 311;
      static readonly VARIANCE = 312;
      static readonly CURRENT_DATE = 313;
      static readonly CURRENT_TIME = 314;
      static readonly CURRENT_TIMESTAMP = 315;
      static readonly LOCALTIME = 316;
      static readonly CURDATE = 317;
      static readonly CURTIME = 318;
      static readonly DATE_ADD = 319;
      static readonly DATE_SUB = 320;
      static readonly EXTRACT = 321;
      static readonly LOCALTIMESTAMP = 322;
      static readonly NOW = 323;
      static readonly POSITION = 324;
      static readonly SUBSTR = 325;
      static readonly SUBSTRING = 326;
      static readonly SYSDATE = 327;
      static readonly TRIM = 328;
      static readonly UTC_DATE = 329;
      static readonly UTC_TIME = 330;
      static readonly UTC_TIMESTAMP = 331;
      static readonly ACCOUNT = 332;
      static readonly ACTION = 333;
      static readonly AFTER = 334;
      static readonly AGGREGATE = 335;
      static readonly ALGORITHM = 336;
      static readonly ANY = 337;
      static readonly AT = 338;
      static readonly AUTHORS = 339;
      static readonly AUTOCOMMIT = 340;
      static readonly AUTOEXTEND_SIZE = 341;
      static readonly AUTO_INCREMENT = 342;
      static readonly AVG_ROW_LENGTH = 343;
      static readonly BEGIN = 344;
      static readonly BINLOG = 345;
      static readonly BIT = 346;
      static readonly BLOCK = 347;
      static readonly BOOL = 348;
      static readonly BOOLEAN = 349;
      static readonly BTREE = 350;
      static readonly CACHE = 351;
      static readonly CASCADED = 352;
      static readonly CHAIN = 353;
      static readonly CHANGED = 354;
      static readonly CHANNEL = 355;
      static readonly CHECKSUM = 356;
      static readonly PAGE_CHECKSUM = 357;
      static readonly CIPHER = 358;
      static readonly CLASS_ORIGIN = 359;
      static readonly CLIENT = 360;
      static readonly CLOSE = 361;
      static readonly CLUSTERING = 362;
      static readonly COALESCE = 363;
      static readonly CODE = 364;
      static readonly COLUMNS = 365;
      static readonly COLUMN_FORMAT = 366;
      static readonly COLUMN_NAME = 367;
      static readonly COMMENT = 368;
      static readonly COMMIT = 369;
      static readonly COMPACT = 370;
      static readonly COMPLETION = 371;
      static readonly COMPRESSED = 372;
      static readonly COMPRESSION = 373;
      static readonly CONCURRENT = 374;
      static readonly CONNECT = 375;
      static readonly CONNECTION = 376;
      static readonly CONSISTENT = 377;
      static readonly CONSTRAINT_CATALOG = 378;
      static readonly CONSTRAINT_SCHEMA = 379;
      static readonly CONSTRAINT_NAME = 380;
      static readonly CONTAINS = 381;
      static readonly CONTEXT = 382;
      static readonly CONTRIBUTORS = 383;
      static readonly COPY = 384;
      static readonly CPU = 385;
      static readonly CYCLE = 386;
      static readonly CURSOR_NAME = 387;
      static readonly DATA = 388;
      static readonly DATAFILE = 389;
      static readonly DEALLOCATE = 390;
      static readonly DEFAULT_AUTH = 391;
      static readonly DEFINER = 392;
      static readonly DELAY_KEY_WRITE = 393;
      static readonly DES_KEY_FILE = 394;
      static readonly DIRECTORY = 395;
      static readonly DISABLE = 396;
      static readonly DISCARD = 397;
      static readonly DISK = 398;
      static readonly DO = 399;
      static readonly DUMPFILE = 400;
      static readonly DUPLICATE = 401;
      static readonly DYNAMIC = 402;
      static readonly ENABLE = 403;
      static readonly ENCRYPTED = 404;
      static readonly ENCRYPTION = 405;
      static readonly ENCRYPTION_KEY_ID = 406;
      static readonly END = 407;
      static readonly ENDS = 408;
      static readonly ENGINE = 409;
      static readonly ENGINES = 410;
      static readonly ERROR = 411;
      static readonly ERRORS = 412;
      static readonly ESCAPE = 413;
      static readonly EVEN = 414;
      static readonly EVENT = 415;
      static readonly EVENTS = 416;
      static readonly EVERY = 417;
      static readonly EXCHANGE = 418;
      static readonly EXCLUSIVE = 419;
      static readonly EXPIRE = 420;
      static readonly EXPORT = 421;
      static readonly EXTENDED = 422;
      static readonly EXTENT_SIZE = 423;
      static readonly FAILED_LOGIN_ATTEMPTS = 424;
      static readonly FAST = 425;
      static readonly FAULTS = 426;
      static readonly FIELDS = 427;
      static readonly FILE_BLOCK_SIZE = 428;
      static readonly FILTER = 429;
      static readonly FIRST = 430;
      static readonly FIXED = 431;
      static readonly FLUSH = 432;
      static readonly FOLLOWING = 433;
      static readonly FOLLOWS = 434;
      static readonly FOUND = 435;
      static readonly FULL = 436;
      static readonly FUNCTION = 437;
      static readonly GENERAL = 438;
      static readonly GLOBAL = 439;
      static readonly GRANTS = 440;
      static readonly GROUP_REPLICATION = 441;
      static readonly HANDLER = 442;
      static readonly HASH = 443;
      static readonly HELP = 444;
      static readonly HISTORY = 445;
      static readonly HOST = 446;
      static readonly HOSTS = 447;
      static readonly IDENTIFIED = 448;
      static readonly IGNORE_SERVER_IDS = 449;
      static readonly IMPORT = 450;
      static readonly INCREMENT = 451;
      static readonly INDEXES = 452;
      static readonly INITIAL_SIZE = 453;
      static readonly INPLACE = 454;
      static readonly INSERT_METHOD = 455;
      static readonly INSTALL = 456;
      static readonly INSTANCE = 457;
      static readonly INSTANT = 458;
      static readonly INVISIBLE = 459;
      static readonly INVOKER = 460;
      static readonly IO = 461;
      static readonly IO_THREAD = 462;
      static readonly IPC = 463;
      static readonly ISOLATION = 464;
      static readonly ISSUER = 465;
      static readonly JSON = 466;
      static readonly KEY_BLOCK_SIZE = 467;
      static readonly LANGUAGE = 468;
      static readonly LAST = 469;
      static readonly LEAVES = 470;
      static readonly LESS = 471;
      static readonly LEVEL = 472;
      static readonly LIST = 473;
      static readonly LOCAL = 474;
      static readonly LOGFILE = 475;
      static readonly LOGS = 476;
      static readonly MASTER = 477;
      static readonly MASTER_AUTO_POSITION = 478;
      static readonly MASTER_CONNECT_RETRY = 479;
      static readonly MASTER_DELAY = 480;
      static readonly MASTER_HEARTBEAT_PERIOD = 481;
      static readonly MASTER_HOST = 482;
      static readonly MASTER_LOG_FILE = 483;
      static readonly MASTER_LOG_POS = 484;
      static readonly MASTER_PASSWORD = 485;
      static readonly MASTER_PORT = 486;
      static readonly MASTER_RETRY_COUNT = 487;
      static readonly MASTER_SSL = 488;
      static readonly MASTER_SSL_CA = 489;
      static readonly MASTER_SSL_CAPATH = 490;
      static readonly MASTER_SSL_CERT = 491;
      static readonly MASTER_SSL_CIPHER = 492;
      static readonly MASTER_SSL_CRL = 493;
      static readonly MASTER_SSL_CRLPATH = 494;
      static readonly MASTER_SSL_KEY = 495;
      static readonly MASTER_TLS_VERSION = 496;
      static readonly MASTER_USER = 497;
      static readonly MAX_CONNECTIONS_PER_HOUR = 498;
      static readonly MAX_QUERIES_PER_HOUR = 499;
      static readonly MAX_ROWS = 500;
      static readonly MAX_SIZE = 501;
      static readonly MAX_UPDATES_PER_HOUR = 502;
      static readonly MAX_USER_CONNECTIONS = 503;
      static readonly MEDIUM = 504;
      static readonly MEMBER = 505;
      static readonly MERGE = 506;
      static readonly MESSAGE_TEXT = 507;
      static readonly MID = 508;
      static readonly MIGRATE = 509;
      static readonly MIN_ROWS = 510;
      static readonly MODE = 511;
      static readonly MODIFY = 512;
      static readonly MUTEX = 513;
      static readonly MYSQL = 514;
      static readonly MYSQL_ERRNO = 515;
      static readonly NAME = 516;
      static readonly NAMES = 517;
      static readonly NCHAR = 518;
      static readonly NEVER = 519;
      static readonly NEXT = 520;
      static readonly NO = 521;
      static readonly NOCACHE = 522;
      static readonly NOCOPY = 523;
      static readonly NOCYCLE = 524;
      static readonly NOMAXVALUE = 525;
      static readonly NOMINVALUE = 526;
      static readonly NOWAIT = 527;
      static readonly NODEGROUP = 528;
      static readonly NONE = 529;
      static readonly ODBC = 530;
      static readonly OFFLINE = 531;
      static readonly OFFSET = 532;
      static readonly OF = 533;
      static readonly OJ = 534;
      static readonly OLD_PASSWORD = 535;
      static readonly ONE = 536;
      static readonly ONLINE = 537;
      static readonly ONLY = 538;
      static readonly OPEN = 539;
      static readonly OPTIMIZER_COSTS = 540;
      static readonly OPTIONS = 541;
      static readonly OWNER = 542;
      static readonly PACK_KEYS = 543;
      static readonly PAGE = 544;
      static readonly PAGE_COMPRESSED = 545;
      static readonly PAGE_COMPRESSION_LEVEL = 546;
      static readonly PARSER = 547;
      static readonly PARTIAL = 548;
      static readonly PARTITIONING = 549;
      static readonly PARTITIONS = 550;
      static readonly PASSWORD = 551;
      static readonly PASSWORD_LOCK_TIME = 552;
      static readonly PHASE = 553;
      static readonly PLUGIN = 554;
      static readonly PLUGIN_DIR = 555;
      static readonly PLUGINS = 556;
      static readonly PORT = 557;
      static readonly PRECEDES = 558;
      static readonly PRECEDING = 559;
      static readonly PREPARE = 560;
      static readonly PRESERVE = 561;
      static readonly PREV = 562;
      static readonly PROCESSLIST = 563;
      static readonly PROFILE = 564;
      static readonly PROFILES = 565;
      static readonly PROXY = 566;
      static readonly QUERY = 567;
      static readonly QUICK = 568;
      static readonly REBUILD = 569;
      static readonly RECOVER = 570;
      static readonly RECURSIVE = 571;
      static readonly REDO_BUFFER_SIZE = 572;
      static readonly REDUNDANT = 573;
      static readonly RELAY = 574;
      static readonly RELAY_LOG_FILE = 575;
      static readonly RELAY_LOG_POS = 576;
      static readonly RELAYLOG = 577;
      static readonly REMOVE = 578;
      static readonly REORGANIZE = 579;
      static readonly REPAIR = 580;
      static readonly REPLICATE_DO_DB = 581;
      static readonly REPLICATE_DO_TABLE = 582;
      static readonly REPLICATE_IGNORE_DB = 583;
      static readonly REPLICATE_IGNORE_TABLE = 584;
      static readonly REPLICATE_REWRITE_DB = 585;
      static readonly REPLICATE_WILD_DO_TABLE = 586;
      static readonly REPLICATE_WILD_IGNORE_TABLE = 587;
      static readonly REPLICATION = 588;
      static readonly RESET = 589;
      static readonly RESTART = 590;
      static readonly RESUME = 591;
      static readonly RETURNED_SQLSTATE = 592;
      static readonly RETURNING = 593;
      static readonly RETURNS = 594;
      static readonly REUSE = 595;
      static readonly ROLE = 596;
      static readonly ROLLBACK = 597;
      static readonly ROLLUP = 598;
      static readonly ROTATE = 599;
      static readonly ROW = 600;
      static readonly ROWS = 601;
      static readonly ROW_FORMAT = 602;
      static readonly RTREE = 603;
      static readonly SAVEPOINT = 604;
      static readonly SCHEDULE = 605;
      static readonly SECURITY = 606;
      static readonly SEQUENCE = 607;
      static readonly SERVER = 608;
      static readonly SESSION = 609;
      static readonly SHARE = 610;
      static readonly SHARED = 611;
      static readonly SIGNED = 612;
      static readonly SIMPLE = 613;
      static readonly SLAVE = 614;
      static readonly SLOW = 615;
      static readonly SNAPSHOT = 616;
      static readonly SOCKET = 617;
      static readonly SOME = 618;
      static readonly SONAME = 619;
      static readonly SOUNDS = 620;
      static readonly SOURCE = 621;
      static readonly SQL_AFTER_GTIDS = 622;
      static readonly SQL_AFTER_MTS_GAPS = 623;
      static readonly SQL_BEFORE_GTIDS = 624;
      static readonly SQL_BUFFER_RESULT = 625;
      static readonly SQL_CACHE = 626;
      static readonly SQL_NO_CACHE = 627;
      static readonly SQL_THREAD = 628;
      static readonly START = 629;
      static readonly STARTS = 630;
      static readonly STATS_AUTO_RECALC = 631;
      static readonly STATS_PERSISTENT = 632;
      static readonly STATS_SAMPLE_PAGES = 633;
      static readonly STATUS = 634;
      static readonly STOP = 635;
      static readonly STORAGE = 636;
      static readonly STORED = 637;
      static readonly STRING = 638;
      static readonly SUBCLASS_ORIGIN = 639;
      static readonly SUBJECT = 640;
      static readonly SUBPARTITION = 641;
      static readonly SUBPARTITIONS = 642;
      static readonly SUSPEND = 643;
      static readonly SWAPS = 644;
      static readonly SWITCHES = 645;
      static readonly TABLE_NAME = 646;
      static readonly TABLESPACE = 647;
      static readonly TABLE_TYPE = 648;
      static readonly TEMPORARY = 649;
      static readonly TEMPTABLE = 650;
      static readonly THAN = 651;
      static readonly TRADITIONAL = 652;
      static readonly TRANSACTION = 653;
      static readonly TRANSACTIONAL = 654;
      static readonly TRIGGERS = 655;
      static readonly TRUNCATE = 656;
      static readonly UNBOUNDED = 657;
      static readonly UNDEFINED = 658;
      static readonly UNDOFILE = 659;
      static readonly UNDO_BUFFER_SIZE = 660;
      static readonly UNINSTALL = 661;
      static readonly UNKNOWN = 662;
      static readonly UNTIL = 663;
      static readonly UPGRADE = 664;
      static readonly USER = 665;
      static readonly USE_FRM = 666;
      static readonly USER_RESOURCES = 667;
      static readonly VALIDATION = 668;
      static readonly VALUE = 669;
      static readonly VARIABLES = 670;
      static readonly VIEW = 671;
      static readonly VIRTUAL = 672;
      static readonly VISIBLE = 673;
      static readonly WAIT = 674;
      static readonly WARNINGS = 675;
      static readonly WINDOW = 676;
      static readonly WITHOUT = 677;
      static readonly WORK = 678;
      static readonly WRAPPER = 679;
      static readonly X509 = 680;
      static readonly XA = 681;
      static readonly XML = 682;
      static readonly YES = 683;
      static readonly EUR = 684;
      static readonly USA = 685;
      static readonly JIS = 686;
      static readonly ISO = 687;
      static readonly INTERNAL = 688;
      static readonly QUARTER = 689;
      static readonly MONTH = 690;
      static readonly DAY = 691;
      static readonly HOUR = 692;
      static readonly MINUTE = 693;
      static readonly WEEK = 694;
      static readonly SECOND = 695;
      static readonly MICROSECOND = 696;
      static readonly ADMIN = 697;
      static readonly APPLICATION_PASSWORD_ADMIN = 698;
      static readonly AUDIT_ABORT_EXEMPT = 699;
      static readonly AUDIT_ADMIN = 700;
      static readonly AUTHENTICATION_POLICY_ADMIN = 701;
      static readonly BACKUP_ADMIN = 702;
      static readonly BINLOG_ADMIN = 703;
      static readonly BINLOG_ENCRYPTION_ADMIN = 704;
      static readonly CLONE_ADMIN = 705;
      static readonly CONNECTION_ADMIN = 706;
      static readonly ENCRYPTION_KEY_ADMIN = 707;
      static readonly EXECUTE = 708;
      static readonly FILE = 709;
      static readonly FIREWALL_ADMIN = 710;
      static readonly FIREWALL_EXEMPT = 711;
      static readonly FIREWALL_USER = 712;
      static readonly FLUSH_OPTIMIZER_COSTS = 713;
      static readonly FLUSH_STATUS = 714;
      static readonly FLUSH_TABLES = 715;
      static readonly FLUSH_USER_RESOURCES = 716;
      static readonly GROUP_REPLICATION_ADMIN = 717;
      static readonly INNODB_REDO_LOG_ARCHIVE = 718;
      static readonly INNODB_REDO_LOG_ENABLE = 719;
      static readonly INVOKE = 720;
      static readonly LAMBDA = 721;
      static readonly NDB_STORED_USER = 722;
      static readonly PASSWORDLESS_USER_ADMIN = 723;
      static readonly PERSIST_RO_VARIABLES_ADMIN = 724;
      static readonly PRIVILEGES = 725;
      static readonly PROCESS = 726;
      static readonly RELOAD = 727;
      static readonly REPLICATION_APPLIER = 728;
      static readonly REPLICATION_SLAVE_ADMIN = 729;
      static readonly RESOURCE_GROUP_ADMIN = 730;
      static readonly RESOURCE_GROUP_USER = 731;
      static readonly ROLE_ADMIN = 732;
      static readonly ROUTINE = 733;
      static readonly S3 = 734;
      static readonly SERVICE_CONNECTION_ADMIN = 735;
      static readonly SESSION_VARIABLES_ADMIN = 736;
      static readonly SET_USER_ID = 737;
      static readonly SHOW_ROUTINE = 738;
      static readonly SHUTDOWN = 739;
      static readonly SUPER = 740;
      static readonly SYSTEM_VARIABLES_ADMIN = 741;
      static readonly TABLES = 742;
      static readonly TABLE_ENCRYPTION_ADMIN = 743;
      static readonly VERSION_TOKEN_ADMIN = 744;
      static readonly XA_RECOVER_ADMIN = 745;
      static readonly ARMSCII8 = 746;
      static readonly ASCII = 747;
      static readonly BIG5 = 748;
      static readonly CP1250 = 749;
      static readonly CP1251 = 750;
      static readonly CP1256 = 751;
      static readonly CP1257 = 752;
      static readonly CP850 = 753;
      static readonly CP852 = 754;
      static readonly CP866 = 755;
      static readonly CP932 = 756;
      static readonly DEC8 = 757;
      static readonly EUCJPMS = 758;
      static readonly EUCKR = 759;
      static readonly GB18030 = 760;
      static readonly GB2312 = 761;
      static readonly GBK = 762;
      static readonly GEOSTD8 = 763;
      static readonly GREEK = 764;
      static readonly HEBREW = 765;
      static readonly HP8 = 766;
      static readonly KEYBCS2 = 767;
      static readonly KOI8R = 768;
      static readonly KOI8U = 769;
      static readonly LATIN1 = 770;
      static readonly LATIN2 = 771;
      static readonly LATIN5 = 772;
      static readonly LATIN7 = 773;
      static readonly MACCE = 774;
      static readonly MACROMAN = 775;
      static readonly SJIS = 776;
      static readonly SWE7 = 777;
      static readonly TIS620 = 778;
      static readonly UCS2 = 779;
      static readonly UJIS = 780;
      static readonly UTF16 = 781;
      static readonly UTF16LE = 782;
      static readonly UTF32 = 783;
      static readonly UTF8 = 784;
      static readonly UTF8MB3 = 785;
      static readonly UTF8MB4 = 786;
      static readonly ARCHIVE = 787;
      static readonly BLACKHOLE = 788;
      static readonly CSV = 789;
      static readonly FEDERATED = 790;
      static readonly INNODB = 791;
      static readonly MEMORY = 792;
      static readonly MRG_MYISAM = 793;
      static readonly MYISAM = 794;
      static readonly NDB = 795;
      static readonly NDBCLUSTER = 796;
      static readonly PERFORMANCE_SCHEMA = 797;
      static readonly TOKUDB = 798;
      static readonly REPEATABLE = 799;
      static readonly COMMITTED = 800;
      static readonly UNCOMMITTED = 801;
      static readonly SERIALIZABLE = 802;
      static readonly GEOMETRYCOLLECTION = 803;
      static readonly GEOMCOLLECTION = 804;
      static readonly GEOMETRY = 805;
      static readonly LINESTRING = 806;
      static readonly MULTILINESTRING = 807;
      static readonly MULTIPOINT = 808;
      static readonly MULTIPOLYGON = 809;
      static readonly POINT = 810;
      static readonly POLYGON = 811;
      static readonly ABS = 812;
      static readonly ACOS = 813;
      static readonly ADDDATE = 814;
      static readonly ADDTIME = 815;
      static readonly AES_DECRYPT = 816;
      static readonly AES_ENCRYPT = 817;
      static readonly AREA = 818;
      static readonly ASBINARY = 819;
      static readonly ASIN = 820;
      static readonly ASTEXT = 821;
      static readonly ASWKB = 822;
      static readonly ASWKT = 823;
      static readonly ASYMMETRIC_DECRYPT = 824;
      static readonly ASYMMETRIC_DERIVE = 825;
      static readonly ASYMMETRIC_ENCRYPT = 826;
      static readonly ASYMMETRIC_SIGN = 827;
      static readonly ASYMMETRIC_VERIFY = 828;
      static readonly ATAN = 829;
      static readonly ATAN2 = 830;
      static readonly BENCHMARK = 831;
      static readonly BIN = 832;
      static readonly BIT_COUNT = 833;
      static readonly BIT_LENGTH = 834;
      static readonly BUFFER = 835;
      static readonly CATALOG_NAME = 836;
      static readonly CEIL = 837;
      static readonly CEILING = 838;
      static readonly CENTROID = 839;
      static readonly CHARACTER_LENGTH = 840;
      static readonly CHARSET = 841;
      static readonly CHAR_LENGTH = 842;
      static readonly COERCIBILITY = 843;
      static readonly COLLATION = 844;
      static readonly COMPRESS = 845;
      static readonly CONCAT = 846;
      static readonly CONCAT_WS = 847;
      static readonly CONNECTION_ID = 848;
      static readonly CONV = 849;
      static readonly CONVERT_TZ = 850;
      static readonly COS = 851;
      static readonly COT = 852;
      static readonly CRC32 = 853;
      static readonly CREATE_ASYMMETRIC_PRIV_KEY = 854;
      static readonly CREATE_ASYMMETRIC_PUB_KEY = 855;
      static readonly CREATE_DH_PARAMETERS = 856;
      static readonly CREATE_DIGEST = 857;
      static readonly CROSSES = 858;
      static readonly DATEDIFF = 859;
      static readonly DATE_FORMAT = 860;
      static readonly DAYNAME = 861;
      static readonly DAYOFMONTH = 862;
      static readonly DAYOFWEEK = 863;
      static readonly DAYOFYEAR = 864;
      static readonly DECODE = 865;
      static readonly DEGREES = 866;
      static readonly DES_DECRYPT = 867;
      static readonly DES_ENCRYPT = 868;
      static readonly DIMENSION = 869;
      static readonly DISJOINT = 870;
      static readonly ELT = 871;
      static readonly ENCODE = 872;
      static readonly ENCRYPT = 873;
      static readonly ENDPOINT = 874;
      static readonly ENGINE_ATTRIBUTE = 875;
      static readonly ENVELOPE = 876;
      static readonly EQUALS = 877;
      static readonly EXP = 878;
      static readonly EXPORT_SET = 879;
      static readonly EXTERIORRING = 880;
      static readonly EXTRACTVALUE = 881;
      static readonly FIELD = 882;
      static readonly FIND_IN_SET = 883;
      static readonly FLOOR = 884;
      static readonly FORMAT = 885;
      static readonly FOUND_ROWS = 886;
      static readonly FROM_BASE64 = 887;
      static readonly FROM_DAYS = 888;
      static readonly FROM_UNIXTIME = 889;
      static readonly GEOMCOLLFROMTEXT = 890;
      static readonly GEOMCOLLFROMWKB = 891;
      static readonly GEOMETRYCOLLECTIONFROMTEXT = 892;
      static readonly GEOMETRYCOLLECTIONFROMWKB = 893;
      static readonly GEOMETRYFROMTEXT = 894;
      static readonly GEOMETRYFROMWKB = 895;
      static readonly GEOMETRYN = 896;
      static readonly GEOMETRYTYPE = 897;
      static readonly GEOMFROMTEXT = 898;
      static readonly GEOMFROMWKB = 899;
      static readonly GET_FORMAT = 900;
      static readonly GET_LOCK = 901;
      static readonly GLENGTH = 902;
      static readonly GREATEST = 903;
      static readonly GTID_SUBSET = 904;
      static readonly GTID_SUBTRACT = 905;
      static readonly HEX = 906;
      static readonly IFNULL = 907;
      static readonly INET6_ATON = 908;
      static readonly INET6_NTOA = 909;
      static readonly INET_ATON = 910;
      static readonly INET_NTOA = 911;
      static readonly INSTR = 912;
      static readonly INTERIORRINGN = 913;
      static readonly INTERSECTS = 914;
      static readonly ISCLOSED = 915;
      static readonly ISEMPTY = 916;
      static readonly ISNULL = 917;
      static readonly ISSIMPLE = 918;
      static readonly IS_FREE_LOCK = 919;
      static readonly IS_IPV4 = 920;
      static readonly IS_IPV4_COMPAT = 921;
      static readonly IS_IPV4_MAPPED = 922;
      static readonly IS_IPV6 = 923;
      static readonly IS_USED_LOCK = 924;
      static readonly LAST_INSERT_ID = 925;
      static readonly LCASE = 926;
      static readonly LEAST = 927;
      static readonly LENGTH = 928;
      static readonly LINEFROMTEXT = 929;
      static readonly LINEFROMWKB = 930;
      static readonly LINESTRINGFROMTEXT = 931;
      static readonly LINESTRINGFROMWKB = 932;
      static readonly LN = 933;
      static readonly LOAD_FILE = 934;
      static readonly LOCATE = 935;
      static readonly LOG = 936;
      static readonly LOG10 = 937;
      static readonly LOG2 = 938;
      static readonly LOWER = 939;
      static readonly LPAD = 940;
      static readonly LTRIM = 941;
      static readonly MAKEDATE = 942;
      static readonly MAKETIME = 943;
      static readonly MAKE_SET = 944;
      static readonly MASTER_POS_WAIT = 945;
      static readonly MBRCONTAINS = 946;
      static readonly MBRDISJOINT = 947;
      static readonly MBREQUAL = 948;
      static readonly MBRINTERSECTS = 949;
      static readonly MBROVERLAPS = 950;
      static readonly MBRTOUCHES = 951;
      static readonly MBRWITHIN = 952;
      static readonly MD5 = 953;
      static readonly MLINEFROMTEXT = 954;
      static readonly MLINEFROMWKB = 955;
      static readonly MONTHNAME = 956;
      static readonly MPOINTFROMTEXT = 957;
      static readonly MPOINTFROMWKB = 958;
      static readonly MPOLYFROMTEXT = 959;
      static readonly MPOLYFROMWKB = 960;
      static readonly MULTILINESTRINGFROMTEXT = 961;
      static readonly MULTILINESTRINGFROMWKB = 962;
      static readonly MULTIPOINTFROMTEXT = 963;
      static readonly MULTIPOINTFROMWKB = 964;
      static readonly MULTIPOLYGONFROMTEXT = 965;
      static readonly MULTIPOLYGONFROMWKB = 966;
      static readonly NAME_CONST = 967;
      static readonly NULLIF = 968;
      static readonly NUMGEOMETRIES = 969;
      static readonly NUMINTERIORRINGS = 970;
      static readonly NUMPOINTS = 971;
      static readonly OCT = 972;
      static readonly OCTET_LENGTH = 973;
      static readonly ORD = 974;
      static readonly OVERLAPS = 975;
      static readonly PERIOD_ADD = 976;
      static readonly PERIOD_DIFF = 977;
      static readonly PI = 978;
      static readonly POINTFROMTEXT = 979;
      static readonly POINTFROMWKB = 980;
      static readonly POINTN = 981;
      static readonly POLYFROMTEXT = 982;
      static readonly POLYFROMWKB = 983;
      static readonly POLYGONFROMTEXT = 984;
      static readonly POLYGONFROMWKB = 985;
      static readonly POW = 986;
      static readonly POWER = 987;
      static readonly QUOTE = 988;
      static readonly RADIANS = 989;
      static readonly RAND = 990;
      static readonly RANDOM = 991;
      static readonly RANDOM_BYTES = 992;
      static readonly RELEASE_LOCK = 993;
      static readonly REVERSE = 994;
      static readonly ROUND = 995;
      static readonly ROW_COUNT = 996;
      static readonly RPAD = 997;
      static readonly RTRIM = 998;
      static readonly SEC_TO_TIME = 999;
      static readonly SECONDARY_ENGINE_ATTRIBUTE = 1000;
      static readonly SESSION_USER = 1001;
      static readonly SHA = 1002;
      static readonly SHA1 = 1003;
      static readonly SHA2 = 1004;
      static readonly SCHEMA_NAME = 1005;
      static readonly SIGN = 1006;
      static readonly SIN = 1007;
      static readonly SLEEP = 1008;
      static readonly SOUNDEX = 1009;
      static readonly SQL_THREAD_WAIT_AFTER_GTIDS = 1010;
      static readonly SQRT = 1011;
      static readonly SRID = 1012;
      static readonly STARTPOINT = 1013;
      static readonly STRCMP = 1014;
      static readonly STR_TO_DATE = 1015;
      static readonly ST_AREA = 1016;
      static readonly ST_ASBINARY = 1017;
      static readonly ST_ASTEXT = 1018;
      static readonly ST_ASWKB = 1019;
      static readonly ST_ASWKT = 1020;
      static readonly ST_BUFFER = 1021;
      static readonly ST_CENTROID = 1022;
      static readonly ST_CONTAINS = 1023;
      static readonly ST_CROSSES = 1024;
      static readonly ST_DIFFERENCE = 1025;
      static readonly ST_DIMENSION = 1026;
      static readonly ST_DISJOINT = 1027;
      static readonly ST_DISTANCE = 1028;
      static readonly ST_ENDPOINT = 1029;
      static readonly ST_ENVELOPE = 1030;
      static readonly ST_EQUALS = 1031;
      static readonly ST_EXTERIORRING = 1032;
      static readonly ST_GEOMCOLLFROMTEXT = 1033;
      static readonly ST_GEOMCOLLFROMTXT = 1034;
      static readonly ST_GEOMCOLLFROMWKB = 1035;
      static readonly ST_GEOMETRYCOLLECTIONFROMTEXT = 1036;
      static readonly ST_GEOMETRYCOLLECTIONFROMWKB = 1037;
      static readonly ST_GEOMETRYFROMTEXT = 1038;
      static readonly ST_GEOMETRYFROMWKB = 1039;
      static readonly ST_GEOMETRYN = 1040;
      static readonly ST_GEOMETRYTYPE = 1041;
      static readonly ST_GEOMFROMTEXT = 1042;
      static readonly ST_GEOMFROMWKB = 1043;
      static readonly ST_INTERIORRINGN = 1044;
      static readonly ST_INTERSECTION = 1045;
      static readonly ST_INTERSECTS = 1046;
      static readonly ST_ISCLOSED = 1047;
      static readonly ST_ISEMPTY = 1048;
      static readonly ST_ISSIMPLE = 1049;
      static readonly ST_LINEFROMTEXT = 1050;
      static readonly ST_LINEFROMWKB = 1051;
      static readonly ST_LINESTRINGFROMTEXT = 1052;
      static readonly ST_LINESTRINGFROMWKB = 1053;
      static readonly ST_NUMGEOMETRIES = 1054;
      static readonly ST_NUMINTERIORRING = 1055;
      static readonly ST_NUMINTERIORRINGS = 1056;
      static readonly ST_NUMPOINTS = 1057;
      static readonly ST_OVERLAPS = 1058;
      static readonly ST_POINTFROMTEXT = 1059;
      static readonly ST_POINTFROMWKB = 1060;
      static readonly ST_POINTN = 1061;
      static readonly ST_POLYFROMTEXT = 1062;
      static readonly ST_POLYFROMWKB = 1063;
      static readonly ST_POLYGONFROMTEXT = 1064;
      static readonly ST_POLYGONFROMWKB = 1065;
      static readonly ST_SRID = 1066;
      static readonly ST_STARTPOINT = 1067;
      static readonly ST_SYMDIFFERENCE = 1068;
      static readonly ST_TOUCHES = 1069;
      static readonly ST_UNION = 1070;
      static readonly ST_WITHIN = 1071;
      static readonly ST_X = 1072;
      static readonly ST_Y = 1073;
      static readonly SUBDATE = 1074;
      static readonly SUBSTRING_INDEX = 1075;
      static readonly SUBTIME = 1076;
      static readonly SYSTEM_USER = 1077;
      static readonly TAN = 1078;
      static readonly TIMEDIFF = 1079;
      static readonly TIMESTAMPADD = 1080;
      static readonly TIMESTAMPDIFF = 1081;
      static readonly TIME_FORMAT = 1082;
      static readonly TIME_TO_SEC = 1083;
      static readonly TOUCHES = 1084;
      static readonly TO_BASE64 = 1085;
      static readonly TO_DAYS = 1086;
      static readonly TO_SECONDS = 1087;
      static readonly TP_CONNECTION_ADMIN = 1088;
      static readonly UCASE = 1089;
      static readonly UNCOMPRESS = 1090;
      static readonly UNCOMPRESSED_LENGTH = 1091;
      static readonly UNHEX = 1092;
      static readonly UNIX_TIMESTAMP = 1093;
      static readonly UPDATEXML = 1094;
      static readonly UPPER = 1095;
      static readonly UUID = 1096;
      static readonly UUID_SHORT = 1097;
      static readonly VALIDATE_PASSWORD_STRENGTH = 1098;
      static readonly VERSION = 1099;
      static readonly WAIT_UNTIL_SQL_THREAD_AFTER_GTIDS = 1100;
      static readonly WEEKDAY = 1101;
      static readonly WEEKOFYEAR = 1102;
      static readonly WEIGHT_STRING = 1103;
      static readonly WITHIN = 1104;
      static readonly YEARWEEK = 1105;
      static readonly Y_FUNCTION = 1106;
      static readonly X_FUNCTION = 1107;
      static readonly VAR_ASSIGN = 1108;
      static readonly PLUS_ASSIGN = 1109;
      static readonly MINUS_ASSIGN = 1110;
      static readonly MULT_ASSIGN = 1111;
      static readonly DIV_ASSIGN = 1112;
      static readonly MOD_ASSIGN = 1113;
      static readonly AND_ASSIGN = 1114;
      static readonly XOR_ASSIGN = 1115;
      static readonly OR_ASSIGN = 1116;
      static readonly STAR = 1117;
      static readonly DIVIDE = 1118;
      static readonly MODULE = 1119;
      static readonly PLUS = 1120;
      static readonly MINUS = 1121;
      static readonly DIV = 1122;
      static readonly MOD = 1123;
      static readonly EQUAL_SYMBOL = 1124;
      static readonly GREATER_SYMBOL = 1125;
      static readonly LESS_SYMBOL = 1126;
      static readonly EXCLAMATION_SYMBOL = 1127;
      static readonly BIT_NOT_OP = 1128;
      static readonly BIT_OR_OP = 1129;
      static readonly BIT_AND_OP = 1130;
      static readonly BIT_XOR_OP = 1131;
      static readonly DOT = 1132;
      static readonly LR_BRACKET = 1133;
      static readonly RR_BRACKET = 1134;
      static readonly COMMA = 1135;
      static readonly SEMI = 1136;
      static readonly AT_SIGN = 1137;
      static readonly ZERO_DECIMAL = 1138;
      static readonly ONE_DECIMAL = 1139;
      static readonly TWO_DECIMAL = 1140;
      static readonly SINGLE_QUOTE_SYMB = 1141;
      static readonly DOUBLE_QUOTE_SYMB = 1142;
      static readonly REVERSE_QUOTE_SYMB = 1143;
      static readonly COLON_SYMB = 1144;
      static readonly CHARSET_REVERSE_QOUTE_STRING = 1145;
      static readonly FILESIZE_LITERAL = 1146;
      static readonly START_NATIONAL_STRING_LITERAL = 1147;
      static readonly STRING_LITERAL = 1148;
      static readonly DECIMAL_LITERAL = 1149;
      static readonly HEXADECIMAL_LITERAL = 1150;
      static readonly REAL_LITERAL = 1151;
      static readonly NULL_SPEC_LITERAL = 1152;
      static readonly BIT_STRING = 1153;
      static readonly STRING_CHARSET_NAME = 1154;
      static readonly DOT_ID = 1155;
      static readonly ID = 1156;
      static readonly REVERSE_QUOTE_ID = 1157;
      static readonly HOST_IP_ADDRESS = 1158;
      static readonly LOCAL_ID = 1159;
      static readonly GLOBAL_ID = 1160;
      static readonly ERROR_RECONGNIGION = 1161;
      static readonly RULE_root = 0;
      static readonly RULE_sqlStatements = 1;
      static readonly RULE_sqlStatement = 2;
      static readonly RULE_emptyStatement_ = 3;
      static readonly RULE_ddlStatement = 4;
      static readonly RULE_dmlStatement = 5;
      static readonly RULE_transactionStatement = 6;
      static readonly RULE_replicationStatement = 7;
      static readonly RULE_preparedStatement = 8;
      static readonly RULE_compoundStatement = 9;
      static readonly RULE_administrationStatement = 10;
      static readonly RULE_utilityStatement = 11;
      static readonly RULE_createDatabase = 12;
      static readonly RULE_createEvent = 13;
      static readonly RULE_createIndex = 14;
      static readonly RULE_createLogfileGroup = 15;
      static readonly RULE_createProcedure = 16;
      static readonly RULE_createFunction = 17;
      static readonly RULE_createRole = 18;
      static readonly RULE_createServer = 19;
      static readonly RULE_createTable = 20;
      static readonly RULE_createTablespaceInnodb = 21;
      static readonly RULE_createTablespaceNdb = 22;
      static readonly RULE_createTrigger = 23;
      static readonly RULE_withClause = 24;
      static readonly RULE_commonTableExpressions = 25;
      static readonly RULE_cteName = 26;
      static readonly RULE_cteColumnName = 27;
      static readonly RULE_createView = 28;
      static readonly RULE_createDatabaseOption = 29;
      static readonly RULE_charSet = 30;
      static readonly RULE_currentUserExpression = 31;
      static readonly RULE_ownerStatement = 32;
      static readonly RULE_scheduleExpression = 33;
      static readonly RULE_timestampValue = 34;
      static readonly RULE_intervalExpr = 35;
      static readonly RULE_intervalType = 36;
      static readonly RULE_enableType = 37;
      static readonly RULE_indexType = 38;
      static readonly RULE_indexOption = 39;
      static readonly RULE_procedureParameter = 40;
      static readonly RULE_functionParameter = 41;
      static readonly RULE_routineOption = 42;
      static readonly RULE_serverOption = 43;
      static readonly RULE_createDefinitions = 44;
      static readonly RULE_createDefinition = 45;
      static readonly RULE_columnDefinition = 46;
      static readonly RULE_columnConstraint = 47;
      static readonly RULE_tableConstraint = 48;
      static readonly RULE_referenceDefinition = 49;
      static readonly RULE_referenceAction = 50;
      static readonly RULE_referenceControlType = 51;
      static readonly RULE_indexColumnDefinition = 52;
      static readonly RULE_tableOption = 53;
      static readonly RULE_tableType = 54;
      static readonly RULE_tablespaceStorage = 55;
      static readonly RULE_partitionDefinitions = 56;
      static readonly RULE_partitionFunctionDefinition = 57;
      static readonly RULE_subpartitionFunctionDefinition = 58;
      static readonly RULE_partitionDefinition = 59;
      static readonly RULE_partitionDefinerAtom = 60;
      static readonly RULE_partitionDefinerVector = 61;
      static readonly RULE_subpartitionDefinition = 62;
      static readonly RULE_partitionOption = 63;
      static readonly RULE_alterDatabase = 64;
      static readonly RULE_alterEvent = 65;
      static readonly RULE_alterFunction = 66;
      static readonly RULE_alterInstance = 67;
      static readonly RULE_alterLogfileGroup = 68;
      static readonly RULE_alterProcedure = 69;
      static readonly RULE_alterServer = 70;
      static readonly RULE_alterTable = 71;
      static readonly RULE_alterTablespace = 72;
      static readonly RULE_alterView = 73;
      static readonly RULE_alterSpecification = 74;
      static readonly RULE_alterPartitionSpecification = 75;
      static readonly RULE_dropDatabase = 76;
      static readonly RULE_dropEvent = 77;
      static readonly RULE_dropIndex = 78;
      static readonly RULE_dropLogfileGroup = 79;
      static readonly RULE_dropProcedure = 80;
      static readonly RULE_dropFunction = 81;
      static readonly RULE_dropServer = 82;
      static readonly RULE_dropTable = 83;
      static readonly RULE_dropTablespace = 84;
      static readonly RULE_dropTrigger = 85;
      static readonly RULE_dropView = 86;
      static readonly RULE_dropRole = 87;
      static readonly RULE_setRole = 88;
      static readonly RULE_renameTable = 89;
      static readonly RULE_renameTableClause = 90;
      static readonly RULE_truncateTable = 91;
      static readonly RULE_callStatement = 92;
      static readonly RULE_deleteStatement = 93;
      static readonly RULE_doStatement = 94;
      static readonly RULE_handlerStatement = 95;
      static readonly RULE_insertStatement = 96;
      static readonly RULE_loadDataStatement = 97;
      static readonly RULE_loadXmlStatement = 98;
      static readonly RULE_replaceStatement = 99;
      static readonly RULE_selectStatement = 100;
      static readonly RULE_updateStatement = 101;
      static readonly RULE_valuesStatement = 102;
      static readonly RULE_insertStatementValue = 103;
      static readonly RULE_updatedElement = 104;
      static readonly RULE_assignmentField = 105;
      static readonly RULE_lockClause = 106;
      static readonly RULE_singleDeleteStatement = 107;
      static readonly RULE_multipleDeleteStatement = 108;
      static readonly RULE_handlerOpenStatement = 109;
      static readonly RULE_handlerReadIndexStatement = 110;
      static readonly RULE_handlerReadStatement = 111;
      static readonly RULE_handlerCloseStatement = 112;
      static readonly RULE_singleUpdateStatement = 113;
      static readonly RULE_multipleUpdateStatement = 114;
      static readonly RULE_orderByClause = 115;
      static readonly RULE_orderByExpression = 116;
      static readonly RULE_tableSources = 117;
      static readonly RULE_tableSource = 118;
      static readonly RULE_tableSourceItem = 119;
      static readonly RULE_indexHint = 120;
      static readonly RULE_indexHintType = 121;
      static readonly RULE_joinPart = 122;
      static readonly RULE_joinSpec = 123;
      static readonly RULE_queryExpression = 124;
      static readonly RULE_queryExpressionNointo = 125;
      static readonly RULE_querySpecification = 126;
      static readonly RULE_querySpecificationNointo = 127;
      static readonly RULE_unionParenthesis = 128;
      static readonly RULE_unionStatement = 129;
      static readonly RULE_lateralStatement = 130;
      static readonly RULE_jsonTable = 131;
      static readonly RULE_jsonColumnList = 132;
      static readonly RULE_jsonColumn = 133;
      static readonly RULE_jsonOnEmpty = 134;
      static readonly RULE_jsonOnError = 135;
      static readonly RULE_selectSpec = 136;
      static readonly RULE_selectElements = 137;
      static readonly RULE_selectElement = 138;
      static readonly RULE_selectIntoExpression = 139;
      static readonly RULE_selectFieldsInto = 140;
      static readonly RULE_selectLinesInto = 141;
      static readonly RULE_fromClause = 142;
      static readonly RULE_groupByClause = 143;
      static readonly RULE_havingClause = 144;
      static readonly RULE_windowClause = 145;
      static readonly RULE_groupByItem = 146;
      static readonly RULE_limitClause = 147;
      static readonly RULE_limitClauseAtom = 148;
      static readonly RULE_startTransaction = 149;
      static readonly RULE_beginWork = 150;
      static readonly RULE_commitWork = 151;
      static readonly RULE_rollbackWork = 152;
      static readonly RULE_savepointStatement = 153;
      static readonly RULE_rollbackStatement = 154;
      static readonly RULE_releaseStatement = 155;
      static readonly RULE_lockTables = 156;
      static readonly RULE_unlockTables = 157;
      static readonly RULE_setAutocommitStatement = 158;
      static readonly RULE_setTransactionStatement = 159;
      static readonly RULE_transactionMode = 160;
      static readonly RULE_lockTableElement = 161;
      static readonly RULE_lockAction = 162;
      static readonly RULE_transactionOption = 163;
      static readonly RULE_transactionLevel = 164;
      static readonly RULE_changeMaster = 165;
      static readonly RULE_changeReplicationFilter = 166;
      static readonly RULE_purgeBinaryLogs = 167;
      static readonly RULE_resetMaster = 168;
      static readonly RULE_resetSlave = 169;
      static readonly RULE_startSlave = 170;
      static readonly RULE_stopSlave = 171;
      static readonly RULE_startGroupReplication = 172;
      static readonly RULE_stopGroupReplication = 173;
      static readonly RULE_masterOption = 174;
      static readonly RULE_stringMasterOption = 175;
      static readonly RULE_decimalMasterOption = 176;
      static readonly RULE_boolMasterOption = 177;
      static readonly RULE_channelOption = 178;
      static readonly RULE_replicationFilter = 179;
      static readonly RULE_tablePair = 180;
      static readonly RULE_threadType = 181;
      static readonly RULE_untilOption = 182;
      static readonly RULE_connectionOption = 183;
      static readonly RULE_gtuidSet = 184;
      static readonly RULE_xaStartTransaction = 185;
      static readonly RULE_xaEndTransaction = 186;
      static readonly RULE_xaPrepareStatement = 187;
      static readonly RULE_xaCommitWork = 188;
      static readonly RULE_xaRollbackWork = 189;
      static readonly RULE_xaRecoverWork = 190;
      static readonly RULE_prepareStatement = 191;
      static readonly RULE_executeStatement = 192;
      static readonly RULE_deallocatePrepare = 193;
      static readonly RULE_routineBody = 194;
      static readonly RULE_blockStatement = 195;
      static readonly RULE_caseStatement = 196;
      static readonly RULE_ifStatement = 197;
      static readonly RULE_iterateStatement = 198;
      static readonly RULE_leaveStatement = 199;
      static readonly RULE_loopStatement = 200;
      static readonly RULE_repeatStatement = 201;
      static readonly RULE_returnStatement = 202;
      static readonly RULE_whileStatement = 203;
      static readonly RULE_cursorStatement = 204;
      static readonly RULE_declareVariable = 205;
      static readonly RULE_declareCondition = 206;
      static readonly RULE_declareCursor = 207;
      static readonly RULE_declareHandler = 208;
      static readonly RULE_handlerConditionValue = 209;
      static readonly RULE_procedureSqlStatement = 210;
      static readonly RULE_caseAlternative = 211;
      static readonly RULE_elifAlternative = 212;
      static readonly RULE_alterUser = 213;
      static readonly RULE_createUser = 214;
      static readonly RULE_dropUser = 215;
      static readonly RULE_grantStatement = 216;
      static readonly RULE_roleOption = 217;
      static readonly RULE_grantProxy = 218;
      static readonly RULE_renameUser = 219;
      static readonly RULE_revokeStatement = 220;
      static readonly RULE_revokeProxy = 221;
      static readonly RULE_setPasswordStatement = 222;
      static readonly RULE_userSpecification = 223;
      static readonly RULE_userAuthOption = 224;
      static readonly RULE_authOptionClause = 225;
      static readonly RULE_authenticationRule = 226;
      static readonly RULE_tlsOption = 227;
      static readonly RULE_userResourceOption = 228;
      static readonly RULE_userPasswordOption = 229;
      static readonly RULE_userLockOption = 230;
      static readonly RULE_privelegeClause = 231;
      static readonly RULE_privilege = 232;
      static readonly RULE_privilegeLevel = 233;
      static readonly RULE_renameUserClause = 234;
      static readonly RULE_analyzeTable = 235;
      static readonly RULE_checkTable = 236;
      static readonly RULE_checksumTable = 237;
      static readonly RULE_optimizeTable = 238;
      static readonly RULE_repairTable = 239;
      static readonly RULE_checkTableOption = 240;
      static readonly RULE_createUdfunction = 241;
      static readonly RULE_installPlugin = 242;
      static readonly RULE_uninstallPlugin = 243;
      static readonly RULE_setStatement = 244;
      static readonly RULE_showStatement = 245;
      static readonly RULE_variableClause = 246;
      static readonly RULE_showCommonEntity = 247;
      static readonly RULE_showFilter = 248;
      static readonly RULE_showGlobalInfoClause = 249;
      static readonly RULE_showSchemaEntity = 250;
      static readonly RULE_showProfileType = 251;
      static readonly RULE_binlogStatement = 252;
      static readonly RULE_cacheIndexStatement = 253;
      static readonly RULE_flushStatement = 254;
      static readonly RULE_killStatement = 255;
      static readonly RULE_loadIndexIntoCache = 256;
      static readonly RULE_resetStatement = 257;
      static readonly RULE_shutdownStatement = 258;
      static readonly RULE_tableIndexes = 259;
      static readonly RULE_flushOption = 260;
      static readonly RULE_flushTableOption = 261;
      static readonly RULE_loadedTableIndexes = 262;
      static readonly RULE_simpleDescribeStatement = 263;
      static readonly RULE_fullDescribeStatement = 264;
      static readonly RULE_helpStatement = 265;
      static readonly RULE_useStatement = 266;
      static readonly RULE_signalStatement = 267;
      static readonly RULE_resignalStatement = 268;
      static readonly RULE_signalConditionInformation = 269;
      static readonly RULE_withStatement = 270;
      static readonly RULE_tableStatement = 271;
      static readonly RULE_diagnosticsStatement = 272;
      static readonly RULE_diagnosticsConditionInformationName = 273;
      static readonly RULE_describeObjectClause = 274;
      static readonly RULE_fullId = 275;
      static readonly RULE_tableName = 276;
      static readonly RULE_roleName = 277;
      static readonly RULE_fullColumnName = 278;
      static readonly RULE_indexColumnName = 279;
      static readonly RULE_simpleUserName = 280;
      static readonly RULE_hostName = 281;
      static readonly RULE_userName = 282;
      static readonly RULE_mysqlVariable = 283;
      static readonly RULE_charsetName = 284;
      static readonly RULE_collationName = 285;
      static readonly RULE_engineName = 286;
      static readonly RULE_engineNameBase = 287;
      static readonly RULE_uuidSet = 288;
      static readonly RULE_xid = 289;
      static readonly RULE_xuidStringId = 290;
      static readonly RULE_authPlugin = 291;
      static readonly RULE_uid = 292;
      static readonly RULE_simpleId = 293;
      static readonly RULE_dottedId = 294;
      static readonly RULE_decimalLiteral = 295;
      static readonly RULE_fileSizeLiteral = 296;
      static readonly RULE_stringLiteral = 297;
      static readonly RULE_booleanLiteral = 298;
      static readonly RULE_hexadecimalLiteral = 299;
      static readonly RULE_nullNotnull = 300;
      static readonly RULE_constant = 301;
      static readonly RULE_dataType = 302;
      static readonly RULE_collectionOptions = 303;
      static readonly RULE_convertedDataType = 304;
      static readonly RULE_lengthOneDimension = 305;
      static readonly RULE_lengthTwoDimension = 306;
      static readonly RULE_lengthTwoOptionalDimension = 307;
      static readonly RULE_uidList = 308;
      static readonly RULE_fullColumnNameList = 309;
      static readonly RULE_tables = 310;
      static readonly RULE_indexColumnNames = 311;
      static readonly RULE_expressions = 312;
      static readonly RULE_expressionsWithDefaults = 313;
      static readonly RULE_constants = 314;
      static readonly RULE_simpleStrings = 315;
      static readonly RULE_userVariables = 316;
      static readonly RULE_defaultValue = 317;
      static readonly RULE_currentTimestamp = 318;
      static readonly RULE_expressionOrDefault = 319;
      static readonly RULE_ifExists = 320;
      static readonly RULE_ifNotExists = 321;
      static readonly RULE_orReplace = 322;
      static readonly RULE_waitNowaitClause = 323;
      static readonly RULE_functionCall = 324;
      static readonly RULE_specificFunction = 325;
      static readonly RULE_caseFuncAlternative = 326;
      static readonly RULE_levelsInWeightString = 327;
      static readonly RULE_levelInWeightListElement = 328;
      static readonly RULE_aggregateWindowedFunction = 329;
      static readonly RULE_nonAggregateWindowedFunction = 330;
      static readonly RULE_overClause = 331;
      static readonly RULE_windowSpec = 332;
      static readonly RULE_windowName = 333;
      static readonly RULE_frameClause = 334;
      static readonly RULE_frameUnits = 335;
      static readonly RULE_frameExtent = 336;
      static readonly RULE_frameBetween = 337;
      static readonly RULE_frameRange = 338;
      static readonly RULE_partitionClause = 339;
      static readonly RULE_scalarFunctionName = 340;
      static readonly RULE_passwordFunctionClause = 341;
      static readonly RULE_functionArgs = 342;
      static readonly RULE_functionArg = 343;
      static readonly RULE_expression = 344;
      static readonly RULE_predicate = 345;
      static readonly RULE_expressionAtom = 346;
      static readonly RULE_unaryOperator = 347;
      static readonly RULE_comparisonOperator = 348;
      static readonly RULE_logicalOperator = 349;
      static readonly RULE_bitOperator = 350;
      static readonly RULE_multOperator = 351;
      static readonly RULE_addOperator = 352;
      static readonly RULE_jsonOperator = 353;
      static readonly RULE_charsetNameBase = 354;
      static readonly RULE_transactionLevelBase = 355;
      static readonly RULE_privilegesBase = 356;
      static readonly RULE_intervalTypeBase = 357;
      static readonly RULE_dataTypeBase = 358;
      static readonly RULE_keywordsCanBeId = 359;
      static readonly RULE_functionNameBase = 360;
      static readonly literalNames: (string | null)[];
      static readonly symbolicNames: (string | null)[];
      static readonly ruleNames: string[];
      get grammarFileName(): string;
      get literalNames(): (string | null)[];
      get symbolicNames(): (string | null)[];
      get ruleNames(): string[];
      get serializedATN(): number[];
      protected createFailedPredicateException(predicate?: string, message?: string): antlr.FailedPredicateException;
      constructor(input: antlr.TokenStream);
      root(): RootContext;
      sqlStatements(): SqlStatementsContext;
      sqlStatement(): SqlStatementContext;
      emptyStatement_(): EmptyStatement_Context;
      ddlStatement(): DdlStatementContext;
      dmlStatement(): DmlStatementContext;
      transactionStatement(): TransactionStatementContext;
      replicationStatement(): ReplicationStatementContext;
      preparedStatement(): PreparedStatementContext;
      compoundStatement(): CompoundStatementContext;
      administrationStatement(): AdministrationStatementContext;
      utilityStatement(): UtilityStatementContext;
      createDatabase(): CreateDatabaseContext;
      createEvent(): CreateEventContext;
      createIndex(): CreateIndexContext;
      createLogfileGroup(): CreateLogfileGroupContext;
      createProcedure(): CreateProcedureContext;
      createFunction(): CreateFunctionContext;
      createRole(): CreateRoleContext;
      createServer(): CreateServerContext;
      createTable(): CreateTableContext;
      createTablespaceInnodb(): CreateTablespaceInnodbContext;
      createTablespaceNdb(): CreateTablespaceNdbContext;
      createTrigger(): CreateTriggerContext;
      withClause(): WithClauseContext;
      commonTableExpressions(): CommonTableExpressionsContext;
      cteName(): CteNameContext;
      cteColumnName(): CteColumnNameContext;
      createView(): CreateViewContext;
      createDatabaseOption(): CreateDatabaseOptionContext;
      charSet(): CharSetContext;
      currentUserExpression(): CurrentUserExpressionContext;
      ownerStatement(): OwnerStatementContext;
      scheduleExpression(): ScheduleExpressionContext;
      timestampValue(): TimestampValueContext;
      intervalExpr(): IntervalExprContext;
      intervalType(): IntervalTypeContext;
      enableType(): EnableTypeContext;
      indexType(): IndexTypeContext;
      indexOption(): IndexOptionContext;
      procedureParameter(): ProcedureParameterContext;
      functionParameter(): FunctionParameterContext;
      routineOption(): RoutineOptionContext;
      serverOption(): ServerOptionContext;
      createDefinitions(): CreateDefinitionsContext;
      createDefinition(): CreateDefinitionContext;
      columnDefinition(): ColumnDefinitionContext;
      columnConstraint(): ColumnConstraintContext;
      tableConstraint(): TableConstraintContext;
      referenceDefinition(): ReferenceDefinitionContext;
      referenceAction(): ReferenceActionContext;
      referenceControlType(): ReferenceControlTypeContext;
      indexColumnDefinition(): IndexColumnDefinitionContext;
      tableOption(): TableOptionContext;
      tableType(): TableTypeContext;
      tablespaceStorage(): TablespaceStorageContext;
      partitionDefinitions(): PartitionDefinitionsContext;
      partitionFunctionDefinition(): PartitionFunctionDefinitionContext;
      subpartitionFunctionDefinition(): SubpartitionFunctionDefinitionContext;
      partitionDefinition(): PartitionDefinitionContext;
      partitionDefinerAtom(): PartitionDefinerAtomContext;
      partitionDefinerVector(): PartitionDefinerVectorContext;
      subpartitionDefinition(): SubpartitionDefinitionContext;
      partitionOption(): PartitionOptionContext;
      alterDatabase(): AlterDatabaseContext;
      alterEvent(): AlterEventContext;
      alterFunction(): AlterFunctionContext;
      alterInstance(): AlterInstanceContext;
      alterLogfileGroup(): AlterLogfileGroupContext;
      alterProcedure(): AlterProcedureContext;
      alterServer(): AlterServerContext;
      alterTable(): AlterTableContext;
      alterTablespace(): AlterTablespaceContext;
      alterView(): AlterViewContext;
      alterSpecification(): AlterSpecificationContext;
      alterPartitionSpecification(): AlterPartitionSpecificationContext;
      dropDatabase(): DropDatabaseContext;
      dropEvent(): DropEventContext;
      dropIndex(): DropIndexContext;
      dropLogfileGroup(): DropLogfileGroupContext;
      dropProcedure(): DropProcedureContext;
      dropFunction(): DropFunctionContext;
      dropServer(): DropServerContext;
      dropTable(): DropTableContext;
      dropTablespace(): DropTablespaceContext;
      dropTrigger(): DropTriggerContext;
      dropView(): DropViewContext;
      dropRole(): DropRoleContext;
      setRole(): SetRoleContext;
      renameTable(): RenameTableContext;
      renameTableClause(): RenameTableClauseContext;
      truncateTable(): TruncateTableContext;
      callStatement(): CallStatementContext;
      deleteStatement(): DeleteStatementContext;
      doStatement(): DoStatementContext;
      handlerStatement(): HandlerStatementContext;
      insertStatement(): InsertStatementContext;
      loadDataStatement(): LoadDataStatementContext;
      loadXmlStatement(): LoadXmlStatementContext;
      replaceStatement(): ReplaceStatementContext;
      selectStatement(): SelectStatementContext;
      updateStatement(): UpdateStatementContext;
      valuesStatement(): ValuesStatementContext;
      insertStatementValue(): InsertStatementValueContext;
      updatedElement(): UpdatedElementContext;
      assignmentField(): AssignmentFieldContext;
      lockClause(): LockClauseContext;
      singleDeleteStatement(): SingleDeleteStatementContext;
      multipleDeleteStatement(): MultipleDeleteStatementContext;
      handlerOpenStatement(): HandlerOpenStatementContext;
      handlerReadIndexStatement(): HandlerReadIndexStatementContext;
      handlerReadStatement(): HandlerReadStatementContext;
      handlerCloseStatement(): HandlerCloseStatementContext;
      singleUpdateStatement(): SingleUpdateStatementContext;
      multipleUpdateStatement(): MultipleUpdateStatementContext;
      orderByClause(): OrderByClauseContext;
      orderByExpression(): OrderByExpressionContext;
      tableSources(): TableSourcesContext;
      tableSource(): TableSourceContext;
      tableSourceItem(): TableSourceItemContext;
      indexHint(): IndexHintContext;
      indexHintType(): IndexHintTypeContext;
      joinPart(): JoinPartContext;
      joinSpec(): JoinSpecContext;
      queryExpression(): QueryExpressionContext;
      queryExpressionNointo(): QueryExpressionNointoContext;
      querySpecification(): QuerySpecificationContext;
      querySpecificationNointo(): QuerySpecificationNointoContext;
      unionParenthesis(): UnionParenthesisContext;
      unionStatement(): UnionStatementContext;
      lateralStatement(): LateralStatementContext;
      jsonTable(): JsonTableContext;
      jsonColumnList(): JsonColumnListContext;
      jsonColumn(): JsonColumnContext;
      jsonOnEmpty(): JsonOnEmptyContext;
      jsonOnError(): JsonOnErrorContext;
      selectSpec(): SelectSpecContext;
      selectElements(): SelectElementsContext;
      selectElement(): SelectElementContext;
      selectIntoExpression(): SelectIntoExpressionContext;
      selectFieldsInto(): SelectFieldsIntoContext;
      selectLinesInto(): SelectLinesIntoContext;
      fromClause(): FromClauseContext;
      groupByClause(): GroupByClauseContext;
      havingClause(): HavingClauseContext;
      windowClause(): WindowClauseContext;
      groupByItem(): GroupByItemContext;
      limitClause(): LimitClauseContext;
      limitClauseAtom(): LimitClauseAtomContext;
      startTransaction(): StartTransactionContext;
      beginWork(): BeginWorkContext;
      commitWork(): CommitWorkContext;
      rollbackWork(): RollbackWorkContext;
      savepointStatement(): SavepointStatementContext;
      rollbackStatement(): RollbackStatementContext;
      releaseStatement(): ReleaseStatementContext;
      lockTables(): LockTablesContext;
      unlockTables(): UnlockTablesContext;
      setAutocommitStatement(): SetAutocommitStatementContext;
      setTransactionStatement(): SetTransactionStatementContext;
      transactionMode(): TransactionModeContext;
      lockTableElement(): LockTableElementContext;
      lockAction(): LockActionContext;
      transactionOption(): TransactionOptionContext;
      transactionLevel(): TransactionLevelContext;
      changeMaster(): ChangeMasterContext;
      changeReplicationFilter(): ChangeReplicationFilterContext;
      purgeBinaryLogs(): PurgeBinaryLogsContext;
      resetMaster(): ResetMasterContext;
      resetSlave(): ResetSlaveContext;
      startSlave(): StartSlaveContext;
      stopSlave(): StopSlaveContext;
      startGroupReplication(): StartGroupReplicationContext;
      stopGroupReplication(): StopGroupReplicationContext;
      masterOption(): MasterOptionContext;
      stringMasterOption(): StringMasterOptionContext;
      decimalMasterOption(): DecimalMasterOptionContext;
      boolMasterOption(): BoolMasterOptionContext;
      channelOption(): ChannelOptionContext;
      replicationFilter(): ReplicationFilterContext;
      tablePair(): TablePairContext;
      threadType(): ThreadTypeContext;
      untilOption(): UntilOptionContext;
      connectionOption(): ConnectionOptionContext;
      gtuidSet(): GtuidSetContext;
      xaStartTransaction(): XaStartTransactionContext;
      xaEndTransaction(): XaEndTransactionContext;
      xaPrepareStatement(): XaPrepareStatementContext;
      xaCommitWork(): XaCommitWorkContext;
      xaRollbackWork(): XaRollbackWorkContext;
      xaRecoverWork(): XaRecoverWorkContext;
      prepareStatement(): PrepareStatementContext;
      executeStatement(): ExecuteStatementContext;
      deallocatePrepare(): DeallocatePrepareContext;
      routineBody(): RoutineBodyContext;
      blockStatement(): BlockStatementContext;
      caseStatement(): CaseStatementContext;
      ifStatement(): IfStatementContext;
      iterateStatement(): IterateStatementContext;
      leaveStatement(): LeaveStatementContext;
      loopStatement(): LoopStatementContext;
      repeatStatement(): RepeatStatementContext;
      returnStatement(): ReturnStatementContext;
      whileStatement(): WhileStatementContext;
      cursorStatement(): CursorStatementContext;
      declareVariable(): DeclareVariableContext;
      declareCondition(): DeclareConditionContext;
      declareCursor(): DeclareCursorContext;
      declareHandler(): DeclareHandlerContext;
      handlerConditionValue(): HandlerConditionValueContext;
      procedureSqlStatement(): ProcedureSqlStatementContext;
      caseAlternative(): CaseAlternativeContext;
      elifAlternative(): ElifAlternativeContext;
      alterUser(): AlterUserContext;
      createUser(): CreateUserContext;
      dropUser(): DropUserContext;
      grantStatement(): GrantStatementContext;
      roleOption(): RoleOptionContext;
      grantProxy(): GrantProxyContext;
      renameUser(): RenameUserContext;
      revokeStatement(): RevokeStatementContext;
      revokeProxy(): RevokeProxyContext;
      setPasswordStatement(): SetPasswordStatementContext;
      userSpecification(): UserSpecificationContext;
      userAuthOption(): UserAuthOptionContext;
      authOptionClause(): AuthOptionClauseContext;
      authenticationRule(): AuthenticationRuleContext;
      tlsOption(): TlsOptionContext;
      userResourceOption(): UserResourceOptionContext;
      userPasswordOption(): UserPasswordOptionContext;
      userLockOption(): UserLockOptionContext;
      privelegeClause(): PrivelegeClauseContext;
      privilege(): PrivilegeContext;
      privilegeLevel(): PrivilegeLevelContext;
      renameUserClause(): RenameUserClauseContext;
      analyzeTable(): AnalyzeTableContext;
      checkTable(): CheckTableContext;
      checksumTable(): ChecksumTableContext;
      optimizeTable(): OptimizeTableContext;
      repairTable(): RepairTableContext;
      checkTableOption(): CheckTableOptionContext;
      createUdfunction(): CreateUdfunctionContext;
      installPlugin(): InstallPluginContext;
      uninstallPlugin(): UninstallPluginContext;
      setStatement(): SetStatementContext;
      showStatement(): ShowStatementContext;
      variableClause(): VariableClauseContext;
      showCommonEntity(): ShowCommonEntityContext;
      showFilter(): ShowFilterContext;
      showGlobalInfoClause(): ShowGlobalInfoClauseContext;
      showSchemaEntity(): ShowSchemaEntityContext;
      showProfileType(): ShowProfileTypeContext;
      binlogStatement(): BinlogStatementContext;
      cacheIndexStatement(): CacheIndexStatementContext;
      flushStatement(): FlushStatementContext;
      killStatement(): KillStatementContext;
      loadIndexIntoCache(): LoadIndexIntoCacheContext;
      resetStatement(): ResetStatementContext;
      shutdownStatement(): ShutdownStatementContext;
      tableIndexes(): TableIndexesContext;
      flushOption(): FlushOptionContext;
      flushTableOption(): FlushTableOptionContext;
      loadedTableIndexes(): LoadedTableIndexesContext;
      simpleDescribeStatement(): SimpleDescribeStatementContext;
      fullDescribeStatement(): FullDescribeStatementContext;
      helpStatement(): HelpStatementContext;
      useStatement(): UseStatementContext;
      signalStatement(): SignalStatementContext;
      resignalStatement(): ResignalStatementContext;
      signalConditionInformation(): SignalConditionInformationContext;
      withStatement(): WithStatementContext;
      tableStatement(): TableStatementContext;
      diagnosticsStatement(): DiagnosticsStatementContext;
      diagnosticsConditionInformationName(): DiagnosticsConditionInformationNameContext;
      describeObjectClause(): DescribeObjectClauseContext;
      fullId(): FullIdContext;
      tableName(): TableNameContext;
      roleName(): RoleNameContext;
      fullColumnName(): FullColumnNameContext;
      indexColumnName(): IndexColumnNameContext;
      simpleUserName(): SimpleUserNameContext;
      hostName(): HostNameContext;
      userName(): UserNameContext;
      mysqlVariable(): MysqlVariableContext;
      charsetName(): CharsetNameContext;
      collationName(): CollationNameContext;
      engineName(): EngineNameContext;
      engineNameBase(): EngineNameBaseContext;
      uuidSet(): UuidSetContext;
      xid(): XidContext;
      xuidStringId(): XuidStringIdContext;
      authPlugin(): AuthPluginContext;
      uid(): UidContext;
      simpleId(): SimpleIdContext;
      dottedId(): DottedIdContext;
      decimalLiteral(): DecimalLiteralContext;
      fileSizeLiteral(): FileSizeLiteralContext;
      stringLiteral(): StringLiteralContext;
      booleanLiteral(): BooleanLiteralContext;
      hexadecimalLiteral(): HexadecimalLiteralContext;
      nullNotnull(): NullNotnullContext;
      constant(): ConstantContext;
      dataType(): DataTypeContext;
      collectionOptions(): CollectionOptionsContext;
      convertedDataType(): ConvertedDataTypeContext;
      lengthOneDimension(): LengthOneDimensionContext;
      lengthTwoDimension(): LengthTwoDimensionContext;
      lengthTwoOptionalDimension(): LengthTwoOptionalDimensionContext;
      uidList(): UidListContext;
      fullColumnNameList(): FullColumnNameListContext;
      tables(): TablesContext;
      indexColumnNames(): IndexColumnNamesContext;
      expressions(): ExpressionsContext;
      expressionsWithDefaults(): ExpressionsWithDefaultsContext;
      constants(): ConstantsContext;
      simpleStrings(): SimpleStringsContext;
      userVariables(): UserVariablesContext;
      defaultValue(): DefaultValueContext;
      currentTimestamp(): CurrentTimestampContext;
      expressionOrDefault(): ExpressionOrDefaultContext;
      ifExists(): IfExistsContext;
      ifNotExists(): IfNotExistsContext;
      orReplace(): OrReplaceContext;
      waitNowaitClause(): WaitNowaitClauseContext;
      functionCall(): FunctionCallContext;
      specificFunction(): SpecificFunctionContext;
      caseFuncAlternative(): CaseFuncAlternativeContext;
      levelsInWeightString(): LevelsInWeightStringContext;
      levelInWeightListElement(): LevelInWeightListElementContext;
      aggregateWindowedFunction(): AggregateWindowedFunctionContext;
      nonAggregateWindowedFunction(): NonAggregateWindowedFunctionContext;
      overClause(): OverClauseContext;
      windowSpec(): WindowSpecContext;
      windowName(): WindowNameContext;
      frameClause(): FrameClauseContext;
      frameUnits(): FrameUnitsContext;
      frameExtent(): FrameExtentContext;
      frameBetween(): FrameBetweenContext;
      frameRange(): FrameRangeContext;
      partitionClause(): PartitionClauseContext;
      scalarFunctionName(): ScalarFunctionNameContext;
      passwordFunctionClause(): PasswordFunctionClauseContext;
      functionArgs(): FunctionArgsContext;
      functionArg(): FunctionArgContext;
      expression(): ExpressionContext;
      expression(_p: number): ExpressionContext;
      predicate(): PredicateContext;
      predicate(_p: number): PredicateContext;
      expressionAtom(): ExpressionAtomContext;
      expressionAtom(_p: number): ExpressionAtomContext;
      unaryOperator(): UnaryOperatorContext;
      comparisonOperator(): ComparisonOperatorContext;
      logicalOperator(): LogicalOperatorContext;
      bitOperator(): BitOperatorContext;
      multOperator(): MultOperatorContext;
      addOperator(): AddOperatorContext;
      jsonOperator(): JsonOperatorContext;
      charsetNameBase(): CharsetNameBaseContext;
      transactionLevelBase(): TransactionLevelBaseContext;
      privilegesBase(): PrivilegesBaseContext;
      intervalTypeBase(): IntervalTypeBaseContext;
      dataTypeBase(): DataTypeBaseContext;
      keywordsCanBeId(): KeywordsCanBeIdContext;
      functionNameBase(): FunctionNameBaseContext;
      sempred(localContext: antlr.RuleContext | null, ruleIndex: number, predIndex: number): boolean;
      private expression_sempred;
      private predicate_sempred;
      private expressionAtom_sempred;
      static readonly _serializedATN: number[];
      private static __ATN;
      static get _ATN(): antlr.ATN;
      private static readonly vocabulary;
      get vocabulary(): antlr.Vocabulary;
      private static readonly decisionsToDFA;
  }
  export class RootContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EOF(): antlr.TerminalNode;
      sqlStatements(): SqlStatementsContext | null;
      MINUS(): antlr.TerminalNode[];
      MINUS(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SqlStatementsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sqlStatement(): SqlStatementContext[];
      sqlStatement(i: number): SqlStatementContext | null;
      emptyStatement_(): EmptyStatement_Context[];
      emptyStatement_(i: number): EmptyStatement_Context | null;
      SEMI(): antlr.TerminalNode[];
      SEMI(i: number): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode[];
      MINUS(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SqlStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ddlStatement(): DdlStatementContext | null;
      dmlStatement(): DmlStatementContext | null;
      transactionStatement(): TransactionStatementContext | null;
      replicationStatement(): ReplicationStatementContext | null;
      preparedStatement(): PreparedStatementContext | null;
      administrationStatement(): AdministrationStatementContext | null;
      utilityStatement(): UtilityStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class EmptyStatement_Context extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DdlStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createDatabase(): CreateDatabaseContext | null;
      createEvent(): CreateEventContext | null;
      createIndex(): CreateIndexContext | null;
      createLogfileGroup(): CreateLogfileGroupContext | null;
      createProcedure(): CreateProcedureContext | null;
      createFunction(): CreateFunctionContext | null;
      createServer(): CreateServerContext | null;
      createTable(): CreateTableContext | null;
      createTablespaceInnodb(): CreateTablespaceInnodbContext | null;
      createTablespaceNdb(): CreateTablespaceNdbContext | null;
      createTrigger(): CreateTriggerContext | null;
      createView(): CreateViewContext | null;
      createRole(): CreateRoleContext | null;
      alterDatabase(): AlterDatabaseContext | null;
      alterEvent(): AlterEventContext | null;
      alterFunction(): AlterFunctionContext | null;
      alterInstance(): AlterInstanceContext | null;
      alterLogfileGroup(): AlterLogfileGroupContext | null;
      alterProcedure(): AlterProcedureContext | null;
      alterServer(): AlterServerContext | null;
      alterTable(): AlterTableContext | null;
      alterTablespace(): AlterTablespaceContext | null;
      alterView(): AlterViewContext | null;
      dropDatabase(): DropDatabaseContext | null;
      dropEvent(): DropEventContext | null;
      dropIndex(): DropIndexContext | null;
      dropLogfileGroup(): DropLogfileGroupContext | null;
      dropProcedure(): DropProcedureContext | null;
      dropFunction(): DropFunctionContext | null;
      dropServer(): DropServerContext | null;
      dropTable(): DropTableContext | null;
      dropTablespace(): DropTablespaceContext | null;
      dropTrigger(): DropTriggerContext | null;
      dropView(): DropViewContext | null;
      dropRole(): DropRoleContext | null;
      setRole(): SetRoleContext | null;
      renameTable(): RenameTableContext | null;
      truncateTable(): TruncateTableContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DmlStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectStatement(): SelectStatementContext | null;
      insertStatement(): InsertStatementContext | null;
      updateStatement(): UpdateStatementContext | null;
      deleteStatement(): DeleteStatementContext | null;
      replaceStatement(): ReplaceStatementContext | null;
      callStatement(): CallStatementContext | null;
      loadDataStatement(): LoadDataStatementContext | null;
      loadXmlStatement(): LoadXmlStatementContext | null;
      doStatement(): DoStatementContext | null;
      handlerStatement(): HandlerStatementContext | null;
      valuesStatement(): ValuesStatementContext | null;
      withStatement(): WithStatementContext | null;
      tableStatement(): TableStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TransactionStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      startTransaction(): StartTransactionContext | null;
      beginWork(): BeginWorkContext | null;
      commitWork(): CommitWorkContext | null;
      rollbackWork(): RollbackWorkContext | null;
      savepointStatement(): SavepointStatementContext | null;
      rollbackStatement(): RollbackStatementContext | null;
      releaseStatement(): ReleaseStatementContext | null;
      lockTables(): LockTablesContext | null;
      unlockTables(): UnlockTablesContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReplicationStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      changeMaster(): ChangeMasterContext | null;
      changeReplicationFilter(): ChangeReplicationFilterContext | null;
      purgeBinaryLogs(): PurgeBinaryLogsContext | null;
      resetMaster(): ResetMasterContext | null;
      resetSlave(): ResetSlaveContext | null;
      startSlave(): StartSlaveContext | null;
      stopSlave(): StopSlaveContext | null;
      startGroupReplication(): StartGroupReplicationContext | null;
      stopGroupReplication(): StopGroupReplicationContext | null;
      xaStartTransaction(): XaStartTransactionContext | null;
      xaEndTransaction(): XaEndTransactionContext | null;
      xaPrepareStatement(): XaPrepareStatementContext | null;
      xaCommitWork(): XaCommitWorkContext | null;
      xaRollbackWork(): XaRollbackWorkContext | null;
      xaRecoverWork(): XaRecoverWorkContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PreparedStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      prepareStatement(): PrepareStatementContext | null;
      executeStatement(): ExecuteStatementContext | null;
      deallocatePrepare(): DeallocatePrepareContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CompoundStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      blockStatement(): BlockStatementContext | null;
      caseStatement(): CaseStatementContext | null;
      ifStatement(): IfStatementContext | null;
      leaveStatement(): LeaveStatementContext | null;
      loopStatement(): LoopStatementContext | null;
      repeatStatement(): RepeatStatementContext | null;
      whileStatement(): WhileStatementContext | null;
      iterateStatement(): IterateStatementContext | null;
      returnStatement(): ReturnStatementContext | null;
      cursorStatement(): CursorStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AdministrationStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alterUser(): AlterUserContext | null;
      createUser(): CreateUserContext | null;
      dropUser(): DropUserContext | null;
      grantStatement(): GrantStatementContext | null;
      grantProxy(): GrantProxyContext | null;
      renameUser(): RenameUserContext | null;
      revokeStatement(): RevokeStatementContext | null;
      revokeProxy(): RevokeProxyContext | null;
      analyzeTable(): AnalyzeTableContext | null;
      checkTable(): CheckTableContext | null;
      checksumTable(): ChecksumTableContext | null;
      optimizeTable(): OptimizeTableContext | null;
      repairTable(): RepairTableContext | null;
      createUdfunction(): CreateUdfunctionContext | null;
      installPlugin(): InstallPluginContext | null;
      uninstallPlugin(): UninstallPluginContext | null;
      setStatement(): SetStatementContext | null;
      showStatement(): ShowStatementContext | null;
      binlogStatement(): BinlogStatementContext | null;
      cacheIndexStatement(): CacheIndexStatementContext | null;
      flushStatement(): FlushStatementContext | null;
      killStatement(): KillStatementContext | null;
      loadIndexIntoCache(): LoadIndexIntoCacheContext | null;
      resetStatement(): ResetStatementContext | null;
      shutdownStatement(): ShutdownStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UtilityStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      simpleDescribeStatement(): SimpleDescribeStatementContext | null;
      fullDescribeStatement(): FullDescribeStatementContext | null;
      helpStatement(): HelpStatementContext | null;
      useStatement(): UseStatementContext | null;
      signalStatement(): SignalStatementContext | null;
      resignalStatement(): ResignalStatementContext | null;
      diagnosticsStatement(): DiagnosticsStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateDatabaseContext extends antlr.ParserRuleContext {
      _dbFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      uid(): UidContext;
      DATABASE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      createDatabaseOption(): CreateDatabaseOptionContext[];
      createDatabaseOption(i: number): CreateDatabaseOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateEventContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      EVENT(): antlr.TerminalNode;
      fullId(): FullIdContext;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      SCHEDULE(): antlr.TerminalNode;
      scheduleExpression(): ScheduleExpressionContext;
      DO(): antlr.TerminalNode;
      routineBody(): RoutineBodyContext;
      ownerStatement(): OwnerStatementContext | null;
      ifNotExists(): IfNotExistsContext | null;
      COMPLETION(): antlr.TerminalNode | null;
      PRESERVE(): antlr.TerminalNode | null;
      enableType(): EnableTypeContext | null;
      COMMENT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateIndexContext extends antlr.ParserRuleContext {
      _intimeAction?: Token | null;
      _indexCategory?: Token | null;
      _algType?: Token | null;
      _lockType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      uid(): UidContext;
      ON(): antlr.TerminalNode;
      tableName(): TableNameContext;
      indexColumnNames(): IndexColumnNamesContext;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      ALGORITHM(): antlr.TerminalNode[];
      ALGORITHM(i: number): antlr.TerminalNode | null;
      LOCK(): antlr.TerminalNode[];
      LOCK(i: number): antlr.TerminalNode | null;
      ONLINE(): antlr.TerminalNode | null;
      OFFLINE(): antlr.TerminalNode | null;
      UNIQUE(): antlr.TerminalNode | null;
      FULLTEXT(): antlr.TerminalNode | null;
      SPATIAL(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode[];
      DEFAULT(i: number): antlr.TerminalNode | null;
      INPLACE(): antlr.TerminalNode[];
      INPLACE(i: number): antlr.TerminalNode | null;
      COPY(): antlr.TerminalNode[];
      COPY(i: number): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode[];
      NONE(i: number): antlr.TerminalNode | null;
      SHARED(): antlr.TerminalNode[];
      SHARED(i: number): antlr.TerminalNode | null;
      EXCLUSIVE(): antlr.TerminalNode[];
      EXCLUSIVE(i: number): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateLogfileGroupContext extends antlr.ParserRuleContext {
      _undoFile?: Token | null;
      _initSize?: FileSizeLiteralContext;
      _undoSize?: FileSizeLiteralContext;
      _redoSize?: FileSizeLiteralContext;
      _comment?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      LOGFILE(): antlr.TerminalNode;
      GROUP(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      ADD(): antlr.TerminalNode;
      UNDOFILE(): antlr.TerminalNode;
      ENGINE(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      INITIAL_SIZE(): antlr.TerminalNode | null;
      UNDO_BUFFER_SIZE(): antlr.TerminalNode | null;
      REDO_BUFFER_SIZE(): antlr.TerminalNode | null;
      NODEGROUP(): antlr.TerminalNode | null;
      WAIT(): antlr.TerminalNode | null;
      COMMENT(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      fileSizeLiteral(): FileSizeLiteralContext[];
      fileSizeLiteral(i: number): FileSizeLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateProcedureContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      PROCEDURE(): antlr.TerminalNode;
      fullId(): FullIdContext;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      routineBody(): RoutineBodyContext;
      ownerStatement(): OwnerStatementContext | null;
      procedureParameter(): ProcedureParameterContext[];
      procedureParameter(i: number): ProcedureParameterContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      routineOption(): RoutineOptionContext[];
      routineOption(i: number): RoutineOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateFunctionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode;
      fullId(): FullIdContext;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      RETURNS(): antlr.TerminalNode;
      dataType(): DataTypeContext;
      routineBody(): RoutineBodyContext | null;
      returnStatement(): ReturnStatementContext | null;
      ownerStatement(): OwnerStatementContext | null;
      AGGREGATE(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      functionParameter(): FunctionParameterContext[];
      functionParameter(i: number): FunctionParameterContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      routineOption(): RoutineOptionContext[];
      routineOption(i: number): RoutineOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateRoleContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      ROLE(): antlr.TerminalNode;
      roleName(): RoleNameContext[];
      roleName(i: number): RoleNameContext | null;
      ifNotExists(): IfNotExistsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateServerContext extends antlr.ParserRuleContext {
      _wrapperName?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      SERVER(): antlr.TerminalNode;
      uid(): UidContext;
      FOREIGN(): antlr.TerminalNode;
      DATA(): antlr.TerminalNode;
      WRAPPER(): antlr.TerminalNode;
      OPTIONS(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      serverOption(): ServerOptionContext[];
      serverOption(i: number): ServerOptionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      MYSQL(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateTableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: CreateTableContext): void;
  }
  export class CopyCreateTableContext extends CreateTableContext {
      _parenthesisTable?: TableNameContext;
      constructor(ctx: CreateTableContext);
      CREATE(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext[];
      tableName(i: number): TableNameContext | null;
      LIKE(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ColumnCreateTableContext extends CreateTableContext {
      constructor(ctx: CreateTableContext);
      CREATE(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      createDefinitions(): CreateDefinitionsContext;
      TEMPORARY(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      tableOption(): TableOptionContext[];
      tableOption(i: number): TableOptionContext | null;
      partitionDefinitions(): PartitionDefinitionsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class QueryCreateTableContext extends CreateTableContext {
      _keyViolate?: Token | null;
      constructor(ctx: CreateTableContext);
      CREATE(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      selectStatement(): SelectStatementContext;
      TEMPORARY(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      createDefinitions(): CreateDefinitionsContext | null;
      tableOption(): TableOptionContext[];
      tableOption(i: number): TableOptionContext | null;
      partitionDefinitions(): PartitionDefinitionsContext | null;
      AS(): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateTablespaceInnodbContext extends antlr.ParserRuleContext {
      _datafile?: Token | null;
      _fileBlockSize?: FileSizeLiteralContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      uid(): UidContext;
      ADD(): antlr.TerminalNode;
      DATAFILE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      FILE_BLOCK_SIZE(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      ENGINE(): antlr.TerminalNode | null;
      engineName(): EngineNameContext | null;
      fileSizeLiteral(): FileSizeLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateTablespaceNdbContext extends antlr.ParserRuleContext {
      _datafile?: Token | null;
      _extentSize?: FileSizeLiteralContext;
      _initialSize?: FileSizeLiteralContext;
      _autoextendSize?: FileSizeLiteralContext;
      _maxSize?: FileSizeLiteralContext;
      _comment?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      ADD(): antlr.TerminalNode;
      DATAFILE(): antlr.TerminalNode;
      USE(): antlr.TerminalNode;
      LOGFILE(): antlr.TerminalNode;
      GROUP(): antlr.TerminalNode;
      ENGINE(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      EXTENT_SIZE(): antlr.TerminalNode | null;
      INITIAL_SIZE(): antlr.TerminalNode | null;
      AUTOEXTEND_SIZE(): antlr.TerminalNode | null;
      MAX_SIZE(): antlr.TerminalNode | null;
      NODEGROUP(): antlr.TerminalNode | null;
      WAIT(): antlr.TerminalNode | null;
      COMMENT(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      fileSizeLiteral(): FileSizeLiteralContext[];
      fileSizeLiteral(i: number): FileSizeLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateTriggerContext extends antlr.ParserRuleContext {
      _thisTrigger?: FullIdContext;
      _triggerTime?: Token | null;
      _triggerEvent?: Token | null;
      _triggerPlace?: Token | null;
      _otherTrigger?: FullIdContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      TRIGGER(): antlr.TerminalNode;
      ON(): antlr.TerminalNode;
      tableName(): TableNameContext;
      FOR(): antlr.TerminalNode;
      EACH(): antlr.TerminalNode;
      ROW(): antlr.TerminalNode;
      routineBody(): RoutineBodyContext;
      fullId(): FullIdContext[];
      fullId(i: number): FullIdContext | null;
      BEFORE(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      DELETE(): antlr.TerminalNode | null;
      ownerStatement(): OwnerStatementContext | null;
      FOLLOWS(): antlr.TerminalNode | null;
      PRECEDES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WithClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode;
      commonTableExpressions(): CommonTableExpressionsContext;
      RECURSIVE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CommonTableExpressionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      cteName(): CteNameContext;
      AS(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      dmlStatement(): DmlStatementContext;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      cteColumnName(): CteColumnNameContext[];
      cteColumnName(i: number): CteColumnNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      commonTableExpressions(): CommonTableExpressionsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CteNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CteColumnNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateViewContext extends antlr.ParserRuleContext {
      _algType?: Token | null;
      _secContext?: Token | null;
      _checkOption?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      fullId(): FullIdContext;
      AS(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      selectStatement(): SelectStatementContext | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      orReplace(): OrReplaceContext | null;
      ALGORITHM(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      ownerStatement(): OwnerStatementContext | null;
      SQL(): antlr.TerminalNode | null;
      SECURITY(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      UNDEFINED(): antlr.TerminalNode | null;
      MERGE(): antlr.TerminalNode | null;
      TEMPTABLE(): antlr.TerminalNode | null;
      DEFINER(): antlr.TerminalNode | null;
      INVOKER(): antlr.TerminalNode | null;
      withClause(): WithClauseContext | null;
      WITH(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      CASCADED(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateDatabaseOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      charSet(): CharSetContext | null;
      charsetName(): CharsetNameContext | null;
      DEFAULT(): antlr.TerminalNode[];
      DEFAULT(i: number): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      ENCRYPTION(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CharSetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHARACTER(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      CHARSET(): antlr.TerminalNode | null;
      CHAR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CurrentUserExpressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CURRENT_USER(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OwnerStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEFINER(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      userName(): UserNameContext | null;
      currentUserExpression(): CurrentUserExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ScheduleExpressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ScheduleExpressionContext): void;
  }
  export class PreciseScheduleContext extends ScheduleExpressionContext {
      constructor(ctx: ScheduleExpressionContext);
      AT(): antlr.TerminalNode;
      timestampValue(): TimestampValueContext;
      intervalExpr(): IntervalExprContext[];
      intervalExpr(i: number): IntervalExprContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IntervalScheduleContext extends ScheduleExpressionContext {
      _startTimestamp?: TimestampValueContext;
      _intervalExpr?: IntervalExprContext;
      _startIntervals: IntervalExprContext[];
      _endTimestamp?: TimestampValueContext;
      _endIntervals: IntervalExprContext[];
      constructor(ctx: ScheduleExpressionContext);
      EVERY(): antlr.TerminalNode;
      intervalType(): IntervalTypeContext;
      decimalLiteral(): DecimalLiteralContext | null;
      expression(): ExpressionContext | null;
      STARTS(): antlr.TerminalNode | null;
      ENDS(): antlr.TerminalNode | null;
      timestampValue(): TimestampValueContext[];
      timestampValue(i: number): TimestampValueContext | null;
      intervalExpr(): IntervalExprContext[];
      intervalExpr(i: number): IntervalExprContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TimestampValueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CURRENT_TIMESTAMP(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      decimalLiteral(): DecimalLiteralContext | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IntervalExprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PLUS(): antlr.TerminalNode;
      INTERVAL(): antlr.TerminalNode;
      intervalType(): IntervalTypeContext;
      decimalLiteral(): DecimalLiteralContext | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IntervalTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      intervalTypeBase(): IntervalTypeBaseContext | null;
      YEAR(): antlr.TerminalNode | null;
      YEAR_MONTH(): antlr.TerminalNode | null;
      DAY_HOUR(): antlr.TerminalNode | null;
      DAY_MINUTE(): antlr.TerminalNode | null;
      DAY_SECOND(): antlr.TerminalNode | null;
      HOUR_MINUTE(): antlr.TerminalNode | null;
      HOUR_SECOND(): antlr.TerminalNode | null;
      MINUTE_SECOND(): antlr.TerminalNode | null;
      SECOND_MICROSECOND(): antlr.TerminalNode | null;
      MINUTE_MICROSECOND(): antlr.TerminalNode | null;
      HOUR_MICROSECOND(): antlr.TerminalNode | null;
      DAY_MICROSECOND(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class EnableTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ENABLE(): antlr.TerminalNode | null;
      DISABLE(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      SLAVE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode;
      BTREE(): antlr.TerminalNode | null;
      HASH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      KEY_BLOCK_SIZE(): antlr.TerminalNode | null;
      fileSizeLiteral(): FileSizeLiteralContext | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      indexType(): IndexTypeContext | null;
      WITH(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      COMMENT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      VISIBLE(): antlr.TerminalNode | null;
      INVISIBLE(): antlr.TerminalNode | null;
      ENGINE_ATTRIBUTE(): antlr.TerminalNode | null;
      SECONDARY_ENGINE_ATTRIBUTE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ProcedureParameterContext extends antlr.ParserRuleContext {
      _direction?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext;
      dataType(): DataTypeContext;
      IN(): antlr.TerminalNode | null;
      OUT(): antlr.TerminalNode | null;
      INOUT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FunctionParameterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext;
      dataType(): DataTypeContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoutineOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: RoutineOptionContext): void;
  }
  export class RoutineBehaviorContext extends RoutineOptionContext {
      constructor(ctx: RoutineOptionContext);
      DETERMINISTIC(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoutineLanguageContext extends RoutineOptionContext {
      constructor(ctx: RoutineOptionContext);
      LANGUAGE(): antlr.TerminalNode;
      SQL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoutineCommentContext extends RoutineOptionContext {
      constructor(ctx: RoutineOptionContext);
      COMMENT(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoutineSecurityContext extends RoutineOptionContext {
      _context?: Token | null;
      constructor(ctx: RoutineOptionContext);
      SQL(): antlr.TerminalNode;
      SECURITY(): antlr.TerminalNode;
      DEFINER(): antlr.TerminalNode | null;
      INVOKER(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoutineDataContext extends RoutineOptionContext {
      constructor(ctx: RoutineOptionContext);
      CONTAINS(): antlr.TerminalNode | null;
      SQL(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      READS(): antlr.TerminalNode | null;
      DATA(): antlr.TerminalNode | null;
      MODIFIES(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ServerOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HOST(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      PASSWORD(): antlr.TerminalNode | null;
      SOCKET(): antlr.TerminalNode | null;
      OWNER(): antlr.TerminalNode | null;
      PORT(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateDefinitionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      createDefinition(): CreateDefinitionContext[];
      createDefinition(i: number): CreateDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: CreateDefinitionContext): void;
  }
  export class ColumnDeclarationContext extends CreateDefinitionContext {
      constructor(ctx: CreateDefinitionContext);
      fullColumnName(): FullColumnNameContext;
      columnDefinition(): ColumnDefinitionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ConstraintDeclarationContext extends CreateDefinitionContext {
      constructor(ctx: CreateDefinitionContext);
      tableConstraint(): TableConstraintContext;
      NOT(): antlr.TerminalNode | null;
      ENFORCED(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexDeclarationContext extends CreateDefinitionContext {
      constructor(ctx: CreateDefinitionContext);
      indexColumnDefinition(): IndexColumnDefinitionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ColumnDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      dataType(): DataTypeContext;
      columnConstraint(): ColumnConstraintContext[];
      columnConstraint(i: number): ColumnConstraintContext | null;
      NOT(): antlr.TerminalNode | null;
      ENFORCED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ColumnConstraintContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ColumnConstraintContext): void;
  }
  export class StorageColumnConstraintContext extends ColumnConstraintContext {
      _storageval?: Token | null;
      constructor(ctx: ColumnConstraintContext);
      STORAGE(): antlr.TerminalNode;
      DISK(): antlr.TerminalNode | null;
      MEMORY(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class VisibilityColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      VISIBLE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AutoIncrementColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      AUTO_INCREMENT(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      currentTimestamp(): CurrentTimestampContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CommentColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      COMMENT(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UniqueKeyColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      UNIQUE(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SerialDefaultColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      SERIAL(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode;
      VALUE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GeneratedColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      AS(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext;
      RR_BRACKET(): antlr.TerminalNode;
      GENERATED(): antlr.TerminalNode | null;
      ALWAYS(): antlr.TerminalNode | null;
      VIRTUAL(): antlr.TerminalNode | null;
      STORED(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FormatColumnConstraintContext extends ColumnConstraintContext {
      _colformat?: Token | null;
      constructor(ctx: ColumnConstraintContext);
      COLUMN_FORMAT(): antlr.TerminalNode;
      FIXED(): antlr.TerminalNode | null;
      DYNAMIC(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CollateColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      COLLATE(): antlr.TerminalNode;
      collationName(): CollationNameContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrimaryKeyColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      KEY(): antlr.TerminalNode;
      PRIMARY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CheckColumnConstraintContext extends ColumnConstraintContext {
      _name?: UidContext;
      constructor(ctx: ColumnConstraintContext);
      CHECK(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext;
      RR_BRACKET(): antlr.TerminalNode;
      CONSTRAINT(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NullColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      nullNotnull(): NullNotnullContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DefaultColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      DEFAULT(): antlr.TerminalNode;
      defaultValue(): DefaultValueContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReferenceColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      referenceDefinition(): ReferenceDefinitionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class InvisibilityColumnConstraintContext extends ColumnConstraintContext {
      constructor(ctx: ColumnConstraintContext);
      INVISIBLE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableConstraintContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableConstraintContext): void;
  }
  export class UniqueKeyTableConstraintContext extends TableConstraintContext {
      _name?: UidContext;
      _indexFormat?: Token | null;
      _index?: UidContext;
      constructor(ctx: TableConstraintContext);
      UNIQUE(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CheckTableConstraintContext extends TableConstraintContext {
      _name?: UidContext;
      constructor(ctx: TableConstraintContext);
      CHECK(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext;
      RR_BRACKET(): antlr.TerminalNode;
      CONSTRAINT(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrimaryKeyTableConstraintContext extends TableConstraintContext {
      _name?: UidContext;
      _index?: UidContext;
      constructor(ctx: TableConstraintContext);
      PRIMARY(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ForeignKeyTableConstraintContext extends TableConstraintContext {
      _name?: UidContext;
      _index?: UidContext;
      constructor(ctx: TableConstraintContext);
      FOREIGN(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      referenceDefinition(): ReferenceDefinitionContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReferenceDefinitionContext extends antlr.ParserRuleContext {
      _matchType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REFERENCES(): antlr.TerminalNode;
      tableName(): TableNameContext;
      indexColumnNames(): IndexColumnNamesContext | null;
      MATCH(): antlr.TerminalNode | null;
      referenceAction(): ReferenceActionContext | null;
      FULL(): antlr.TerminalNode | null;
      PARTIAL(): antlr.TerminalNode | null;
      SIMPLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReferenceActionContext extends antlr.ParserRuleContext {
      _onDelete?: ReferenceControlTypeContext;
      _onUpdate?: ReferenceControlTypeContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      DELETE(): antlr.TerminalNode | null;
      referenceControlType(): ReferenceControlTypeContext[];
      referenceControlType(i: number): ReferenceControlTypeContext | null;
      UPDATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReferenceControlTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESTRICT(): antlr.TerminalNode | null;
      CASCADE(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      NULL_LITERAL(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      ACTION(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexColumnDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: IndexColumnDefinitionContext): void;
  }
  export class SpecialIndexDeclarationContext extends IndexColumnDefinitionContext {
      _indexFormat?: Token | null;
      constructor(ctx: IndexColumnDefinitionContext);
      indexColumnNames(): IndexColumnNamesContext;
      FULLTEXT(): antlr.TerminalNode | null;
      SPATIAL(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleIndexDeclarationContext extends IndexColumnDefinitionContext {
      _indexFormat?: Token | null;
      constructor(ctx: IndexColumnDefinitionContext);
      indexColumnNames(): IndexColumnNamesContext;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableOptionContext): void;
  }
  export class TableOptionEngineContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      ENGINE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      engineName(): EngineNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionMaxRowsContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      MAX_ROWS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionCollateContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      COLLATE(): antlr.TerminalNode;
      collationName(): CollationNameContext;
      DEFAULT(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionPersistentContext extends TableOptionContext {
      _extBoolValue?: Token | null;
      constructor(ctx: TableOptionContext);
      STATS_PERSISTENT(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionTablespaceContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      TABLESPACE(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      tablespaceStorage(): TablespaceStorageContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionAutoextendSizeContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      AUTOEXTEND_SIZE(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionPageCompressedContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      PAGE_COMPRESSED(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionStartTransactionContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      START(): antlr.TerminalNode;
      TRANSACTION(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionPackKeysContext extends TableOptionContext {
      _extBoolValue?: Token | null;
      constructor(ctx: TableOptionContext);
      PACK_KEYS(): antlr.TerminalNode;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionPasswordContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      PASSWORD(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionUnionContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      UNION(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      tables(): TablesContext;
      RR_BRACKET(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionSamplePageContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      STATS_SAMPLE_PAGES(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionCharsetContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      charSet(): CharSetContext;
      charsetName(): CharsetNameContext | null;
      DEFAULT(): antlr.TerminalNode[];
      DEFAULT(i: number): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionIndexDirectoryContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      INDEX(): antlr.TerminalNode;
      DIRECTORY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionTableTypeContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      TABLE_TYPE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      tableType(): TableTypeContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionKeyBlockSizeContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      KEY_BLOCK_SIZE(): antlr.TerminalNode;
      fileSizeLiteral(): FileSizeLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionEncryptionContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      ENCRYPTION(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionDataDirectoryContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      DIRECTORY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      DATA(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionRecalculationContext extends TableOptionContext {
      _extBoolValue?: Token | null;
      constructor(ctx: TableOptionContext);
      STATS_AUTO_RECALC(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionAutoIncrementContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      AUTO_INCREMENT(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionEncryptionKeyIdContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      ENCRYPTION_KEY_ID(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionChecksumContext extends TableOptionContext {
      _boolValue?: Token | null;
      constructor(ctx: TableOptionContext);
      CHECKSUM(): antlr.TerminalNode | null;
      PAGE_CHECKSUM(): antlr.TerminalNode | null;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionDelayContext extends TableOptionContext {
      _boolValue?: Token | null;
      constructor(ctx: TableOptionContext);
      DELAY_KEY_WRITE(): antlr.TerminalNode;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionConnectionContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      CONNECTION(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionTransactionalContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      TRANSACTIONAL(): antlr.TerminalNode;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionPageCompressionLevelContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      decimalLiteral(): DecimalLiteralContext;
      PAGE_COMPRESSION_LEVEL(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionSecondaryEngineAttributeContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      SECONDARY_ENGINE_ATTRIBUTE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionCommentContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      COMMENT(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionAverageContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      AVG_ROW_LENGTH(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionRowFormatContext extends TableOptionContext {
      _rowFormat?: Token | null;
      constructor(ctx: TableOptionContext);
      ROW_FORMAT(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      DYNAMIC(): antlr.TerminalNode | null;
      FIXED(): antlr.TerminalNode | null;
      COMPRESSED(): antlr.TerminalNode | null;
      REDUNDANT(): antlr.TerminalNode | null;
      COMPACT(): antlr.TerminalNode | null;
      ID(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionCompressionContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      COMPRESSION(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode | null;
      ID(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionInsertMethodContext extends TableOptionContext {
      _insertMethod?: Token | null;
      constructor(ctx: TableOptionContext);
      INSERT_METHOD(): antlr.TerminalNode;
      NO(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      LAST(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionEngineAttributeContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      ENGINE_ATTRIBUTE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableOptionMinRowsContext extends TableOptionContext {
      constructor(ctx: TableOptionContext);
      MIN_ROWS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MYSQL(): antlr.TerminalNode | null;
      ODBC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TablespaceStorageContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STORAGE(): antlr.TerminalNode;
      DISK(): antlr.TerminalNode | null;
      MEMORY(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionDefinitionsContext extends antlr.ParserRuleContext {
      _count?: DecimalLiteralContext;
      _subCount?: DecimalLiteralContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode;
      BY(): antlr.TerminalNode[];
      BY(i: number): antlr.TerminalNode | null;
      partitionFunctionDefinition(): PartitionFunctionDefinitionContext;
      PARTITIONS(): antlr.TerminalNode | null;
      SUBPARTITION(): antlr.TerminalNode | null;
      subpartitionFunctionDefinition(): SubpartitionFunctionDefinitionContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      partitionDefinition(): PartitionDefinitionContext[];
      partitionDefinition(i: number): PartitionDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      SUBPARTITIONS(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionFunctionDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: PartitionFunctionDefinitionContext): void;
  }
  export class PartitionFunctionKeyContext extends PartitionFunctionDefinitionContext {
      _algType?: Token | null;
      constructor(ctx: PartitionFunctionDefinitionContext);
      KEY(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      LINEAR(): antlr.TerminalNode | null;
      ALGORITHM(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      TWO_DECIMAL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionFunctionHashContext extends PartitionFunctionDefinitionContext {
      constructor(ctx: PartitionFunctionDefinitionContext);
      HASH(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext;
      RR_BRACKET(): antlr.TerminalNode;
      LINEAR(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionFunctionListContext extends PartitionFunctionDefinitionContext {
      constructor(ctx: PartitionFunctionDefinitionContext);
      LIST(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionFunctionRangeContext extends PartitionFunctionDefinitionContext {
      constructor(ctx: PartitionFunctionDefinitionContext);
      RANGE(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SubpartitionFunctionDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: SubpartitionFunctionDefinitionContext): void;
  }
  export class SubPartitionFunctionHashContext extends SubpartitionFunctionDefinitionContext {
      constructor(ctx: SubpartitionFunctionDefinitionContext);
      HASH(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext;
      RR_BRACKET(): antlr.TerminalNode;
      LINEAR(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SubPartitionFunctionKeyContext extends SubpartitionFunctionDefinitionContext {
      _algType?: Token | null;
      constructor(ctx: SubpartitionFunctionDefinitionContext);
      KEY(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      uidList(): UidListContext;
      RR_BRACKET(): antlr.TerminalNode;
      LINEAR(): antlr.TerminalNode | null;
      ALGORITHM(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      TWO_DECIMAL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: PartitionDefinitionContext): void;
  }
  export class PartitionComparisonContext extends PartitionDefinitionContext {
      constructor(ctx: PartitionDefinitionContext);
      PARTITION(): antlr.TerminalNode;
      uid(): UidContext;
      VALUES(): antlr.TerminalNode;
      LESS(): antlr.TerminalNode;
      THAN(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      partitionDefinerAtom(): PartitionDefinerAtomContext[];
      partitionDefinerAtom(i: number): PartitionDefinerAtomContext | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      partitionOption(): PartitionOptionContext[];
      partitionOption(i: number): PartitionOptionContext | null;
      subpartitionDefinition(): SubpartitionDefinitionContext[];
      subpartitionDefinition(i: number): SubpartitionDefinitionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionListAtomContext extends PartitionDefinitionContext {
      constructor(ctx: PartitionDefinitionContext);
      PARTITION(): antlr.TerminalNode;
      uid(): UidContext;
      VALUES(): antlr.TerminalNode;
      IN(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      partitionDefinerAtom(): PartitionDefinerAtomContext[];
      partitionDefinerAtom(i: number): PartitionDefinerAtomContext | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      partitionOption(): PartitionOptionContext[];
      partitionOption(i: number): PartitionOptionContext | null;
      subpartitionDefinition(): SubpartitionDefinitionContext[];
      subpartitionDefinition(i: number): SubpartitionDefinitionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionListVectorContext extends PartitionDefinitionContext {
      constructor(ctx: PartitionDefinitionContext);
      PARTITION(): antlr.TerminalNode;
      uid(): UidContext;
      VALUES(): antlr.TerminalNode;
      IN(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      partitionDefinerVector(): PartitionDefinerVectorContext[];
      partitionDefinerVector(i: number): PartitionDefinerVectorContext | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      partitionOption(): PartitionOptionContext[];
      partitionOption(i: number): PartitionOptionContext | null;
      subpartitionDefinition(): SubpartitionDefinitionContext[];
      subpartitionDefinition(i: number): SubpartitionDefinitionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionSimpleContext extends PartitionDefinitionContext {
      constructor(ctx: PartitionDefinitionContext);
      PARTITION(): antlr.TerminalNode;
      uid(): UidContext;
      partitionOption(): PartitionOptionContext[];
      partitionOption(i: number): PartitionOptionContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      subpartitionDefinition(): SubpartitionDefinitionContext[];
      subpartitionDefinition(i: number): SubpartitionDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionDefinerAtomContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      constant(): ConstantContext | null;
      expression(): ExpressionContext | null;
      MAXVALUE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionDefinerVectorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      partitionDefinerAtom(): PartitionDefinerAtomContext[];
      partitionDefinerAtom(i: number): PartitionDefinerAtomContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SubpartitionDefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SUBPARTITION(): antlr.TerminalNode;
      uid(): UidContext;
      partitionOption(): PartitionOptionContext[];
      partitionOption(i: number): PartitionOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: PartitionOptionContext): void;
  }
  export class PartitionOptionCommentContext extends PartitionOptionContext {
      _comment?: Token | null;
      constructor(ctx: PartitionOptionContext);
      COMMENT(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionNodeGroupContext extends PartitionOptionContext {
      _nodegroup?: UidContext;
      constructor(ctx: PartitionOptionContext);
      NODEGROUP(): antlr.TerminalNode;
      uid(): UidContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionIndexDirectoryContext extends PartitionOptionContext {
      _indexDirectory?: Token | null;
      constructor(ctx: PartitionOptionContext);
      INDEX(): antlr.TerminalNode;
      DIRECTORY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionMaxRowsContext extends PartitionOptionContext {
      _maxRows?: DecimalLiteralContext;
      constructor(ctx: PartitionOptionContext);
      MAX_ROWS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionTablespaceContext extends PartitionOptionContext {
      _tablespace?: UidContext;
      constructor(ctx: PartitionOptionContext);
      TABLESPACE(): antlr.TerminalNode;
      uid(): UidContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionEngineContext extends PartitionOptionContext {
      constructor(ctx: PartitionOptionContext);
      ENGINE(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      DEFAULT(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionMinRowsContext extends PartitionOptionContext {
      _minRows?: DecimalLiteralContext;
      constructor(ctx: PartitionOptionContext);
      MIN_ROWS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionOptionDataDirectoryContext extends PartitionOptionContext {
      _dataDirectory?: Token | null;
      constructor(ctx: PartitionOptionContext);
      DATA(): antlr.TerminalNode;
      DIRECTORY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterDatabaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AlterDatabaseContext): void;
  }
  export class AlterUpgradeNameContext extends AlterDatabaseContext {
      _dbFormat?: Token | null;
      constructor(ctx: AlterDatabaseContext);
      ALTER(): antlr.TerminalNode;
      uid(): UidContext;
      UPGRADE(): antlr.TerminalNode;
      DATA(): antlr.TerminalNode;
      DIRECTORY(): antlr.TerminalNode;
      NAME(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterSimpleDatabaseContext extends AlterDatabaseContext {
      _dbFormat?: Token | null;
      constructor(ctx: AlterDatabaseContext);
      ALTER(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      createDatabaseOption(): CreateDatabaseOptionContext[];
      createDatabaseOption(i: number): CreateDatabaseOptionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterEventContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      EVENT(): antlr.TerminalNode;
      fullId(): FullIdContext[];
      fullId(i: number): FullIdContext | null;
      ownerStatement(): OwnerStatementContext | null;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      SCHEDULE(): antlr.TerminalNode | null;
      scheduleExpression(): ScheduleExpressionContext | null;
      COMPLETION(): antlr.TerminalNode | null;
      PRESERVE(): antlr.TerminalNode | null;
      RENAME(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      enableType(): EnableTypeContext | null;
      COMMENT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      DO(): antlr.TerminalNode | null;
      routineBody(): RoutineBodyContext | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterFunctionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode;
      fullId(): FullIdContext;
      routineOption(): RoutineOptionContext[];
      routineOption(i: number): RoutineOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterInstanceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      INSTANCE(): antlr.TerminalNode;
      ROTATE(): antlr.TerminalNode;
      INNODB(): antlr.TerminalNode;
      MASTER(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterLogfileGroupContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      LOGFILE(): antlr.TerminalNode;
      GROUP(): antlr.TerminalNode;
      uid(): UidContext;
      ADD(): antlr.TerminalNode;
      UNDOFILE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      ENGINE(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      INITIAL_SIZE(): antlr.TerminalNode | null;
      fileSizeLiteral(): FileSizeLiteralContext | null;
      WAIT(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterProcedureContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      PROCEDURE(): antlr.TerminalNode;
      fullId(): FullIdContext;
      routineOption(): RoutineOptionContext[];
      routineOption(i: number): RoutineOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterServerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      SERVER(): antlr.TerminalNode;
      uid(): UidContext;
      OPTIONS(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      serverOption(): ServerOptionContext[];
      serverOption(i: number): ServerOptionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterTableContext extends antlr.ParserRuleContext {
      _intimeAction?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      IGNORE(): antlr.TerminalNode | null;
      waitNowaitClause(): WaitNowaitClauseContext | null;
      alterSpecification(): AlterSpecificationContext[];
      alterSpecification(i: number): AlterSpecificationContext | null;
      partitionDefinitions(): PartitionDefinitionsContext | null;
      ONLINE(): antlr.TerminalNode | null;
      OFFLINE(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterTablespaceContext extends antlr.ParserRuleContext {
      _objectAction?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      uid(): UidContext;
      DATAFILE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      ENGINE(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      ADD(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      INITIAL_SIZE(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      fileSizeLiteral(): FileSizeLiteralContext | null;
      WAIT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterViewContext extends antlr.ParserRuleContext {
      _algType?: Token | null;
      _secContext?: Token | null;
      _checkOpt?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      fullId(): FullIdContext;
      AS(): antlr.TerminalNode;
      selectStatement(): SelectStatementContext;
      ALGORITHM(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      ownerStatement(): OwnerStatementContext | null;
      SQL(): antlr.TerminalNode | null;
      SECURITY(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      UNDEFINED(): antlr.TerminalNode | null;
      MERGE(): antlr.TerminalNode | null;
      TEMPTABLE(): antlr.TerminalNode | null;
      DEFINER(): antlr.TerminalNode | null;
      INVOKER(): antlr.TerminalNode | null;
      CASCADED(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterSpecificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AlterSpecificationContext): void;
  }
  export class AlterByAlterColumnDefaultContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ALTER(): antlr.TerminalNode;
      uid(): UidContext;
      SET(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      COLUMN(): antlr.TerminalNode | null;
      VISIBLE(): antlr.TerminalNode | null;
      INVISIBLE(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDisableKeysContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      DISABLE(): antlr.TerminalNode;
      KEYS(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDefaultCharsetContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      CHARACTER(): antlr.TerminalNode;
      SET(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      charsetName(): CharsetNameContext;
      DEFAULT(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByRenameColumnContext extends AlterSpecificationContext {
      _oldColumn?: UidContext;
      _newColumn?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      RENAME(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByConvertCharsetContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      CONVERT(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      charsetName(): CharsetNameContext;
      CHARSET(): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddForeignKeyContext extends AlterSpecificationContext {
      _name?: UidContext;
      _indexName?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      FOREIGN(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      referenceDefinition(): ReferenceDefinitionContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByRenameIndexContext extends AlterSpecificationContext {
      _indexFormat?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      RENAME(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      TO(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByRenameContext extends AlterSpecificationContext {
      _renameFormat?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      RENAME(): antlr.TerminalNode;
      uid(): UidContext | null;
      fullId(): FullIdContext | null;
      TO(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByImportTablespaceContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      IMPORT(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddDefinitionsContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      createDefinition(): CreateDefinitionContext[];
      createDefinition(i: number): CreateDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAlterCheckTableConstraintContext extends AlterSpecificationContext {
      _name?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      ALTER(): antlr.TerminalNode;
      CHECK(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      stringLiteral(): StringLiteralContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      ENFORCED(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDropConstraintCheckContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      DROP(): antlr.TerminalNode;
      uid(): UidContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddColumnsContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      columnDefinition(): ColumnDefinitionContext[];
      columnDefinition(i: number): ColumnDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COLUMN(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAlterIndexVisibilityContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ALTER(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      uid(): UidContext;
      VISIBLE(): antlr.TerminalNode | null;
      INVISIBLE(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDropForeignKeyContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      DROP(): antlr.TerminalNode;
      FOREIGN(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      uid(): UidContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddCheckTableConstraintContext extends AlterSpecificationContext {
      _name?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      CHECK(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      stringLiteral(): StringLiteralContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      ENFORCED(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterPartitionContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      alterPartitionSpecification(): AlterPartitionSpecificationContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddIndexContext extends AlterSpecificationContext {
      _indexFormat?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDropColumnContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      DROP(): antlr.TerminalNode;
      uid(): UidContext;
      COLUMN(): antlr.TerminalNode | null;
      RESTRICT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByChangeDefaultContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ALTER(): antlr.TerminalNode;
      uid(): UidContext;
      SET(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      defaultValue(): DefaultValueContext | null;
      DROP(): antlr.TerminalNode | null;
      COLUMN(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByForceContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      FORCE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddSpecialIndexContext extends AlterSpecificationContext {
      _keyType?: Token | null;
      _indexFormat?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      FULLTEXT(): antlr.TerminalNode | null;
      SPATIAL(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByModifyColumnContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      MODIFY(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      columnDefinition(): ColumnDefinitionContext;
      COLUMN(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByTableOptionContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      tableOption(): TableOptionContext[];
      tableOption(i: number): TableOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDropPrimaryKeyContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      DROP(): antlr.TerminalNode;
      PRIMARY(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByLockContext extends AlterSpecificationContext {
      _lockType?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      LOCK(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode | null;
      SHARED(): antlr.TerminalNode | null;
      EXCLUSIVE(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDiscardTablespaceContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      DISCARD(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByValidateContext extends AlterSpecificationContext {
      _validationFormat?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      VALIDATION(): antlr.TerminalNode;
      WITHOUT(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddPrimaryKeyContext extends AlterSpecificationContext {
      _name?: UidContext;
      _index?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      PRIMARY(): antlr.TerminalNode;
      KEY(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByEnableKeysContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ENABLE(): antlr.TerminalNode;
      KEYS(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterBySetAlgorithmContext extends AlterSpecificationContext {
      _algType?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      ALGORITHM(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      INSTANT(): antlr.TerminalNode | null;
      INPLACE(): antlr.TerminalNode | null;
      COPY(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByChangeColumnContext extends AlterSpecificationContext {
      _oldColumn?: UidContext;
      _newColumn?: UidContext;
      _afterColumn?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      CHANGE(): antlr.TerminalNode;
      columnDefinition(): ColumnDefinitionContext;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COLUMN(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddUniqueKeyContext extends AlterSpecificationContext {
      _name?: UidContext;
      _indexFormat?: Token | null;
      _indexName?: UidContext;
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      UNIQUE(): antlr.TerminalNode;
      indexColumnNames(): IndexColumnNamesContext;
      CONSTRAINT(): antlr.TerminalNode | null;
      indexType(): IndexTypeContext | null;
      indexOption(): IndexOptionContext[];
      indexOption(i: number): IndexOptionContext | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDropIndexContext extends AlterSpecificationContext {
      _indexFormat?: Token | null;
      constructor(ctx: AlterSpecificationContext);
      DROP(): antlr.TerminalNode;
      uid(): UidContext;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddColumnContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ADD(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      columnDefinition(): ColumnDefinitionContext;
      COLUMN(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByOrderContext extends AlterSpecificationContext {
      constructor(ctx: AlterSpecificationContext);
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      uidList(): UidListContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterPartitionSpecificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AlterPartitionSpecificationContext): void;
  }
  export class AlterByImportPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      IMPORT(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDropPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      DROP(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByDiscardPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      DISCARD(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAddPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      ADD(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      partitionDefinition(): PartitionDefinitionContext[];
      partitionDefinition(i: number): PartitionDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByRemovePartitioningContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      REMOVE(): antlr.TerminalNode;
      PARTITIONING(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByOptimizePartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      OPTIMIZE(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByCheckPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      CHECK(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByCoalescePartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      COALESCE(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByReorganizePartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      REORGANIZE(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext;
      INTO(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      partitionDefinition(): PartitionDefinitionContext[];
      partitionDefinition(i: number): PartitionDefinitionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByAnalyzePartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      ANALYZE(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByRebuildPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      REBUILD(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByUpgradePartitioningContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      UPGRADE(): antlr.TerminalNode;
      PARTITIONING(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByTruncatePartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      TRUNCATE(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByRepairPartitionContext extends AlterPartitionSpecificationContext {
      constructor(ctx: AlterPartitionSpecificationContext);
      REPAIR(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterByExchangePartitionContext extends AlterPartitionSpecificationContext {
      _validationFormat?: Token | null;
      constructor(ctx: AlterPartitionSpecificationContext);
      EXCHANGE(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      uid(): UidContext;
      WITH(): antlr.TerminalNode[];
      WITH(i: number): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      VALIDATION(): antlr.TerminalNode | null;
      WITHOUT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropDatabaseContext extends antlr.ParserRuleContext {
      _dbFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      uid(): UidContext;
      DATABASE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      ifExists(): IfExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropEventContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      EVENT(): antlr.TerminalNode;
      fullId(): FullIdContext;
      ifExists(): IfExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropIndexContext extends antlr.ParserRuleContext {
      _intimeAction?: Token | null;
      _algType?: Token | null;
      _lockType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      uid(): UidContext;
      ON(): antlr.TerminalNode;
      tableName(): TableNameContext;
      ALGORITHM(): antlr.TerminalNode[];
      ALGORITHM(i: number): antlr.TerminalNode | null;
      LOCK(): antlr.TerminalNode[];
      LOCK(i: number): antlr.TerminalNode | null;
      ONLINE(): antlr.TerminalNode | null;
      OFFLINE(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode[];
      DEFAULT(i: number): antlr.TerminalNode | null;
      INPLACE(): antlr.TerminalNode[];
      INPLACE(i: number): antlr.TerminalNode | null;
      COPY(): antlr.TerminalNode[];
      COPY(i: number): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode[];
      NONE(i: number): antlr.TerminalNode | null;
      SHARED(): antlr.TerminalNode[];
      SHARED(i: number): antlr.TerminalNode | null;
      EXCLUSIVE(): antlr.TerminalNode[];
      EXCLUSIVE(i: number): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropLogfileGroupContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      LOGFILE(): antlr.TerminalNode;
      GROUP(): antlr.TerminalNode;
      uid(): UidContext;
      ENGINE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropProcedureContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      PROCEDURE(): antlr.TerminalNode;
      fullId(): FullIdContext;
      ifExists(): IfExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropFunctionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode;
      fullId(): FullIdContext;
      ifExists(): IfExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropServerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      SERVER(): antlr.TerminalNode;
      uid(): UidContext;
      ifExists(): IfExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropTableContext extends antlr.ParserRuleContext {
      _dropType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tables(): TablesContext;
      TEMPORARY(): antlr.TerminalNode | null;
      ifExists(): IfExistsContext | null;
      RESTRICT(): antlr.TerminalNode | null;
      CASCADE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropTablespaceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      uid(): UidContext;
      ENGINE(): antlr.TerminalNode | null;
      engineName(): EngineNameContext | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropTriggerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      TRIGGER(): antlr.TerminalNode;
      fullId(): FullIdContext;
      ifExists(): IfExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropViewContext extends antlr.ParserRuleContext {
      _dropType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      fullId(): FullIdContext[];
      fullId(i: number): FullIdContext | null;
      ifExists(): IfExistsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      RESTRICT(): antlr.TerminalNode | null;
      CASCADE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropRoleContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      ROLE(): antlr.TerminalNode;
      roleName(): RoleNameContext[];
      roleName(i: number): RoleNameContext | null;
      ifExists(): IfExistsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetRoleContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode;
      TO(): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      roleName(): RoleNameContext[];
      roleName(i: number): RoleNameContext | null;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      roleOption(): RoleOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RenameTableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RENAME(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      renameTableClause(): RenameTableClauseContext[];
      renameTableClause(i: number): RenameTableClauseContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RenameTableClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableName(): TableNameContext[];
      tableName(i: number): TableNameContext | null;
      TO(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TruncateTableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRUNCATE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      TABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CallStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CALL(): antlr.TerminalNode;
      fullId(): FullIdContext;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      constants(): ConstantsContext | null;
      expressions(): ExpressionsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DeleteStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      singleDeleteStatement(): SingleDeleteStatementContext | null;
      multipleDeleteStatement(): MultipleDeleteStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DoStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DO(): antlr.TerminalNode;
      expressions(): ExpressionsContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      handlerOpenStatement(): HandlerOpenStatementContext | null;
      handlerReadIndexStatement(): HandlerReadIndexStatementContext | null;
      handlerReadStatement(): HandlerReadStatementContext | null;
      handlerCloseStatement(): HandlerCloseStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class InsertStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      _partitions?: UidListContext;
      _columns?: FullColumnNameListContext;
      _setFirst?: UpdatedElementContext;
      _updatedElement?: UpdatedElementContext;
      _setElements: UpdatedElementContext[];
      _duplicatedFirst?: UpdatedElementContext;
      _duplicatedElements: UpdatedElementContext[];
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INSERT(): antlr.TerminalNode;
      tableName(): TableNameContext;
      insertStatementValue(): InsertStatementValueContext | null;
      SET(): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode | null;
      INTO(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      updatedElement(): UpdatedElementContext[];
      updatedElement(i: number): UpdatedElementContext | null;
      ON(): antlr.TerminalNode | null;
      DUPLICATE(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      DELAYED(): antlr.TerminalNode | null;
      HIGH_PRIORITY(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      AS(): antlr.TerminalNode | null;
      fullColumnNameList(): FullColumnNameListContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LoadDataStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      _filename?: Token | null;
      _violation?: Token | null;
      _charset?: CharsetNameContext;
      _fieldsFormat?: Token | null;
      _linesFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOAD(): antlr.TerminalNode;
      DATA(): antlr.TerminalNode;
      INFILE(): antlr.TerminalNode;
      INTO(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      STRING_LITERAL(): antlr.TerminalNode;
      LOCAL(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode[];
      SET(i: number): antlr.TerminalNode | null;
      LINES(): antlr.TerminalNode[];
      LINES(i: number): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode[];
      IGNORE(i: number): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      assignmentField(): AssignmentFieldContext[];
      assignmentField(i: number): AssignmentFieldContext | null;
      updatedElement(): UpdatedElementContext[];
      updatedElement(i: number): UpdatedElementContext | null;
      charsetName(): CharsetNameContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      CONCURRENT(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      FIELDS(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode | null;
      selectFieldsInto(): SelectFieldsIntoContext[];
      selectFieldsInto(i: number): SelectFieldsIntoContext | null;
      selectLinesInto(): SelectLinesIntoContext[];
      selectLinesInto(i: number): SelectLinesIntoContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LoadXmlStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      _filename?: Token | null;
      _violation?: Token | null;
      _charset?: CharsetNameContext;
      _tag?: Token | null;
      _linesFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOAD(): antlr.TerminalNode;
      XML(): antlr.TerminalNode;
      INFILE(): antlr.TerminalNode;
      INTO(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode[];
      SET(i: number): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode[];
      ROWS(i: number): antlr.TerminalNode | null;
      IDENTIFIED(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      LESS_SYMBOL(): antlr.TerminalNode | null;
      GREATER_SYMBOL(): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode[];
      IGNORE(i: number): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      assignmentField(): AssignmentFieldContext[];
      assignmentField(i: number): AssignmentFieldContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      updatedElement(): UpdatedElementContext[];
      updatedElement(i: number): UpdatedElementContext | null;
      charsetName(): CharsetNameContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      CONCURRENT(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      LINES(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReplaceStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      _partitions?: UidListContext;
      _columns?: UidListContext;
      _setFirst?: UpdatedElementContext;
      _updatedElement?: UpdatedElementContext;
      _setElements: UpdatedElementContext[];
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPLACE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      insertStatementValue(): InsertStatementValueContext | null;
      SET(): antlr.TerminalNode | null;
      INTO(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      updatedElement(): UpdatedElementContext[];
      updatedElement(i: number): UpdatedElementContext | null;
      uidList(): UidListContext[];
      uidList(i: number): UidListContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      DELAYED(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: SelectStatementContext): void;
  }
  export class UnionSelectContext extends SelectStatementContext {
      _unionType?: Token | null;
      constructor(ctx: SelectStatementContext);
      querySpecificationNointo(): QuerySpecificationNointoContext | null;
      queryExpressionNointo(): QueryExpressionNointoContext | null;
      unionStatement(): UnionStatementContext[];
      unionStatement(i: number): UnionStatementContext | null;
      UNION(): antlr.TerminalNode | null;
      orderByClause(): OrderByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      lockClause(): LockClauseContext | null;
      querySpecification(): QuerySpecificationContext | null;
      queryExpression(): QueryExpressionContext | null;
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UnionParenthesisSelectContext extends SelectStatementContext {
      _unionType?: Token | null;
      constructor(ctx: SelectStatementContext);
      queryExpressionNointo(): QueryExpressionNointoContext;
      unionParenthesis(): UnionParenthesisContext[];
      unionParenthesis(i: number): UnionParenthesisContext | null;
      UNION(): antlr.TerminalNode | null;
      queryExpression(): QueryExpressionContext | null;
      orderByClause(): OrderByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      lockClause(): LockClauseContext | null;
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleSelectContext extends SelectStatementContext {
      constructor(ctx: SelectStatementContext);
      querySpecification(): QuerySpecificationContext;
      lockClause(): LockClauseContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ParenthesisSelectContext extends SelectStatementContext {
      constructor(ctx: SelectStatementContext);
      queryExpression(): QueryExpressionContext;
      lockClause(): LockClauseContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WithLateralStatementContext extends SelectStatementContext {
      constructor(ctx: SelectStatementContext);
      querySpecificationNointo(): QuerySpecificationNointoContext;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      lateralStatement(): LateralStatementContext[];
      lateralStatement(i: number): LateralStatementContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UpdateStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      singleUpdateStatement(): SingleUpdateStatementContext | null;
      multipleUpdateStatement(): MultipleUpdateStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ValuesStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VALUES(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      expressionsWithDefaults(): ExpressionsWithDefaultsContext[];
      expressionsWithDefaults(i: number): ExpressionsWithDefaultsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class InsertStatementValueContext extends antlr.ParserRuleContext {
      _insertFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectStatement(): SelectStatementContext | null;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      VALUES(): antlr.TerminalNode | null;
      VALUE(): antlr.TerminalNode | null;
      expressionsWithDefaults(): ExpressionsWithDefaultsContext[];
      expressionsWithDefaults(i: number): ExpressionsWithDefaultsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UpdatedElementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fullColumnName(): FullColumnNameContext;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      expression(): ExpressionContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AssignmentFieldContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext | null;
      LOCAL_ID(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LockClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      LOCK(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      SHARE(): antlr.TerminalNode | null;
      MODE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SingleDeleteStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DELETE(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      tableName(): TableNameContext;
      QUICK(): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      orderByClause(): OrderByClauseContext | null;
      LIMIT(): antlr.TerminalNode | null;
      limitClauseAtom(): LimitClauseAtomContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MultipleDeleteStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DELETE(): antlr.TerminalNode;
      tableName(): TableNameContext[];
      tableName(i: number): TableNameContext | null;
      FROM(): antlr.TerminalNode | null;
      tableSources(): TableSourcesContext | null;
      USING(): antlr.TerminalNode | null;
      QUICK(): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      DOT(): antlr.TerminalNode[];
      DOT(i: number): antlr.TerminalNode | null;
      STAR(): antlr.TerminalNode[];
      STAR(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerOpenStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HANDLER(): antlr.TerminalNode;
      tableName(): TableNameContext;
      OPEN(): antlr.TerminalNode;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerReadIndexStatementContext extends antlr.ParserRuleContext {
      _index?: UidContext;
      _moveOrder?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HANDLER(): antlr.TerminalNode;
      tableName(): TableNameContext;
      READ(): antlr.TerminalNode;
      uid(): UidContext;
      comparisonOperator(): ComparisonOperatorContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      constants(): ConstantsContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      LIMIT(): antlr.TerminalNode | null;
      limitClauseAtom(): LimitClauseAtomContext | null;
      FIRST(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      PREV(): antlr.TerminalNode | null;
      LAST(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerReadStatementContext extends antlr.ParserRuleContext {
      _moveOrder?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HANDLER(): antlr.TerminalNode;
      tableName(): TableNameContext;
      READ(): antlr.TerminalNode;
      FIRST(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      LIMIT(): antlr.TerminalNode | null;
      limitClauseAtom(): LimitClauseAtomContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerCloseStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HANDLER(): antlr.TerminalNode;
      tableName(): TableNameContext;
      CLOSE(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SingleUpdateStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UPDATE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      SET(): antlr.TerminalNode;
      updatedElement(): UpdatedElementContext[];
      updatedElement(i: number): UpdatedElementContext | null;
      IGNORE(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      orderByClause(): OrderByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MultipleUpdateStatementContext extends antlr.ParserRuleContext {
      _priority?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UPDATE(): antlr.TerminalNode;
      tableSources(): TableSourcesContext;
      SET(): antlr.TerminalNode;
      updatedElement(): UpdatedElementContext[];
      updatedElement(i: number): UpdatedElementContext | null;
      IGNORE(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OrderByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      orderByExpression(): OrderByExpressionContext[];
      orderByExpression(i: number): OrderByExpressionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OrderByExpressionContext extends antlr.ParserRuleContext {
      _order?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expression(): ExpressionContext;
      ASC(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableSourcesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableSource(): TableSourceContext[];
      tableSource(i: number): TableSourceContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableSourceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableSourceContext): void;
  }
  export class TableJsonContext extends TableSourceContext {
      constructor(ctx: TableSourceContext);
      jsonTable(): JsonTableContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableSourceNestedContext extends TableSourceContext {
      constructor(ctx: TableSourceContext);
      LR_BRACKET(): antlr.TerminalNode;
      tableSourceItem(): TableSourceItemContext;
      RR_BRACKET(): antlr.TerminalNode;
      joinPart(): JoinPartContext[];
      joinPart(i: number): JoinPartContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableSourceBaseContext extends TableSourceContext {
      constructor(ctx: TableSourceContext);
      tableSourceItem(): TableSourceItemContext;
      joinPart(): JoinPartContext[];
      joinPart(i: number): JoinPartContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableSourceItemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: TableSourceItemContext): void;
  }
  export class SubqueryTableItemContext extends TableSourceItemContext {
      _parenthesisSubquery?: SelectStatementContext;
      _alias?: UidContext;
      constructor(ctx: TableSourceItemContext);
      uid(): UidContext;
      selectStatement(): SelectStatementContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AtomTableItemContext extends TableSourceItemContext {
      _alias?: UidContext;
      constructor(ctx: TableSourceItemContext);
      tableName(): TableNameContext;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      indexHint(): IndexHintContext[];
      indexHint(i: number): IndexHintContext | null;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableSourcesItemContext extends TableSourceItemContext {
      constructor(ctx: TableSourceItemContext);
      LR_BRACKET(): antlr.TerminalNode;
      tableSources(): TableSourcesContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexHintContext extends antlr.ParserRuleContext {
      _indexHintAction?: Token | null;
      _keyFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      uidList(): UidListContext;
      RR_BRACKET(): antlr.TerminalNode;
      USE(): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode | null;
      FORCE(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      indexHintType(): IndexHintTypeContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexHintTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      JOIN(): antlr.TerminalNode | null;
      ORDER(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      GROUP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JoinPartContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: JoinPartContext): void;
  }
  export class InnerJoinContext extends JoinPartContext {
      constructor(ctx: JoinPartContext);
      JOIN(): antlr.TerminalNode;
      tableSourceItem(): TableSourceItemContext;
      LATERAL(): antlr.TerminalNode | null;
      joinSpec(): JoinSpecContext[];
      joinSpec(i: number): JoinSpecContext | null;
      INNER(): antlr.TerminalNode | null;
      CROSS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NaturalJoinContext extends JoinPartContext {
      constructor(ctx: JoinPartContext);
      NATURAL(): antlr.TerminalNode;
      JOIN(): antlr.TerminalNode;
      tableSourceItem(): TableSourceItemContext;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      OUTER(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OuterJoinContext extends JoinPartContext {
      constructor(ctx: JoinPartContext);
      JOIN(): antlr.TerminalNode;
      tableSourceItem(): TableSourceItemContext;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      OUTER(): antlr.TerminalNode | null;
      LATERAL(): antlr.TerminalNode | null;
      joinSpec(): JoinSpecContext[];
      joinSpec(i: number): JoinSpecContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StraightJoinContext extends JoinPartContext {
      constructor(ctx: JoinPartContext);
      STRAIGHT_JOIN(): antlr.TerminalNode;
      tableSourceItem(): TableSourceItemContext;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JoinSpecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      USING(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class QueryExpressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      querySpecification(): QuerySpecificationContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      queryExpression(): QueryExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class QueryExpressionNointoContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      querySpecificationNointo(): QuerySpecificationNointoContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      queryExpressionNointo(): QueryExpressionNointoContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class QuerySpecificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SELECT(): antlr.TerminalNode;
      selectElements(): SelectElementsContext;
      fromClause(): FromClauseContext;
      selectSpec(): SelectSpecContext[];
      selectSpec(i: number): SelectSpecContext | null;
      selectIntoExpression(): SelectIntoExpressionContext | null;
      groupByClause(): GroupByClauseContext | null;
      havingClause(): HavingClauseContext | null;
      windowClause(): WindowClauseContext | null;
      orderByClause(): OrderByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class QuerySpecificationNointoContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SELECT(): antlr.TerminalNode;
      selectElements(): SelectElementsContext;
      fromClause(): FromClauseContext;
      selectSpec(): SelectSpecContext[];
      selectSpec(i: number): SelectSpecContext | null;
      groupByClause(): GroupByClauseContext | null;
      havingClause(): HavingClauseContext | null;
      windowClause(): WindowClauseContext | null;
      orderByClause(): OrderByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      unionStatement(): UnionStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UnionParenthesisContext extends antlr.ParserRuleContext {
      _unionType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNION(): antlr.TerminalNode;
      queryExpressionNointo(): QueryExpressionNointoContext;
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UnionStatementContext extends antlr.ParserRuleContext {
      _unionType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNION(): antlr.TerminalNode;
      querySpecificationNointo(): QuerySpecificationNointoContext | null;
      queryExpressionNointo(): QueryExpressionNointoContext | null;
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LateralStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LATERAL(): antlr.TerminalNode;
      querySpecificationNointo(): QuerySpecificationNointoContext | null;
      queryExpressionNointo(): QueryExpressionNointoContext | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonTableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      JSON_TABLE(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode;
      COLUMNS(): antlr.TerminalNode;
      jsonColumnList(): JsonColumnListContext;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonColumnListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      jsonColumn(): JsonColumnContext[];
      jsonColumn(i: number): JsonColumnContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonColumnContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fullColumnName(): FullColumnNameContext | null;
      FOR(): antlr.TerminalNode | null;
      ORDINALITY(): antlr.TerminalNode | null;
      dataType(): DataTypeContext | null;
      PATH(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      jsonOnEmpty(): JsonOnEmptyContext | null;
      jsonOnError(): JsonOnErrorContext | null;
      NESTED(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      jsonColumnList(): JsonColumnListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonOnEmptyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode;
      EMPTY(): antlr.TerminalNode;
      NULL_LITERAL(): antlr.TerminalNode | null;
      ERROR(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      defaultValue(): DefaultValueContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonOnErrorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode;
      ERROR(): antlr.TerminalNode[];
      ERROR(i: number): antlr.TerminalNode | null;
      NULL_LITERAL(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      defaultValue(): DefaultValueContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectSpecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      DISTINCTROW(): antlr.TerminalNode | null;
      HIGH_PRIORITY(): antlr.TerminalNode | null;
      STRAIGHT_JOIN(): antlr.TerminalNode | null;
      SQL_SMALL_RESULT(): antlr.TerminalNode | null;
      SQL_BIG_RESULT(): antlr.TerminalNode | null;
      SQL_BUFFER_RESULT(): antlr.TerminalNode | null;
      SQL_CACHE(): antlr.TerminalNode | null;
      SQL_NO_CACHE(): antlr.TerminalNode | null;
      SQL_CALC_FOUND_ROWS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectElementsContext extends antlr.ParserRuleContext {
      _star?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectElement(): SelectElementContext[];
      selectElement(i: number): SelectElementContext | null;
      STAR(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectElementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: SelectElementContext): void;
  }
  export class SelectExpressionElementContext extends SelectElementContext {
      constructor(ctx: SelectElementContext);
      expression(): ExpressionContext;
      LOCAL_ID(): antlr.TerminalNode | null;
      VAR_ASSIGN(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectFunctionElementContext extends SelectElementContext {
      constructor(ctx: SelectElementContext);
      functionCall(): FunctionCallContext;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectStarElementContext extends SelectElementContext {
      constructor(ctx: SelectElementContext);
      fullId(): FullIdContext;
      DOT(): antlr.TerminalNode;
      STAR(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectColumnElementContext extends SelectElementContext {
      constructor(ctx: SelectElementContext);
      fullColumnName(): FullColumnNameContext;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectIntoExpressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: SelectIntoExpressionContext): void;
  }
  export class SelectIntoVariablesContext extends SelectIntoExpressionContext {
      constructor(ctx: SelectIntoExpressionContext);
      INTO(): antlr.TerminalNode;
      assignmentField(): AssignmentFieldContext[];
      assignmentField(i: number): AssignmentFieldContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectIntoTextFileContext extends SelectIntoExpressionContext {
      _filename?: Token | null;
      _charset?: CharsetNameContext;
      _fieldsFormat?: Token | null;
      constructor(ctx: SelectIntoExpressionContext);
      INTO(): antlr.TerminalNode | null;
      OUTFILE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      LINES(): antlr.TerminalNode | null;
      charsetName(): CharsetNameContext | null;
      FIELDS(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      selectFieldsInto(): SelectFieldsIntoContext[];
      selectFieldsInto(i: number): SelectFieldsIntoContext | null;
      selectLinesInto(): SelectLinesIntoContext[];
      selectLinesInto(i: number): SelectLinesIntoContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectIntoDumpFileContext extends SelectIntoExpressionContext {
      constructor(ctx: SelectIntoExpressionContext);
      INTO(): antlr.TerminalNode;
      DUMPFILE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectFieldsIntoContext extends antlr.ParserRuleContext {
      _terminationField?: Token | null;
      _enclosion?: Token | null;
      _escaping?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TERMINATED(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      ENCLOSED(): antlr.TerminalNode | null;
      OPTIONALLY(): antlr.TerminalNode | null;
      ESCAPED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SelectLinesIntoContext extends antlr.ParserRuleContext {
      _starting?: Token | null;
      _terminationLine?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STARTING(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      TERMINATED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FromClauseContext extends antlr.ParserRuleContext {
      _whereExpr?: ExpressionContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      tableSources(): TableSourcesContext | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GroupByClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GROUP(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      groupByItem(): GroupByItemContext[];
      groupByItem(i: number): GroupByItemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      ROLLUP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HavingClauseContext extends antlr.ParserRuleContext {
      _havingExpr?: ExpressionContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HAVING(): antlr.TerminalNode;
      expression(): ExpressionContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WindowClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WINDOW(): antlr.TerminalNode;
      windowName(): WindowNameContext[];
      windowName(i: number): WindowNameContext | null;
      AS(): antlr.TerminalNode[];
      AS(i: number): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      windowSpec(): WindowSpecContext[];
      windowSpec(i: number): WindowSpecContext | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GroupByItemContext extends antlr.ParserRuleContext {
      _order?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expression(): ExpressionContext;
      ASC(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LimitClauseContext extends antlr.ParserRuleContext {
      _offset?: LimitClauseAtomContext;
      _limit?: LimitClauseAtomContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIMIT(): antlr.TerminalNode;
      OFFSET(): antlr.TerminalNode | null;
      limitClauseAtom(): LimitClauseAtomContext[];
      limitClauseAtom(i: number): LimitClauseAtomContext | null;
      COMMA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LimitClauseAtomContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decimalLiteral(): DecimalLiteralContext | null;
      mysqlVariable(): MysqlVariableContext | null;
      simpleId(): SimpleIdContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StartTransactionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      START(): antlr.TerminalNode;
      TRANSACTION(): antlr.TerminalNode;
      transactionMode(): TransactionModeContext[];
      transactionMode(i: number): TransactionModeContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BeginWorkContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BEGIN(): antlr.TerminalNode;
      WORK(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CommitWorkContext extends antlr.ParserRuleContext {
      _nochain?: Token | null;
      _norelease?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMIT(): antlr.TerminalNode;
      WORK(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      RELEASE(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode[];
      NO(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RollbackWorkContext extends antlr.ParserRuleContext {
      _nochain?: Token | null;
      _norelease?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROLLBACK(): antlr.TerminalNode;
      WORK(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      RELEASE(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode[];
      NO(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SavepointStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SAVEPOINT(): antlr.TerminalNode;
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RollbackStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROLLBACK(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      uid(): UidContext;
      WORK(): antlr.TerminalNode | null;
      SAVEPOINT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReleaseStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RELEASE(): antlr.TerminalNode;
      SAVEPOINT(): antlr.TerminalNode;
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LockTablesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOCK(): antlr.TerminalNode;
      lockTableElement(): LockTableElementContext[];
      lockTableElement(i: number): LockTableElementContext | null;
      TABLE(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      waitNowaitClause(): WaitNowaitClauseContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UnlockTablesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNLOCK(): antlr.TerminalNode;
      TABLES(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetAutocommitStatementContext extends antlr.ParserRuleContext {
      _autocommitValue?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      AUTOCOMMIT(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetTransactionStatementContext extends antlr.ParserRuleContext {
      _transactionContext?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      TRANSACTION(): antlr.TerminalNode;
      transactionOption(): TransactionOptionContext[];
      transactionOption(i: number): TransactionOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TransactionModeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      CONSISTENT(): antlr.TerminalNode | null;
      SNAPSHOT(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      WRITE(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LockTableElementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableName(): TableNameContext;
      lockAction(): LockActionContext;
      uid(): UidContext | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LockActionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      READ(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      WRITE(): antlr.TerminalNode | null;
      LOW_PRIORITY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TransactionOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ISOLATION(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      transactionLevel(): TransactionLevelContext | null;
      READ(): antlr.TerminalNode | null;
      WRITE(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TransactionLevelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPEATABLE(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      COMMITTED(): antlr.TerminalNode | null;
      UNCOMMITTED(): antlr.TerminalNode | null;
      SERIALIZABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ChangeMasterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHANGE(): antlr.TerminalNode;
      MASTER(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      masterOption(): MasterOptionContext[];
      masterOption(i: number): MasterOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      channelOption(): ChannelOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ChangeReplicationFilterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHANGE(): antlr.TerminalNode;
      REPLICATION(): antlr.TerminalNode;
      FILTER(): antlr.TerminalNode;
      replicationFilter(): ReplicationFilterContext[];
      replicationFilter(i: number): ReplicationFilterContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PurgeBinaryLogsContext extends antlr.ParserRuleContext {
      _purgeFormat?: Token | null;
      _fileName?: Token | null;
      _timeValue?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PURGE(): antlr.TerminalNode;
      LOGS(): antlr.TerminalNode;
      BINARY(): antlr.TerminalNode | null;
      MASTER(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      BEFORE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ResetMasterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESET(): antlr.TerminalNode;
      MASTER(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ResetSlaveContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESET(): antlr.TerminalNode;
      SLAVE(): antlr.TerminalNode;
      ALL(): antlr.TerminalNode | null;
      channelOption(): ChannelOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StartSlaveContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      START(): antlr.TerminalNode;
      SLAVE(): antlr.TerminalNode;
      threadType(): ThreadTypeContext[];
      threadType(i: number): ThreadTypeContext | null;
      UNTIL(): antlr.TerminalNode | null;
      untilOption(): UntilOptionContext | null;
      connectionOption(): ConnectionOptionContext[];
      connectionOption(i: number): ConnectionOptionContext | null;
      channelOption(): ChannelOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StopSlaveContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STOP(): antlr.TerminalNode;
      SLAVE(): antlr.TerminalNode;
      threadType(): ThreadTypeContext[];
      threadType(i: number): ThreadTypeContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StartGroupReplicationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      START(): antlr.TerminalNode;
      GROUP_REPLICATION(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StopGroupReplicationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STOP(): antlr.TerminalNode;
      GROUP_REPLICATION(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MasterOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: MasterOptionContext): void;
  }
  export class MasterStringOptionContext extends MasterOptionContext {
      constructor(ctx: MasterOptionContext);
      stringMasterOption(): StringMasterOptionContext;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MasterRealOptionContext extends MasterOptionContext {
      constructor(ctx: MasterOptionContext);
      MASTER_HEARTBEAT_PERIOD(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      REAL_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MasterBoolOptionContext extends MasterOptionContext {
      _boolVal?: Token | null;
      constructor(ctx: MasterOptionContext);
      boolMasterOption(): BoolMasterOptionContext;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MasterUidListOptionContext extends MasterOptionContext {
      constructor(ctx: MasterOptionContext);
      IGNORE_SERVER_IDS(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MasterDecimalOptionContext extends MasterOptionContext {
      constructor(ctx: MasterOptionContext);
      decimalMasterOption(): DecimalMasterOptionContext;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StringMasterOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MASTER_BIND(): antlr.TerminalNode | null;
      MASTER_HOST(): antlr.TerminalNode | null;
      MASTER_USER(): antlr.TerminalNode | null;
      MASTER_PASSWORD(): antlr.TerminalNode | null;
      MASTER_LOG_FILE(): antlr.TerminalNode | null;
      RELAY_LOG_FILE(): antlr.TerminalNode | null;
      MASTER_SSL_CA(): antlr.TerminalNode | null;
      MASTER_SSL_CAPATH(): antlr.TerminalNode | null;
      MASTER_SSL_CERT(): antlr.TerminalNode | null;
      MASTER_SSL_CRL(): antlr.TerminalNode | null;
      MASTER_SSL_CRLPATH(): antlr.TerminalNode | null;
      MASTER_SSL_KEY(): antlr.TerminalNode | null;
      MASTER_SSL_CIPHER(): antlr.TerminalNode | null;
      MASTER_TLS_VERSION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DecimalMasterOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MASTER_PORT(): antlr.TerminalNode | null;
      MASTER_CONNECT_RETRY(): antlr.TerminalNode | null;
      MASTER_RETRY_COUNT(): antlr.TerminalNode | null;
      MASTER_DELAY(): antlr.TerminalNode | null;
      MASTER_LOG_POS(): antlr.TerminalNode | null;
      RELAY_LOG_POS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BoolMasterOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MASTER_AUTO_POSITION(): antlr.TerminalNode | null;
      MASTER_SSL(): antlr.TerminalNode | null;
      MASTER_SSL_VERIFY_SERVER_CERT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ChannelOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode;
      CHANNEL(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReplicationFilterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ReplicationFilterContext): void;
  }
  export class WildIgnoreTableReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_WILD_IGNORE_TABLE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      simpleStrings(): SimpleStringsContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DoTableReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_DO_TABLE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      tables(): TablesContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IgnoreTableReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_IGNORE_TABLE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      tables(): TablesContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RewriteDbReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_REWRITE_DB(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      tablePair(): TablePairContext[];
      tablePair(i: number): TablePairContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DoDbReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_DO_DB(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      uidList(): UidListContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IgnoreDbReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_IGNORE_DB(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      uidList(): UidListContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WildDoTableReplicationContext extends ReplicationFilterContext {
      constructor(ctx: ReplicationFilterContext);
      REPLICATE_WILD_DO_TABLE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      simpleStrings(): SimpleStringsContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TablePairContext extends antlr.ParserRuleContext {
      _firstTable?: TableNameContext;
      _secondTable?: TableNameContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      tableName(): TableNameContext[];
      tableName(i: number): TableNameContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ThreadTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IO_THREAD(): antlr.TerminalNode | null;
      SQL_THREAD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UntilOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: UntilOptionContext): void;
  }
  export class GtidsUntilOptionContext extends UntilOptionContext {
      _gtids?: Token | null;
      constructor(ctx: UntilOptionContext);
      EQUAL_SYMBOL(): antlr.TerminalNode;
      gtuidSet(): GtuidSetContext;
      SQL_BEFORE_GTIDS(): antlr.TerminalNode | null;
      SQL_AFTER_GTIDS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SqlGapsUntilOptionContext extends UntilOptionContext {
      constructor(ctx: UntilOptionContext);
      SQL_AFTER_MTS_GAPS(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MasterLogUntilOptionContext extends UntilOptionContext {
      constructor(ctx: UntilOptionContext);
      MASTER_LOG_FILE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode;
      MASTER_LOG_POS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RelayLogUntilOptionContext extends UntilOptionContext {
      constructor(ctx: UntilOptionContext);
      RELAY_LOG_FILE(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode;
      RELAY_LOG_POS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ConnectionOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ConnectionOptionContext): void;
  }
  export class PluginDirConnectionOptionContext extends ConnectionOptionContext {
      _conOptPluginDir?: Token | null;
      constructor(ctx: ConnectionOptionContext);
      PLUGIN_DIR(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserConnectionOptionContext extends ConnectionOptionContext {
      _conOptUser?: Token | null;
      constructor(ctx: ConnectionOptionContext);
      USER(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DefaultAuthConnectionOptionContext extends ConnectionOptionContext {
      _conOptDefAuth?: Token | null;
      constructor(ctx: ConnectionOptionContext);
      DEFAULT_AUTH(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PasswordConnectionOptionContext extends ConnectionOptionContext {
      _conOptPassword?: Token | null;
      constructor(ctx: ConnectionOptionContext);
      PASSWORD(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GtuidSetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uuidSet(): UuidSetContext[];
      uuidSet(i: number): UuidSetContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XaStartTransactionContext extends antlr.ParserRuleContext {
      _xaStart?: Token | null;
      _xaAction?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XA(): antlr.TerminalNode;
      xid(): XidContext;
      START(): antlr.TerminalNode | null;
      BEGIN(): antlr.TerminalNode | null;
      JOIN(): antlr.TerminalNode | null;
      RESUME(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XaEndTransactionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XA(): antlr.TerminalNode;
      END(): antlr.TerminalNode;
      xid(): XidContext;
      SUSPEND(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      MIGRATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XaPrepareStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XA(): antlr.TerminalNode;
      PREPARE(): antlr.TerminalNode;
      xid(): XidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XaCommitWorkContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XA(): antlr.TerminalNode;
      COMMIT(): antlr.TerminalNode;
      xid(): XidContext;
      ONE(): antlr.TerminalNode | null;
      PHASE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XaRollbackWorkContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XA(): antlr.TerminalNode;
      ROLLBACK(): antlr.TerminalNode;
      xid(): XidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XaRecoverWorkContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XA(): antlr.TerminalNode;
      RECOVER(): antlr.TerminalNode;
      CONVERT(): antlr.TerminalNode | null;
      xid(): XidContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrepareStatementContext extends antlr.ParserRuleContext {
      _query?: Token | null;
      _variable?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PREPARE(): antlr.TerminalNode;
      uid(): UidContext;
      FROM(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode | null;
      LOCAL_ID(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExecuteStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXECUTE(): antlr.TerminalNode;
      uid(): UidContext;
      USING(): antlr.TerminalNode | null;
      userVariables(): UserVariablesContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DeallocatePrepareContext extends antlr.ParserRuleContext {
      _dropFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PREPARE(): antlr.TerminalNode;
      uid(): UidContext;
      DEALLOCATE(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoutineBodyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      blockStatement(): BlockStatementContext | null;
      sqlStatement(): SqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BlockStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BEGIN(): antlr.TerminalNode;
      END(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COLON_SYMB(): antlr.TerminalNode | null;
      declareVariable(): DeclareVariableContext[];
      declareVariable(i: number): DeclareVariableContext | null;
      SEMI(): antlr.TerminalNode[];
      SEMI(i: number): antlr.TerminalNode | null;
      declareCondition(): DeclareConditionContext[];
      declareCondition(i: number): DeclareConditionContext | null;
      declareCursor(): DeclareCursorContext[];
      declareCursor(i: number): DeclareCursorContext | null;
      declareHandler(): DeclareHandlerContext[];
      declareHandler(i: number): DeclareHandlerContext | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CaseStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CASE(): antlr.TerminalNode[];
      CASE(i: number): antlr.TerminalNode | null;
      END(): antlr.TerminalNode;
      uid(): UidContext | null;
      expression(): ExpressionContext | null;
      caseAlternative(): CaseAlternativeContext[];
      caseAlternative(i: number): CaseAlternativeContext | null;
      ELSE(): antlr.TerminalNode | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IfStatementContext extends antlr.ParserRuleContext {
      _procedureSqlStatement?: ProcedureSqlStatementContext;
      _thenStatements: ProcedureSqlStatementContext[];
      _elseStatements: ProcedureSqlStatementContext[];
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IF(): antlr.TerminalNode[];
      IF(i: number): antlr.TerminalNode | null;
      expression(): ExpressionContext;
      THEN(): antlr.TerminalNode;
      END(): antlr.TerminalNode;
      elifAlternative(): ElifAlternativeContext[];
      elifAlternative(i: number): ElifAlternativeContext | null;
      ELSE(): antlr.TerminalNode | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IterateStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ITERATE(): antlr.TerminalNode;
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LeaveStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LEAVE(): antlr.TerminalNode;
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LoopStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOOP(): antlr.TerminalNode[];
      LOOP(i: number): antlr.TerminalNode | null;
      END(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COLON_SYMB(): antlr.TerminalNode | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RepeatStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPEAT(): antlr.TerminalNode[];
      REPEAT(i: number): antlr.TerminalNode | null;
      UNTIL(): antlr.TerminalNode;
      expression(): ExpressionContext;
      END(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COLON_SYMB(): antlr.TerminalNode | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ReturnStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RETURN(): antlr.TerminalNode;
      expression(): ExpressionContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WhileStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHILE(): antlr.TerminalNode[];
      WHILE(i: number): antlr.TerminalNode | null;
      expression(): ExpressionContext;
      DO(): antlr.TerminalNode;
      END(): antlr.TerminalNode;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COLON_SYMB(): antlr.TerminalNode | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CursorStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: CursorStatementContext): void;
  }
  export class CloseCursorContext extends CursorStatementContext {
      constructor(ctx: CursorStatementContext);
      CLOSE(): antlr.TerminalNode;
      uid(): UidContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OpenCursorContext extends CursorStatementContext {
      constructor(ctx: CursorStatementContext);
      OPEN(): antlr.TerminalNode;
      uid(): UidContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FetchCursorContext extends CursorStatementContext {
      constructor(ctx: CursorStatementContext);
      FETCH(): antlr.TerminalNode;
      uid(): UidContext;
      INTO(): antlr.TerminalNode;
      uidList(): UidListContext;
      FROM(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DeclareVariableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECLARE(): antlr.TerminalNode;
      uidList(): UidListContext;
      dataType(): DataTypeContext;
      DEFAULT(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DeclareConditionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECLARE(): antlr.TerminalNode;
      uid(): UidContext;
      CONDITION(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext | null;
      SQLSTATE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      VALUE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DeclareCursorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECLARE(): antlr.TerminalNode;
      uid(): UidContext;
      CURSOR(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      selectStatement(): SelectStatementContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DeclareHandlerContext extends antlr.ParserRuleContext {
      _handlerAction?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECLARE(): antlr.TerminalNode;
      HANDLER(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      handlerConditionValue(): HandlerConditionValueContext[];
      handlerConditionValue(i: number): HandlerConditionValueContext | null;
      routineBody(): RoutineBodyContext;
      CONTINUE(): antlr.TerminalNode | null;
      EXIT(): antlr.TerminalNode | null;
      UNDO(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerConditionValueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: HandlerConditionValueContext): void;
  }
  export class HandlerConditionWarningContext extends HandlerConditionValueContext {
      constructor(ctx: HandlerConditionValueContext);
      SQLWARNING(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerConditionCodeContext extends HandlerConditionValueContext {
      constructor(ctx: HandlerConditionValueContext);
      decimalLiteral(): DecimalLiteralContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerConditionNotfoundContext extends HandlerConditionValueContext {
      constructor(ctx: HandlerConditionValueContext);
      NOT(): antlr.TerminalNode;
      FOUND(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerConditionStateContext extends HandlerConditionValueContext {
      constructor(ctx: HandlerConditionValueContext);
      SQLSTATE(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      VALUE(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerConditionExceptionContext extends HandlerConditionValueContext {
      constructor(ctx: HandlerConditionValueContext);
      SQLEXCEPTION(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HandlerConditionNameContext extends HandlerConditionValueContext {
      constructor(ctx: HandlerConditionValueContext);
      uid(): UidContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ProcedureSqlStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SEMI(): antlr.TerminalNode;
      compoundStatement(): CompoundStatementContext | null;
      sqlStatement(): SqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CaseAlternativeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      THEN(): antlr.TerminalNode;
      constant(): ConstantContext | null;
      expression(): ExpressionContext | null;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ElifAlternativeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ELSEIF(): antlr.TerminalNode;
      expression(): ExpressionContext;
      THEN(): antlr.TerminalNode;
      procedureSqlStatement(): ProcedureSqlStatementContext[];
      procedureSqlStatement(i: number): ProcedureSqlStatementContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterUserContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AlterUserContext): void;
  }
  export class AlterUserMysqlV80Context extends AlterUserContext {
      _tlsNone?: Token | null;
      constructor(ctx: AlterUserContext);
      ALTER(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      userAuthOption(): UserAuthOptionContext[];
      userAuthOption(i: number): UserAuthOptionContext | null;
      ifExists(): IfExistsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      REQUIRE(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      userPasswordOption(): UserPasswordOptionContext[];
      userPasswordOption(i: number): UserPasswordOptionContext | null;
      userLockOption(): UserLockOptionContext[];
      userLockOption(i: number): UserLockOptionContext | null;
      COMMENT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      ATTRIBUTE(): antlr.TerminalNode | null;
      tlsOption(): TlsOptionContext[];
      tlsOption(i: number): TlsOptionContext | null;
      NONE(): antlr.TerminalNode | null;
      userResourceOption(): UserResourceOptionContext[];
      userResourceOption(i: number): UserResourceOptionContext | null;
      AND(): antlr.TerminalNode[];
      AND(i: number): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      roleOption(): RoleOptionContext | null;
      userName(): UserNameContext | null;
      uid(): UidContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AlterUserMysqlV56Context extends AlterUserContext {
      constructor(ctx: AlterUserContext);
      ALTER(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      userSpecification(): UserSpecificationContext[];
      userSpecification(i: number): UserSpecificationContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateUserContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: CreateUserContext): void;
  }
  export class CreateUserMysqlV56Context extends CreateUserContext {
      constructor(ctx: CreateUserContext);
      CREATE(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      userAuthOption(): UserAuthOptionContext[];
      userAuthOption(i: number): UserAuthOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateUserMysqlV80Context extends CreateUserContext {
      _tlsNone?: Token | null;
      constructor(ctx: CreateUserContext);
      CREATE(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      userAuthOption(): UserAuthOptionContext[];
      userAuthOption(i: number): UserAuthOptionContext | null;
      ifNotExists(): IfNotExistsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      roleOption(): RoleOptionContext | null;
      REQUIRE(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      userPasswordOption(): UserPasswordOptionContext[];
      userPasswordOption(i: number): UserPasswordOptionContext | null;
      userLockOption(): UserLockOptionContext[];
      userLockOption(i: number): UserLockOptionContext | null;
      COMMENT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      ATTRIBUTE(): antlr.TerminalNode | null;
      tlsOption(): TlsOptionContext[];
      tlsOption(i: number): TlsOptionContext | null;
      NONE(): antlr.TerminalNode | null;
      userResourceOption(): UserResourceOptionContext[];
      userResourceOption(i: number): UserResourceOptionContext | null;
      AND(): antlr.TerminalNode[];
      AND(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DropUserContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      ifExists(): IfExistsContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GrantStatementContext extends antlr.ParserRuleContext {
      _privilegeObject?: Token | null;
      _tlsNone?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GRANT(): antlr.TerminalNode[];
      GRANT(i: number): antlr.TerminalNode | null;
      privelegeClause(): PrivelegeClauseContext[];
      privelegeClause(i: number): PrivelegeClauseContext | null;
      ON(): antlr.TerminalNode | null;
      privilegeLevel(): PrivilegeLevelContext | null;
      TO(): antlr.TerminalNode;
      userAuthOption(): UserAuthOptionContext[];
      userAuthOption(i: number): UserAuthOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      REQUIRE(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode[];
      WITH(i: number): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      ROLE(): antlr.TerminalNode | null;
      roleOption(): RoleOptionContext | null;
      TABLE(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      tlsOption(): TlsOptionContext[];
      tlsOption(i: number): TlsOptionContext | null;
      NONE(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode[];
      OPTION(i: number): antlr.TerminalNode | null;
      userResourceOption(): UserResourceOptionContext[];
      userResourceOption(i: number): UserResourceOptionContext | null;
      AND(): antlr.TerminalNode[];
      AND(i: number): antlr.TerminalNode | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      ADMIN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoleOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEFAULT(): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      EXCEPT(): antlr.TerminalNode | null;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GrantProxyContext extends antlr.ParserRuleContext {
      _fromFirst?: UserNameContext;
      _toFirst?: UserNameContext;
      _userName?: UserNameContext;
      _toOther: UserNameContext[];
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GRANT(): antlr.TerminalNode[];
      GRANT(i: number): antlr.TerminalNode | null;
      PROXY(): antlr.TerminalNode;
      ON(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RenameUserContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RENAME(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      renameUserClause(): RenameUserClauseContext[];
      renameUserClause(i: number): RenameUserClauseContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RevokeStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: RevokeStatementContext): void;
  }
  export class DetailRevokeContext extends RevokeStatementContext {
      _privilegeObject?: Token | null;
      constructor(ctx: RevokeStatementContext);
      REVOKE(): antlr.TerminalNode;
      privelegeClause(): PrivelegeClauseContext[];
      privelegeClause(i: number): PrivelegeClauseContext | null;
      ON(): antlr.TerminalNode;
      privilegeLevel(): PrivilegeLevelContext;
      FROM(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoleRevokeContext extends RevokeStatementContext {
      constructor(ctx: RevokeStatementContext);
      REVOKE(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShortRevokeContext extends RevokeStatementContext {
      constructor(ctx: RevokeStatementContext);
      REVOKE(): antlr.TerminalNode;
      ALL(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      GRANT(): antlr.TerminalNode;
      OPTION(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RevokeProxyContext extends antlr.ParserRuleContext {
      _onUser?: UserNameContext;
      _fromFirst?: UserNameContext;
      _userName?: UserNameContext;
      _fromOther: UserNameContext[];
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REVOKE(): antlr.TerminalNode;
      PROXY(): antlr.TerminalNode;
      ON(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetPasswordStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      PASSWORD(): antlr.TerminalNode;
      EQUAL_SYMBOL(): antlr.TerminalNode;
      passwordFunctionClause(): PasswordFunctionClauseContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      userName(): UserNameContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserSpecificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      userName(): UserNameContext;
      userPasswordOption(): UserPasswordOptionContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserAuthOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: UserAuthOptionContext): void;
  }
  export class SimpleAuthOptionContext extends UserAuthOptionContext {
      constructor(ctx: UserAuthOptionContext);
      userName(): UserNameContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ModuleAuthOptionContext extends UserAuthOptionContext {
      constructor(ctx: UserAuthOptionContext);
      userName(): UserNameContext;
      IDENTIFIED(): antlr.TerminalNode;
      WITH(): antlr.TerminalNode;
      authenticationRule(): AuthenticationRuleContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RandomAuthOptionContext extends UserAuthOptionContext {
      constructor(ctx: UserAuthOptionContext);
      userName(): UserNameContext;
      IDENTIFIED(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      RANDOM(): antlr.TerminalNode;
      PASSWORD(): antlr.TerminalNode;
      authOptionClause(): AuthOptionClauseContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StringAuthOptionContext extends UserAuthOptionContext {
      constructor(ctx: UserAuthOptionContext);
      userName(): UserNameContext;
      IDENTIFIED(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      authOptionClause(): AuthOptionClauseContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HashAuthOptionContext extends UserAuthOptionContext {
      _hashed?: Token | null;
      constructor(ctx: UserAuthOptionContext);
      userName(): UserNameContext;
      IDENTIFIED(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      PASSWORD(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AuthOptionClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPLACE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      RETAIN(): antlr.TerminalNode | null;
      CURRENT(): antlr.TerminalNode | null;
      PASSWORD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AuthenticationRuleContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: AuthenticationRuleContext): void;
  }
  export class PasswordModuleOptionContext extends AuthenticationRuleContext {
      constructor(ctx: AuthenticationRuleContext);
      authPlugin(): AuthPluginContext;
      USING(): antlr.TerminalNode;
      passwordFunctionClause(): PasswordFunctionClauseContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ModuleContext extends AuthenticationRuleContext {
      constructor(ctx: AuthenticationRuleContext);
      authPlugin(): AuthPluginContext;
      authOptionClause(): AuthOptionClauseContext | null;
      BY(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      RANDOM(): antlr.TerminalNode | null;
      PASSWORD(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TlsOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SSL(): antlr.TerminalNode | null;
      X509(): antlr.TerminalNode | null;
      CIPHER(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      ISSUER(): antlr.TerminalNode | null;
      SUBJECT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserResourceOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MAX_QUERIES_PER_HOUR(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext;
      MAX_UPDATES_PER_HOUR(): antlr.TerminalNode | null;
      MAX_CONNECTIONS_PER_HOUR(): antlr.TerminalNode | null;
      MAX_USER_CONNECTIONS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserPasswordOptionContext extends antlr.ParserRuleContext {
      _expireType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PASSWORD(): antlr.TerminalNode | null;
      EXPIRE(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      DAY(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      NEVER(): antlr.TerminalNode | null;
      INTERVAL(): antlr.TerminalNode | null;
      HISTORY(): antlr.TerminalNode | null;
      REUSE(): antlr.TerminalNode | null;
      REQUIRE(): antlr.TerminalNode | null;
      CURRENT(): antlr.TerminalNode | null;
      OPTIONAL(): antlr.TerminalNode | null;
      FAILED_LOGIN_ATTEMPTS(): antlr.TerminalNode | null;
      PASSWORD_LOCK_TIME(): antlr.TerminalNode | null;
      UNBOUNDED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserLockOptionContext extends antlr.ParserRuleContext {
      _lockType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ACCOUNT(): antlr.TerminalNode;
      LOCK(): antlr.TerminalNode | null;
      UNLOCK(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrivelegeClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      privilege(): PrivilegeContext;
      LR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrivilegeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      ALTER(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      DELETE(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      EVENT(): antlr.TerminalNode | null;
      EXECUTE(): antlr.TerminalNode | null;
      FILE(): antlr.TerminalNode | null;
      GRANT(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      LOCK(): antlr.TerminalNode | null;
      PROCESS(): antlr.TerminalNode | null;
      PROXY(): antlr.TerminalNode | null;
      REFERENCES(): antlr.TerminalNode | null;
      RELOAD(): antlr.TerminalNode | null;
      REPLICATION(): antlr.TerminalNode | null;
      CLIENT(): antlr.TerminalNode | null;
      SLAVE(): antlr.TerminalNode | null;
      SELECT(): antlr.TerminalNode | null;
      SHOW(): antlr.TerminalNode | null;
      DATABASES(): antlr.TerminalNode | null;
      SHUTDOWN(): antlr.TerminalNode | null;
      SUPER(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      USAGE(): antlr.TerminalNode | null;
      APPLICATION_PASSWORD_ADMIN(): antlr.TerminalNode | null;
      AUDIT_ABORT_EXEMPT(): antlr.TerminalNode | null;
      AUDIT_ADMIN(): antlr.TerminalNode | null;
      AUTHENTICATION_POLICY_ADMIN(): antlr.TerminalNode | null;
      BACKUP_ADMIN(): antlr.TerminalNode | null;
      BINLOG_ADMIN(): antlr.TerminalNode | null;
      BINLOG_ENCRYPTION_ADMIN(): antlr.TerminalNode | null;
      CLONE_ADMIN(): antlr.TerminalNode | null;
      CONNECTION_ADMIN(): antlr.TerminalNode | null;
      ENCRYPTION_KEY_ADMIN(): antlr.TerminalNode | null;
      FIREWALL_ADMIN(): antlr.TerminalNode | null;
      FIREWALL_EXEMPT(): antlr.TerminalNode | null;
      FIREWALL_USER(): antlr.TerminalNode | null;
      FLUSH_OPTIMIZER_COSTS(): antlr.TerminalNode | null;
      FLUSH_STATUS(): antlr.TerminalNode | null;
      FLUSH_TABLES(): antlr.TerminalNode | null;
      FLUSH_USER_RESOURCES(): antlr.TerminalNode | null;
      GROUP_REPLICATION_ADMIN(): antlr.TerminalNode | null;
      INNODB_REDO_LOG_ARCHIVE(): antlr.TerminalNode | null;
      INNODB_REDO_LOG_ENABLE(): antlr.TerminalNode | null;
      NDB_STORED_USER(): antlr.TerminalNode | null;
      PASSWORDLESS_USER_ADMIN(): antlr.TerminalNode | null;
      PERSIST_RO_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      REPLICATION_APPLIER(): antlr.TerminalNode | null;
      REPLICATION_SLAVE_ADMIN(): antlr.TerminalNode | null;
      RESOURCE_GROUP_ADMIN(): antlr.TerminalNode | null;
      RESOURCE_GROUP_USER(): antlr.TerminalNode | null;
      ROLE_ADMIN(): antlr.TerminalNode | null;
      SERVICE_CONNECTION_ADMIN(): antlr.TerminalNode | null;
      SESSION_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      SET_USER_ID(): antlr.TerminalNode | null;
      SKIP_QUERY_REWRITE(): antlr.TerminalNode | null;
      SHOW_ROUTINE(): antlr.TerminalNode | null;
      SYSTEM_USER(): antlr.TerminalNode | null;
      SYSTEM_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      TABLE_ENCRYPTION_ADMIN(): antlr.TerminalNode | null;
      TP_CONNECTION_ADMIN(): antlr.TerminalNode | null;
      VERSION_TOKEN_ADMIN(): antlr.TerminalNode | null;
      XA_RECOVER_ADMIN(): antlr.TerminalNode | null;
      LOAD(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      S3(): antlr.TerminalNode | null;
      INTO(): antlr.TerminalNode | null;
      INVOKE(): antlr.TerminalNode | null;
      LAMBDA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrivilegeLevelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: PrivilegeLevelContext): void;
  }
  export class DefiniteSchemaPrivLevelContext extends PrivilegeLevelContext {
      constructor(ctx: PrivilegeLevelContext);
      uid(): UidContext;
      DOT(): antlr.TerminalNode;
      STAR(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DefiniteFullTablePrivLevel2Context extends PrivilegeLevelContext {
      constructor(ctx: PrivilegeLevelContext);
      uid(): UidContext;
      dottedId(): DottedIdContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DefiniteFullTablePrivLevelContext extends PrivilegeLevelContext {
      constructor(ctx: PrivilegeLevelContext);
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      DOT(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GlobalPrivLevelContext extends PrivilegeLevelContext {
      constructor(ctx: PrivilegeLevelContext);
      STAR(): antlr.TerminalNode[];
      STAR(i: number): antlr.TerminalNode | null;
      DOT(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DefiniteTablePrivLevelContext extends PrivilegeLevelContext {
      constructor(ctx: PrivilegeLevelContext);
      uid(): UidContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CurrentSchemaPriviLevelContext extends PrivilegeLevelContext {
      constructor(ctx: PrivilegeLevelContext);
      STAR(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RenameUserClauseContext extends antlr.ParserRuleContext {
      _fromFirst?: UserNameContext;
      _toFirst?: UserNameContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TO(): antlr.TerminalNode;
      userName(): UserNameContext[];
      userName(i: number): UserNameContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AnalyzeTableContext extends antlr.ParserRuleContext {
      _actionOption?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ANALYZE(): antlr.TerminalNode;
      tables(): TablesContext;
      TABLE(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      HISTOGRAM(): antlr.TerminalNode[];
      HISTOGRAM(i: number): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      fullColumnName(): FullColumnNameContext[];
      fullColumnName(i: number): FullColumnNameContext | null;
      DROP(): antlr.TerminalNode | null;
      NO_WRITE_TO_BINLOG(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      BUCKETS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CheckTableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHECK(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tables(): TablesContext;
      checkTableOption(): CheckTableOptionContext[];
      checkTableOption(i: number): CheckTableOptionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ChecksumTableContext extends antlr.ParserRuleContext {
      _actionOption?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHECKSUM(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tables(): TablesContext;
      QUICK(): antlr.TerminalNode | null;
      EXTENDED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OptimizeTableContext extends antlr.ParserRuleContext {
      _actionOption?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPTIMIZE(): antlr.TerminalNode;
      tables(): TablesContext;
      TABLE(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      NO_WRITE_TO_BINLOG(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RepairTableContext extends antlr.ParserRuleContext {
      _actionOption?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPAIR(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      tables(): TablesContext;
      QUICK(): antlr.TerminalNode | null;
      EXTENDED(): antlr.TerminalNode | null;
      USE_FRM(): antlr.TerminalNode | null;
      NO_WRITE_TO_BINLOG(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CheckTableOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      UPGRADE(): antlr.TerminalNode | null;
      QUICK(): antlr.TerminalNode | null;
      FAST(): antlr.TerminalNode | null;
      MEDIUM(): antlr.TerminalNode | null;
      EXTENDED(): antlr.TerminalNode | null;
      CHANGED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CreateUdfunctionContext extends antlr.ParserRuleContext {
      _returnType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode;
      uid(): UidContext;
      RETURNS(): antlr.TerminalNode;
      SONAME(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      STRING(): antlr.TerminalNode | null;
      INTEGER(): antlr.TerminalNode | null;
      REAL(): antlr.TerminalNode | null;
      DECIMAL(): antlr.TerminalNode | null;
      AGGREGATE(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class InstallPluginContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INSTALL(): antlr.TerminalNode;
      PLUGIN(): antlr.TerminalNode;
      uid(): UidContext;
      SONAME(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UninstallPluginContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNINSTALL(): antlr.TerminalNode;
      PLUGIN(): antlr.TerminalNode;
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: SetStatementContext): void;
  }
  export class SetTransactionContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      setTransactionStatement(): SetTransactionStatementContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetCharsetContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      SET(): antlr.TerminalNode;
      charSet(): CharSetContext;
      charsetName(): CharsetNameContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetNamesContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      SET(): antlr.TerminalNode;
      NAMES(): antlr.TerminalNode;
      charsetName(): CharsetNameContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetPasswordContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      setPasswordStatement(): SetPasswordStatementContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetAutocommitContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      setAutocommitStatement(): SetAutocommitStatementContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetNewValueInsideTriggerContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      SET(): antlr.TerminalNode;
      fullId(): FullIdContext[];
      fullId(i: number): FullIdContext | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      VAR_ASSIGN(): antlr.TerminalNode[];
      VAR_ASSIGN(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SetVariableContext extends SetStatementContext {
      constructor(ctx: SetStatementContext);
      SET(): antlr.TerminalNode;
      variableClause(): VariableClauseContext[];
      variableClause(i: number): VariableClauseContext | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      VAR_ASSIGN(): antlr.TerminalNode[];
      VAR_ASSIGN(i: number): antlr.TerminalNode | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ShowStatementContext): void;
  }
  export class ShowOpenTablesContext extends ShowStatementContext {
      _schemaFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      OPEN(): antlr.TerminalNode;
      TABLES(): antlr.TerminalNode;
      uid(): UidContext | null;
      showFilter(): ShowFilterContext | null;
      FROM(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowGlobalInfoContext extends ShowStatementContext {
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      showGlobalInfoClause(): ShowGlobalInfoClauseContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowCreateFullIdObjectContext extends ShowStatementContext {
      _namedEntity?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      CREATE(): antlr.TerminalNode;
      fullId(): FullIdContext;
      EVENT(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowCreateUserContext extends ShowStatementContext {
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      CREATE(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      userName(): UserNameContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowErrorsContext extends ShowStatementContext {
      _errorFormat?: Token | null;
      _offset?: DecimalLiteralContext;
      _rowCount?: DecimalLiteralContext;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      ERRORS(): antlr.TerminalNode | null;
      WARNINGS(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      COMMA(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowCountErrorsContext extends ShowStatementContext {
      _errorFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      COUNT(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      STAR(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      ERRORS(): antlr.TerminalNode | null;
      WARNINGS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowObjectFilterContext extends ShowStatementContext {
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      showCommonEntity(): ShowCommonEntityContext;
      showFilter(): ShowFilterContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowCreateDbContext extends ShowStatementContext {
      _schemaFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      CREATE(): antlr.TerminalNode;
      uid(): UidContext;
      DATABASE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      ifNotExists(): IfNotExistsContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowEngineContext extends ShowStatementContext {
      _engineOption?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      ENGINE(): antlr.TerminalNode;
      engineName(): EngineNameContext;
      STATUS(): antlr.TerminalNode | null;
      MUTEX(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowSchemaFilterContext extends ShowStatementContext {
      _schemaFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      showSchemaEntity(): ShowSchemaEntityContext;
      uid(): UidContext | null;
      showFilter(): ShowFilterContext | null;
      FROM(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowIndexesContext extends ShowStatementContext {
      _indexFormat?: Token | null;
      _tableFormat?: Token | null;
      _schemaFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      tableName(): TableNameContext;
      INDEX(): antlr.TerminalNode | null;
      INDEXES(): antlr.TerminalNode | null;
      KEYS(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode[];
      FROM(i: number): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode[];
      IN(i: number): antlr.TerminalNode | null;
      uid(): UidContext | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowLogEventsContext extends ShowStatementContext {
      _logFormat?: Token | null;
      _filename?: Token | null;
      _fromPosition?: DecimalLiteralContext;
      _offset?: DecimalLiteralContext;
      _rowCount?: DecimalLiteralContext;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      EVENTS(): antlr.TerminalNode;
      BINLOG(): antlr.TerminalNode | null;
      RELAYLOG(): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      COMMA(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowMasterLogsContext extends ShowStatementContext {
      _logFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      LOGS(): antlr.TerminalNode;
      BINARY(): antlr.TerminalNode | null;
      MASTER(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowGrantsContext extends ShowStatementContext {
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      GRANTS(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode | null;
      userName(): UserNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowSlaveStatusContext extends ShowStatementContext {
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      SLAVE(): antlr.TerminalNode;
      STATUS(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode | null;
      CHANNEL(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowRoutineContext extends ShowStatementContext {
      _routine?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      CODE(): antlr.TerminalNode;
      fullId(): FullIdContext;
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowProfileContext extends ShowStatementContext {
      _queryCount?: DecimalLiteralContext;
      _offset?: DecimalLiteralContext;
      _rowCount?: DecimalLiteralContext;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      PROFILE(): antlr.TerminalNode;
      showProfileType(): ShowProfileTypeContext[];
      showProfileType(i: number): ShowProfileTypeContext | null;
      LIMIT(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      QUERY(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowColumnsContext extends ShowStatementContext {
      _columnsFormat?: Token | null;
      _tableFormat?: Token | null;
      _schemaFormat?: Token | null;
      constructor(ctx: ShowStatementContext);
      SHOW(): antlr.TerminalNode;
      tableName(): TableNameContext;
      COLUMNS(): antlr.TerminalNode | null;
      FIELDS(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode[];
      FROM(i: number): antlr.TerminalNode | null;
      IN(): antlr.TerminalNode[];
      IN(i: number): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      showFilter(): ShowFilterContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class VariableClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOCAL_ID(): antlr.TerminalNode | null;
      GLOBAL_ID(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      GLOBAL(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      AT_SIGN(): antlr.TerminalNode[];
      AT_SIGN(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowCommonEntityContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHARACTER(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      COLLATION(): antlr.TerminalNode | null;
      DATABASES(): antlr.TerminalNode | null;
      SCHEMAS(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      STATUS(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      VARIABLES(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowFilterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIKE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowGlobalInfoClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ENGINES(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      MASTER(): antlr.TerminalNode | null;
      STATUS(): antlr.TerminalNode | null;
      PLUGINS(): antlr.TerminalNode | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      PROCESSLIST(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      PROFILES(): antlr.TerminalNode | null;
      SLAVE(): antlr.TerminalNode | null;
      HOSTS(): antlr.TerminalNode | null;
      AUTHORS(): antlr.TerminalNode | null;
      CONTRIBUTORS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowSchemaEntityContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EVENTS(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      STATUS(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      TRIGGERS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShowProfileTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      BLOCK(): antlr.TerminalNode | null;
      IO(): antlr.TerminalNode | null;
      CONTEXT(): antlr.TerminalNode | null;
      SWITCHES(): antlr.TerminalNode | null;
      CPU(): antlr.TerminalNode | null;
      IPC(): antlr.TerminalNode | null;
      MEMORY(): antlr.TerminalNode | null;
      PAGE(): antlr.TerminalNode | null;
      FAULTS(): antlr.TerminalNode | null;
      SOURCE(): antlr.TerminalNode | null;
      SWAPS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BinlogStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BINLOG(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CacheIndexStatementContext extends antlr.ParserRuleContext {
      _schema?: UidContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CACHE(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      tableIndexes(): TableIndexesContext[];
      tableIndexes(i: number): TableIndexesContext | null;
      IN(): antlr.TerminalNode;
      uid(): UidContext;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FlushStatementContext extends antlr.ParserRuleContext {
      _flushFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FLUSH(): antlr.TerminalNode;
      flushOption(): FlushOptionContext[];
      flushOption(i: number): FlushOptionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      NO_WRITE_TO_BINLOG(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class KillStatementContext extends antlr.ParserRuleContext {
      _connectionFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      KILL(): antlr.TerminalNode;
      expression(): ExpressionContext;
      CONNECTION(): antlr.TerminalNode | null;
      QUERY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LoadIndexIntoCacheContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOAD(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      INTO(): antlr.TerminalNode;
      CACHE(): antlr.TerminalNode;
      loadedTableIndexes(): LoadedTableIndexesContext[];
      loadedTableIndexes(i: number): LoadedTableIndexesContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ResetStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESET(): antlr.TerminalNode;
      QUERY(): antlr.TerminalNode;
      CACHE(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ShutdownStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SHUTDOWN(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableIndexesContext extends antlr.ParserRuleContext {
      _indexFormat?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableName(): TableNameContext;
      LR_BRACKET(): antlr.TerminalNode | null;
      uidList(): UidListContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FlushOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: FlushOptionContext): void;
  }
  export class TableFlushOptionContext extends FlushOptionContext {
      constructor(ctx: FlushOptionContext);
      TABLE(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      tables(): TablesContext | null;
      flushTableOption(): FlushTableOptionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ChannelFlushOptionContext extends FlushOptionContext {
      constructor(ctx: FlushOptionContext);
      RELAY(): antlr.TerminalNode;
      LOGS(): antlr.TerminalNode;
      channelOption(): ChannelOptionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleFlushOptionContext extends FlushOptionContext {
      constructor(ctx: FlushOptionContext);
      DES_KEY_FILE(): antlr.TerminalNode | null;
      HOSTS(): antlr.TerminalNode | null;
      LOGS(): antlr.TerminalNode | null;
      OPTIMIZER_COSTS(): antlr.TerminalNode | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      QUERY(): antlr.TerminalNode | null;
      CACHE(): antlr.TerminalNode | null;
      STATUS(): antlr.TerminalNode | null;
      USER_RESOURCES(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      LOCK(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      ENGINE(): antlr.TerminalNode | null;
      ERROR(): antlr.TerminalNode | null;
      GENERAL(): antlr.TerminalNode | null;
      RELAY(): antlr.TerminalNode | null;
      SLOW(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FlushTableOptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      LOCK(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      EXPORT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LoadedTableIndexesContext extends antlr.ParserRuleContext {
      _partitionList?: UidListContext;
      _indexFormat?: Token | null;
      _indexList?: UidListContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableName(): TableNameContext;
      PARTITION(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      IGNORE(): antlr.TerminalNode | null;
      LEAVES(): antlr.TerminalNode | null;
      uidList(): UidListContext[];
      uidList(i: number): UidListContext | null;
      ALL(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleDescribeStatementContext extends antlr.ParserRuleContext {
      _command?: Token | null;
      _column?: UidContext;
      _pattern?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableName(): TableNameContext;
      EXPLAIN(): antlr.TerminalNode | null;
      DESCRIBE(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FullDescribeStatementContext extends antlr.ParserRuleContext {
      _command?: Token | null;
      _formatType?: Token | null;
      _formatValue?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      describeObjectClause(): DescribeObjectClauseContext;
      EXPLAIN(): antlr.TerminalNode | null;
      DESCRIBE(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      EXTENDED(): antlr.TerminalNode | null;
      PARTITIONS(): antlr.TerminalNode | null;
      FORMAT(): antlr.TerminalNode | null;
      TRADITIONAL(): antlr.TerminalNode | null;
      JSON(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HelpStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HELP(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UseStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USE(): antlr.TerminalNode;
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SignalStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SIGNAL(): antlr.TerminalNode;
      ID(): antlr.TerminalNode | null;
      REVERSE_QUOTE_ID(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      signalConditionInformation(): SignalConditionInformationContext[];
      signalConditionInformation(i: number): SignalConditionInformationContext | null;
      SQLSTATE(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      VALUE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ResignalStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESIGNAL(): antlr.TerminalNode;
      ID(): antlr.TerminalNode | null;
      REVERSE_QUOTE_ID(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      signalConditionInformation(): SignalConditionInformationContext[];
      signalConditionInformation(i: number): SignalConditionInformationContext | null;
      SQLSTATE(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      VALUE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SignalConditionInformationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EQUAL_SYMBOL(): antlr.TerminalNode;
      CLASS_ORIGIN(): antlr.TerminalNode | null;
      SUBCLASS_ORIGIN(): antlr.TerminalNode | null;
      MESSAGE_TEXT(): antlr.TerminalNode | null;
      MYSQL_ERRNO(): antlr.TerminalNode | null;
      CONSTRAINT_CATALOG(): antlr.TerminalNode | null;
      CONSTRAINT_SCHEMA(): antlr.TerminalNode | null;
      CONSTRAINT_NAME(): antlr.TerminalNode | null;
      CATALOG_NAME(): antlr.TerminalNode | null;
      SCHEMA_NAME(): antlr.TerminalNode | null;
      TABLE_NAME(): antlr.TerminalNode | null;
      COLUMN_NAME(): antlr.TerminalNode | null;
      CURSOR_NAME(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      DECIMAL_LITERAL(): antlr.TerminalNode | null;
      mysqlVariable(): MysqlVariableContext | null;
      simpleId(): SimpleIdContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WithStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode;
      commonTableExpressions(): CommonTableExpressionsContext[];
      commonTableExpressions(i: number): CommonTableExpressionsContext | null;
      RECURSIVE(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLE(): antlr.TerminalNode;
      tableName(): TableNameContext;
      orderByClause(): OrderByClauseContext | null;
      limitClause(): LimitClauseContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DiagnosticsStatementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GET(): antlr.TerminalNode;
      DIAGNOSTICS(): antlr.TerminalNode;
      CURRENT(): antlr.TerminalNode | null;
      STACKED(): antlr.TerminalNode | null;
      variableClause(): VariableClauseContext[];
      variableClause(i: number): VariableClauseContext | null;
      EQUAL_SYMBOL(): antlr.TerminalNode[];
      EQUAL_SYMBOL(i: number): antlr.TerminalNode | null;
      CONDITION(): antlr.TerminalNode | null;
      diagnosticsConditionInformationName(): DiagnosticsConditionInformationNameContext[];
      diagnosticsConditionInformationName(i: number): DiagnosticsConditionInformationNameContext | null;
      NUMBER(): antlr.TerminalNode[];
      NUMBER(i: number): antlr.TerminalNode | null;
      ROW_COUNT(): antlr.TerminalNode[];
      ROW_COUNT(i: number): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DiagnosticsConditionInformationNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CLASS_ORIGIN(): antlr.TerminalNode | null;
      SUBCLASS_ORIGIN(): antlr.TerminalNode | null;
      RETURNED_SQLSTATE(): antlr.TerminalNode | null;
      MESSAGE_TEXT(): antlr.TerminalNode | null;
      MYSQL_ERRNO(): antlr.TerminalNode | null;
      CONSTRAINT_CATALOG(): antlr.TerminalNode | null;
      CONSTRAINT_SCHEMA(): antlr.TerminalNode | null;
      CONSTRAINT_NAME(): antlr.TerminalNode | null;
      CATALOG_NAME(): antlr.TerminalNode | null;
      SCHEMA_NAME(): antlr.TerminalNode | null;
      TABLE_NAME(): antlr.TerminalNode | null;
      COLUMN_NAME(): antlr.TerminalNode | null;
      CURSOR_NAME(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DescribeObjectClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: DescribeObjectClauseContext): void;
  }
  export class DescribeStatementsContext extends DescribeObjectClauseContext {
      constructor(ctx: DescribeObjectClauseContext);
      selectStatement(): SelectStatementContext | null;
      deleteStatement(): DeleteStatementContext | null;
      insertStatement(): InsertStatementContext | null;
      replaceStatement(): ReplaceStatementContext | null;
      updateStatement(): UpdateStatementContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DescribeConnectionContext extends DescribeObjectClauseContext {
      constructor(ctx: DescribeObjectClauseContext);
      FOR(): antlr.TerminalNode;
      CONNECTION(): antlr.TerminalNode;
      uid(): UidContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FullIdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      DOT_ID(): antlr.TerminalNode | null;
      DOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TableNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fullId(): FullIdContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RoleNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      userName(): UserNameContext | null;
      uid(): UidContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FullColumnNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext | null;
      dottedId(): DottedIdContext[];
      dottedId(i: number): DottedIdContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexColumnNameContext extends antlr.ParserRuleContext {
      _sortType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expression(): ExpressionContext | null;
      uid(): UidContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      ASC(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleUserNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STRING_LITERAL(): antlr.TerminalNode | null;
      ID(): antlr.TerminalNode | null;
      ADMIN(): antlr.TerminalNode | null;
      keywordsCanBeId(): KeywordsCanBeIdContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HostNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOCAL_ID(): antlr.TerminalNode | null;
      HOST_IP_ADDRESS(): antlr.TerminalNode | null;
      AT_SIGN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      simpleUserName(): SimpleUserNameContext | null;
      hostName(): HostNameContext | null;
      currentUserExpression(): CurrentUserExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MysqlVariableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOCAL_ID(): antlr.TerminalNode | null;
      GLOBAL_ID(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CharsetNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BINARY(): antlr.TerminalNode | null;
      charsetNameBase(): CharsetNameBaseContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      CHARSET_REVERSE_QOUTE_STRING(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CollationNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class EngineNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      engineNameBase(): EngineNameBaseContext | null;
      ID(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class EngineNameBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ARCHIVE(): antlr.TerminalNode | null;
      BLACKHOLE(): antlr.TerminalNode | null;
      CONNECT(): antlr.TerminalNode | null;
      CSV(): antlr.TerminalNode | null;
      FEDERATED(): antlr.TerminalNode | null;
      INNODB(): antlr.TerminalNode | null;
      MEMORY(): antlr.TerminalNode | null;
      MRG_MYISAM(): antlr.TerminalNode | null;
      MYISAM(): antlr.TerminalNode | null;
      NDB(): antlr.TerminalNode | null;
      NDBCLUSTER(): antlr.TerminalNode | null;
      PERFORMANCE_SCHEMA(): antlr.TerminalNode | null;
      TOKUDB(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UuidSetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      MINUS(): antlr.TerminalNode[];
      MINUS(i: number): antlr.TerminalNode | null;
      COLON_SYMB(): antlr.TerminalNode[];
      COLON_SYMB(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XidContext extends antlr.ParserRuleContext {
      _globalTableUid?: XuidStringIdContext;
      _qualifier?: XuidStringIdContext;
      _idFormat?: DecimalLiteralContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      xuidStringId(): XuidStringIdContext[];
      xuidStringId(i: number): XuidStringIdContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class XuidStringIdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STRING_LITERAL(): antlr.TerminalNode | null;
      BIT_STRING(): antlr.TerminalNode | null;
      HEXADECIMAL_LITERAL(): antlr.TerminalNode[];
      HEXADECIMAL_LITERAL(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AuthPluginContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UidContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      simpleId(): SimpleIdContext | null;
      CHARSET_REVERSE_QOUTE_STRING(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleIdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ID(): antlr.TerminalNode | null;
      charsetNameBase(): CharsetNameBaseContext | null;
      transactionLevelBase(): TransactionLevelBaseContext | null;
      engineNameBase(): EngineNameBaseContext | null;
      privilegesBase(): PrivilegesBaseContext | null;
      intervalTypeBase(): IntervalTypeBaseContext | null;
      dataTypeBase(): DataTypeBaseContext | null;
      keywordsCanBeId(): KeywordsCanBeIdContext | null;
      scalarFunctionName(): ScalarFunctionNameContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DottedIdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DOT_ID(): antlr.TerminalNode | null;
      DOT(): antlr.TerminalNode | null;
      uid(): UidContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DecimalLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECIMAL_LITERAL(): antlr.TerminalNode | null;
      ZERO_DECIMAL(): antlr.TerminalNode | null;
      ONE_DECIMAL(): antlr.TerminalNode | null;
      TWO_DECIMAL(): antlr.TerminalNode | null;
      REAL_LITERAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FileSizeLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FILESIZE_LITERAL(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StringLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      START_NATIONAL_STRING_LITERAL(): antlr.TerminalNode | null;
      STRING_CHARSET_NAME(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BooleanLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRUE(): antlr.TerminalNode | null;
      FALSE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class HexadecimalLiteralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HEXADECIMAL_LITERAL(): antlr.TerminalNode;
      STRING_CHARSET_NAME(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NullNotnullContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NULL_LITERAL(): antlr.TerminalNode | null;
      NULL_SPEC_LITERAL(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ConstantContext extends antlr.ParserRuleContext {
      _nullLiteral?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      stringLiteral(): StringLiteralContext | null;
      decimalLiteral(): DecimalLiteralContext | null;
      MINUS(): antlr.TerminalNode | null;
      hexadecimalLiteral(): HexadecimalLiteralContext | null;
      booleanLiteral(): BooleanLiteralContext | null;
      REAL_LITERAL(): antlr.TerminalNode | null;
      BIT_STRING(): antlr.TerminalNode | null;
      NULL_LITERAL(): antlr.TerminalNode | null;
      NULL_SPEC_LITERAL(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DataTypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: DataTypeContext): void;
  }
  export class SpatialDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      GEOMETRYCOLLECTION(): antlr.TerminalNode | null;
      GEOMCOLLECTION(): antlr.TerminalNode | null;
      LINESTRING(): antlr.TerminalNode | null;
      MULTILINESTRING(): antlr.TerminalNode | null;
      MULTIPOINT(): antlr.TerminalNode | null;
      MULTIPOLYGON(): antlr.TerminalNode | null;
      POINT(): antlr.TerminalNode | null;
      POLYGON(): antlr.TerminalNode | null;
      JSON(): antlr.TerminalNode | null;
      GEOMETRY(): antlr.TerminalNode | null;
      SRID(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LongVarbinaryDataTypeContext extends DataTypeContext {
      constructor(ctx: DataTypeContext);
      LONG(): antlr.TerminalNode;
      VARBINARY(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CollectionDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      collectionOptions(): CollectionOptionsContext;
      ENUM(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      charSet(): CharSetContext | null;
      charsetName(): CharsetNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NationalVaryingStringDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      NATIONAL(): antlr.TerminalNode;
      VARYING(): antlr.TerminalNode;
      CHAR(): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      lengthOneDimension(): LengthOneDimensionContext | null;
      BINARY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DimensionDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      TINYINT(): antlr.TerminalNode | null;
      SMALLINT(): antlr.TerminalNode | null;
      MEDIUMINT(): antlr.TerminalNode | null;
      INT(): antlr.TerminalNode | null;
      INTEGER(): antlr.TerminalNode | null;
      BIGINT(): antlr.TerminalNode | null;
      MIDDLEINT(): antlr.TerminalNode | null;
      INT1(): antlr.TerminalNode | null;
      INT2(): antlr.TerminalNode | null;
      INT3(): antlr.TerminalNode | null;
      INT4(): antlr.TerminalNode | null;
      INT8(): antlr.TerminalNode | null;
      lengthOneDimension(): LengthOneDimensionContext | null;
      SIGNED(): antlr.TerminalNode[];
      SIGNED(i: number): antlr.TerminalNode | null;
      UNSIGNED(): antlr.TerminalNode[];
      UNSIGNED(i: number): antlr.TerminalNode | null;
      ZEROFILL(): antlr.TerminalNode[];
      ZEROFILL(i: number): antlr.TerminalNode | null;
      REAL(): antlr.TerminalNode | null;
      lengthTwoDimension(): LengthTwoDimensionContext | null;
      DOUBLE(): antlr.TerminalNode | null;
      PRECISION(): antlr.TerminalNode | null;
      DECIMAL(): antlr.TerminalNode | null;
      DEC(): antlr.TerminalNode | null;
      FIXED(): antlr.TerminalNode | null;
      NUMERIC(): antlr.TerminalNode | null;
      FLOAT(): antlr.TerminalNode | null;
      FLOAT4(): antlr.TerminalNode | null;
      FLOAT8(): antlr.TerminalNode | null;
      lengthTwoOptionalDimension(): LengthTwoOptionalDimensionContext | null;
      BIT(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      TIMESTAMP(): antlr.TerminalNode | null;
      DATETIME(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      VARBINARY(): antlr.TerminalNode | null;
      BLOB(): antlr.TerminalNode | null;
      YEAR(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class StringDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      CHAR(): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      VARCHAR(): antlr.TerminalNode | null;
      TINYTEXT(): antlr.TerminalNode | null;
      TEXT(): antlr.TerminalNode | null;
      MEDIUMTEXT(): antlr.TerminalNode | null;
      LONGTEXT(): antlr.TerminalNode | null;
      NCHAR(): antlr.TerminalNode | null;
      NVARCHAR(): antlr.TerminalNode | null;
      LONG(): antlr.TerminalNode | null;
      VARYING(): antlr.TerminalNode | null;
      lengthOneDimension(): LengthOneDimensionContext | null;
      BINARY(): antlr.TerminalNode[];
      BINARY(i: number): antlr.TerminalNode | null;
      charSet(): CharSetContext | null;
      charsetName(): CharsetNameContext | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LongVarcharDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      LONG(): antlr.TerminalNode;
      VARCHAR(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      charSet(): CharSetContext | null;
      charsetName(): CharsetNameContext | null;
      COLLATE(): antlr.TerminalNode | null;
      collationName(): CollationNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NationalStringDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      NATIONAL(): antlr.TerminalNode | null;
      VARCHAR(): antlr.TerminalNode | null;
      CHARACTER(): antlr.TerminalNode | null;
      CHAR(): antlr.TerminalNode | null;
      lengthOneDimension(): LengthOneDimensionContext | null;
      BINARY(): antlr.TerminalNode | null;
      NCHAR(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleDataTypeContext extends DataTypeContext {
      _typeName?: Token | null;
      constructor(ctx: DataTypeContext);
      DATE(): antlr.TerminalNode | null;
      TINYBLOB(): antlr.TerminalNode | null;
      MEDIUMBLOB(): antlr.TerminalNode | null;
      LONGBLOB(): antlr.TerminalNode | null;
      BOOL(): antlr.TerminalNode | null;
      BOOLEAN(): antlr.TerminalNode | null;
      SERIAL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CollectionOptionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ConvertedDataTypeContext extends antlr.ParserRuleContext {
      _typeName?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHAR(): antlr.TerminalNode | null;
      SIGNED(): antlr.TerminalNode | null;
      UNSIGNED(): antlr.TerminalNode | null;
      ARRAY(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      NCHAR(): antlr.TerminalNode | null;
      FLOAT(): antlr.TerminalNode | null;
      DATE(): antlr.TerminalNode | null;
      DATETIME(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      YEAR(): antlr.TerminalNode | null;
      JSON(): antlr.TerminalNode | null;
      INT(): antlr.TerminalNode | null;
      INTEGER(): antlr.TerminalNode | null;
      DOUBLE(): antlr.TerminalNode | null;
      DECIMAL(): antlr.TerminalNode | null;
      DEC(): antlr.TerminalNode | null;
      lengthOneDimension(): LengthOneDimensionContext | null;
      charSet(): CharSetContext | null;
      charsetName(): CharsetNameContext | null;
      lengthTwoOptionalDimension(): LengthTwoOptionalDimensionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LengthOneDimensionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext;
      RR_BRACKET(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LengthTwoDimensionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      COMMA(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LengthTwoOptionalDimensionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UidListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext[];
      uid(i: number): UidContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FullColumnNameListContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fullColumnName(): FullColumnNameContext[];
      fullColumnName(i: number): FullColumnNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TablesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableName(): TableNameContext[];
      tableName(i: number): TableNameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IndexColumnNamesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      indexColumnName(): IndexColumnNameContext[];
      indexColumnName(i: number): IndexColumnNameContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExpressionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExpressionsWithDefaultsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expressionOrDefault(): ExpressionOrDefaultContext[];
      expressionOrDefault(i: number): ExpressionOrDefaultContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ConstantsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      constant(): ConstantContext[];
      constant(i: number): ConstantContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleStringsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STRING_LITERAL(): antlr.TerminalNode[];
      STRING_LITERAL(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UserVariablesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOCAL_ID(): antlr.TerminalNode[];
      LOCAL_ID(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DefaultValueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NULL_LITERAL(): antlr.TerminalNode | null;
      CAST(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      AS(): antlr.TerminalNode | null;
      convertedDataType(): ConvertedDataTypeContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      constant(): ConstantContext | null;
      unaryOperator(): UnaryOperatorContext | null;
      currentTimestamp(): CurrentTimestampContext[];
      currentTimestamp(i: number): CurrentTimestampContext | null;
      ON(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      fullId(): FullIdContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CurrentTimestampContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOW(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      CURRENT_TIMESTAMP(): antlr.TerminalNode | null;
      LOCALTIME(): antlr.TerminalNode | null;
      LOCALTIMESTAMP(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExpressionOrDefaultContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expression(): ExpressionContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IfExistsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IF(): antlr.TerminalNode;
      EXISTS(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IfNotExistsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IF(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode;
      EXISTS(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OrReplaceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OR(): antlr.TerminalNode;
      REPLACE(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WaitNowaitClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WAIT(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      NOWAIT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FunctionCallContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: FunctionCallContext): void;
  }
  export class SpecificFunctionCallContext extends FunctionCallContext {
      constructor(ctx: FunctionCallContext);
      specificFunction(): SpecificFunctionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PasswordFunctionCallContext extends FunctionCallContext {
      constructor(ctx: FunctionCallContext);
      passwordFunctionClause(): PasswordFunctionClauseContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UdfFunctionCallContext extends FunctionCallContext {
      constructor(ctx: FunctionCallContext);
      fullId(): FullIdContext;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      functionArgs(): FunctionArgsContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NonAggregateFunctionCallContext extends FunctionCallContext {
      constructor(ctx: FunctionCallContext);
      nonAggregateWindowedFunction(): NonAggregateWindowedFunctionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AggregateFunctionCallContext extends FunctionCallContext {
      constructor(ctx: FunctionCallContext);
      aggregateWindowedFunction(): AggregateWindowedFunctionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ScalarFunctionCallContext extends FunctionCallContext {
      constructor(ctx: FunctionCallContext);
      scalarFunctionName(): ScalarFunctionNameContext;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      functionArgs(): FunctionArgsContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SpecificFunctionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: SpecificFunctionContext): void;
  }
  export class PositionFunctionCallContext extends SpecificFunctionContext {
      _positionString?: StringLiteralContext;
      _positionExpression?: ExpressionContext;
      _inString?: StringLiteralContext;
      _inExpression?: ExpressionContext;
      constructor(ctx: SpecificFunctionContext);
      POSITION(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      IN(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      stringLiteral(): StringLiteralContext[];
      stringLiteral(i: number): StringLiteralContext | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TrimFunctionCallContext extends SpecificFunctionContext {
      _positioinForm?: Token | null;
      _sourceString?: StringLiteralContext;
      _sourceExpression?: ExpressionContext;
      _fromString?: StringLiteralContext;
      _fromExpression?: ExpressionContext;
      constructor(ctx: SpecificFunctionContext);
      TRIM(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      BOTH(): antlr.TerminalNode | null;
      LEADING(): antlr.TerminalNode | null;
      TRAILING(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext[];
      stringLiteral(i: number): StringLiteralContext | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonValueFunctionCallContext extends SpecificFunctionContext {
      constructor(ctx: SpecificFunctionContext);
      JSON_VALUE(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      COMMA(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      RETURNING(): antlr.TerminalNode | null;
      convertedDataType(): ConvertedDataTypeContext | null;
      jsonOnEmpty(): JsonOnEmptyContext | null;
      jsonOnError(): JsonOnErrorContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CaseFunctionCallContext extends SpecificFunctionContext {
      _elseArg?: FunctionArgContext;
      constructor(ctx: SpecificFunctionContext);
      CASE(): antlr.TerminalNode;
      END(): antlr.TerminalNode;
      caseFuncAlternative(): CaseFuncAlternativeContext[];
      caseFuncAlternative(i: number): CaseFuncAlternativeContext | null;
      ELSE(): antlr.TerminalNode | null;
      functionArg(): FunctionArgContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExtractFunctionCallContext extends SpecificFunctionContext {
      _sourceString?: StringLiteralContext;
      _sourceExpression?: ExpressionContext;
      constructor(ctx: SpecificFunctionContext);
      EXTRACT(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      intervalType(): IntervalTypeContext;
      FROM(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      stringLiteral(): StringLiteralContext | null;
      expression(): ExpressionContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DataTypeFunctionCallContext extends SpecificFunctionContext {
      _separator?: Token | null;
      constructor(ctx: SpecificFunctionContext);
      CONVERT(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext;
      convertedDataType(): ConvertedDataTypeContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      charsetName(): CharsetNameContext | null;
      CAST(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ValuesFunctionCallContext extends SpecificFunctionContext {
      constructor(ctx: SpecificFunctionContext);
      VALUES(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      fullColumnName(): FullColumnNameContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CaseExpressionFunctionCallContext extends SpecificFunctionContext {
      _elseArg?: FunctionArgContext;
      constructor(ctx: SpecificFunctionContext);
      CASE(): antlr.TerminalNode;
      expression(): ExpressionContext;
      END(): antlr.TerminalNode;
      caseFuncAlternative(): CaseFuncAlternativeContext[];
      caseFuncAlternative(i: number): CaseFuncAlternativeContext | null;
      ELSE(): antlr.TerminalNode | null;
      functionArg(): FunctionArgContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CurrentUserContext extends SpecificFunctionContext {
      constructor(ctx: SpecificFunctionContext);
      currentUserExpression(): CurrentUserExpressionContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SimpleFunctionCallContext extends SpecificFunctionContext {
      constructor(ctx: SpecificFunctionContext);
      CURRENT_DATE(): antlr.TerminalNode | null;
      CURRENT_TIME(): antlr.TerminalNode | null;
      CURRENT_TIMESTAMP(): antlr.TerminalNode | null;
      LOCALTIME(): antlr.TerminalNode | null;
      UTC_TIMESTAMP(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      LR_BRACKET(): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CharFunctionCallContext extends SpecificFunctionContext {
      constructor(ctx: SpecificFunctionContext);
      CHAR(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      functionArgs(): FunctionArgsContext;
      RR_BRACKET(): antlr.TerminalNode;
      USING(): antlr.TerminalNode | null;
      charsetName(): CharsetNameContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WeightFunctionCallContext extends SpecificFunctionContext {
      _stringFormat?: Token | null;
      constructor(ctx: SpecificFunctionContext);
      WEIGHT_STRING(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode[];
      LR_BRACKET(i: number): antlr.TerminalNode | null;
      RR_BRACKET(): antlr.TerminalNode[];
      RR_BRACKET(i: number): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      expression(): ExpressionContext | null;
      AS(): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext | null;
      levelsInWeightString(): LevelsInWeightStringContext | null;
      CHAR(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class GetFormatFunctionCallContext extends SpecificFunctionContext {
      _datetimeFormat?: Token | null;
      constructor(ctx: SpecificFunctionContext);
      GET_FORMAT(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode;
      stringLiteral(): StringLiteralContext;
      RR_BRACKET(): antlr.TerminalNode;
      DATE(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      DATETIME(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SubstrFunctionCallContext extends SpecificFunctionContext {
      _sourceString?: StringLiteralContext;
      _sourceExpression?: ExpressionContext;
      _fromDecimal?: DecimalLiteralContext;
      _fromExpression?: ExpressionContext;
      _forDecimal?: DecimalLiteralContext;
      _forExpression?: ExpressionContext;
      constructor(ctx: SpecificFunctionContext);
      LR_BRACKET(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      SUBSTR(): antlr.TerminalNode | null;
      SUBSTRING(): antlr.TerminalNode | null;
      stringLiteral(): StringLiteralContext | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      FOR(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CaseFuncAlternativeContext extends antlr.ParserRuleContext {
      _condition?: FunctionArgContext;
      _consequent?: FunctionArgContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      THEN(): antlr.TerminalNode;
      functionArg(): FunctionArgContext[];
      functionArg(i: number): FunctionArgContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LevelsInWeightStringContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: LevelsInWeightStringContext): void;
  }
  export class LevelWeightRangeContext extends LevelsInWeightStringContext {
      _firstLevel?: DecimalLiteralContext;
      _lastLevel?: DecimalLiteralContext;
      constructor(ctx: LevelsInWeightStringContext);
      LEVEL(): antlr.TerminalNode;
      MINUS(): antlr.TerminalNode;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LevelWeightListContext extends LevelsInWeightStringContext {
      constructor(ctx: LevelsInWeightStringContext);
      LEVEL(): antlr.TerminalNode;
      levelInWeightListElement(): LevelInWeightListElementContext[];
      levelInWeightListElement(i: number): LevelInWeightListElementContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LevelInWeightListElementContext extends antlr.ParserRuleContext {
      _orderType?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decimalLiteral(): DecimalLiteralContext;
      ASC(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      REVERSE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AggregateWindowedFunctionContext extends antlr.ParserRuleContext {
      _aggregator?: Token | null;
      _starArg?: Token | null;
      _separator?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      functionArg(): FunctionArgContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      AVG(): antlr.TerminalNode | null;
      MAX(): antlr.TerminalNode | null;
      MIN(): antlr.TerminalNode | null;
      SUM(): antlr.TerminalNode | null;
      overClause(): OverClauseContext | null;
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      COUNT(): antlr.TerminalNode | null;
      functionArgs(): FunctionArgsContext | null;
      STAR(): antlr.TerminalNode | null;
      BIT_AND(): antlr.TerminalNode | null;
      BIT_OR(): antlr.TerminalNode | null;
      BIT_XOR(): antlr.TerminalNode | null;
      STD(): antlr.TerminalNode | null;
      STDDEV(): antlr.TerminalNode | null;
      STDDEV_POP(): antlr.TerminalNode | null;
      STDDEV_SAMP(): antlr.TerminalNode | null;
      VAR_POP(): antlr.TerminalNode | null;
      VAR_SAMP(): antlr.TerminalNode | null;
      VARIANCE(): antlr.TerminalNode | null;
      GROUP_CONCAT(): antlr.TerminalNode | null;
      ORDER(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      orderByExpression(): OrderByExpressionContext[];
      orderByExpression(i: number): OrderByExpressionContext | null;
      SEPARATOR(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NonAggregateWindowedFunctionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      overClause(): OverClauseContext;
      LAG(): antlr.TerminalNode | null;
      LEAD(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      decimalLiteral(): DecimalLiteralContext[];
      decimalLiteral(i: number): DecimalLiteralContext | null;
      FIRST_VALUE(): antlr.TerminalNode | null;
      LAST_VALUE(): antlr.TerminalNode | null;
      CUME_DIST(): antlr.TerminalNode | null;
      DENSE_RANK(): antlr.TerminalNode | null;
      PERCENT_RANK(): antlr.TerminalNode | null;
      RANK(): antlr.TerminalNode | null;
      ROW_NUMBER(): antlr.TerminalNode | null;
      NTH_VALUE(): antlr.TerminalNode | null;
      NTILE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class OverClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OVER(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode | null;
      windowSpec(): WindowSpecContext | null;
      RR_BRACKET(): antlr.TerminalNode | null;
      windowName(): WindowNameContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WindowSpecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      windowName(): WindowNameContext | null;
      partitionClause(): PartitionClauseContext | null;
      orderByClause(): OrderByClauseContext | null;
      frameClause(): FrameClauseContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class WindowNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      uid(): UidContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FrameClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      frameUnits(): FrameUnitsContext;
      frameExtent(): FrameExtentContext;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FrameUnitsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROWS(): antlr.TerminalNode | null;
      RANGE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FrameExtentContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      frameRange(): FrameRangeContext | null;
      frameBetween(): FrameBetweenContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FrameBetweenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BETWEEN(): antlr.TerminalNode;
      frameRange(): FrameRangeContext[];
      frameRange(i: number): FrameRangeContext | null;
      AND(): antlr.TerminalNode;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FrameRangeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CURRENT(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      UNBOUNDED(): antlr.TerminalNode | null;
      PRECEDING(): antlr.TerminalNode | null;
      FOLLOWING(): antlr.TerminalNode | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PartitionClauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ScalarFunctionNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      functionNameBase(): FunctionNameBaseContext | null;
      ASCII(): antlr.TerminalNode | null;
      CURDATE(): antlr.TerminalNode | null;
      CURRENT_DATE(): antlr.TerminalNode | null;
      CURRENT_TIME(): antlr.TerminalNode | null;
      CURRENT_TIMESTAMP(): antlr.TerminalNode | null;
      CURTIME(): antlr.TerminalNode | null;
      DATE_ADD(): antlr.TerminalNode | null;
      DATE_SUB(): antlr.TerminalNode | null;
      IF(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      LOCALTIME(): antlr.TerminalNode | null;
      LOCALTIMESTAMP(): antlr.TerminalNode | null;
      MID(): antlr.TerminalNode | null;
      NOW(): antlr.TerminalNode | null;
      REPEAT(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      SUBSTR(): antlr.TerminalNode | null;
      SUBSTRING(): antlr.TerminalNode | null;
      SYSDATE(): antlr.TerminalNode | null;
      TRIM(): antlr.TerminalNode | null;
      UTC_DATE(): antlr.TerminalNode | null;
      UTC_TIME(): antlr.TerminalNode | null;
      UTC_TIMESTAMP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PasswordFunctionClauseContext extends antlr.ParserRuleContext {
      _functionName?: Token | null;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LR_BRACKET(): antlr.TerminalNode;
      functionArg(): FunctionArgContext;
      RR_BRACKET(): antlr.TerminalNode;
      PASSWORD(): antlr.TerminalNode | null;
      OLD_PASSWORD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FunctionArgsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      constant(): ConstantContext[];
      constant(i: number): ConstantContext | null;
      fullColumnName(): FullColumnNameContext[];
      fullColumnName(i: number): FullColumnNameContext | null;
      functionCall(): FunctionCallContext[];
      functionCall(i: number): FunctionCallContext | null;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FunctionArgContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      constant(): ConstantContext | null;
      fullColumnName(): FullColumnNameContext | null;
      functionCall(): FunctionCallContext | null;
      expression(): ExpressionContext | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExpressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ExpressionContext): void;
  }
  export class IsExpressionContext extends ExpressionContext {
      _testValue?: Token | null;
      constructor(ctx: ExpressionContext);
      predicate(): PredicateContext;
      IS(): antlr.TerminalNode;
      TRUE(): antlr.TerminalNode | null;
      FALSE(): antlr.TerminalNode | null;
      UNKNOWN(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NotExpressionContext extends ExpressionContext {
      _notOperator?: Token | null;
      constructor(ctx: ExpressionContext);
      expression(): ExpressionContext;
      NOT(): antlr.TerminalNode | null;
      EXCLAMATION_SYMBOL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LogicalExpressionContext extends ExpressionContext {
      constructor(ctx: ExpressionContext);
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      logicalOperator(): LogicalOperatorContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PredicateExpressionContext extends ExpressionContext {
      constructor(ctx: ExpressionContext);
      predicate(): PredicateContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PredicateContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: PredicateContext): void;
  }
  export class SoundsLikePredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext[];
      predicate(i: number): PredicateContext | null;
      SOUNDS(): antlr.TerminalNode;
      LIKE(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExpressionAtomPredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      expressionAtom(): ExpressionAtomContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SubqueryComparisonPredicateContext extends PredicateContext {
      _quantifier?: Token | null;
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext;
      comparisonOperator(): ComparisonOperatorContext;
      LR_BRACKET(): antlr.TerminalNode;
      selectStatement(): SelectStatementContext;
      RR_BRACKET(): antlr.TerminalNode;
      ALL(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      SOME(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonMemberOfPredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext[];
      predicate(i: number): PredicateContext | null;
      MEMBER(): antlr.TerminalNode;
      OF(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BinaryComparisonPredicateContext extends PredicateContext {
      _left?: PredicateContext;
      _right?: PredicateContext;
      constructor(ctx: PredicateContext);
      comparisonOperator(): ComparisonOperatorContext;
      predicate(): PredicateContext[];
      predicate(i: number): PredicateContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class InPredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext;
      IN(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      RR_BRACKET(): antlr.TerminalNode;
      selectStatement(): SelectStatementContext | null;
      expressions(): ExpressionsContext | null;
      NOT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BetweenPredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext[];
      predicate(i: number): PredicateContext | null;
      BETWEEN(): antlr.TerminalNode;
      AND(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IsNullPredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext;
      IS(): antlr.TerminalNode;
      nullNotnull(): NullNotnullContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LikePredicateContext extends PredicateContext {
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext[];
      predicate(i: number): PredicateContext | null;
      LIKE(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode | null;
      ESCAPE(): antlr.TerminalNode | null;
      STRING_LITERAL(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class RegexpPredicateContext extends PredicateContext {
      _regex?: Token | null;
      constructor(ctx: PredicateContext);
      predicate(): PredicateContext[];
      predicate(i: number): PredicateContext | null;
      REGEXP(): antlr.TerminalNode | null;
      RLIKE(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExpressionAtomContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: ExpressionAtomContext): void;
  }
  export class UnaryExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      unaryOperator(): UnaryOperatorContext;
      expressionAtom(): ExpressionAtomContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CollateExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      expressionAtom(): ExpressionAtomContext;
      COLLATE(): antlr.TerminalNode;
      collationName(): CollationNameContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class VariableAssignExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      LOCAL_ID(): antlr.TerminalNode;
      VAR_ASSIGN(): antlr.TerminalNode;
      expressionAtom(): ExpressionAtomContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MysqlVariableExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      mysqlVariable(): MysqlVariableContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NestedExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class NestedRowExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      ROW(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      expression(): ExpressionContext[];
      expression(i: number): ExpressionContext | null;
      RR_BRACKET(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MathExpressionAtomContext extends ExpressionAtomContext {
      _left?: ExpressionAtomContext;
      _right?: ExpressionAtomContext;
      constructor(ctx: ExpressionAtomContext);
      multOperator(): MultOperatorContext | null;
      expressionAtom(): ExpressionAtomContext[];
      expressionAtom(i: number): ExpressionAtomContext | null;
      addOperator(): AddOperatorContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ExistsExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      EXISTS(): antlr.TerminalNode;
      LR_BRACKET(): antlr.TerminalNode;
      selectStatement(): SelectStatementContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IntervalExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      INTERVAL(): antlr.TerminalNode;
      expression(): ExpressionContext;
      intervalType(): IntervalTypeContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonExpressionAtomContext extends ExpressionAtomContext {
      _left?: ExpressionAtomContext;
      _right?: ExpressionAtomContext;
      constructor(ctx: ExpressionAtomContext);
      jsonOperator(): JsonOperatorContext;
      expressionAtom(): ExpressionAtomContext[];
      expressionAtom(i: number): ExpressionAtomContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class SubqueryExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      LR_BRACKET(): antlr.TerminalNode;
      selectStatement(): SelectStatementContext;
      RR_BRACKET(): antlr.TerminalNode;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ConstantExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      constant(): ConstantContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FunctionCallExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      functionCall(): FunctionCallContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BinaryExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      BINARY(): antlr.TerminalNode;
      expressionAtom(): ExpressionAtomContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FullColumnNameExpressionAtomContext extends ExpressionAtomContext {
      constructor(ctx: ExpressionAtomContext);
      fullColumnName(): FullColumnNameContext;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BitExpressionAtomContext extends ExpressionAtomContext {
      _left?: ExpressionAtomContext;
      _right?: ExpressionAtomContext;
      constructor(ctx: ExpressionAtomContext);
      bitOperator(): BitOperatorContext;
      expressionAtom(): ExpressionAtomContext[];
      expressionAtom(i: number): ExpressionAtomContext | null;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class UnaryOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXCLAMATION_SYMBOL(): antlr.TerminalNode | null;
      BIT_NOT_OP(): antlr.TerminalNode | null;
      PLUS(): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class ComparisonOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EQUAL_SYMBOL(): antlr.TerminalNode | null;
      GREATER_SYMBOL(): antlr.TerminalNode | null;
      LESS_SYMBOL(): antlr.TerminalNode | null;
      EXCLAMATION_SYMBOL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class LogicalOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AND(): antlr.TerminalNode | null;
      BIT_AND_OP(): antlr.TerminalNode[];
      BIT_AND_OP(i: number): antlr.TerminalNode | null;
      XOR(): antlr.TerminalNode | null;
      OR(): antlr.TerminalNode | null;
      BIT_OR_OP(): antlr.TerminalNode[];
      BIT_OR_OP(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class BitOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LESS_SYMBOL(): antlr.TerminalNode[];
      LESS_SYMBOL(i: number): antlr.TerminalNode | null;
      GREATER_SYMBOL(): antlr.TerminalNode[];
      GREATER_SYMBOL(i: number): antlr.TerminalNode | null;
      BIT_AND_OP(): antlr.TerminalNode | null;
      BIT_XOR_OP(): antlr.TerminalNode | null;
      BIT_OR_OP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class MultOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STAR(): antlr.TerminalNode | null;
      DIVIDE(): antlr.TerminalNode | null;
      MODULE(): antlr.TerminalNode | null;
      DIV(): antlr.TerminalNode | null;
      MOD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class AddOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PLUS(): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class JsonOperatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MINUS(): antlr.TerminalNode;
      GREATER_SYMBOL(): antlr.TerminalNode[];
      GREATER_SYMBOL(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class CharsetNameBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ARMSCII8(): antlr.TerminalNode | null;
      ASCII(): antlr.TerminalNode | null;
      BIG5(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      CP1250(): antlr.TerminalNode | null;
      CP1251(): antlr.TerminalNode | null;
      CP1256(): antlr.TerminalNode | null;
      CP1257(): antlr.TerminalNode | null;
      CP850(): antlr.TerminalNode | null;
      CP852(): antlr.TerminalNode | null;
      CP866(): antlr.TerminalNode | null;
      CP932(): antlr.TerminalNode | null;
      DEC8(): antlr.TerminalNode | null;
      EUCJPMS(): antlr.TerminalNode | null;
      EUCKR(): antlr.TerminalNode | null;
      GB18030(): antlr.TerminalNode | null;
      GB2312(): antlr.TerminalNode | null;
      GBK(): antlr.TerminalNode | null;
      GEOSTD8(): antlr.TerminalNode | null;
      GREEK(): antlr.TerminalNode | null;
      HEBREW(): antlr.TerminalNode | null;
      HP8(): antlr.TerminalNode | null;
      KEYBCS2(): antlr.TerminalNode | null;
      KOI8R(): antlr.TerminalNode | null;
      KOI8U(): antlr.TerminalNode | null;
      LATIN1(): antlr.TerminalNode | null;
      LATIN2(): antlr.TerminalNode | null;
      LATIN5(): antlr.TerminalNode | null;
      LATIN7(): antlr.TerminalNode | null;
      MACCE(): antlr.TerminalNode | null;
      MACROMAN(): antlr.TerminalNode | null;
      SJIS(): antlr.TerminalNode | null;
      SWE7(): antlr.TerminalNode | null;
      TIS620(): antlr.TerminalNode | null;
      UCS2(): antlr.TerminalNode | null;
      UJIS(): antlr.TerminalNode | null;
      UTF16(): antlr.TerminalNode | null;
      UTF16LE(): antlr.TerminalNode | null;
      UTF32(): antlr.TerminalNode | null;
      UTF8(): antlr.TerminalNode | null;
      UTF8MB3(): antlr.TerminalNode | null;
      UTF8MB4(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class TransactionLevelBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPEATABLE(): antlr.TerminalNode | null;
      COMMITTED(): antlr.TerminalNode | null;
      UNCOMMITTED(): antlr.TerminalNode | null;
      SERIALIZABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class PrivilegesBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLES(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      EXECUTE(): antlr.TerminalNode | null;
      FILE(): antlr.TerminalNode | null;
      PROCESS(): antlr.TerminalNode | null;
      RELOAD(): antlr.TerminalNode | null;
      SHUTDOWN(): antlr.TerminalNode | null;
      SUPER(): antlr.TerminalNode | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class IntervalTypeBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      QUARTER(): antlr.TerminalNode | null;
      MONTH(): antlr.TerminalNode | null;
      DAY(): antlr.TerminalNode | null;
      HOUR(): antlr.TerminalNode | null;
      MINUTE(): antlr.TerminalNode | null;
      WEEK(): antlr.TerminalNode | null;
      SECOND(): antlr.TerminalNode | null;
      MICROSECOND(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class DataTypeBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DATE(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      TIMESTAMP(): antlr.TerminalNode | null;
      DATETIME(): antlr.TerminalNode | null;
      YEAR(): antlr.TerminalNode | null;
      ENUM(): antlr.TerminalNode | null;
      TEXT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class KeywordsCanBeIdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ACCOUNT(): antlr.TerminalNode | null;
      ACTION(): antlr.TerminalNode | null;
      ADMIN(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      AGGREGATE(): antlr.TerminalNode | null;
      ALGORITHM(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      ARRAY(): antlr.TerminalNode | null;
      AT(): antlr.TerminalNode | null;
      AUDIT_ADMIN(): antlr.TerminalNode | null;
      AUDIT_ABORT_EXEMPT(): antlr.TerminalNode | null;
      AUTHORS(): antlr.TerminalNode | null;
      AUTOCOMMIT(): antlr.TerminalNode | null;
      AUTOEXTEND_SIZE(): antlr.TerminalNode | null;
      AUTO_INCREMENT(): antlr.TerminalNode | null;
      AUTHENTICATION_POLICY_ADMIN(): antlr.TerminalNode | null;
      AVG(): antlr.TerminalNode | null;
      AVG_ROW_LENGTH(): antlr.TerminalNode | null;
      ATTRIBUTE(): antlr.TerminalNode | null;
      BACKUP_ADMIN(): antlr.TerminalNode | null;
      BEGIN(): antlr.TerminalNode | null;
      BINLOG(): antlr.TerminalNode | null;
      BINLOG_ADMIN(): antlr.TerminalNode | null;
      BINLOG_ENCRYPTION_ADMIN(): antlr.TerminalNode | null;
      BIT(): antlr.TerminalNode | null;
      BIT_AND(): antlr.TerminalNode | null;
      BIT_OR(): antlr.TerminalNode | null;
      BIT_XOR(): antlr.TerminalNode | null;
      BLOCK(): antlr.TerminalNode | null;
      BOOL(): antlr.TerminalNode | null;
      BOOLEAN(): antlr.TerminalNode | null;
      BTREE(): antlr.TerminalNode | null;
      BUCKETS(): antlr.TerminalNode | null;
      CACHE(): antlr.TerminalNode | null;
      CASCADED(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      CHANGED(): antlr.TerminalNode | null;
      CHANNEL(): antlr.TerminalNode | null;
      CHECKSUM(): antlr.TerminalNode | null;
      PAGE_CHECKSUM(): antlr.TerminalNode | null;
      CATALOG_NAME(): antlr.TerminalNode | null;
      CIPHER(): antlr.TerminalNode | null;
      CLASS_ORIGIN(): antlr.TerminalNode | null;
      CLIENT(): antlr.TerminalNode | null;
      CLONE_ADMIN(): antlr.TerminalNode | null;
      CLOSE(): antlr.TerminalNode | null;
      CLUSTERING(): antlr.TerminalNode | null;
      COALESCE(): antlr.TerminalNode | null;
      CODE(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      COLUMN_FORMAT(): antlr.TerminalNode | null;
      COLUMN_NAME(): antlr.TerminalNode | null;
      COMMENT(): antlr.TerminalNode | null;
      COMMIT(): antlr.TerminalNode | null;
      COMPACT(): antlr.TerminalNode | null;
      COMPLETION(): antlr.TerminalNode | null;
      COMPRESSED(): antlr.TerminalNode | null;
      COMPRESSION(): antlr.TerminalNode | null;
      CONCURRENT(): antlr.TerminalNode | null;
      CONDITION(): antlr.TerminalNode | null;
      CONNECT(): antlr.TerminalNode | null;
      CONNECTION(): antlr.TerminalNode | null;
      CONNECTION_ADMIN(): antlr.TerminalNode | null;
      CONSISTENT(): antlr.TerminalNode | null;
      CONSTRAINT_CATALOG(): antlr.TerminalNode | null;
      CONSTRAINT_NAME(): antlr.TerminalNode | null;
      CONSTRAINT_SCHEMA(): antlr.TerminalNode | null;
      CONTAINS(): antlr.TerminalNode | null;
      CONTEXT(): antlr.TerminalNode | null;
      CONTRIBUTORS(): antlr.TerminalNode | null;
      COPY(): antlr.TerminalNode | null;
      COUNT(): antlr.TerminalNode | null;
      CPU(): antlr.TerminalNode | null;
      CURRENT(): antlr.TerminalNode | null;
      CURRENT_USER(): antlr.TerminalNode | null;
      CURSOR_NAME(): antlr.TerminalNode | null;
      DATA(): antlr.TerminalNode | null;
      DATAFILE(): antlr.TerminalNode | null;
      DEALLOCATE(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      DEFAULT_AUTH(): antlr.TerminalNode | null;
      DEFINER(): antlr.TerminalNode | null;
      DELAY_KEY_WRITE(): antlr.TerminalNode | null;
      DES_KEY_FILE(): antlr.TerminalNode | null;
      DIAGNOSTICS(): antlr.TerminalNode | null;
      DIRECTORY(): antlr.TerminalNode | null;
      DISABLE(): antlr.TerminalNode | null;
      DISCARD(): antlr.TerminalNode | null;
      DISK(): antlr.TerminalNode | null;
      DO(): antlr.TerminalNode | null;
      DUMPFILE(): antlr.TerminalNode | null;
      DUPLICATE(): antlr.TerminalNode | null;
      DYNAMIC(): antlr.TerminalNode | null;
      EMPTY(): antlr.TerminalNode | null;
      ENABLE(): antlr.TerminalNode | null;
      ENCRYPTION(): antlr.TerminalNode | null;
      ENCRYPTION_KEY_ADMIN(): antlr.TerminalNode | null;
      END(): antlr.TerminalNode | null;
      ENDS(): antlr.TerminalNode | null;
      ENGINE(): antlr.TerminalNode | null;
      ENGINE_ATTRIBUTE(): antlr.TerminalNode | null;
      ENGINES(): antlr.TerminalNode | null;
      ENFORCED(): antlr.TerminalNode | null;
      ERROR(): antlr.TerminalNode | null;
      ERRORS(): antlr.TerminalNode | null;
      ESCAPE(): antlr.TerminalNode | null;
      EUR(): antlr.TerminalNode | null;
      EVEN(): antlr.TerminalNode | null;
      EVENT(): antlr.TerminalNode | null;
      EVENTS(): antlr.TerminalNode | null;
      EVERY(): antlr.TerminalNode | null;
      EXCEPT(): antlr.TerminalNode | null;
      EXCHANGE(): antlr.TerminalNode | null;
      EXCLUSIVE(): antlr.TerminalNode | null;
      EXPIRE(): antlr.TerminalNode | null;
      EXPORT(): antlr.TerminalNode | null;
      EXTENDED(): antlr.TerminalNode | null;
      EXTENT_SIZE(): antlr.TerminalNode | null;
      FAILED_LOGIN_ATTEMPTS(): antlr.TerminalNode | null;
      FAST(): antlr.TerminalNode | null;
      FAULTS(): antlr.TerminalNode | null;
      FIELDS(): antlr.TerminalNode | null;
      FILE_BLOCK_SIZE(): antlr.TerminalNode | null;
      FILTER(): antlr.TerminalNode | null;
      FIREWALL_ADMIN(): antlr.TerminalNode | null;
      FIREWALL_EXEMPT(): antlr.TerminalNode | null;
      FIREWALL_USER(): antlr.TerminalNode | null;
      FIRST(): antlr.TerminalNode | null;
      FIXED(): antlr.TerminalNode | null;
      FLUSH(): antlr.TerminalNode | null;
      FOLLOWS(): antlr.TerminalNode | null;
      FOUND(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      GENERAL(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      GRANTS(): antlr.TerminalNode | null;
      GROUP(): antlr.TerminalNode | null;
      GROUP_CONCAT(): antlr.TerminalNode | null;
      GROUP_REPLICATION(): antlr.TerminalNode | null;
      GROUP_REPLICATION_ADMIN(): antlr.TerminalNode | null;
      HANDLER(): antlr.TerminalNode | null;
      HASH(): antlr.TerminalNode | null;
      HELP(): antlr.TerminalNode | null;
      HISTORY(): antlr.TerminalNode | null;
      HOST(): antlr.TerminalNode | null;
      HOSTS(): antlr.TerminalNode | null;
      IDENTIFIED(): antlr.TerminalNode | null;
      IGNORED(): antlr.TerminalNode | null;
      IGNORE_SERVER_IDS(): antlr.TerminalNode | null;
      IMPORT(): antlr.TerminalNode | null;
      INDEXES(): antlr.TerminalNode | null;
      INITIAL_SIZE(): antlr.TerminalNode | null;
      INNODB_REDO_LOG_ARCHIVE(): antlr.TerminalNode | null;
      INPLACE(): antlr.TerminalNode | null;
      INSERT_METHOD(): antlr.TerminalNode | null;
      INSTALL(): antlr.TerminalNode | null;
      INSTANCE(): antlr.TerminalNode | null;
      INSTANT(): antlr.TerminalNode | null;
      INTERNAL(): antlr.TerminalNode | null;
      INVOKE(): antlr.TerminalNode | null;
      INVOKER(): antlr.TerminalNode | null;
      IO(): antlr.TerminalNode | null;
      IO_THREAD(): antlr.TerminalNode | null;
      IPC(): antlr.TerminalNode | null;
      ISO(): antlr.TerminalNode | null;
      ISOLATION(): antlr.TerminalNode | null;
      ISSUER(): antlr.TerminalNode | null;
      JIS(): antlr.TerminalNode | null;
      JSON(): antlr.TerminalNode | null;
      KEY_BLOCK_SIZE(): antlr.TerminalNode | null;
      LAMBDA(): antlr.TerminalNode | null;
      LANGUAGE(): antlr.TerminalNode | null;
      LAST(): antlr.TerminalNode | null;
      LATERAL(): antlr.TerminalNode | null;
      LEAVES(): antlr.TerminalNode | null;
      LESS(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      LIST(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      LOGFILE(): antlr.TerminalNode | null;
      LOGS(): antlr.TerminalNode | null;
      MASTER(): antlr.TerminalNode | null;
      MASTER_AUTO_POSITION(): antlr.TerminalNode | null;
      MASTER_CONNECT_RETRY(): antlr.TerminalNode | null;
      MASTER_DELAY(): antlr.TerminalNode | null;
      MASTER_HEARTBEAT_PERIOD(): antlr.TerminalNode | null;
      MASTER_HOST(): antlr.TerminalNode | null;
      MASTER_LOG_FILE(): antlr.TerminalNode | null;
      MASTER_LOG_POS(): antlr.TerminalNode | null;
      MASTER_PASSWORD(): antlr.TerminalNode | null;
      MASTER_PORT(): antlr.TerminalNode | null;
      MASTER_RETRY_COUNT(): antlr.TerminalNode | null;
      MASTER_SSL(): antlr.TerminalNode | null;
      MASTER_SSL_CA(): antlr.TerminalNode | null;
      MASTER_SSL_CAPATH(): antlr.TerminalNode | null;
      MASTER_SSL_CERT(): antlr.TerminalNode | null;
      MASTER_SSL_CIPHER(): antlr.TerminalNode | null;
      MASTER_SSL_CRL(): antlr.TerminalNode | null;
      MASTER_SSL_CRLPATH(): antlr.TerminalNode | null;
      MASTER_SSL_KEY(): antlr.TerminalNode | null;
      MASTER_TLS_VERSION(): antlr.TerminalNode | null;
      MASTER_USER(): antlr.TerminalNode | null;
      MAX_CONNECTIONS_PER_HOUR(): antlr.TerminalNode | null;
      MAX_QUERIES_PER_HOUR(): antlr.TerminalNode | null;
      MAX(): antlr.TerminalNode | null;
      MAX_ROWS(): antlr.TerminalNode | null;
      MAX_SIZE(): antlr.TerminalNode | null;
      MAX_UPDATES_PER_HOUR(): antlr.TerminalNode | null;
      MAX_USER_CONNECTIONS(): antlr.TerminalNode | null;
      MEDIUM(): antlr.TerminalNode | null;
      MEMBER(): antlr.TerminalNode | null;
      MEMORY(): antlr.TerminalNode | null;
      MERGE(): antlr.TerminalNode | null;
      MESSAGE_TEXT(): antlr.TerminalNode | null;
      MID(): antlr.TerminalNode | null;
      MIGRATE(): antlr.TerminalNode | null;
      MIN(): antlr.TerminalNode | null;
      MIN_ROWS(): antlr.TerminalNode | null;
      MODE(): antlr.TerminalNode | null;
      MODIFY(): antlr.TerminalNode | null;
      MUTEX(): antlr.TerminalNode | null;
      MYSQL(): antlr.TerminalNode | null;
      MYSQL_ERRNO(): antlr.TerminalNode | null;
      NAME(): antlr.TerminalNode | null;
      NAMES(): antlr.TerminalNode | null;
      NCHAR(): antlr.TerminalNode | null;
      NDB_STORED_USER(): antlr.TerminalNode | null;
      NESTED(): antlr.TerminalNode | null;
      NEVER(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      NOCOPY(): antlr.TerminalNode | null;
      NODEGROUP(): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode | null;
      NOWAIT(): antlr.TerminalNode | null;
      NUMBER(): antlr.TerminalNode | null;
      ODBC(): antlr.TerminalNode | null;
      OFFLINE(): antlr.TerminalNode | null;
      OFFSET(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      OJ(): antlr.TerminalNode | null;
      OLD_PASSWORD(): antlr.TerminalNode | null;
      ONE(): antlr.TerminalNode | null;
      ONLINE(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      OPEN(): antlr.TerminalNode | null;
      OPTIMIZER_COSTS(): antlr.TerminalNode | null;
      OPTIONAL(): antlr.TerminalNode | null;
      OPTIONS(): antlr.TerminalNode | null;
      ORDER(): antlr.TerminalNode | null;
      ORDINALITY(): antlr.TerminalNode | null;
      OWNER(): antlr.TerminalNode | null;
      PACK_KEYS(): antlr.TerminalNode | null;
      PAGE(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      PARTIAL(): antlr.TerminalNode | null;
      PARTITIONING(): antlr.TerminalNode | null;
      PARTITIONS(): antlr.TerminalNode | null;
      PASSWORD(): antlr.TerminalNode | null;
      PASSWORDLESS_USER_ADMIN(): antlr.TerminalNode | null;
      PASSWORD_LOCK_TIME(): antlr.TerminalNode | null;
      PATH(): antlr.TerminalNode | null;
      PERSIST_RO_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      PHASE(): antlr.TerminalNode | null;
      PLUGINS(): antlr.TerminalNode | null;
      PLUGIN_DIR(): antlr.TerminalNode | null;
      PLUGIN(): antlr.TerminalNode | null;
      PORT(): antlr.TerminalNode | null;
      PRECEDES(): antlr.TerminalNode | null;
      PREPARE(): antlr.TerminalNode | null;
      PRESERVE(): antlr.TerminalNode | null;
      PREV(): antlr.TerminalNode | null;
      PRIMARY(): antlr.TerminalNode | null;
      PROCESSLIST(): antlr.TerminalNode | null;
      PROFILE(): antlr.TerminalNode | null;
      PROFILES(): antlr.TerminalNode | null;
      PROXY(): antlr.TerminalNode | null;
      QUERY(): antlr.TerminalNode | null;
      QUICK(): antlr.TerminalNode | null;
      REBUILD(): antlr.TerminalNode | null;
      RECOVER(): antlr.TerminalNode | null;
      RECURSIVE(): antlr.TerminalNode | null;
      REDO_BUFFER_SIZE(): antlr.TerminalNode | null;
      REDUNDANT(): antlr.TerminalNode | null;
      RELAY(): antlr.TerminalNode | null;
      RELAYLOG(): antlr.TerminalNode | null;
      RELAY_LOG_FILE(): antlr.TerminalNode | null;
      RELAY_LOG_POS(): antlr.TerminalNode | null;
      REMOVE(): antlr.TerminalNode | null;
      REORGANIZE(): antlr.TerminalNode | null;
      REPAIR(): antlr.TerminalNode | null;
      REPLICATE_DO_DB(): antlr.TerminalNode | null;
      REPLICATE_DO_TABLE(): antlr.TerminalNode | null;
      REPLICATE_IGNORE_DB(): antlr.TerminalNode | null;
      REPLICATE_IGNORE_TABLE(): antlr.TerminalNode | null;
      REPLICATE_REWRITE_DB(): antlr.TerminalNode | null;
      REPLICATE_WILD_DO_TABLE(): antlr.TerminalNode | null;
      REPLICATE_WILD_IGNORE_TABLE(): antlr.TerminalNode | null;
      REPLICATION(): antlr.TerminalNode | null;
      REPLICATION_APPLIER(): antlr.TerminalNode | null;
      REPLICATION_SLAVE_ADMIN(): antlr.TerminalNode | null;
      RESET(): antlr.TerminalNode | null;
      RESOURCE_GROUP_ADMIN(): antlr.TerminalNode | null;
      RESOURCE_GROUP_USER(): antlr.TerminalNode | null;
      RESUME(): antlr.TerminalNode | null;
      RETURNED_SQLSTATE(): antlr.TerminalNode | null;
      RETURNS(): antlr.TerminalNode | null;
      REUSE(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      ROLE_ADMIN(): antlr.TerminalNode | null;
      ROLLBACK(): antlr.TerminalNode | null;
      ROLLUP(): antlr.TerminalNode | null;
      ROTATE(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode | null;
      ROW_FORMAT(): antlr.TerminalNode | null;
      RTREE(): antlr.TerminalNode | null;
      S3(): antlr.TerminalNode | null;
      SAVEPOINT(): antlr.TerminalNode | null;
      SCHEDULE(): antlr.TerminalNode | null;
      SCHEMA_NAME(): antlr.TerminalNode | null;
      SECURITY(): antlr.TerminalNode | null;
      SECONDARY_ENGINE_ATTRIBUTE(): antlr.TerminalNode | null;
      SERIAL(): antlr.TerminalNode | null;
      SERVER(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      SESSION_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      SET_USER_ID(): antlr.TerminalNode | null;
      SHARE(): antlr.TerminalNode | null;
      SHARED(): antlr.TerminalNode | null;
      SHOW_ROUTINE(): antlr.TerminalNode | null;
      SIGNED(): antlr.TerminalNode | null;
      SIMPLE(): antlr.TerminalNode | null;
      SLAVE(): antlr.TerminalNode | null;
      SLOW(): antlr.TerminalNode | null;
      SKIP_QUERY_REWRITE(): antlr.TerminalNode | null;
      SNAPSHOT(): antlr.TerminalNode | null;
      SOCKET(): antlr.TerminalNode | null;
      SOME(): antlr.TerminalNode | null;
      SONAME(): antlr.TerminalNode | null;
      SOUNDS(): antlr.TerminalNode | null;
      SOURCE(): antlr.TerminalNode | null;
      SQL_AFTER_GTIDS(): antlr.TerminalNode | null;
      SQL_AFTER_MTS_GAPS(): antlr.TerminalNode | null;
      SQL_BEFORE_GTIDS(): antlr.TerminalNode | null;
      SQL_BUFFER_RESULT(): antlr.TerminalNode | null;
      SQL_CACHE(): antlr.TerminalNode | null;
      SQL_NO_CACHE(): antlr.TerminalNode | null;
      SQL_THREAD(): antlr.TerminalNode | null;
      STACKED(): antlr.TerminalNode | null;
      START(): antlr.TerminalNode | null;
      STARTS(): antlr.TerminalNode | null;
      STATS_AUTO_RECALC(): antlr.TerminalNode | null;
      STATS_PERSISTENT(): antlr.TerminalNode | null;
      STATS_SAMPLE_PAGES(): antlr.TerminalNode | null;
      STATUS(): antlr.TerminalNode | null;
      STD(): antlr.TerminalNode | null;
      STDDEV(): antlr.TerminalNode | null;
      STDDEV_POP(): antlr.TerminalNode | null;
      STDDEV_SAMP(): antlr.TerminalNode | null;
      STOP(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      STRING(): antlr.TerminalNode | null;
      SUBCLASS_ORIGIN(): antlr.TerminalNode | null;
      SUBJECT(): antlr.TerminalNode | null;
      SUBPARTITION(): antlr.TerminalNode | null;
      SUBPARTITIONS(): antlr.TerminalNode | null;
      SUM(): antlr.TerminalNode | null;
      SUSPEND(): antlr.TerminalNode | null;
      SWAPS(): antlr.TerminalNode | null;
      SWITCHES(): antlr.TerminalNode | null;
      SYSTEM_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      TABLE_NAME(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      TABLE_ENCRYPTION_ADMIN(): antlr.TerminalNode | null;
      TABLE_TYPE(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      TEMPTABLE(): antlr.TerminalNode | null;
      THAN(): antlr.TerminalNode | null;
      TP_CONNECTION_ADMIN(): antlr.TerminalNode | null;
      TRADITIONAL(): antlr.TerminalNode | null;
      TRANSACTION(): antlr.TerminalNode | null;
      TRANSACTIONAL(): antlr.TerminalNode | null;
      TRIGGERS(): antlr.TerminalNode | null;
      TRUNCATE(): antlr.TerminalNode | null;
      UNBOUNDED(): antlr.TerminalNode | null;
      UNDEFINED(): antlr.TerminalNode | null;
      UNDOFILE(): antlr.TerminalNode | null;
      UNDO_BUFFER_SIZE(): antlr.TerminalNode | null;
      UNINSTALL(): antlr.TerminalNode | null;
      UNKNOWN(): antlr.TerminalNode | null;
      UNTIL(): antlr.TerminalNode | null;
      UPGRADE(): antlr.TerminalNode | null;
      USA(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      USE_FRM(): antlr.TerminalNode | null;
      USER_RESOURCES(): antlr.TerminalNode | null;
      VALIDATION(): antlr.TerminalNode | null;
      VALUE(): antlr.TerminalNode | null;
      VAR_POP(): antlr.TerminalNode | null;
      VAR_SAMP(): antlr.TerminalNode | null;
      VARIABLES(): antlr.TerminalNode | null;
      VARIANCE(): antlr.TerminalNode | null;
      VERSION_TOKEN_ADMIN(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      VIRTUAL(): antlr.TerminalNode | null;
      WAIT(): antlr.TerminalNode | null;
      WARNINGS(): antlr.TerminalNode | null;
      WITHOUT(): antlr.TerminalNode | null;
      WORK(): antlr.TerminalNode | null;
      WRAPPER(): antlr.TerminalNode | null;
      X509(): antlr.TerminalNode | null;
      XA(): antlr.TerminalNode | null;
      XA_RECOVER_ADMIN(): antlr.TerminalNode | null;
      XML(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }
  export class FunctionNameBaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ABS(): antlr.TerminalNode | null;
      ACOS(): antlr.TerminalNode | null;
      ADDDATE(): antlr.TerminalNode | null;
      ADDTIME(): antlr.TerminalNode | null;
      AES_DECRYPT(): antlr.TerminalNode | null;
      AES_ENCRYPT(): antlr.TerminalNode | null;
      AREA(): antlr.TerminalNode | null;
      ASBINARY(): antlr.TerminalNode | null;
      ASIN(): antlr.TerminalNode | null;
      ASTEXT(): antlr.TerminalNode | null;
      ASWKB(): antlr.TerminalNode | null;
      ASWKT(): antlr.TerminalNode | null;
      ASYMMETRIC_DECRYPT(): antlr.TerminalNode | null;
      ASYMMETRIC_DERIVE(): antlr.TerminalNode | null;
      ASYMMETRIC_ENCRYPT(): antlr.TerminalNode | null;
      ASYMMETRIC_SIGN(): antlr.TerminalNode | null;
      ASYMMETRIC_VERIFY(): antlr.TerminalNode | null;
      ATAN(): antlr.TerminalNode | null;
      ATAN2(): antlr.TerminalNode | null;
      BENCHMARK(): antlr.TerminalNode | null;
      BIN(): antlr.TerminalNode | null;
      BIT_COUNT(): antlr.TerminalNode | null;
      BIT_LENGTH(): antlr.TerminalNode | null;
      BUFFER(): antlr.TerminalNode | null;
      CEIL(): antlr.TerminalNode | null;
      CEILING(): antlr.TerminalNode | null;
      CENTROID(): antlr.TerminalNode | null;
      CHARACTER_LENGTH(): antlr.TerminalNode | null;
      CHARSET(): antlr.TerminalNode | null;
      CHAR_LENGTH(): antlr.TerminalNode | null;
      COERCIBILITY(): antlr.TerminalNode | null;
      COLLATION(): antlr.TerminalNode | null;
      COMPRESS(): antlr.TerminalNode | null;
      CONCAT(): antlr.TerminalNode | null;
      CONCAT_WS(): antlr.TerminalNode | null;
      CONNECTION_ID(): antlr.TerminalNode | null;
      CONV(): antlr.TerminalNode | null;
      CONVERT_TZ(): antlr.TerminalNode | null;
      COS(): antlr.TerminalNode | null;
      COT(): antlr.TerminalNode | null;
      COUNT(): antlr.TerminalNode | null;
      CRC32(): antlr.TerminalNode | null;
      CREATE_ASYMMETRIC_PRIV_KEY(): antlr.TerminalNode | null;
      CREATE_ASYMMETRIC_PUB_KEY(): antlr.TerminalNode | null;
      CREATE_DH_PARAMETERS(): antlr.TerminalNode | null;
      CREATE_DIGEST(): antlr.TerminalNode | null;
      CROSSES(): antlr.TerminalNode | null;
      CUME_DIST(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      DATE(): antlr.TerminalNode | null;
      DATEDIFF(): antlr.TerminalNode | null;
      DATE_FORMAT(): antlr.TerminalNode | null;
      DAY(): antlr.TerminalNode | null;
      DAYNAME(): antlr.TerminalNode | null;
      DAYOFMONTH(): antlr.TerminalNode | null;
      DAYOFWEEK(): antlr.TerminalNode | null;
      DAYOFYEAR(): antlr.TerminalNode | null;
      DECODE(): antlr.TerminalNode | null;
      DEGREES(): antlr.TerminalNode | null;
      DENSE_RANK(): antlr.TerminalNode | null;
      DES_DECRYPT(): antlr.TerminalNode | null;
      DES_ENCRYPT(): antlr.TerminalNode | null;
      DIMENSION(): antlr.TerminalNode | null;
      DISJOINT(): antlr.TerminalNode | null;
      ELT(): antlr.TerminalNode | null;
      ENCODE(): antlr.TerminalNode | null;
      ENCRYPT(): antlr.TerminalNode | null;
      ENDPOINT(): antlr.TerminalNode | null;
      ENVELOPE(): antlr.TerminalNode | null;
      EQUALS(): antlr.TerminalNode | null;
      EXP(): antlr.TerminalNode | null;
      EXPORT_SET(): antlr.TerminalNode | null;
      EXTERIORRING(): antlr.TerminalNode | null;
      EXTRACTVALUE(): antlr.TerminalNode | null;
      FIELD(): antlr.TerminalNode | null;
      FIND_IN_SET(): antlr.TerminalNode | null;
      FIRST_VALUE(): antlr.TerminalNode | null;
      FLOOR(): antlr.TerminalNode | null;
      FORMAT(): antlr.TerminalNode | null;
      FOUND_ROWS(): antlr.TerminalNode | null;
      FROM_BASE64(): antlr.TerminalNode | null;
      FROM_DAYS(): antlr.TerminalNode | null;
      FROM_UNIXTIME(): antlr.TerminalNode | null;
      GEOMCOLLFROMTEXT(): antlr.TerminalNode | null;
      GEOMCOLLFROMWKB(): antlr.TerminalNode | null;
      GEOMETRYCOLLECTION(): antlr.TerminalNode | null;
      GEOMETRYCOLLECTIONFROMTEXT(): antlr.TerminalNode | null;
      GEOMETRYCOLLECTIONFROMWKB(): antlr.TerminalNode | null;
      GEOMETRYFROMTEXT(): antlr.TerminalNode | null;
      GEOMETRYFROMWKB(): antlr.TerminalNode | null;
      GEOMETRYN(): antlr.TerminalNode | null;
      GEOMETRYTYPE(): antlr.TerminalNode | null;
      GEOMFROMTEXT(): antlr.TerminalNode | null;
      GEOMFROMWKB(): antlr.TerminalNode | null;
      GET_FORMAT(): antlr.TerminalNode | null;
      GET_LOCK(): antlr.TerminalNode | null;
      GLENGTH(): antlr.TerminalNode | null;
      GREATEST(): antlr.TerminalNode | null;
      GTID_SUBSET(): antlr.TerminalNode | null;
      GTID_SUBTRACT(): antlr.TerminalNode | null;
      HEX(): antlr.TerminalNode | null;
      HOUR(): antlr.TerminalNode | null;
      IFNULL(): antlr.TerminalNode | null;
      INET6_ATON(): antlr.TerminalNode | null;
      INET6_NTOA(): antlr.TerminalNode | null;
      INET_ATON(): antlr.TerminalNode | null;
      INET_NTOA(): antlr.TerminalNode | null;
      INSTR(): antlr.TerminalNode | null;
      INTERIORRINGN(): antlr.TerminalNode | null;
      INTERSECTS(): antlr.TerminalNode | null;
      INVISIBLE(): antlr.TerminalNode | null;
      ISCLOSED(): antlr.TerminalNode | null;
      ISEMPTY(): antlr.TerminalNode | null;
      ISNULL(): antlr.TerminalNode | null;
      ISSIMPLE(): antlr.TerminalNode | null;
      IS_FREE_LOCK(): antlr.TerminalNode | null;
      IS_IPV4(): antlr.TerminalNode | null;
      IS_IPV4_COMPAT(): antlr.TerminalNode | null;
      IS_IPV4_MAPPED(): antlr.TerminalNode | null;
      IS_IPV6(): antlr.TerminalNode | null;
      IS_USED_LOCK(): antlr.TerminalNode | null;
      LAG(): antlr.TerminalNode | null;
      LAST_INSERT_ID(): antlr.TerminalNode | null;
      LAST_VALUE(): antlr.TerminalNode | null;
      LCASE(): antlr.TerminalNode | null;
      LEAD(): antlr.TerminalNode | null;
      LEAST(): antlr.TerminalNode | null;
      LEFT(): antlr.TerminalNode | null;
      LENGTH(): antlr.TerminalNode | null;
      LINEFROMTEXT(): antlr.TerminalNode | null;
      LINEFROMWKB(): antlr.TerminalNode | null;
      LINESTRING(): antlr.TerminalNode | null;
      LINESTRINGFROMTEXT(): antlr.TerminalNode | null;
      LINESTRINGFROMWKB(): antlr.TerminalNode | null;
      LN(): antlr.TerminalNode | null;
      LOAD_FILE(): antlr.TerminalNode | null;
      LOCATE(): antlr.TerminalNode | null;
      LOG(): antlr.TerminalNode | null;
      LOG10(): antlr.TerminalNode | null;
      LOG2(): antlr.TerminalNode | null;
      LOWER(): antlr.TerminalNode | null;
      LPAD(): antlr.TerminalNode | null;
      LTRIM(): antlr.TerminalNode | null;
      MAKEDATE(): antlr.TerminalNode | null;
      MAKETIME(): antlr.TerminalNode | null;
      MAKE_SET(): antlr.TerminalNode | null;
      MASTER_POS_WAIT(): antlr.TerminalNode | null;
      MBRCONTAINS(): antlr.TerminalNode | null;
      MBRDISJOINT(): antlr.TerminalNode | null;
      MBREQUAL(): antlr.TerminalNode | null;
      MBRINTERSECTS(): antlr.TerminalNode | null;
      MBROVERLAPS(): antlr.TerminalNode | null;
      MBRTOUCHES(): antlr.TerminalNode | null;
      MBRWITHIN(): antlr.TerminalNode | null;
      MD5(): antlr.TerminalNode | null;
      MICROSECOND(): antlr.TerminalNode | null;
      MINUTE(): antlr.TerminalNode | null;
      MLINEFROMTEXT(): antlr.TerminalNode | null;
      MLINEFROMWKB(): antlr.TerminalNode | null;
      MOD(): antlr.TerminalNode | null;
      MONTH(): antlr.TerminalNode | null;
      MONTHNAME(): antlr.TerminalNode | null;
      MPOINTFROMTEXT(): antlr.TerminalNode | null;
      MPOINTFROMWKB(): antlr.TerminalNode | null;
      MPOLYFROMTEXT(): antlr.TerminalNode | null;
      MPOLYFROMWKB(): antlr.TerminalNode | null;
      MULTILINESTRING(): antlr.TerminalNode | null;
      MULTILINESTRINGFROMTEXT(): antlr.TerminalNode | null;
      MULTILINESTRINGFROMWKB(): antlr.TerminalNode | null;
      MULTIPOINT(): antlr.TerminalNode | null;
      MULTIPOINTFROMTEXT(): antlr.TerminalNode | null;
      MULTIPOINTFROMWKB(): antlr.TerminalNode | null;
      MULTIPOLYGON(): antlr.TerminalNode | null;
      MULTIPOLYGONFROMTEXT(): antlr.TerminalNode | null;
      MULTIPOLYGONFROMWKB(): antlr.TerminalNode | null;
      NAME_CONST(): antlr.TerminalNode | null;
      NTH_VALUE(): antlr.TerminalNode | null;
      NTILE(): antlr.TerminalNode | null;
      NULLIF(): antlr.TerminalNode | null;
      NUMGEOMETRIES(): antlr.TerminalNode | null;
      NUMINTERIORRINGS(): antlr.TerminalNode | null;
      NUMPOINTS(): antlr.TerminalNode | null;
      OCT(): antlr.TerminalNode | null;
      OCTET_LENGTH(): antlr.TerminalNode | null;
      ORD(): antlr.TerminalNode | null;
      OVERLAPS(): antlr.TerminalNode | null;
      PERCENT_RANK(): antlr.TerminalNode | null;
      PERIOD_ADD(): antlr.TerminalNode | null;
      PERIOD_DIFF(): antlr.TerminalNode | null;
      PI(): antlr.TerminalNode | null;
      POINT(): antlr.TerminalNode | null;
      POINTFROMTEXT(): antlr.TerminalNode | null;
      POINTFROMWKB(): antlr.TerminalNode | null;
      POINTN(): antlr.TerminalNode | null;
      POLYFROMTEXT(): antlr.TerminalNode | null;
      POLYFROMWKB(): antlr.TerminalNode | null;
      POLYGON(): antlr.TerminalNode | null;
      POLYGONFROMTEXT(): antlr.TerminalNode | null;
      POLYGONFROMWKB(): antlr.TerminalNode | null;
      POSITION(): antlr.TerminalNode | null;
      POW(): antlr.TerminalNode | null;
      POWER(): antlr.TerminalNode | null;
      QUARTER(): antlr.TerminalNode | null;
      QUOTE(): antlr.TerminalNode | null;
      RADIANS(): antlr.TerminalNode | null;
      RAND(): antlr.TerminalNode | null;
      RANDOM(): antlr.TerminalNode | null;
      RANK(): antlr.TerminalNode | null;
      RANDOM_BYTES(): antlr.TerminalNode | null;
      RELEASE_LOCK(): antlr.TerminalNode | null;
      REVERSE(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      ROUND(): antlr.TerminalNode | null;
      ROW_COUNT(): antlr.TerminalNode | null;
      ROW_NUMBER(): antlr.TerminalNode | null;
      RPAD(): antlr.TerminalNode | null;
      RTRIM(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      SECOND(): antlr.TerminalNode | null;
      SEC_TO_TIME(): antlr.TerminalNode | null;
      SESSION_USER(): antlr.TerminalNode | null;
      SESSION_VARIABLES_ADMIN(): antlr.TerminalNode | null;
      SHA(): antlr.TerminalNode | null;
      SHA1(): antlr.TerminalNode | null;
      SHA2(): antlr.TerminalNode | null;
      SIGN(): antlr.TerminalNode | null;
      SIN(): antlr.TerminalNode | null;
      SLEEP(): antlr.TerminalNode | null;
      SOUNDEX(): antlr.TerminalNode | null;
      SQL_THREAD_WAIT_AFTER_GTIDS(): antlr.TerminalNode | null;
      SQRT(): antlr.TerminalNode | null;
      SRID(): antlr.TerminalNode | null;
      STARTPOINT(): antlr.TerminalNode | null;
      STRCMP(): antlr.TerminalNode | null;
      STR_TO_DATE(): antlr.TerminalNode | null;
      ST_AREA(): antlr.TerminalNode | null;
      ST_ASBINARY(): antlr.TerminalNode | null;
      ST_ASTEXT(): antlr.TerminalNode | null;
      ST_ASWKB(): antlr.TerminalNode | null;
      ST_ASWKT(): antlr.TerminalNode | null;
      ST_BUFFER(): antlr.TerminalNode | null;
      ST_CENTROID(): antlr.TerminalNode | null;
      ST_CONTAINS(): antlr.TerminalNode | null;
      ST_CROSSES(): antlr.TerminalNode | null;
      ST_DIFFERENCE(): antlr.TerminalNode | null;
      ST_DIMENSION(): antlr.TerminalNode | null;
      ST_DISJOINT(): antlr.TerminalNode | null;
      ST_DISTANCE(): antlr.TerminalNode | null;
      ST_ENDPOINT(): antlr.TerminalNode | null;
      ST_ENVELOPE(): antlr.TerminalNode | null;
      ST_EQUALS(): antlr.TerminalNode | null;
      ST_EXTERIORRING(): antlr.TerminalNode | null;
      ST_GEOMCOLLFROMTEXT(): antlr.TerminalNode | null;
      ST_GEOMCOLLFROMTXT(): antlr.TerminalNode | null;
      ST_GEOMCOLLFROMWKB(): antlr.TerminalNode | null;
      ST_GEOMETRYCOLLECTIONFROMTEXT(): antlr.TerminalNode | null;
      ST_GEOMETRYCOLLECTIONFROMWKB(): antlr.TerminalNode | null;
      ST_GEOMETRYFROMTEXT(): antlr.TerminalNode | null;
      ST_GEOMETRYFROMWKB(): antlr.TerminalNode | null;
      ST_GEOMETRYN(): antlr.TerminalNode | null;
      ST_GEOMETRYTYPE(): antlr.TerminalNode | null;
      ST_GEOMFROMTEXT(): antlr.TerminalNode | null;
      ST_GEOMFROMWKB(): antlr.TerminalNode | null;
      ST_INTERIORRINGN(): antlr.TerminalNode | null;
      ST_INTERSECTION(): antlr.TerminalNode | null;
      ST_INTERSECTS(): antlr.TerminalNode | null;
      ST_ISCLOSED(): antlr.TerminalNode | null;
      ST_ISEMPTY(): antlr.TerminalNode | null;
      ST_ISSIMPLE(): antlr.TerminalNode | null;
      ST_LINEFROMTEXT(): antlr.TerminalNode | null;
      ST_LINEFROMWKB(): antlr.TerminalNode | null;
      ST_LINESTRINGFROMTEXT(): antlr.TerminalNode | null;
      ST_LINESTRINGFROMWKB(): antlr.TerminalNode | null;
      ST_NUMGEOMETRIES(): antlr.TerminalNode | null;
      ST_NUMINTERIORRING(): antlr.TerminalNode | null;
      ST_NUMINTERIORRINGS(): antlr.TerminalNode | null;
      ST_NUMPOINTS(): antlr.TerminalNode | null;
      ST_OVERLAPS(): antlr.TerminalNode | null;
      ST_POINTFROMTEXT(): antlr.TerminalNode | null;
      ST_POINTFROMWKB(): antlr.TerminalNode | null;
      ST_POINTN(): antlr.TerminalNode | null;
      ST_POLYFROMTEXT(): antlr.TerminalNode | null;
      ST_POLYFROMWKB(): antlr.TerminalNode | null;
      ST_POLYGONFROMTEXT(): antlr.TerminalNode | null;
      ST_POLYGONFROMWKB(): antlr.TerminalNode | null;
      ST_SRID(): antlr.TerminalNode | null;
      ST_STARTPOINT(): antlr.TerminalNode | null;
      ST_SYMDIFFERENCE(): antlr.TerminalNode | null;
      ST_TOUCHES(): antlr.TerminalNode | null;
      ST_UNION(): antlr.TerminalNode | null;
      ST_WITHIN(): antlr.TerminalNode | null;
      ST_X(): antlr.TerminalNode | null;
      ST_Y(): antlr.TerminalNode | null;
      SUBDATE(): antlr.TerminalNode | null;
      SUBSTRING_INDEX(): antlr.TerminalNode | null;
      SUBTIME(): antlr.TerminalNode | null;
      SYSTEM_USER(): antlr.TerminalNode | null;
      TAN(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      TIMEDIFF(): antlr.TerminalNode | null;
      TIMESTAMP(): antlr.TerminalNode | null;
      TIMESTAMPADD(): antlr.TerminalNode | null;
      TIMESTAMPDIFF(): antlr.TerminalNode | null;
      TIME_FORMAT(): antlr.TerminalNode | null;
      TIME_TO_SEC(): antlr.TerminalNode | null;
      TOUCHES(): antlr.TerminalNode | null;
      TO_BASE64(): antlr.TerminalNode | null;
      TO_DAYS(): antlr.TerminalNode | null;
      TO_SECONDS(): antlr.TerminalNode | null;
      UCASE(): antlr.TerminalNode | null;
      UNCOMPRESS(): antlr.TerminalNode | null;
      UNCOMPRESSED_LENGTH(): antlr.TerminalNode | null;
      UNHEX(): antlr.TerminalNode | null;
      UNIX_TIMESTAMP(): antlr.TerminalNode | null;
      UPDATEXML(): antlr.TerminalNode | null;
      UPPER(): antlr.TerminalNode | null;
      UUID(): antlr.TerminalNode | null;
      UUID_SHORT(): antlr.TerminalNode | null;
      VALIDATE_PASSWORD_STRENGTH(): antlr.TerminalNode | null;
      VERSION(): antlr.TerminalNode | null;
      VISIBLE(): antlr.TerminalNode | null;
      WAIT_UNTIL_SQL_THREAD_AFTER_GTIDS(): antlr.TerminalNode | null;
      WEEK(): antlr.TerminalNode | null;
      WEEKDAY(): antlr.TerminalNode | null;
      WEEKOFYEAR(): antlr.TerminalNode | null;
      WEIGHT_STRING(): antlr.TerminalNode | null;
      WITHIN(): antlr.TerminalNode | null;
      YEAR(): antlr.TerminalNode | null;
      YEARWEEK(): antlr.TerminalNode | null;
      Y_FUNCTION(): antlr.TerminalNode | null;
      X_FUNCTION(): antlr.TerminalNode | null;
      JSON_ARRAY(): antlr.TerminalNode | null;
      JSON_OBJECT(): antlr.TerminalNode | null;
      JSON_QUOTE(): antlr.TerminalNode | null;
      JSON_CONTAINS(): antlr.TerminalNode | null;
      JSON_CONTAINS_PATH(): antlr.TerminalNode | null;
      JSON_EXTRACT(): antlr.TerminalNode | null;
      JSON_KEYS(): antlr.TerminalNode | null;
      JSON_OVERLAPS(): antlr.TerminalNode | null;
      JSON_SEARCH(): antlr.TerminalNode | null;
      JSON_VALUE(): antlr.TerminalNode | null;
      JSON_ARRAY_APPEND(): antlr.TerminalNode | null;
      JSON_ARRAY_INSERT(): antlr.TerminalNode | null;
      JSON_INSERT(): antlr.TerminalNode | null;
      JSON_MERGE(): antlr.TerminalNode | null;
      JSON_MERGE_PATCH(): antlr.TerminalNode | null;
      JSON_MERGE_PRESERVE(): antlr.TerminalNode | null;
      JSON_REMOVE(): antlr.TerminalNode | null;
      JSON_REPLACE(): antlr.TerminalNode | null;
      JSON_SET(): antlr.TerminalNode | null;
      JSON_UNQUOTE(): antlr.TerminalNode | null;
      JSON_DEPTH(): antlr.TerminalNode | null;
      JSON_LENGTH(): antlr.TerminalNode | null;
      JSON_TYPE(): antlr.TerminalNode | null;
      JSON_VALID(): antlr.TerminalNode | null;
      JSON_TABLE(): antlr.TerminalNode | null;
      JSON_SCHEMA_VALID(): antlr.TerminalNode | null;
      JSON_SCHEMA_VALIDATION_REPORT(): antlr.TerminalNode | null;
      JSON_PRETTY(): antlr.TerminalNode | null;
      JSON_STORAGE_FREE(): antlr.TerminalNode | null;
      JSON_STORAGE_SIZE(): antlr.TerminalNode | null;
      JSON_ARRAYAGG(): antlr.TerminalNode | null;
      JSON_OBJECTAGG(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      enterRule(listener: MySqlParserListener): void;
      exitRule(listener: MySqlParserListener): void;
      accept<Result>(visitor: MySqlParserVisitor<Result>): Result | null;
  }

}
declare module 'websql-autocomplete-2/parsers/mysql/generated/MySqlParserVisitor' {
  import { AbstractParseTreeVisitor } from "antlr4ng";
  import { RootContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SqlStatementsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SqlStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { EmptyStatement_Context } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DdlStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DmlStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TransactionStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReplicationStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PreparedStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CompoundStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AdministrationStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UtilityStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateDatabaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateEventContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateIndexContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateLogfileGroupContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateProcedureContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateFunctionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateRoleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateServerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CopyCreateTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { QueryCreateTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ColumnCreateTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateTablespaceInnodbContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateTablespaceNdbContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateTriggerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WithClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CommonTableExpressionsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CteNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CteColumnNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateViewContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateDatabaseOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CharSetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CurrentUserExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OwnerStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PreciseScheduleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IntervalScheduleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TimestampValueContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IntervalExprContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IntervalTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { EnableTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ProcedureParameterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FunctionParameterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoutineCommentContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoutineLanguageContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoutineBehaviorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoutineDataContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoutineSecurityContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ServerOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateDefinitionsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ColumnDeclarationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ConstraintDeclarationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexDeclarationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ColumnDefinitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NullColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefaultColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { VisibilityColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { InvisibilityColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AutoIncrementColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PrimaryKeyColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UniqueKeyColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CommentColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FormatColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StorageColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReferenceColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CollateColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GeneratedColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SerialDefaultColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CheckColumnConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PrimaryKeyTableConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UniqueKeyTableConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ForeignKeyTableConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CheckTableConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReferenceDefinitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReferenceActionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReferenceControlTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleIndexDeclarationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SpecialIndexDeclarationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionEngineContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionEngineAttributeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionAutoextendSizeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionAutoIncrementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionAverageContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionCharsetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionChecksumContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionCollateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionCommentContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionCompressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionConnectionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionDataDirectoryContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionDelayContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionEncryptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionPageCompressedContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionPageCompressionLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionEncryptionKeyIdContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionIndexDirectoryContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionInsertMethodContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionKeyBlockSizeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionMaxRowsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionMinRowsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionPackKeysContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionPasswordContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionRowFormatContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionStartTransactionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionSecondaryEngineAttributeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionRecalculationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionPersistentContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionSamplePageContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionTablespaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionTableTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionTransactionalContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableOptionUnionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TablespaceStorageContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionDefinitionsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionFunctionHashContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionFunctionKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionFunctionRangeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionFunctionListContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubPartitionFunctionHashContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubPartitionFunctionKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionComparisonContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionListAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionListVectorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionSimpleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionDefinerAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionDefinerVectorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubpartitionDefinitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionEngineContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionCommentContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionDataDirectoryContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionIndexDirectoryContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionMaxRowsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionMinRowsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionTablespaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionOptionNodeGroupContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterSimpleDatabaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterUpgradeNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterEventContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterFunctionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterInstanceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterLogfileGroupContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterProcedureContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterServerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterTablespaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterViewContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByTableOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddColumnContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddColumnsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddIndexContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddPrimaryKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddUniqueKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddSpecialIndexContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddForeignKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddCheckTableConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAlterCheckTableConstraintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterBySetAlgorithmContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByChangeDefaultContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByChangeColumnContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByRenameColumnContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByLockContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByModifyColumnContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDropColumnContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDropConstraintCheckContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDropPrimaryKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDropIndexContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByRenameIndexContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAlterColumnDefaultContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAlterIndexVisibilityContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDropForeignKeyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDisableKeysContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByEnableKeysContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByRenameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByOrderContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByConvertCharsetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDefaultCharsetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDiscardTablespaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByImportTablespaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByForceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByValidateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddDefinitionsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAddPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDropPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByDiscardPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByImportPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByTruncatePartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByCoalescePartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByReorganizePartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByExchangePartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByAnalyzePartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByCheckPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByOptimizePartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByRebuildPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByRepairPartitionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByRemovePartitioningContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterByUpgradePartitioningContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropDatabaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropEventContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropIndexContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropLogfileGroupContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropProcedureContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropFunctionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropServerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropTablespaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropTriggerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropViewContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropRoleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetRoleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RenameTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RenameTableClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TruncateTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CallStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DeleteStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DoStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { InsertStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LoadDataStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LoadXmlStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReplaceStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleSelectContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ParenthesisSelectContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnionSelectContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnionParenthesisSelectContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WithLateralStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UpdateStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ValuesStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { InsertStatementValueContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UpdatedElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AssignmentFieldContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LockClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SingleDeleteStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MultipleDeleteStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerOpenStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerReadIndexStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerReadStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerCloseStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SingleUpdateStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MultipleUpdateStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OrderByClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OrderByExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableSourcesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableSourceBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableSourceNestedContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableJsonContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AtomTableItemContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubqueryTableItemContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableSourcesItemContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexHintContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexHintTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { InnerJoinContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StraightJoinContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OuterJoinContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NaturalJoinContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JoinSpecContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { QueryExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { QueryExpressionNointoContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { QuerySpecificationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { QuerySpecificationNointoContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnionParenthesisContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnionStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LateralStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonColumnListContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonColumnContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonOnEmptyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonOnErrorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectSpecContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectElementsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectStarElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectColumnElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectFunctionElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectExpressionElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectIntoVariablesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectIntoDumpFileContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectIntoTextFileContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectFieldsIntoContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SelectLinesIntoContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FromClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GroupByClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HavingClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WindowClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GroupByItemContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LimitClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LimitClauseAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StartTransactionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BeginWorkContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CommitWorkContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RollbackWorkContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SavepointStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RollbackStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReleaseStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LockTablesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnlockTablesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetAutocommitStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetTransactionStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TransactionModeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LockTableElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LockActionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TransactionOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TransactionLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ChangeMasterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ChangeReplicationFilterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PurgeBinaryLogsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ResetMasterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ResetSlaveContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StartSlaveContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StopSlaveContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StartGroupReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StopGroupReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MasterStringOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MasterDecimalOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MasterBoolOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MasterRealOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MasterUidListOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StringMasterOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DecimalMasterOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BoolMasterOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ChannelOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DoDbReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IgnoreDbReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DoTableReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IgnoreTableReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WildDoTableReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WildIgnoreTableReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RewriteDbReplicationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TablePairContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ThreadTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GtidsUntilOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MasterLogUntilOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RelayLogUntilOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SqlGapsUntilOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserConnectionOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PasswordConnectionOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefaultAuthConnectionOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PluginDirConnectionOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GtuidSetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XaStartTransactionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XaEndTransactionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XaPrepareStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XaCommitWorkContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XaRollbackWorkContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XaRecoverWorkContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PrepareStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExecuteStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DeallocatePrepareContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoutineBodyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BlockStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CaseStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IfStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IterateStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LeaveStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LoopStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RepeatStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ReturnStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WhileStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CloseCursorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FetchCursorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OpenCursorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DeclareVariableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DeclareConditionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DeclareCursorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DeclareHandlerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerConditionCodeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerConditionStateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerConditionNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerConditionWarningContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerConditionNotfoundContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HandlerConditionExceptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ProcedureSqlStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CaseAlternativeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ElifAlternativeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterUserMysqlV56Context } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AlterUserMysqlV80Context } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateUserMysqlV56Context } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateUserMysqlV80Context } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DropUserContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GrantStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoleOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GrantProxyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RenameUserContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DetailRevokeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShortRevokeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoleRevokeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RevokeProxyContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetPasswordStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserSpecificationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HashAuthOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RandomAuthOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StringAuthOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ModuleAuthOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleAuthOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AuthOptionClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ModuleContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PasswordModuleOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TlsOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserResourceOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserPasswordOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserLockOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PrivelegeClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PrivilegeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CurrentSchemaPriviLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GlobalPrivLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefiniteSchemaPrivLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefiniteFullTablePrivLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefiniteFullTablePrivLevel2Context } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefiniteTablePrivLevelContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RenameUserClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AnalyzeTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CheckTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ChecksumTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OptimizeTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RepairTableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CheckTableOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CreateUdfunctionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { InstallPluginContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UninstallPluginContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetVariableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetCharsetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetNamesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetPasswordContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetTransactionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetAutocommitContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SetNewValueInsideTriggerContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowMasterLogsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowLogEventsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowObjectFilterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowColumnsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowCreateDbContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowCreateFullIdObjectContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowCreateUserContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowEngineContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowGlobalInfoContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowErrorsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowCountErrorsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowSchemaFilterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowRoutineContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowGrantsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowIndexesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowOpenTablesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowProfileContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowSlaveStatusContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { VariableClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowCommonEntityContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowFilterContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowGlobalInfoClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowSchemaEntityContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShowProfileTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BinlogStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CacheIndexStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FlushStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { KillStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LoadIndexIntoCacheContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ResetStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ShutdownStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableIndexesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleFlushOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ChannelFlushOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableFlushOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FlushTableOptionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LoadedTableIndexesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleDescribeStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FullDescribeStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HelpStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UseStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SignalStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ResignalStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SignalConditionInformationContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WithStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DiagnosticsStatementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DiagnosticsConditionInformationNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DescribeStatementsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DescribeConnectionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FullIdContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TableNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RoleNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FullColumnNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexColumnNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleUserNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HostNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MysqlVariableContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CharsetNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CollationNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { EngineNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { EngineNameBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UuidSetContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XidContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { XuidStringIdContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AuthPluginContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UidContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleIdContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DottedIdContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DecimalLiteralContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FileSizeLiteralContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StringLiteralContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BooleanLiteralContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { HexadecimalLiteralContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NullNotnullContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ConstantContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { StringDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NationalVaryingStringDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NationalStringDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DimensionDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CollectionDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SpatialDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LongVarcharDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LongVarbinaryDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CollectionOptionsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ConvertedDataTypeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LengthOneDimensionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LengthTwoDimensionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LengthTwoOptionalDimensionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UidListContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FullColumnNameListContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TablesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IndexColumnNamesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExpressionsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExpressionsWithDefaultsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ConstantsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleStringsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UserVariablesContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DefaultValueContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CurrentTimestampContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExpressionOrDefaultContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IfExistsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IfNotExistsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OrReplaceContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WaitNowaitClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SpecificFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AggregateFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NonAggregateFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ScalarFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UdfFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PasswordFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SimpleFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CurrentUserContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DataTypeFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ValuesFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CaseExpressionFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CaseFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CharFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PositionFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubstrFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TrimFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WeightFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExtractFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { GetFormatFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonValueFunctionCallContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CaseFuncAlternativeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LevelWeightListContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LevelWeightRangeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LevelInWeightListElementContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AggregateWindowedFunctionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NonAggregateWindowedFunctionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { OverClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WindowSpecContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { WindowNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FrameClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FrameUnitsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FrameExtentContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FrameBetweenContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FrameRangeContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PartitionClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ScalarFunctionNameContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PasswordFunctionClauseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FunctionArgsContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FunctionArgContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IsExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NotExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LogicalExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PredicateExpressionContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SoundsLikePredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExpressionAtomPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubqueryComparisonPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonMemberOfPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BinaryComparisonPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { InPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BetweenPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IsNullPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LikePredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { RegexpPredicateContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnaryExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CollateExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { VariableAssignExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MysqlVariableExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NestedExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { NestedRowExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MathExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ExistsExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IntervalExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { SubqueryExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ConstantExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FunctionCallExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BinaryExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FullColumnNameExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BitExpressionAtomContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { UnaryOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { ComparisonOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { LogicalOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { BitOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { MultOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { AddOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { JsonOperatorContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { CharsetNameBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { TransactionLevelBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { PrivilegesBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { IntervalTypeBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { DataTypeBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { KeywordsCanBeIdContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  import { FunctionNameBaseContext } from "websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index";
  /**
   * This interface defines a complete generic visitor for a parse tree produced
   * by `MySqlParser`.
   *
   * @param <Result> The return type of the visit operation. Use `void` for
   * operations with no return type.
   */
  export class MySqlParserVisitor<Result> extends AbstractParseTreeVisitor<Result> {
      /**
       * Visit a parse tree produced by `MySqlParser.root`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoot?: (ctx: RootContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.sqlStatements`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSqlStatements?: (ctx: SqlStatementsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.sqlStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSqlStatement?: (ctx: SqlStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.emptyStatement_`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEmptyStatement_?: (ctx: EmptyStatement_Context) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.ddlStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDdlStatement?: (ctx: DdlStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dmlStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDmlStatement?: (ctx: DmlStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.transactionStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransactionStatement?: (ctx: TransactionStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.replicationStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReplicationStatement?: (ctx: ReplicationStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.preparedStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPreparedStatement?: (ctx: PreparedStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.compoundStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCompoundStatement?: (ctx: CompoundStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.administrationStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAdministrationStatement?: (ctx: AdministrationStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.utilityStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUtilityStatement?: (ctx: UtilityStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createDatabase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateDatabase?: (ctx: CreateDatabaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createEvent`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateEvent?: (ctx: CreateEventContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createIndex`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateIndex?: (ctx: CreateIndexContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createLogfileGroup`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateLogfileGroup?: (ctx: CreateLogfileGroupContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createProcedure`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateProcedure?: (ctx: CreateProcedureContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateFunction?: (ctx: CreateFunctionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createRole`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateRole?: (ctx: CreateRoleContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createServer`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateServer?: (ctx: CreateServerContext) => Result;
      /**
       * Visit a parse tree produced by the `copyCreateTable`
       * labeled alternative in `MySqlParser.createTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopyCreateTable?: (ctx: CopyCreateTableContext) => Result;
      /**
       * Visit a parse tree produced by the `queryCreateTable`
       * labeled alternative in `MySqlParser.createTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQueryCreateTable?: (ctx: QueryCreateTableContext) => Result;
      /**
       * Visit a parse tree produced by the `columnCreateTable`
       * labeled alternative in `MySqlParser.createTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnCreateTable?: (ctx: ColumnCreateTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createTablespaceInnodb`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateTablespaceInnodb?: (ctx: CreateTablespaceInnodbContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createTablespaceNdb`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateTablespaceNdb?: (ctx: CreateTablespaceNdbContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createTrigger`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateTrigger?: (ctx: CreateTriggerContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.withClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWithClause?: (ctx: WithClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.commonTableExpressions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCommonTableExpressions?: (ctx: CommonTableExpressionsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.cteName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCteName?: (ctx: CteNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.cteColumnName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCteColumnName?: (ctx: CteColumnNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createView`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateView?: (ctx: CreateViewContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createDatabaseOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateDatabaseOption?: (ctx: CreateDatabaseOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.charSet`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCharSet?: (ctx: CharSetContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.currentUserExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCurrentUserExpression?: (ctx: CurrentUserExpressionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.ownerStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOwnerStatement?: (ctx: OwnerStatementContext) => Result;
      /**
       * Visit a parse tree produced by the `preciseSchedule`
       * labeled alternative in `MySqlParser.scheduleExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPreciseSchedule?: (ctx: PreciseScheduleContext) => Result;
      /**
       * Visit a parse tree produced by the `intervalSchedule`
       * labeled alternative in `MySqlParser.scheduleExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIntervalSchedule?: (ctx: IntervalScheduleContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.timestampValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTimestampValue?: (ctx: TimestampValueContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.intervalExpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIntervalExpr?: (ctx: IntervalExprContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.intervalType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIntervalType?: (ctx: IntervalTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.enableType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEnableType?: (ctx: EnableTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.indexType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexType?: (ctx: IndexTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.indexOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexOption?: (ctx: IndexOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.procedureParameter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProcedureParameter?: (ctx: ProcedureParameterContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.functionParameter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunctionParameter?: (ctx: FunctionParameterContext) => Result;
      /**
       * Visit a parse tree produced by the `routineComment`
       * labeled alternative in `MySqlParser.routineOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoutineComment?: (ctx: RoutineCommentContext) => Result;
      /**
       * Visit a parse tree produced by the `routineLanguage`
       * labeled alternative in `MySqlParser.routineOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoutineLanguage?: (ctx: RoutineLanguageContext) => Result;
      /**
       * Visit a parse tree produced by the `routineBehavior`
       * labeled alternative in `MySqlParser.routineOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoutineBehavior?: (ctx: RoutineBehaviorContext) => Result;
      /**
       * Visit a parse tree produced by the `routineData`
       * labeled alternative in `MySqlParser.routineOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoutineData?: (ctx: RoutineDataContext) => Result;
      /**
       * Visit a parse tree produced by the `routineSecurity`
       * labeled alternative in `MySqlParser.routineOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoutineSecurity?: (ctx: RoutineSecurityContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.serverOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitServerOption?: (ctx: ServerOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createDefinitions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateDefinitions?: (ctx: CreateDefinitionsContext) => Result;
      /**
       * Visit a parse tree produced by the `columnDeclaration`
       * labeled alternative in `MySqlParser.createDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnDeclaration?: (ctx: ColumnDeclarationContext) => Result;
      /**
       * Visit a parse tree produced by the `constraintDeclaration`
       * labeled alternative in `MySqlParser.createDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraintDeclaration?: (ctx: ConstraintDeclarationContext) => Result;
      /**
       * Visit a parse tree produced by the `indexDeclaration`
       * labeled alternative in `MySqlParser.createDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexDeclaration?: (ctx: IndexDeclarationContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.columnDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnDefinition?: (ctx: ColumnDefinitionContext) => Result;
      /**
       * Visit a parse tree produced by the `nullColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNullColumnConstraint?: (ctx: NullColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `defaultColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefaultColumnConstraint?: (ctx: DefaultColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `visibilityColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVisibilityColumnConstraint?: (ctx: VisibilityColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `invisibilityColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInvisibilityColumnConstraint?: (ctx: InvisibilityColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `autoIncrementColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAutoIncrementColumnConstraint?: (ctx: AutoIncrementColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `primaryKeyColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrimaryKeyColumnConstraint?: (ctx: PrimaryKeyColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `uniqueKeyColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUniqueKeyColumnConstraint?: (ctx: UniqueKeyColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `commentColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCommentColumnConstraint?: (ctx: CommentColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `formatColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFormatColumnConstraint?: (ctx: FormatColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `storageColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStorageColumnConstraint?: (ctx: StorageColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `referenceColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReferenceColumnConstraint?: (ctx: ReferenceColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `collateColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCollateColumnConstraint?: (ctx: CollateColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `generatedColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneratedColumnConstraint?: (ctx: GeneratedColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `serialDefaultColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSerialDefaultColumnConstraint?: (ctx: SerialDefaultColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `checkColumnConstraint`
       * labeled alternative in `MySqlParser.columnConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCheckColumnConstraint?: (ctx: CheckColumnConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `primaryKeyTableConstraint`
       * labeled alternative in `MySqlParser.tableConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrimaryKeyTableConstraint?: (ctx: PrimaryKeyTableConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `uniqueKeyTableConstraint`
       * labeled alternative in `MySqlParser.tableConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUniqueKeyTableConstraint?: (ctx: UniqueKeyTableConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `foreignKeyTableConstraint`
       * labeled alternative in `MySqlParser.tableConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitForeignKeyTableConstraint?: (ctx: ForeignKeyTableConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `checkTableConstraint`
       * labeled alternative in `MySqlParser.tableConstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCheckTableConstraint?: (ctx: CheckTableConstraintContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.referenceDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReferenceDefinition?: (ctx: ReferenceDefinitionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.referenceAction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReferenceAction?: (ctx: ReferenceActionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.referenceControlType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReferenceControlType?: (ctx: ReferenceControlTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `simpleIndexDeclaration`
       * labeled alternative in `MySqlParser.indexColumnDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleIndexDeclaration?: (ctx: SimpleIndexDeclarationContext) => Result;
      /**
       * Visit a parse tree produced by the `specialIndexDeclaration`
       * labeled alternative in `MySqlParser.indexColumnDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSpecialIndexDeclaration?: (ctx: SpecialIndexDeclarationContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionEngine`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionEngine?: (ctx: TableOptionEngineContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionEngineAttribute`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionEngineAttribute?: (ctx: TableOptionEngineAttributeContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionAutoextendSize`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionAutoextendSize?: (ctx: TableOptionAutoextendSizeContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionAutoIncrement`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionAutoIncrement?: (ctx: TableOptionAutoIncrementContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionAverage`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionAverage?: (ctx: TableOptionAverageContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionCharset`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionCharset?: (ctx: TableOptionCharsetContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionChecksum`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionChecksum?: (ctx: TableOptionChecksumContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionCollate`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionCollate?: (ctx: TableOptionCollateContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionComment`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionComment?: (ctx: TableOptionCommentContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionCompression`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionCompression?: (ctx: TableOptionCompressionContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionConnection`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionConnection?: (ctx: TableOptionConnectionContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionDataDirectory`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionDataDirectory?: (ctx: TableOptionDataDirectoryContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionDelay`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionDelay?: (ctx: TableOptionDelayContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionEncryption`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionEncryption?: (ctx: TableOptionEncryptionContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionPageCompressed`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionPageCompressed?: (ctx: TableOptionPageCompressedContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionPageCompressionLevel`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionPageCompressionLevel?: (ctx: TableOptionPageCompressionLevelContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionEncryptionKeyId`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionEncryptionKeyId?: (ctx: TableOptionEncryptionKeyIdContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionIndexDirectory`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionIndexDirectory?: (ctx: TableOptionIndexDirectoryContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionInsertMethod`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionInsertMethod?: (ctx: TableOptionInsertMethodContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionKeyBlockSize`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionKeyBlockSize?: (ctx: TableOptionKeyBlockSizeContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionMaxRows`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionMaxRows?: (ctx: TableOptionMaxRowsContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionMinRows`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionMinRows?: (ctx: TableOptionMinRowsContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionPackKeys`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionPackKeys?: (ctx: TableOptionPackKeysContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionPassword`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionPassword?: (ctx: TableOptionPasswordContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionRowFormat`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionRowFormat?: (ctx: TableOptionRowFormatContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionStartTransaction`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionStartTransaction?: (ctx: TableOptionStartTransactionContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionSecondaryEngineAttribute`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionSecondaryEngineAttribute?: (ctx: TableOptionSecondaryEngineAttributeContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionRecalculation`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionRecalculation?: (ctx: TableOptionRecalculationContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionPersistent`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionPersistent?: (ctx: TableOptionPersistentContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionSamplePage`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionSamplePage?: (ctx: TableOptionSamplePageContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionTablespace`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionTablespace?: (ctx: TableOptionTablespaceContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionTableType`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionTableType?: (ctx: TableOptionTableTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionTransactional`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionTransactional?: (ctx: TableOptionTransactionalContext) => Result;
      /**
       * Visit a parse tree produced by the `tableOptionUnion`
       * labeled alternative in `MySqlParser.tableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableOptionUnion?: (ctx: TableOptionUnionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tableType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableType?: (ctx: TableTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tablespaceStorage`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablespaceStorage?: (ctx: TablespaceStorageContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.partitionDefinitions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionDefinitions?: (ctx: PartitionDefinitionsContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionFunctionHash`
       * labeled alternative in `MySqlParser.partitionFunctionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionFunctionHash?: (ctx: PartitionFunctionHashContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionFunctionKey`
       * labeled alternative in `MySqlParser.partitionFunctionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionFunctionKey?: (ctx: PartitionFunctionKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionFunctionRange`
       * labeled alternative in `MySqlParser.partitionFunctionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionFunctionRange?: (ctx: PartitionFunctionRangeContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionFunctionList`
       * labeled alternative in `MySqlParser.partitionFunctionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionFunctionList?: (ctx: PartitionFunctionListContext) => Result;
      /**
       * Visit a parse tree produced by the `subPartitionFunctionHash`
       * labeled alternative in `MySqlParser.subpartitionFunctionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubPartitionFunctionHash?: (ctx: SubPartitionFunctionHashContext) => Result;
      /**
       * Visit a parse tree produced by the `subPartitionFunctionKey`
       * labeled alternative in `MySqlParser.subpartitionFunctionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubPartitionFunctionKey?: (ctx: SubPartitionFunctionKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionComparison`
       * labeled alternative in `MySqlParser.partitionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionComparison?: (ctx: PartitionComparisonContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionListAtom`
       * labeled alternative in `MySqlParser.partitionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionListAtom?: (ctx: PartitionListAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionListVector`
       * labeled alternative in `MySqlParser.partitionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionListVector?: (ctx: PartitionListVectorContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionSimple`
       * labeled alternative in `MySqlParser.partitionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionSimple?: (ctx: PartitionSimpleContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.partitionDefinerAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionDefinerAtom?: (ctx: PartitionDefinerAtomContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.partitionDefinerVector`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionDefinerVector?: (ctx: PartitionDefinerVectorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.subpartitionDefinition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubpartitionDefinition?: (ctx: SubpartitionDefinitionContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionEngine`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionEngine?: (ctx: PartitionOptionEngineContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionComment`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionComment?: (ctx: PartitionOptionCommentContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionDataDirectory`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionDataDirectory?: (ctx: PartitionOptionDataDirectoryContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionIndexDirectory`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionIndexDirectory?: (ctx: PartitionOptionIndexDirectoryContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionMaxRows`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionMaxRows?: (ctx: PartitionOptionMaxRowsContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionMinRows`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionMinRows?: (ctx: PartitionOptionMinRowsContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionTablespace`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionTablespace?: (ctx: PartitionOptionTablespaceContext) => Result;
      /**
       * Visit a parse tree produced by the `partitionOptionNodeGroup`
       * labeled alternative in `MySqlParser.partitionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionOptionNodeGroup?: (ctx: PartitionOptionNodeGroupContext) => Result;
      /**
       * Visit a parse tree produced by the `alterSimpleDatabase`
       * labeled alternative in `MySqlParser.alterDatabase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterSimpleDatabase?: (ctx: AlterSimpleDatabaseContext) => Result;
      /**
       * Visit a parse tree produced by the `alterUpgradeName`
       * labeled alternative in `MySqlParser.alterDatabase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterUpgradeName?: (ctx: AlterUpgradeNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterEvent`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterEvent?: (ctx: AlterEventContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterFunction?: (ctx: AlterFunctionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterInstance`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterInstance?: (ctx: AlterInstanceContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterLogfileGroup`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterLogfileGroup?: (ctx: AlterLogfileGroupContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterProcedure`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterProcedure?: (ctx: AlterProcedureContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterServer`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterServer?: (ctx: AlterServerContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTable?: (ctx: AlterTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterTablespace`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterTablespace?: (ctx: AlterTablespaceContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.alterView`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterView?: (ctx: AlterViewContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByTableOption`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByTableOption?: (ctx: AlterByTableOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddColumn`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddColumn?: (ctx: AlterByAddColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddColumns`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddColumns?: (ctx: AlterByAddColumnsContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddIndex`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddIndex?: (ctx: AlterByAddIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddPrimaryKey`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddPrimaryKey?: (ctx: AlterByAddPrimaryKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddUniqueKey`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddUniqueKey?: (ctx: AlterByAddUniqueKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddSpecialIndex`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddSpecialIndex?: (ctx: AlterByAddSpecialIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddForeignKey`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddForeignKey?: (ctx: AlterByAddForeignKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddCheckTableConstraint`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddCheckTableConstraint?: (ctx: AlterByAddCheckTableConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAlterCheckTableConstraint`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAlterCheckTableConstraint?: (ctx: AlterByAlterCheckTableConstraintContext) => Result;
      /**
       * Visit a parse tree produced by the `alterBySetAlgorithm`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterBySetAlgorithm?: (ctx: AlterBySetAlgorithmContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByChangeDefault`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByChangeDefault?: (ctx: AlterByChangeDefaultContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByChangeColumn`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByChangeColumn?: (ctx: AlterByChangeColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByRenameColumn`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByRenameColumn?: (ctx: AlterByRenameColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByLock`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByLock?: (ctx: AlterByLockContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByModifyColumn`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByModifyColumn?: (ctx: AlterByModifyColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDropColumn`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDropColumn?: (ctx: AlterByDropColumnContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDropConstraintCheck`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDropConstraintCheck?: (ctx: AlterByDropConstraintCheckContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDropPrimaryKey`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDropPrimaryKey?: (ctx: AlterByDropPrimaryKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDropIndex`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDropIndex?: (ctx: AlterByDropIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByRenameIndex`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByRenameIndex?: (ctx: AlterByRenameIndexContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAlterColumnDefault`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAlterColumnDefault?: (ctx: AlterByAlterColumnDefaultContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAlterIndexVisibility`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAlterIndexVisibility?: (ctx: AlterByAlterIndexVisibilityContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDropForeignKey`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDropForeignKey?: (ctx: AlterByDropForeignKeyContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDisableKeys`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDisableKeys?: (ctx: AlterByDisableKeysContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByEnableKeys`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByEnableKeys?: (ctx: AlterByEnableKeysContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByRename`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByRename?: (ctx: AlterByRenameContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByOrder`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByOrder?: (ctx: AlterByOrderContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByConvertCharset`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByConvertCharset?: (ctx: AlterByConvertCharsetContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDefaultCharset`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDefaultCharset?: (ctx: AlterByDefaultCharsetContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDiscardTablespace`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDiscardTablespace?: (ctx: AlterByDiscardTablespaceContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByImportTablespace`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByImportTablespace?: (ctx: AlterByImportTablespaceContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByForce`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByForce?: (ctx: AlterByForceContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByValidate`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByValidate?: (ctx: AlterByValidateContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddDefinitions`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddDefinitions?: (ctx: AlterByAddDefinitionsContext) => Result;
      /**
       * Visit a parse tree produced by the `alterPartition`
       * labeled alternative in `MySqlParser.alterSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterPartition?: (ctx: AlterPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAddPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAddPartition?: (ctx: AlterByAddPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDropPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDropPartition?: (ctx: AlterByDropPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByDiscardPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByDiscardPartition?: (ctx: AlterByDiscardPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByImportPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByImportPartition?: (ctx: AlterByImportPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByTruncatePartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByTruncatePartition?: (ctx: AlterByTruncatePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByCoalescePartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByCoalescePartition?: (ctx: AlterByCoalescePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByReorganizePartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByReorganizePartition?: (ctx: AlterByReorganizePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByExchangePartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByExchangePartition?: (ctx: AlterByExchangePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByAnalyzePartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByAnalyzePartition?: (ctx: AlterByAnalyzePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByCheckPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByCheckPartition?: (ctx: AlterByCheckPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByOptimizePartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByOptimizePartition?: (ctx: AlterByOptimizePartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByRebuildPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByRebuildPartition?: (ctx: AlterByRebuildPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByRepairPartition`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByRepairPartition?: (ctx: AlterByRepairPartitionContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByRemovePartitioning`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByRemovePartitioning?: (ctx: AlterByRemovePartitioningContext) => Result;
      /**
       * Visit a parse tree produced by the `alterByUpgradePartitioning`
       * labeled alternative in `MySqlParser.alterPartitionSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterByUpgradePartitioning?: (ctx: AlterByUpgradePartitioningContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropDatabase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropDatabase?: (ctx: DropDatabaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropEvent`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropEvent?: (ctx: DropEventContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropIndex`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropIndex?: (ctx: DropIndexContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropLogfileGroup`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropLogfileGroup?: (ctx: DropLogfileGroupContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropProcedure`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropProcedure?: (ctx: DropProcedureContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropFunction?: (ctx: DropFunctionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropServer`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropServer?: (ctx: DropServerContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropTable?: (ctx: DropTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropTablespace`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropTablespace?: (ctx: DropTablespaceContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropTrigger`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropTrigger?: (ctx: DropTriggerContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropView`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropView?: (ctx: DropViewContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropRole`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropRole?: (ctx: DropRoleContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.setRole`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetRole?: (ctx: SetRoleContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.renameTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRenameTable?: (ctx: RenameTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.renameTableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRenameTableClause?: (ctx: RenameTableClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.truncateTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTruncateTable?: (ctx: TruncateTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.callStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCallStatement?: (ctx: CallStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.deleteStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeleteStatement?: (ctx: DeleteStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.doStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDoStatement?: (ctx: DoStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.handlerStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerStatement?: (ctx: HandlerStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.insertStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsertStatement?: (ctx: InsertStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.loadDataStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoadDataStatement?: (ctx: LoadDataStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.loadXmlStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoadXmlStatement?: (ctx: LoadXmlStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.replaceStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReplaceStatement?: (ctx: ReplaceStatementContext) => Result;
      /**
       * Visit a parse tree produced by the `simpleSelect`
       * labeled alternative in `MySqlParser.selectStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleSelect?: (ctx: SimpleSelectContext) => Result;
      /**
       * Visit a parse tree produced by the `parenthesisSelect`
       * labeled alternative in `MySqlParser.selectStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitParenthesisSelect?: (ctx: ParenthesisSelectContext) => Result;
      /**
       * Visit a parse tree produced by the `unionSelect`
       * labeled alternative in `MySqlParser.selectStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnionSelect?: (ctx: UnionSelectContext) => Result;
      /**
       * Visit a parse tree produced by the `unionParenthesisSelect`
       * labeled alternative in `MySqlParser.selectStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnionParenthesisSelect?: (ctx: UnionParenthesisSelectContext) => Result;
      /**
       * Visit a parse tree produced by the `withLateralStatement`
       * labeled alternative in `MySqlParser.selectStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWithLateralStatement?: (ctx: WithLateralStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.updateStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUpdateStatement?: (ctx: UpdateStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.valuesStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitValuesStatement?: (ctx: ValuesStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.insertStatementValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsertStatementValue?: (ctx: InsertStatementValueContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.updatedElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUpdatedElement?: (ctx: UpdatedElementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.assignmentField`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAssignmentField?: (ctx: AssignmentFieldContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lockClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLockClause?: (ctx: LockClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.singleDeleteStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSingleDeleteStatement?: (ctx: SingleDeleteStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.multipleDeleteStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMultipleDeleteStatement?: (ctx: MultipleDeleteStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.handlerOpenStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerOpenStatement?: (ctx: HandlerOpenStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.handlerReadIndexStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerReadIndexStatement?: (ctx: HandlerReadIndexStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.handlerReadStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerReadStatement?: (ctx: HandlerReadStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.handlerCloseStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerCloseStatement?: (ctx: HandlerCloseStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.singleUpdateStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSingleUpdateStatement?: (ctx: SingleUpdateStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.multipleUpdateStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMultipleUpdateStatement?: (ctx: MultipleUpdateStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.orderByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOrderByClause?: (ctx: OrderByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.orderByExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOrderByExpression?: (ctx: OrderByExpressionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tableSources`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableSources?: (ctx: TableSourcesContext) => Result;
      /**
       * Visit a parse tree produced by the `tableSourceBase`
       * labeled alternative in `MySqlParser.tableSource`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableSourceBase?: (ctx: TableSourceBaseContext) => Result;
      /**
       * Visit a parse tree produced by the `tableSourceNested`
       * labeled alternative in `MySqlParser.tableSource`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableSourceNested?: (ctx: TableSourceNestedContext) => Result;
      /**
       * Visit a parse tree produced by the `tableJson`
       * labeled alternative in `MySqlParser.tableSource`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableJson?: (ctx: TableJsonContext) => Result;
      /**
       * Visit a parse tree produced by the `atomTableItem`
       * labeled alternative in `MySqlParser.tableSourceItem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAtomTableItem?: (ctx: AtomTableItemContext) => Result;
      /**
       * Visit a parse tree produced by the `subqueryTableItem`
       * labeled alternative in `MySqlParser.tableSourceItem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubqueryTableItem?: (ctx: SubqueryTableItemContext) => Result;
      /**
       * Visit a parse tree produced by the `tableSourcesItem`
       * labeled alternative in `MySqlParser.tableSourceItem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableSourcesItem?: (ctx: TableSourcesItemContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.indexHint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexHint?: (ctx: IndexHintContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.indexHintType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexHintType?: (ctx: IndexHintTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `innerJoin`
       * labeled alternative in `MySqlParser.joinPart`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInnerJoin?: (ctx: InnerJoinContext) => Result;
      /**
       * Visit a parse tree produced by the `straightJoin`
       * labeled alternative in `MySqlParser.joinPart`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStraightJoin?: (ctx: StraightJoinContext) => Result;
      /**
       * Visit a parse tree produced by the `outerJoin`
       * labeled alternative in `MySqlParser.joinPart`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOuterJoin?: (ctx: OuterJoinContext) => Result;
      /**
       * Visit a parse tree produced by the `naturalJoin`
       * labeled alternative in `MySqlParser.joinPart`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNaturalJoin?: (ctx: NaturalJoinContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.joinSpec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoinSpec?: (ctx: JoinSpecContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.queryExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQueryExpression?: (ctx: QueryExpressionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.queryExpressionNointo`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQueryExpressionNointo?: (ctx: QueryExpressionNointoContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.querySpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQuerySpecification?: (ctx: QuerySpecificationContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.querySpecificationNointo`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQuerySpecificationNointo?: (ctx: QuerySpecificationNointoContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.unionParenthesis`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnionParenthesis?: (ctx: UnionParenthesisContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.unionStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnionStatement?: (ctx: UnionStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lateralStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLateralStatement?: (ctx: LateralStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.jsonTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonTable?: (ctx: JsonTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.jsonColumnList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonColumnList?: (ctx: JsonColumnListContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.jsonColumn`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonColumn?: (ctx: JsonColumnContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.jsonOnEmpty`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonOnEmpty?: (ctx: JsonOnEmptyContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.jsonOnError`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonOnError?: (ctx: JsonOnErrorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.selectSpec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectSpec?: (ctx: SelectSpecContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.selectElements`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectElements?: (ctx: SelectElementsContext) => Result;
      /**
       * Visit a parse tree produced by the `selectStarElement`
       * labeled alternative in `MySqlParser.selectElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectStarElement?: (ctx: SelectStarElementContext) => Result;
      /**
       * Visit a parse tree produced by the `selectColumnElement`
       * labeled alternative in `MySqlParser.selectElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectColumnElement?: (ctx: SelectColumnElementContext) => Result;
      /**
       * Visit a parse tree produced by the `selectFunctionElement`
       * labeled alternative in `MySqlParser.selectElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectFunctionElement?: (ctx: SelectFunctionElementContext) => Result;
      /**
       * Visit a parse tree produced by the `selectExpressionElement`
       * labeled alternative in `MySqlParser.selectElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectExpressionElement?: (ctx: SelectExpressionElementContext) => Result;
      /**
       * Visit a parse tree produced by the `selectIntoVariables`
       * labeled alternative in `MySqlParser.selectIntoExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectIntoVariables?: (ctx: SelectIntoVariablesContext) => Result;
      /**
       * Visit a parse tree produced by the `selectIntoDumpFile`
       * labeled alternative in `MySqlParser.selectIntoExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectIntoDumpFile?: (ctx: SelectIntoDumpFileContext) => Result;
      /**
       * Visit a parse tree produced by the `selectIntoTextFile`
       * labeled alternative in `MySqlParser.selectIntoExpression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectIntoTextFile?: (ctx: SelectIntoTextFileContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.selectFieldsInto`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectFieldsInto?: (ctx: SelectFieldsIntoContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.selectLinesInto`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectLinesInto?: (ctx: SelectLinesIntoContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.fromClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFromClause?: (ctx: FromClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.groupByClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGroupByClause?: (ctx: GroupByClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.havingClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHavingClause?: (ctx: HavingClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.windowClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindowClause?: (ctx: WindowClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.groupByItem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGroupByItem?: (ctx: GroupByItemContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.limitClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLimitClause?: (ctx: LimitClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.limitClauseAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLimitClauseAtom?: (ctx: LimitClauseAtomContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.startTransaction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStartTransaction?: (ctx: StartTransactionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.beginWork`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBeginWork?: (ctx: BeginWorkContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.commitWork`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCommitWork?: (ctx: CommitWorkContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.rollbackWork`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRollbackWork?: (ctx: RollbackWorkContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.savepointStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSavepointStatement?: (ctx: SavepointStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.rollbackStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRollbackStatement?: (ctx: RollbackStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.releaseStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReleaseStatement?: (ctx: ReleaseStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lockTables`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLockTables?: (ctx: LockTablesContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.unlockTables`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnlockTables?: (ctx: UnlockTablesContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.setAutocommitStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetAutocommitStatement?: (ctx: SetAutocommitStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.setTransactionStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetTransactionStatement?: (ctx: SetTransactionStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.transactionMode`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransactionMode?: (ctx: TransactionModeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lockTableElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLockTableElement?: (ctx: LockTableElementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lockAction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLockAction?: (ctx: LockActionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.transactionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransactionOption?: (ctx: TransactionOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.transactionLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransactionLevel?: (ctx: TransactionLevelContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.changeMaster`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitChangeMaster?: (ctx: ChangeMasterContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.changeReplicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitChangeReplicationFilter?: (ctx: ChangeReplicationFilterContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.purgeBinaryLogs`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPurgeBinaryLogs?: (ctx: PurgeBinaryLogsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.resetMaster`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitResetMaster?: (ctx: ResetMasterContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.resetSlave`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitResetSlave?: (ctx: ResetSlaveContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.startSlave`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStartSlave?: (ctx: StartSlaveContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.stopSlave`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStopSlave?: (ctx: StopSlaveContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.startGroupReplication`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStartGroupReplication?: (ctx: StartGroupReplicationContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.stopGroupReplication`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStopGroupReplication?: (ctx: StopGroupReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `masterStringOption`
       * labeled alternative in `MySqlParser.masterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMasterStringOption?: (ctx: MasterStringOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `masterDecimalOption`
       * labeled alternative in `MySqlParser.masterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMasterDecimalOption?: (ctx: MasterDecimalOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `masterBoolOption`
       * labeled alternative in `MySqlParser.masterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMasterBoolOption?: (ctx: MasterBoolOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `masterRealOption`
       * labeled alternative in `MySqlParser.masterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMasterRealOption?: (ctx: MasterRealOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `masterUidListOption`
       * labeled alternative in `MySqlParser.masterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMasterUidListOption?: (ctx: MasterUidListOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.stringMasterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStringMasterOption?: (ctx: StringMasterOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.decimalMasterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecimalMasterOption?: (ctx: DecimalMasterOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.boolMasterOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBoolMasterOption?: (ctx: BoolMasterOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.channelOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitChannelOption?: (ctx: ChannelOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `doDbReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDoDbReplication?: (ctx: DoDbReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `ignoreDbReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIgnoreDbReplication?: (ctx: IgnoreDbReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `doTableReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDoTableReplication?: (ctx: DoTableReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `ignoreTableReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIgnoreTableReplication?: (ctx: IgnoreTableReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `wildDoTableReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWildDoTableReplication?: (ctx: WildDoTableReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `wildIgnoreTableReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWildIgnoreTableReplication?: (ctx: WildIgnoreTableReplicationContext) => Result;
      /**
       * Visit a parse tree produced by the `rewriteDbReplication`
       * labeled alternative in `MySqlParser.replicationFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRewriteDbReplication?: (ctx: RewriteDbReplicationContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tablePair`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablePair?: (ctx: TablePairContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.threadType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitThreadType?: (ctx: ThreadTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `gtidsUntilOption`
       * labeled alternative in `MySqlParser.untilOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGtidsUntilOption?: (ctx: GtidsUntilOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `masterLogUntilOption`
       * labeled alternative in `MySqlParser.untilOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMasterLogUntilOption?: (ctx: MasterLogUntilOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `relayLogUntilOption`
       * labeled alternative in `MySqlParser.untilOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRelayLogUntilOption?: (ctx: RelayLogUntilOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `sqlGapsUntilOption`
       * labeled alternative in `MySqlParser.untilOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSqlGapsUntilOption?: (ctx: SqlGapsUntilOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `userConnectionOption`
       * labeled alternative in `MySqlParser.connectionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserConnectionOption?: (ctx: UserConnectionOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `passwordConnectionOption`
       * labeled alternative in `MySqlParser.connectionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPasswordConnectionOption?: (ctx: PasswordConnectionOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `defaultAuthConnectionOption`
       * labeled alternative in `MySqlParser.connectionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefaultAuthConnectionOption?: (ctx: DefaultAuthConnectionOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `pluginDirConnectionOption`
       * labeled alternative in `MySqlParser.connectionOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPluginDirConnectionOption?: (ctx: PluginDirConnectionOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.gtuidSet`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGtuidSet?: (ctx: GtuidSetContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xaStartTransaction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXaStartTransaction?: (ctx: XaStartTransactionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xaEndTransaction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXaEndTransaction?: (ctx: XaEndTransactionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xaPrepareStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXaPrepareStatement?: (ctx: XaPrepareStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xaCommitWork`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXaCommitWork?: (ctx: XaCommitWorkContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xaRollbackWork`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXaRollbackWork?: (ctx: XaRollbackWorkContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xaRecoverWork`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXaRecoverWork?: (ctx: XaRecoverWorkContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.prepareStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrepareStatement?: (ctx: PrepareStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.executeStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExecuteStatement?: (ctx: ExecuteStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.deallocatePrepare`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeallocatePrepare?: (ctx: DeallocatePrepareContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.routineBody`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoutineBody?: (ctx: RoutineBodyContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.blockStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBlockStatement?: (ctx: BlockStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.caseStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCaseStatement?: (ctx: CaseStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.ifStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIfStatement?: (ctx: IfStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.iterateStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIterateStatement?: (ctx: IterateStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.leaveStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLeaveStatement?: (ctx: LeaveStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.loopStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoopStatement?: (ctx: LoopStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.repeatStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRepeatStatement?: (ctx: RepeatStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.returnStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReturnStatement?: (ctx: ReturnStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.whileStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWhileStatement?: (ctx: WhileStatementContext) => Result;
      /**
       * Visit a parse tree produced by the `CloseCursor`
       * labeled alternative in `MySqlParser.cursorStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCloseCursor?: (ctx: CloseCursorContext) => Result;
      /**
       * Visit a parse tree produced by the `FetchCursor`
       * labeled alternative in `MySqlParser.cursorStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFetchCursor?: (ctx: FetchCursorContext) => Result;
      /**
       * Visit a parse tree produced by the `OpenCursor`
       * labeled alternative in `MySqlParser.cursorStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpenCursor?: (ctx: OpenCursorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.declareVariable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeclareVariable?: (ctx: DeclareVariableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.declareCondition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeclareCondition?: (ctx: DeclareConditionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.declareCursor`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeclareCursor?: (ctx: DeclareCursorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.declareHandler`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeclareHandler?: (ctx: DeclareHandlerContext) => Result;
      /**
       * Visit a parse tree produced by the `handlerConditionCode`
       * labeled alternative in `MySqlParser.handlerConditionValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerConditionCode?: (ctx: HandlerConditionCodeContext) => Result;
      /**
       * Visit a parse tree produced by the `handlerConditionState`
       * labeled alternative in `MySqlParser.handlerConditionValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerConditionState?: (ctx: HandlerConditionStateContext) => Result;
      /**
       * Visit a parse tree produced by the `handlerConditionName`
       * labeled alternative in `MySqlParser.handlerConditionValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerConditionName?: (ctx: HandlerConditionNameContext) => Result;
      /**
       * Visit a parse tree produced by the `handlerConditionWarning`
       * labeled alternative in `MySqlParser.handlerConditionValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerConditionWarning?: (ctx: HandlerConditionWarningContext) => Result;
      /**
       * Visit a parse tree produced by the `handlerConditionNotfound`
       * labeled alternative in `MySqlParser.handlerConditionValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerConditionNotfound?: (ctx: HandlerConditionNotfoundContext) => Result;
      /**
       * Visit a parse tree produced by the `handlerConditionException`
       * labeled alternative in `MySqlParser.handlerConditionValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandlerConditionException?: (ctx: HandlerConditionExceptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.procedureSqlStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProcedureSqlStatement?: (ctx: ProcedureSqlStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.caseAlternative`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCaseAlternative?: (ctx: CaseAlternativeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.elifAlternative`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitElifAlternative?: (ctx: ElifAlternativeContext) => Result;
      /**
       * Visit a parse tree produced by the `alterUserMysqlV56`
       * labeled alternative in `MySqlParser.alterUser`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterUserMysqlV56?: (ctx: AlterUserMysqlV56Context) => Result;
      /**
       * Visit a parse tree produced by the `alterUserMysqlV80`
       * labeled alternative in `MySqlParser.alterUser`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterUserMysqlV80?: (ctx: AlterUserMysqlV80Context) => Result;
      /**
       * Visit a parse tree produced by the `createUserMysqlV56`
       * labeled alternative in `MySqlParser.createUser`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateUserMysqlV56?: (ctx: CreateUserMysqlV56Context) => Result;
      /**
       * Visit a parse tree produced by the `createUserMysqlV80`
       * labeled alternative in `MySqlParser.createUser`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateUserMysqlV80?: (ctx: CreateUserMysqlV80Context) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dropUser`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropUser?: (ctx: DropUserContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.grantStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrantStatement?: (ctx: GrantStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.roleOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoleOption?: (ctx: RoleOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.grantProxy`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrantProxy?: (ctx: GrantProxyContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.renameUser`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRenameUser?: (ctx: RenameUserContext) => Result;
      /**
       * Visit a parse tree produced by the `detailRevoke`
       * labeled alternative in `MySqlParser.revokeStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDetailRevoke?: (ctx: DetailRevokeContext) => Result;
      /**
       * Visit a parse tree produced by the `shortRevoke`
       * labeled alternative in `MySqlParser.revokeStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShortRevoke?: (ctx: ShortRevokeContext) => Result;
      /**
       * Visit a parse tree produced by the `roleRevoke`
       * labeled alternative in `MySqlParser.revokeStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoleRevoke?: (ctx: RoleRevokeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.revokeProxy`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRevokeProxy?: (ctx: RevokeProxyContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.setPasswordStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetPasswordStatement?: (ctx: SetPasswordStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.userSpecification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserSpecification?: (ctx: UserSpecificationContext) => Result;
      /**
       * Visit a parse tree produced by the `hashAuthOption`
       * labeled alternative in `MySqlParser.userAuthOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHashAuthOption?: (ctx: HashAuthOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `randomAuthOption`
       * labeled alternative in `MySqlParser.userAuthOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRandomAuthOption?: (ctx: RandomAuthOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `stringAuthOption`
       * labeled alternative in `MySqlParser.userAuthOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStringAuthOption?: (ctx: StringAuthOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `moduleAuthOption`
       * labeled alternative in `MySqlParser.userAuthOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitModuleAuthOption?: (ctx: ModuleAuthOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `simpleAuthOption`
       * labeled alternative in `MySqlParser.userAuthOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleAuthOption?: (ctx: SimpleAuthOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.authOptionClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAuthOptionClause?: (ctx: AuthOptionClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `module`
       * labeled alternative in `MySqlParser.authenticationRule`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitModule?: (ctx: ModuleContext) => Result;
      /**
       * Visit a parse tree produced by the `passwordModuleOption`
       * labeled alternative in `MySqlParser.authenticationRule`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPasswordModuleOption?: (ctx: PasswordModuleOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tlsOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTlsOption?: (ctx: TlsOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.userResourceOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserResourceOption?: (ctx: UserResourceOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.userPasswordOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserPasswordOption?: (ctx: UserPasswordOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.userLockOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserLockOption?: (ctx: UserLockOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.privelegeClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivelegeClause?: (ctx: PrivelegeClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.privilege`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivilege?: (ctx: PrivilegeContext) => Result;
      /**
       * Visit a parse tree produced by the `currentSchemaPriviLevel`
       * labeled alternative in `MySqlParser.privilegeLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCurrentSchemaPriviLevel?: (ctx: CurrentSchemaPriviLevelContext) => Result;
      /**
       * Visit a parse tree produced by the `globalPrivLevel`
       * labeled alternative in `MySqlParser.privilegeLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGlobalPrivLevel?: (ctx: GlobalPrivLevelContext) => Result;
      /**
       * Visit a parse tree produced by the `definiteSchemaPrivLevel`
       * labeled alternative in `MySqlParser.privilegeLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefiniteSchemaPrivLevel?: (ctx: DefiniteSchemaPrivLevelContext) => Result;
      /**
       * Visit a parse tree produced by the `definiteFullTablePrivLevel`
       * labeled alternative in `MySqlParser.privilegeLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefiniteFullTablePrivLevel?: (ctx: DefiniteFullTablePrivLevelContext) => Result;
      /**
       * Visit a parse tree produced by the `definiteFullTablePrivLevel2`
       * labeled alternative in `MySqlParser.privilegeLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefiniteFullTablePrivLevel2?: (ctx: DefiniteFullTablePrivLevel2Context) => Result;
      /**
       * Visit a parse tree produced by the `definiteTablePrivLevel`
       * labeled alternative in `MySqlParser.privilegeLevel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefiniteTablePrivLevel?: (ctx: DefiniteTablePrivLevelContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.renameUserClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRenameUserClause?: (ctx: RenameUserClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.analyzeTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAnalyzeTable?: (ctx: AnalyzeTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.checkTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCheckTable?: (ctx: CheckTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.checksumTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitChecksumTable?: (ctx: ChecksumTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.optimizeTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptimizeTable?: (ctx: OptimizeTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.repairTable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRepairTable?: (ctx: RepairTableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.checkTableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCheckTableOption?: (ctx: CheckTableOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.createUdfunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateUdfunction?: (ctx: CreateUdfunctionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.installPlugin`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInstallPlugin?: (ctx: InstallPluginContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.uninstallPlugin`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUninstallPlugin?: (ctx: UninstallPluginContext) => Result;
      /**
       * Visit a parse tree produced by the `setVariable`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetVariable?: (ctx: SetVariableContext) => Result;
      /**
       * Visit a parse tree produced by the `setCharset`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetCharset?: (ctx: SetCharsetContext) => Result;
      /**
       * Visit a parse tree produced by the `setNames`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetNames?: (ctx: SetNamesContext) => Result;
      /**
       * Visit a parse tree produced by the `setPassword`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetPassword?: (ctx: SetPasswordContext) => Result;
      /**
       * Visit a parse tree produced by the `setTransaction`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetTransaction?: (ctx: SetTransactionContext) => Result;
      /**
       * Visit a parse tree produced by the `setAutocommit`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetAutocommit?: (ctx: SetAutocommitContext) => Result;
      /**
       * Visit a parse tree produced by the `setNewValueInsideTrigger`
       * labeled alternative in `MySqlParser.setStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetNewValueInsideTrigger?: (ctx: SetNewValueInsideTriggerContext) => Result;
      /**
       * Visit a parse tree produced by the `showMasterLogs`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowMasterLogs?: (ctx: ShowMasterLogsContext) => Result;
      /**
       * Visit a parse tree produced by the `showLogEvents`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowLogEvents?: (ctx: ShowLogEventsContext) => Result;
      /**
       * Visit a parse tree produced by the `showObjectFilter`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowObjectFilter?: (ctx: ShowObjectFilterContext) => Result;
      /**
       * Visit a parse tree produced by the `showColumns`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowColumns?: (ctx: ShowColumnsContext) => Result;
      /**
       * Visit a parse tree produced by the `showCreateDb`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCreateDb?: (ctx: ShowCreateDbContext) => Result;
      /**
       * Visit a parse tree produced by the `showCreateFullIdObject`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCreateFullIdObject?: (ctx: ShowCreateFullIdObjectContext) => Result;
      /**
       * Visit a parse tree produced by the `showCreateUser`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCreateUser?: (ctx: ShowCreateUserContext) => Result;
      /**
       * Visit a parse tree produced by the `showEngine`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowEngine?: (ctx: ShowEngineContext) => Result;
      /**
       * Visit a parse tree produced by the `showGlobalInfo`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowGlobalInfo?: (ctx: ShowGlobalInfoContext) => Result;
      /**
       * Visit a parse tree produced by the `showErrors`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowErrors?: (ctx: ShowErrorsContext) => Result;
      /**
       * Visit a parse tree produced by the `showCountErrors`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCountErrors?: (ctx: ShowCountErrorsContext) => Result;
      /**
       * Visit a parse tree produced by the `showSchemaFilter`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowSchemaFilter?: (ctx: ShowSchemaFilterContext) => Result;
      /**
       * Visit a parse tree produced by the `showRoutine`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowRoutine?: (ctx: ShowRoutineContext) => Result;
      /**
       * Visit a parse tree produced by the `showGrants`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowGrants?: (ctx: ShowGrantsContext) => Result;
      /**
       * Visit a parse tree produced by the `showIndexes`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowIndexes?: (ctx: ShowIndexesContext) => Result;
      /**
       * Visit a parse tree produced by the `showOpenTables`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowOpenTables?: (ctx: ShowOpenTablesContext) => Result;
      /**
       * Visit a parse tree produced by the `showProfile`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowProfile?: (ctx: ShowProfileContext) => Result;
      /**
       * Visit a parse tree produced by the `showSlaveStatus`
       * labeled alternative in `MySqlParser.showStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowSlaveStatus?: (ctx: ShowSlaveStatusContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.variableClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVariableClause?: (ctx: VariableClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.showCommonEntity`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowCommonEntity?: (ctx: ShowCommonEntityContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.showFilter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowFilter?: (ctx: ShowFilterContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.showGlobalInfoClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowGlobalInfoClause?: (ctx: ShowGlobalInfoClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.showSchemaEntity`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowSchemaEntity?: (ctx: ShowSchemaEntityContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.showProfileType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShowProfileType?: (ctx: ShowProfileTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.binlogStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBinlogStatement?: (ctx: BinlogStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.cacheIndexStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCacheIndexStatement?: (ctx: CacheIndexStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.flushStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFlushStatement?: (ctx: FlushStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.killStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKillStatement?: (ctx: KillStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.loadIndexIntoCache`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoadIndexIntoCache?: (ctx: LoadIndexIntoCacheContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.resetStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitResetStatement?: (ctx: ResetStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.shutdownStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitShutdownStatement?: (ctx: ShutdownStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tableIndexes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableIndexes?: (ctx: TableIndexesContext) => Result;
      /**
       * Visit a parse tree produced by the `simpleFlushOption`
       * labeled alternative in `MySqlParser.flushOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleFlushOption?: (ctx: SimpleFlushOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `channelFlushOption`
       * labeled alternative in `MySqlParser.flushOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitChannelFlushOption?: (ctx: ChannelFlushOptionContext) => Result;
      /**
       * Visit a parse tree produced by the `tableFlushOption`
       * labeled alternative in `MySqlParser.flushOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableFlushOption?: (ctx: TableFlushOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.flushTableOption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFlushTableOption?: (ctx: FlushTableOptionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.loadedTableIndexes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoadedTableIndexes?: (ctx: LoadedTableIndexesContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.simpleDescribeStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleDescribeStatement?: (ctx: SimpleDescribeStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.fullDescribeStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFullDescribeStatement?: (ctx: FullDescribeStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.helpStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHelpStatement?: (ctx: HelpStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.useStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUseStatement?: (ctx: UseStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.signalStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSignalStatement?: (ctx: SignalStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.resignalStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitResignalStatement?: (ctx: ResignalStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.signalConditionInformation`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSignalConditionInformation?: (ctx: SignalConditionInformationContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.withStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWithStatement?: (ctx: WithStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tableStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableStatement?: (ctx: TableStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.diagnosticsStatement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDiagnosticsStatement?: (ctx: DiagnosticsStatementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.diagnosticsConditionInformationName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDiagnosticsConditionInformationName?: (ctx: DiagnosticsConditionInformationNameContext) => Result;
      /**
       * Visit a parse tree produced by the `describeStatements`
       * labeled alternative in `MySqlParser.describeObjectClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDescribeStatements?: (ctx: DescribeStatementsContext) => Result;
      /**
       * Visit a parse tree produced by the `describeConnection`
       * labeled alternative in `MySqlParser.describeObjectClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDescribeConnection?: (ctx: DescribeConnectionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.fullId`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFullId?: (ctx: FullIdContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tableName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableName?: (ctx: TableNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.roleName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoleName?: (ctx: RoleNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.fullColumnName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFullColumnName?: (ctx: FullColumnNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.indexColumnName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexColumnName?: (ctx: IndexColumnNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.simpleUserName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleUserName?: (ctx: SimpleUserNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.hostName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHostName?: (ctx: HostNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.userName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserName?: (ctx: UserNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.mysqlVariable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMysqlVariable?: (ctx: MysqlVariableContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.charsetName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCharsetName?: (ctx: CharsetNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.collationName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCollationName?: (ctx: CollationNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.engineName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEngineName?: (ctx: EngineNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.engineNameBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEngineNameBase?: (ctx: EngineNameBaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.uuidSet`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUuidSet?: (ctx: UuidSetContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xid`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXid?: (ctx: XidContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.xuidStringId`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXuidStringId?: (ctx: XuidStringIdContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.authPlugin`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAuthPlugin?: (ctx: AuthPluginContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.uid`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUid?: (ctx: UidContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.simpleId`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleId?: (ctx: SimpleIdContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dottedId`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDottedId?: (ctx: DottedIdContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.decimalLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecimalLiteral?: (ctx: DecimalLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.fileSizeLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFileSizeLiteral?: (ctx: FileSizeLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.stringLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStringLiteral?: (ctx: StringLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.booleanLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBooleanLiteral?: (ctx: BooleanLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.hexadecimalLiteral`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHexadecimalLiteral?: (ctx: HexadecimalLiteralContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.nullNotnull`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNullNotnull?: (ctx: NullNotnullContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.constant`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstant?: (ctx: ConstantContext) => Result;
      /**
       * Visit a parse tree produced by the `stringDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStringDataType?: (ctx: StringDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `nationalVaryingStringDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNationalVaryingStringDataType?: (ctx: NationalVaryingStringDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `nationalStringDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNationalStringDataType?: (ctx: NationalStringDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `dimensionDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDimensionDataType?: (ctx: DimensionDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `simpleDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleDataType?: (ctx: SimpleDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `collectionDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCollectionDataType?: (ctx: CollectionDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `spatialDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSpatialDataType?: (ctx: SpatialDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `longVarcharDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLongVarcharDataType?: (ctx: LongVarcharDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by the `longVarbinaryDataType`
       * labeled alternative in `MySqlParser.dataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLongVarbinaryDataType?: (ctx: LongVarbinaryDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.collectionOptions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCollectionOptions?: (ctx: CollectionOptionsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.convertedDataType`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConvertedDataType?: (ctx: ConvertedDataTypeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lengthOneDimension`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLengthOneDimension?: (ctx: LengthOneDimensionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lengthTwoDimension`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLengthTwoDimension?: (ctx: LengthTwoDimensionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.lengthTwoOptionalDimension`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLengthTwoOptionalDimension?: (ctx: LengthTwoOptionalDimensionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.uidList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUidList?: (ctx: UidListContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.fullColumnNameList`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFullColumnNameList?: (ctx: FullColumnNameListContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.tables`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTables?: (ctx: TablesContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.indexColumnNames`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexColumnNames?: (ctx: IndexColumnNamesContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.expressions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpressions?: (ctx: ExpressionsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.expressionsWithDefaults`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpressionsWithDefaults?: (ctx: ExpressionsWithDefaultsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.constants`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstants?: (ctx: ConstantsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.simpleStrings`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleStrings?: (ctx: SimpleStringsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.userVariables`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUserVariables?: (ctx: UserVariablesContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.defaultValue`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefaultValue?: (ctx: DefaultValueContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.currentTimestamp`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCurrentTimestamp?: (ctx: CurrentTimestampContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.expressionOrDefault`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpressionOrDefault?: (ctx: ExpressionOrDefaultContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.ifExists`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIfExists?: (ctx: IfExistsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.ifNotExists`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIfNotExists?: (ctx: IfNotExistsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.orReplace`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOrReplace?: (ctx: OrReplaceContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.waitNowaitClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWaitNowaitClause?: (ctx: WaitNowaitClauseContext) => Result;
      /**
       * Visit a parse tree produced by the `specificFunctionCall`
       * labeled alternative in `MySqlParser.functionCall`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSpecificFunctionCall?: (ctx: SpecificFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `aggregateFunctionCall`
       * labeled alternative in `MySqlParser.functionCall`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggregateFunctionCall?: (ctx: AggregateFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `nonAggregateFunctionCall`
       * labeled alternative in `MySqlParser.functionCall`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNonAggregateFunctionCall?: (ctx: NonAggregateFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `scalarFunctionCall`
       * labeled alternative in `MySqlParser.functionCall`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitScalarFunctionCall?: (ctx: ScalarFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `udfFunctionCall`
       * labeled alternative in `MySqlParser.functionCall`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUdfFunctionCall?: (ctx: UdfFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `passwordFunctionCall`
       * labeled alternative in `MySqlParser.functionCall`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPasswordFunctionCall?: (ctx: PasswordFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `simpleFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpleFunctionCall?: (ctx: SimpleFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `currentUser`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCurrentUser?: (ctx: CurrentUserContext) => Result;
      /**
       * Visit a parse tree produced by the `dataTypeFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDataTypeFunctionCall?: (ctx: DataTypeFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `valuesFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitValuesFunctionCall?: (ctx: ValuesFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `caseExpressionFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCaseExpressionFunctionCall?: (ctx: CaseExpressionFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `caseFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCaseFunctionCall?: (ctx: CaseFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `charFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCharFunctionCall?: (ctx: CharFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `positionFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPositionFunctionCall?: (ctx: PositionFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `substrFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubstrFunctionCall?: (ctx: SubstrFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `trimFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTrimFunctionCall?: (ctx: TrimFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `weightFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWeightFunctionCall?: (ctx: WeightFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `extractFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExtractFunctionCall?: (ctx: ExtractFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `getFormatFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGetFormatFunctionCall?: (ctx: GetFormatFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by the `jsonValueFunctionCall`
       * labeled alternative in `MySqlParser.specificFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonValueFunctionCall?: (ctx: JsonValueFunctionCallContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.caseFuncAlternative`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCaseFuncAlternative?: (ctx: CaseFuncAlternativeContext) => Result;
      /**
       * Visit a parse tree produced by the `levelWeightList`
       * labeled alternative in `MySqlParser.levelsInWeightString`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLevelWeightList?: (ctx: LevelWeightListContext) => Result;
      /**
       * Visit a parse tree produced by the `levelWeightRange`
       * labeled alternative in `MySqlParser.levelsInWeightString`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLevelWeightRange?: (ctx: LevelWeightRangeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.levelInWeightListElement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLevelInWeightListElement?: (ctx: LevelInWeightListElementContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.aggregateWindowedFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggregateWindowedFunction?: (ctx: AggregateWindowedFunctionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.nonAggregateWindowedFunction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNonAggregateWindowedFunction?: (ctx: NonAggregateWindowedFunctionContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.overClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOverClause?: (ctx: OverClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.windowSpec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindowSpec?: (ctx: WindowSpecContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.windowName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindowName?: (ctx: WindowNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.frameClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameClause?: (ctx: FrameClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.frameUnits`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameUnits?: (ctx: FrameUnitsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.frameExtent`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameExtent?: (ctx: FrameExtentContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.frameBetween`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameBetween?: (ctx: FrameBetweenContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.frameRange`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrameRange?: (ctx: FrameRangeContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.partitionClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionClause?: (ctx: PartitionClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.scalarFunctionName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitScalarFunctionName?: (ctx: ScalarFunctionNameContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.passwordFunctionClause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPasswordFunctionClause?: (ctx: PasswordFunctionClauseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.functionArgs`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunctionArgs?: (ctx: FunctionArgsContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.functionArg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunctionArg?: (ctx: FunctionArgContext) => Result;
      /**
       * Visit a parse tree produced by the `isExpression`
       * labeled alternative in `MySqlParser.expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIsExpression?: (ctx: IsExpressionContext) => Result;
      /**
       * Visit a parse tree produced by the `notExpression`
       * labeled alternative in `MySqlParser.expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNotExpression?: (ctx: NotExpressionContext) => Result;
      /**
       * Visit a parse tree produced by the `logicalExpression`
       * labeled alternative in `MySqlParser.expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLogicalExpression?: (ctx: LogicalExpressionContext) => Result;
      /**
       * Visit a parse tree produced by the `predicateExpression`
       * labeled alternative in `MySqlParser.expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPredicateExpression?: (ctx: PredicateExpressionContext) => Result;
      /**
       * Visit a parse tree produced by the `soundsLikePredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSoundsLikePredicate?: (ctx: SoundsLikePredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `expressionAtomPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpressionAtomPredicate?: (ctx: ExpressionAtomPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `subqueryComparisonPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubqueryComparisonPredicate?: (ctx: SubqueryComparisonPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `jsonMemberOfPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonMemberOfPredicate?: (ctx: JsonMemberOfPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `binaryComparisonPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBinaryComparisonPredicate?: (ctx: BinaryComparisonPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `inPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInPredicate?: (ctx: InPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `betweenPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBetweenPredicate?: (ctx: BetweenPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `isNullPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIsNullPredicate?: (ctx: IsNullPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `likePredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLikePredicate?: (ctx: LikePredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `regexpPredicate`
       * labeled alternative in `MySqlParser.predicate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRegexpPredicate?: (ctx: RegexpPredicateContext) => Result;
      /**
       * Visit a parse tree produced by the `unaryExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnaryExpressionAtom?: (ctx: UnaryExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `collateExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCollateExpressionAtom?: (ctx: CollateExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `variableAssignExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVariableAssignExpressionAtom?: (ctx: VariableAssignExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `mysqlVariableExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMysqlVariableExpressionAtom?: (ctx: MysqlVariableExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `nestedExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNestedExpressionAtom?: (ctx: NestedExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `nestedRowExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNestedRowExpressionAtom?: (ctx: NestedRowExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `mathExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMathExpressionAtom?: (ctx: MathExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `existsExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExistsExpressionAtom?: (ctx: ExistsExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `intervalExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIntervalExpressionAtom?: (ctx: IntervalExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `jsonExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonExpressionAtom?: (ctx: JsonExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `subqueryExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubqueryExpressionAtom?: (ctx: SubqueryExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `constantExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstantExpressionAtom?: (ctx: ConstantExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `functionCallExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunctionCallExpressionAtom?: (ctx: FunctionCallExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `binaryExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBinaryExpressionAtom?: (ctx: BinaryExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `fullColumnNameExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFullColumnNameExpressionAtom?: (ctx: FullColumnNameExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by the `bitExpressionAtom`
       * labeled alternative in `MySqlParser.expressionAtom`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBitExpressionAtom?: (ctx: BitExpressionAtomContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.unaryOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnaryOperator?: (ctx: UnaryOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.comparisonOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitComparisonOperator?: (ctx: ComparisonOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.logicalOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLogicalOperator?: (ctx: LogicalOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.bitOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBitOperator?: (ctx: BitOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.multOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMultOperator?: (ctx: MultOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.addOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAddOperator?: (ctx: AddOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.jsonOperator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJsonOperator?: (ctx: JsonOperatorContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.charsetNameBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCharsetNameBase?: (ctx: CharsetNameBaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.transactionLevelBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransactionLevelBase?: (ctx: TransactionLevelBaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.privilegesBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivilegesBase?: (ctx: PrivilegesBaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.intervalTypeBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIntervalTypeBase?: (ctx: IntervalTypeBaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.dataTypeBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDataTypeBase?: (ctx: DataTypeBaseContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.keywordsCanBeId`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKeywordsCanBeId?: (ctx: KeywordsCanBeIdContext) => Result;
      /**
       * Visit a parse tree produced by `MySqlParser.functionNameBase`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunctionNameBase?: (ctx: FunctionNameBaseContext) => Result;
  }

}
declare module 'websql-autocomplete-2/parsers/mysql/mySqlParserData' {
  import { ParseTree, Token } from 'antlr4ng';
  import * as c3 from 'antlr4-c3';
  import { AutocompleteParseResult, ISymbolTableVisitor } from 'websql-autocomplete-2/types.js/index';
  import { MySqlLexer } from 'websql-autocomplete-2/parsers/mysql/generated/MySqlLexer.js/index';
  import { AtomTableItemContext, MySqlParser, TableNameContext } from 'websql-autocomplete-2/parsers/mysql/generated/MySqlParser.js/index';
  import { MySqlParserVisitor } from 'websql-autocomplete-2/parsers/mysql/generated/MySqlParserVisitor.js/index';
  import { TableQueryPosition, TokenDictionary } from 'websql-autocomplete-2/lib/tables.js/index';
  class MySqlSymbolTableVisitor extends MySqlParserVisitor<{}> implements ISymbolTableVisitor {
      symbolTable: c3.SymbolTable;
      scope: c3.ScopedSymbol;
      constructor();
      visitTableName: (context: TableNameContext) => {};
      visitAtomTableItem: (context: AtomTableItemContext) => {};
  }
  function generateSuggestionsFromRules(rules: c3.CandidatesCollection['rules'], cursorTokenIndex: number, previousToken?: Token): Partial<AutocompleteParseResult> & {
      suggestColumns?: boolean;
  };
  function getParseTree(parser: MySqlParser, type?: TableQueryPosition['type']): ParseTree;
  export const mySqlParserData: {
      Lexer: typeof MySqlLexer;
      Parser: typeof MySqlParser;
      SymbolTableVisitor: typeof MySqlSymbolTableVisitor;
      tokenDictionary: TokenDictionary;
      ignoredTokens: Set<number>;
      preferredRules: Set<number>;
      explicitlyParseJoin: boolean;
      getParseTree: typeof getParseTree;
      generateSuggestionsFromRules: typeof generateSuggestionsFromRules;
  };
  export {};

}
declare module 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlLexer' {
  import * as antlr from 'antlr4ng';
  import PostgreSqlLexerBase from 'websql-autocomplete-2/parsers/postgresql/grammar/PostgreSqlLexerBase.js/index';
  export class PostgreSqlLexer extends PostgreSqlLexerBase {
      static readonly Dollar = 1;
      static readonly OPEN_PAREN = 2;
      static readonly CLOSE_PAREN = 3;
      static readonly OPEN_BRACKET = 4;
      static readonly CLOSE_BRACKET = 5;
      static readonly COMMA = 6;
      static readonly SEMI = 7;
      static readonly COLON = 8;
      static readonly STAR = 9;
      static readonly EQUAL = 10;
      static readonly DOT = 11;
      static readonly PLUS = 12;
      static readonly MINUS = 13;
      static readonly SLASH = 14;
      static readonly CARET = 15;
      static readonly LT = 16;
      static readonly GT = 17;
      static readonly LESS_LESS = 18;
      static readonly GREATER_GREATER = 19;
      static readonly COLON_EQUALS = 20;
      static readonly LESS_EQUALS = 21;
      static readonly EQUALS_GREATER = 22;
      static readonly GREATER_EQUALS = 23;
      static readonly DOT_DOT = 24;
      static readonly NOT_EQUALS = 25;
      static readonly TYPECAST = 26;
      static readonly PERCENT = 27;
      static readonly PARAM = 28;
      static readonly Operator = 29;
      static readonly ALL = 30;
      static readonly ANALYSE = 31;
      static readonly ANALYZE = 32;
      static readonly AND = 33;
      static readonly ANY = 34;
      static readonly ARRAY = 35;
      static readonly AS = 36;
      static readonly ASC = 37;
      static readonly ASYMMETRIC = 38;
      static readonly BOTH = 39;
      static readonly CASE = 40;
      static readonly CAST = 41;
      static readonly CHECK = 42;
      static readonly COLLATE = 43;
      static readonly COLUMN = 44;
      static readonly CONSTRAINT = 45;
      static readonly CREATE = 46;
      static readonly CURRENT_CATALOG = 47;
      static readonly CURRENT_DATE = 48;
      static readonly CURRENT_ROLE = 49;
      static readonly CURRENT_TIME = 50;
      static readonly CURRENT_TIMESTAMP = 51;
      static readonly CURRENT_USER = 52;
      static readonly DEFAULT = 53;
      static readonly DEFERRABLE = 54;
      static readonly DESC = 55;
      static readonly DISTINCT = 56;
      static readonly DO = 57;
      static readonly ELSE = 58;
      static readonly EXCEPT = 59;
      static readonly FALSE_P = 60;
      static readonly FETCH = 61;
      static readonly FOR = 62;
      static readonly FOREIGN = 63;
      static readonly FROM = 64;
      static readonly GRANT = 65;
      static readonly GROUP_P = 66;
      static readonly HAVING = 67;
      static readonly IN_P = 68;
      static readonly INITIALLY = 69;
      static readonly INTERSECT = 70;
      static readonly INTO = 71;
      static readonly LATERAL_P = 72;
      static readonly LEADING = 73;
      static readonly LIMIT = 74;
      static readonly LOCALTIME = 75;
      static readonly LOCALTIMESTAMP = 76;
      static readonly NOT = 77;
      static readonly NULL_P = 78;
      static readonly OFFSET = 79;
      static readonly ON = 80;
      static readonly ONLY = 81;
      static readonly OR = 82;
      static readonly ORDER = 83;
      static readonly PLACING = 84;
      static readonly PRIMARY = 85;
      static readonly REFERENCES = 86;
      static readonly RETURNING = 87;
      static readonly SELECT = 88;
      static readonly SESSION_USER = 89;
      static readonly SOME = 90;
      static readonly SYMMETRIC = 91;
      static readonly TABLE = 92;
      static readonly THEN = 93;
      static readonly TO = 94;
      static readonly TRAILING = 95;
      static readonly TRUE_P = 96;
      static readonly UNION = 97;
      static readonly UNIQUE = 98;
      static readonly USER = 99;
      static readonly USING = 100;
      static readonly VARIADIC = 101;
      static readonly WHEN = 102;
      static readonly WHERE = 103;
      static readonly WINDOW = 104;
      static readonly WITH = 105;
      static readonly AUTHORIZATION = 106;
      static readonly BINARY = 107;
      static readonly COLLATION = 108;
      static readonly CONCURRENTLY = 109;
      static readonly CROSS = 110;
      static readonly CURRENT_SCHEMA = 111;
      static readonly FREEZE = 112;
      static readonly FULL = 113;
      static readonly ILIKE = 114;
      static readonly INNER_P = 115;
      static readonly IS = 116;
      static readonly ISNULL = 117;
      static readonly JOIN = 118;
      static readonly LEFT = 119;
      static readonly LIKE = 120;
      static readonly NATURAL = 121;
      static readonly NOTNULL = 122;
      static readonly OUTER_P = 123;
      static readonly OVER = 124;
      static readonly OVERLAPS = 125;
      static readonly RIGHT = 126;
      static readonly SIMILAR = 127;
      static readonly VERBOSE = 128;
      static readonly ABORT_P = 129;
      static readonly ABSOLUTE_P = 130;
      static readonly ACCESS = 131;
      static readonly ACTION = 132;
      static readonly ADD_P = 133;
      static readonly ADMIN = 134;
      static readonly AFTER = 135;
      static readonly AGGREGATE = 136;
      static readonly ALSO = 137;
      static readonly ALTER = 138;
      static readonly ALWAYS = 139;
      static readonly ASSERTION = 140;
      static readonly ASSIGNMENT = 141;
      static readonly AT = 142;
      static readonly ATTRIBUTE = 143;
      static readonly BACKWARD = 144;
      static readonly BEFORE = 145;
      static readonly BEGIN_P = 146;
      static readonly BY = 147;
      static readonly CACHE = 148;
      static readonly CALLED = 149;
      static readonly CASCADE = 150;
      static readonly CASCADED = 151;
      static readonly CATALOG = 152;
      static readonly CHAIN = 153;
      static readonly CHARACTERISTICS = 154;
      static readonly CHECKPOINT = 155;
      static readonly CLASS = 156;
      static readonly CLOSE = 157;
      static readonly CLUSTER = 158;
      static readonly COMMENT = 159;
      static readonly COMMENTS = 160;
      static readonly COMMIT = 161;
      static readonly COMMITTED = 162;
      static readonly CONFIGURATION = 163;
      static readonly CONNECTION = 164;
      static readonly CONSTRAINTS = 165;
      static readonly CONTENT_P = 166;
      static readonly CONTINUE_P = 167;
      static readonly CONVERSION_P = 168;
      static readonly COPY = 169;
      static readonly COST = 170;
      static readonly CSV = 171;
      static readonly CURSOR = 172;
      static readonly CYCLE = 173;
      static readonly DATA_P = 174;
      static readonly DATABASE = 175;
      static readonly DAY_P = 176;
      static readonly DEALLOCATE = 177;
      static readonly DECLARE = 178;
      static readonly DEFAULTS = 179;
      static readonly DEFERRED = 180;
      static readonly DEFINER = 181;
      static readonly DELETE_P = 182;
      static readonly DELIMITER = 183;
      static readonly DELIMITERS = 184;
      static readonly DICTIONARY = 185;
      static readonly DISABLE_P = 186;
      static readonly DISCARD = 187;
      static readonly DOCUMENT_P = 188;
      static readonly DOMAIN_P = 189;
      static readonly DOUBLE_P = 190;
      static readonly DROP = 191;
      static readonly EACH = 192;
      static readonly ENABLE_P = 193;
      static readonly ENCODING = 194;
      static readonly ENCRYPTED = 195;
      static readonly ENUM_P = 196;
      static readonly ESCAPE = 197;
      static readonly EVENT = 198;
      static readonly EXCLUDE = 199;
      static readonly EXCLUDING = 200;
      static readonly EXCLUSIVE = 201;
      static readonly EXECUTE = 202;
      static readonly EXPLAIN = 203;
      static readonly EXTENSION = 204;
      static readonly EXTERNAL = 205;
      static readonly FAMILY = 206;
      static readonly FIRST_P = 207;
      static readonly FOLLOWING = 208;
      static readonly FORCE = 209;
      static readonly FORWARD = 210;
      static readonly FUNCTION = 211;
      static readonly FUNCTIONS = 212;
      static readonly GLOBAL = 213;
      static readonly GRANTED = 214;
      static readonly HANDLER = 215;
      static readonly HEADER_P = 216;
      static readonly HOLD = 217;
      static readonly HOUR_P = 218;
      static readonly IDENTITY_P = 219;
      static readonly IF_P = 220;
      static readonly IMMEDIATE = 221;
      static readonly IMMUTABLE = 222;
      static readonly IMPLICIT_P = 223;
      static readonly INCLUDING = 224;
      static readonly INCREMENT = 225;
      static readonly INDEX = 226;
      static readonly INDEXES = 227;
      static readonly INHERIT = 228;
      static readonly INHERITS = 229;
      static readonly INLINE_P = 230;
      static readonly INSENSITIVE = 231;
      static readonly INSERT = 232;
      static readonly INSTEAD = 233;
      static readonly INVOKER = 234;
      static readonly ISOLATION = 235;
      static readonly KEY = 236;
      static readonly LABEL = 237;
      static readonly LANGUAGE = 238;
      static readonly LARGE_P = 239;
      static readonly LAST_P = 240;
      static readonly LEAKPROOF = 241;
      static readonly LEVEL = 242;
      static readonly LISTEN = 243;
      static readonly LOAD = 244;
      static readonly LOCAL = 245;
      static readonly LOCATION = 246;
      static readonly LOCK_P = 247;
      static readonly MAPPING = 248;
      static readonly MATCH = 249;
      static readonly MATCHED = 250;
      static readonly MATERIALIZED = 251;
      static readonly MAXVALUE = 252;
      static readonly MERGE = 253;
      static readonly MINUTE_P = 254;
      static readonly MINVALUE = 255;
      static readonly MODE = 256;
      static readonly MONTH_P = 257;
      static readonly MOVE = 258;
      static readonly NAME_P = 259;
      static readonly NAMES = 260;
      static readonly NEXT = 261;
      static readonly NO = 262;
      static readonly NOTHING = 263;
      static readonly NOTIFY = 264;
      static readonly NOWAIT = 265;
      static readonly NULLS_P = 266;
      static readonly OBJECT_P = 267;
      static readonly OF = 268;
      static readonly OFF = 269;
      static readonly OIDS = 270;
      static readonly OPERATOR = 271;
      static readonly OPTION = 272;
      static readonly OPTIONS = 273;
      static readonly OWNED = 274;
      static readonly OWNER = 275;
      static readonly PARSER = 276;
      static readonly PARTIAL = 277;
      static readonly PARTITION = 278;
      static readonly PASSING = 279;
      static readonly PASSWORD = 280;
      static readonly PLANS = 281;
      static readonly PRECEDING = 282;
      static readonly PREPARE = 283;
      static readonly PREPARED = 284;
      static readonly PRESERVE = 285;
      static readonly PRIOR = 286;
      static readonly PRIVILEGES = 287;
      static readonly PROCEDURAL = 288;
      static readonly PROCEDURE = 289;
      static readonly PROGRAM = 290;
      static readonly QUOTE = 291;
      static readonly RANGE = 292;
      static readonly READ = 293;
      static readonly REASSIGN = 294;
      static readonly RECHECK = 295;
      static readonly RECURSIVE = 296;
      static readonly REF = 297;
      static readonly REFRESH = 298;
      static readonly REINDEX = 299;
      static readonly RELATIVE_P = 300;
      static readonly RELEASE = 301;
      static readonly RENAME = 302;
      static readonly REPEATABLE = 303;
      static readonly REPLACE = 304;
      static readonly REPLICA = 305;
      static readonly RESET = 306;
      static readonly RESTART = 307;
      static readonly RESTRICT = 308;
      static readonly RETURNS = 309;
      static readonly REVOKE = 310;
      static readonly ROLE = 311;
      static readonly ROLLBACK = 312;
      static readonly ROWS = 313;
      static readonly RULE = 314;
      static readonly SAVEPOINT = 315;
      static readonly SCHEMA = 316;
      static readonly SCROLL = 317;
      static readonly SEARCH = 318;
      static readonly SECOND_P = 319;
      static readonly SECURITY = 320;
      static readonly SEQUENCE = 321;
      static readonly SEQUENCES = 322;
      static readonly SERIALIZABLE = 323;
      static readonly SERVER = 324;
      static readonly SESSION = 325;
      static readonly SET = 326;
      static readonly SHARE = 327;
      static readonly SHOW = 328;
      static readonly SIMPLE = 329;
      static readonly SNAPSHOT = 330;
      static readonly STABLE = 331;
      static readonly STANDALONE_P = 332;
      static readonly START = 333;
      static readonly STATEMENT = 334;
      static readonly STATISTICS = 335;
      static readonly STDIN = 336;
      static readonly STDOUT = 337;
      static readonly STORAGE = 338;
      static readonly STRICT_P = 339;
      static readonly STRIP_P = 340;
      static readonly SYSID = 341;
      static readonly SYSTEM_P = 342;
      static readonly TABLES = 343;
      static readonly TABLESPACE = 344;
      static readonly TEMP = 345;
      static readonly TEMPLATE = 346;
      static readonly TEMPORARY = 347;
      static readonly TEXT_P = 348;
      static readonly TRANSACTION = 349;
      static readonly TRIGGER = 350;
      static readonly TRUNCATE = 351;
      static readonly TRUSTED = 352;
      static readonly TYPE_P = 353;
      static readonly TYPES_P = 354;
      static readonly UNBOUNDED = 355;
      static readonly UNCOMMITTED = 356;
      static readonly UNENCRYPTED = 357;
      static readonly UNKNOWN = 358;
      static readonly UNLISTEN = 359;
      static readonly UNLOGGED = 360;
      static readonly UNTIL = 361;
      static readonly UPDATE = 362;
      static readonly VACUUM = 363;
      static readonly VALID = 364;
      static readonly VALIDATE = 365;
      static readonly VALIDATOR = 366;
      static readonly VARYING = 367;
      static readonly VERSION_P = 368;
      static readonly VIEW = 369;
      static readonly VOLATILE = 370;
      static readonly WHITESPACE_P = 371;
      static readonly WITHOUT = 372;
      static readonly WORK = 373;
      static readonly WRAPPER = 374;
      static readonly WRITE = 375;
      static readonly XML_P = 376;
      static readonly YEAR_P = 377;
      static readonly YES_P = 378;
      static readonly ZONE = 379;
      static readonly BETWEEN = 380;
      static readonly BIGINT = 381;
      static readonly BIT = 382;
      static readonly BOOLEAN_P = 383;
      static readonly CHAR_P = 384;
      static readonly CHARACTER = 385;
      static readonly COALESCE = 386;
      static readonly DEC = 387;
      static readonly DECIMAL_P = 388;
      static readonly EXISTS = 389;
      static readonly EXTRACT = 390;
      static readonly FLOAT_P = 391;
      static readonly GREATEST = 392;
      static readonly INOUT = 393;
      static readonly INT_P = 394;
      static readonly INTEGER = 395;
      static readonly INTERVAL = 396;
      static readonly LEAST = 397;
      static readonly NATIONAL = 398;
      static readonly NCHAR = 399;
      static readonly NONE = 400;
      static readonly NULLIF = 401;
      static readonly NUMERIC = 402;
      static readonly OVERLAY = 403;
      static readonly POSITION = 404;
      static readonly PRECISION = 405;
      static readonly REAL = 406;
      static readonly ROW = 407;
      static readonly SETOF = 408;
      static readonly SMALLINT = 409;
      static readonly SUBSTRING = 410;
      static readonly TIME = 411;
      static readonly TIMESTAMP = 412;
      static readonly TREAT = 413;
      static readonly TRIM = 414;
      static readonly VALUES = 415;
      static readonly VARCHAR = 416;
      static readonly XMLATTRIBUTES = 417;
      static readonly XMLCOMMENT = 418;
      static readonly XMLAGG = 419;
      static readonly XML_IS_WELL_FORMED = 420;
      static readonly XML_IS_WELL_FORMED_DOCUMENT = 421;
      static readonly XML_IS_WELL_FORMED_CONTENT = 422;
      static readonly XPATH = 423;
      static readonly XPATH_EXISTS = 424;
      static readonly XMLCONCAT = 425;
      static readonly XMLELEMENT = 426;
      static readonly XMLEXISTS = 427;
      static readonly XMLFOREST = 428;
      static readonly XMLPARSE = 429;
      static readonly XMLPI = 430;
      static readonly XMLROOT = 431;
      static readonly XMLSERIALIZE = 432;
      static readonly CALL = 433;
      static readonly CURRENT_P = 434;
      static readonly ATTACH = 435;
      static readonly DETACH = 436;
      static readonly EXPRESSION = 437;
      static readonly GENERATED = 438;
      static readonly LOGGED = 439;
      static readonly STORED = 440;
      static readonly INCLUDE = 441;
      static readonly ROUTINE = 442;
      static readonly TRANSFORM = 443;
      static readonly IMPORT_P = 444;
      static readonly POLICY = 445;
      static readonly METHOD = 446;
      static readonly REFERENCING = 447;
      static readonly NEW = 448;
      static readonly OLD = 449;
      static readonly VALUE_P = 450;
      static readonly SUBSCRIPTION = 451;
      static readonly PUBLICATION = 452;
      static readonly OUT_P = 453;
      static readonly END_P = 454;
      static readonly ROUTINES = 455;
      static readonly SCHEMAS = 456;
      static readonly PROCEDURES = 457;
      static readonly INPUT_P = 458;
      static readonly SUPPORT = 459;
      static readonly PARALLEL = 460;
      static readonly SQL_P = 461;
      static readonly DEPENDS = 462;
      static readonly OVERRIDING = 463;
      static readonly CONFLICT = 464;
      static readonly SKIP_P = 465;
      static readonly LOCKED = 466;
      static readonly TIES = 467;
      static readonly ROLLUP = 468;
      static readonly CUBE = 469;
      static readonly GROUPING = 470;
      static readonly SETS = 471;
      static readonly TABLESAMPLE = 472;
      static readonly ORDINALITY = 473;
      static readonly XMLTABLE = 474;
      static readonly COLUMNS = 475;
      static readonly XMLNAMESPACES = 476;
      static readonly ROWTYPE = 477;
      static readonly NORMALIZED = 478;
      static readonly WITHIN = 479;
      static readonly FILTER = 480;
      static readonly GROUPS = 481;
      static readonly OTHERS = 482;
      static readonly NFC = 483;
      static readonly NFD = 484;
      static readonly NFKC = 485;
      static readonly NFKD = 486;
      static readonly UESCAPE = 487;
      static readonly VIEWS = 488;
      static readonly NORMALIZE = 489;
      static readonly DUMP = 490;
      static readonly PRINT_STRICT_PARAMS = 491;
      static readonly VARIABLE_CONFLICT = 492;
      static readonly ERROR = 493;
      static readonly USE_VARIABLE = 494;
      static readonly USE_COLUMN = 495;
      static readonly ALIAS = 496;
      static readonly CONSTANT = 497;
      static readonly PERFORM = 498;
      static readonly GET = 499;
      static readonly DIAGNOSTICS = 500;
      static readonly STACKED = 501;
      static readonly ELSIF = 502;
      static readonly WHILE = 503;
      static readonly REVERSE = 504;
      static readonly FOREACH = 505;
      static readonly SLICE = 506;
      static readonly EXIT = 507;
      static readonly RETURN = 508;
      static readonly QUERY = 509;
      static readonly RAISE = 510;
      static readonly SQLSTATE = 511;
      static readonly DEBUG = 512;
      static readonly LOG = 513;
      static readonly INFO = 514;
      static readonly NOTICE = 515;
      static readonly WARNING = 516;
      static readonly EXCEPTION = 517;
      static readonly ASSERT = 518;
      static readonly LOOP = 519;
      static readonly OPEN = 520;
      static readonly ABS = 521;
      static readonly CBRT = 522;
      static readonly CEIL = 523;
      static readonly CEILING = 524;
      static readonly DEGREES = 525;
      static readonly DIV = 526;
      static readonly EXP = 527;
      static readonly FACTORIAL = 528;
      static readonly FLOOR = 529;
      static readonly GCD = 530;
      static readonly LCM = 531;
      static readonly LN = 532;
      static readonly LOG10 = 533;
      static readonly MIN_SCALE = 534;
      static readonly MOD = 535;
      static readonly PI = 536;
      static readonly POWER = 537;
      static readonly RADIANS = 538;
      static readonly ROUND = 539;
      static readonly SCALE = 540;
      static readonly SIGN = 541;
      static readonly SQRT = 542;
      static readonly TRIM_SCALE = 543;
      static readonly TRUNC = 544;
      static readonly WIDTH_BUCKET = 545;
      static readonly RANDOM = 546;
      static readonly SETSEED = 547;
      static readonly ACOS = 548;
      static readonly ACOSD = 549;
      static readonly ASIN = 550;
      static readonly ASIND = 551;
      static readonly ATAN = 552;
      static readonly ATAND = 553;
      static readonly ATAN2 = 554;
      static readonly ATAN2D = 555;
      static readonly COS = 556;
      static readonly COSD = 557;
      static readonly COT = 558;
      static readonly COTD = 559;
      static readonly SIN = 560;
      static readonly SIND = 561;
      static readonly TAN = 562;
      static readonly TAND = 563;
      static readonly SINH = 564;
      static readonly COSH = 565;
      static readonly TANH = 566;
      static readonly ASINH = 567;
      static readonly ACOSH = 568;
      static readonly ATANH = 569;
      static readonly BIT_LENGTH = 570;
      static readonly CHAR_LENGTH = 571;
      static readonly CHARACTER_LENGTH = 572;
      static readonly LOWER = 573;
      static readonly OCTET_LENGTH = 574;
      static readonly UPPER = 575;
      static readonly ASCII = 576;
      static readonly BTRIM = 577;
      static readonly CHR = 578;
      static readonly CONCAT = 579;
      static readonly CONCAT_WS = 580;
      static readonly FORMAT = 581;
      static readonly INITCAP = 582;
      static readonly LENGTH = 583;
      static readonly LPAD = 584;
      static readonly LTRIM = 585;
      static readonly MD5 = 586;
      static readonly PARSE_IDENT = 587;
      static readonly PG_CLIENT_ENCODING = 588;
      static readonly QUOTE_IDENT = 589;
      static readonly QUOTE_LITERAL = 590;
      static readonly QUOTE_NULLABLE = 591;
      static readonly REGEXP_COUNT = 592;
      static readonly REGEXP_INSTR = 593;
      static readonly REGEXP_LIKE = 594;
      static readonly REGEXP_MATCH = 595;
      static readonly REGEXP_MATCHES = 596;
      static readonly REGEXP_REPLACE = 597;
      static readonly REGEXP_SPLIT_TO_ARRAY = 598;
      static readonly REGEXP_SPLIT_TO_TABLE = 599;
      static readonly REGEXP_SUBSTR = 600;
      static readonly REPEAT = 601;
      static readonly RPAD = 602;
      static readonly RTRIM = 603;
      static readonly SPLIT_PART = 604;
      static readonly STARTS_WITH = 605;
      static readonly STRING_TO_ARRAY = 606;
      static readonly STRING_TO_TABLE = 607;
      static readonly STRPOS = 608;
      static readonly SUBSTR = 609;
      static readonly TO_ASCII = 610;
      static readonly TO_HEX = 611;
      static readonly TRANSLATE = 612;
      static readonly UNISTR = 613;
      static readonly AGE = 614;
      static readonly CLOCK_TIMESTAMP = 615;
      static readonly DATE_BIN = 616;
      static readonly DATE_PART = 617;
      static readonly DATE_TRUNC = 618;
      static readonly ISFINITE = 619;
      static readonly JUSTIFY_DAYS = 620;
      static readonly JUSTIFY_HOURS = 621;
      static readonly JUSTIFY_INTERVAL = 622;
      static readonly MAKE_DATE = 623;
      static readonly MAKE_INTERVAL = 624;
      static readonly MAKE_TIME = 625;
      static readonly MAKE_TIMESTAMP = 626;
      static readonly MAKE_TIMESTAMPTZ = 627;
      static readonly NOW = 628;
      static readonly STATEMENT_TIMESTAMP = 629;
      static readonly TIMEOFDAY = 630;
      static readonly TRANSACTION_TIMESTAMP = 631;
      static readonly TO_TIMESTAMP = 632;
      static readonly TO_CHAR = 633;
      static readonly TO_DATE = 634;
      static readonly TO_NUMBER = 635;
      static readonly Identifier = 636;
      static readonly QuotedIdentifier = 637;
      static readonly UnterminatedQuotedIdentifier = 638;
      static readonly InvalidQuotedIdentifier = 639;
      static readonly InvalidUnterminatedQuotedIdentifier = 640;
      static readonly UnicodeQuotedIdentifier = 641;
      static readonly UnterminatedUnicodeQuotedIdentifier = 642;
      static readonly InvalidUnicodeQuotedIdentifier = 643;
      static readonly InvalidUnterminatedUnicodeQuotedIdentifier = 644;
      static readonly StringConstant = 645;
      static readonly UnterminatedStringConstant = 646;
      static readonly UnicodeEscapeStringConstant = 647;
      static readonly UnterminatedUnicodeEscapeStringConstant = 648;
      static readonly BeginDollarStringConstant = 649;
      static readonly BinaryStringConstant = 650;
      static readonly UnterminatedBinaryStringConstant = 651;
      static readonly InvalidBinaryStringConstant = 652;
      static readonly InvalidUnterminatedBinaryStringConstant = 653;
      static readonly HexadecimalStringConstant = 654;
      static readonly UnterminatedHexadecimalStringConstant = 655;
      static readonly InvalidHexadecimalStringConstant = 656;
      static readonly InvalidUnterminatedHexadecimalStringConstant = 657;
      static readonly Integral = 658;
      static readonly NumericFail = 659;
      static readonly Numeric = 660;
      static readonly PLSQLVARIABLENAME = 661;
      static readonly PLSQLIDENTIFIER = 662;
      static readonly Whitespace = 663;
      static readonly Newline = 664;
      static readonly LineComment = 665;
      static readonly BlockComment = 666;
      static readonly UnterminatedBlockComment = 667;
      static readonly MetaCommand = 668;
      static readonly EndMetaCommand = 669;
      static readonly ErrorCharacter = 670;
      static readonly EscapeStringConstant = 671;
      static readonly UnterminatedEscapeStringConstant = 672;
      static readonly InvalidEscapeStringConstant = 673;
      static readonly InvalidUnterminatedEscapeStringConstant = 674;
      static readonly AfterEscapeStringConstantMode_NotContinued = 675;
      static readonly AfterEscapeStringConstantWithNewlineMode_NotContinued = 676;
      static readonly DollarText = 677;
      static readonly EndDollarStringConstant = 678;
      static readonly AfterEscapeStringConstantWithNewlineMode_Continued = 679;
      static readonly EscapeStringConstantMode = 1;
      static readonly AfterEscapeStringConstantMode = 2;
      static readonly AfterEscapeStringConstantWithNewlineMode = 3;
      static readonly DollarQuotedStringMode = 4;
      static readonly channelNames: string[];
      static readonly literalNames: (string | null)[];
      static readonly symbolicNames: (string | null)[];
      static readonly modeNames: string[];
      static readonly ruleNames: string[];
      constructor(input: antlr.CharStream);
      get grammarFileName(): string;
      get literalNames(): (string | null)[];
      get symbolicNames(): (string | null)[];
      get ruleNames(): string[];
      get serializedATN(): number[];
      get channelNames(): string[];
      get modeNames(): string[];
      action(localContext: antlr.RuleContext | null, ruleIndex: number, actionIndex: number): void;
      private Operator_action;
      private BeginDollarStringConstant_action;
      private NumericFail_action;
      private UnterminatedBlockComment_action;
      private AfterEscapeStringConstantMode_NotContinued_action;
      private AfterEscapeStringConstantWithNewlineMode_NotContinued_action;
      private EndDollarStringConstant_action;
      sempred(localContext: antlr.RuleContext | null, ruleIndex: number, predIndex: number): boolean;
      private Operator_sempred;
      private OperatorEndingWithPlusMinus_sempred;
      private IdentifierStartChar_sempred;
      private EndDollarStringConstant_sempred;
      static readonly _serializedATN: number[];
      private static __ATN;
      static get _ATN(): antlr.ATN;
      private static readonly vocabulary;
      get vocabulary(): antlr.Vocabulary;
      private static readonly decisionsToDFA;
  }

}
declare module 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser' {
  import * as antlr from 'antlr4ng';
  import { PostgreSqlParserVisitor } from 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParserVisitor.js/index';
  import PostgreSqlParserBase from 'websql-autocomplete-2/parsers/postgresql/grammar/PostgreSqlParserBase.js/index';
  export class PostgreSqlParser extends PostgreSqlParserBase {
      static readonly Dollar = 1;
      static readonly OPEN_PAREN = 2;
      static readonly CLOSE_PAREN = 3;
      static readonly OPEN_BRACKET = 4;
      static readonly CLOSE_BRACKET = 5;
      static readonly COMMA = 6;
      static readonly SEMI = 7;
      static readonly COLON = 8;
      static readonly STAR = 9;
      static readonly EQUAL = 10;
      static readonly DOT = 11;
      static readonly PLUS = 12;
      static readonly MINUS = 13;
      static readonly SLASH = 14;
      static readonly CARET = 15;
      static readonly LT = 16;
      static readonly GT = 17;
      static readonly LESS_LESS = 18;
      static readonly GREATER_GREATER = 19;
      static readonly COLON_EQUALS = 20;
      static readonly LESS_EQUALS = 21;
      static readonly EQUALS_GREATER = 22;
      static readonly GREATER_EQUALS = 23;
      static readonly DOT_DOT = 24;
      static readonly NOT_EQUALS = 25;
      static readonly TYPECAST = 26;
      static readonly PERCENT = 27;
      static readonly PARAM = 28;
      static readonly Operator = 29;
      static readonly ALL = 30;
      static readonly ANALYSE = 31;
      static readonly ANALYZE = 32;
      static readonly AND = 33;
      static readonly ANY = 34;
      static readonly ARRAY = 35;
      static readonly AS = 36;
      static readonly ASC = 37;
      static readonly ASYMMETRIC = 38;
      static readonly BOTH = 39;
      static readonly CASE = 40;
      static readonly CAST = 41;
      static readonly CHECK = 42;
      static readonly COLLATE = 43;
      static readonly COLUMN = 44;
      static readonly CONSTRAINT = 45;
      static readonly CREATE = 46;
      static readonly CURRENT_CATALOG = 47;
      static readonly CURRENT_DATE = 48;
      static readonly CURRENT_ROLE = 49;
      static readonly CURRENT_TIME = 50;
      static readonly CURRENT_TIMESTAMP = 51;
      static readonly CURRENT_USER = 52;
      static readonly DEFAULT = 53;
      static readonly DEFERRABLE = 54;
      static readonly DESC = 55;
      static readonly DISTINCT = 56;
      static readonly DO = 57;
      static readonly ELSE = 58;
      static readonly EXCEPT = 59;
      static readonly FALSE_P = 60;
      static readonly FETCH = 61;
      static readonly FOR = 62;
      static readonly FOREIGN = 63;
      static readonly FROM = 64;
      static readonly GRANT = 65;
      static readonly GROUP_P = 66;
      static readonly HAVING = 67;
      static readonly IN_P = 68;
      static readonly INITIALLY = 69;
      static readonly INTERSECT = 70;
      static readonly INTO = 71;
      static readonly LATERAL_P = 72;
      static readonly LEADING = 73;
      static readonly LIMIT = 74;
      static readonly LOCALTIME = 75;
      static readonly LOCALTIMESTAMP = 76;
      static readonly NOT = 77;
      static readonly NULL_P = 78;
      static readonly OFFSET = 79;
      static readonly ON = 80;
      static readonly ONLY = 81;
      static readonly OR = 82;
      static readonly ORDER = 83;
      static readonly PLACING = 84;
      static readonly PRIMARY = 85;
      static readonly REFERENCES = 86;
      static readonly RETURNING = 87;
      static readonly SELECT = 88;
      static readonly SESSION_USER = 89;
      static readonly SOME = 90;
      static readonly SYMMETRIC = 91;
      static readonly TABLE = 92;
      static readonly THEN = 93;
      static readonly TO = 94;
      static readonly TRAILING = 95;
      static readonly TRUE_P = 96;
      static readonly UNION = 97;
      static readonly UNIQUE = 98;
      static readonly USER = 99;
      static readonly USING = 100;
      static readonly VARIADIC = 101;
      static readonly WHEN = 102;
      static readonly WHERE = 103;
      static readonly WINDOW = 104;
      static readonly WITH = 105;
      static readonly AUTHORIZATION = 106;
      static readonly BINARY = 107;
      static readonly COLLATION = 108;
      static readonly CONCURRENTLY = 109;
      static readonly CROSS = 110;
      static readonly CURRENT_SCHEMA = 111;
      static readonly FREEZE = 112;
      static readonly FULL = 113;
      static readonly ILIKE = 114;
      static readonly INNER_P = 115;
      static readonly IS = 116;
      static readonly ISNULL = 117;
      static readonly JOIN = 118;
      static readonly LEFT = 119;
      static readonly LIKE = 120;
      static readonly NATURAL = 121;
      static readonly NOTNULL = 122;
      static readonly OUTER_P = 123;
      static readonly OVER = 124;
      static readonly OVERLAPS = 125;
      static readonly RIGHT = 126;
      static readonly SIMILAR = 127;
      static readonly VERBOSE = 128;
      static readonly ABORT_P = 129;
      static readonly ABSOLUTE_P = 130;
      static readonly ACCESS = 131;
      static readonly ACTION = 132;
      static readonly ADD_P = 133;
      static readonly ADMIN = 134;
      static readonly AFTER = 135;
      static readonly AGGREGATE = 136;
      static readonly ALSO = 137;
      static readonly ALTER = 138;
      static readonly ALWAYS = 139;
      static readonly ASSERTION = 140;
      static readonly ASSIGNMENT = 141;
      static readonly AT = 142;
      static readonly ATTRIBUTE = 143;
      static readonly BACKWARD = 144;
      static readonly BEFORE = 145;
      static readonly BEGIN_P = 146;
      static readonly BY = 147;
      static readonly CACHE = 148;
      static readonly CALLED = 149;
      static readonly CASCADE = 150;
      static readonly CASCADED = 151;
      static readonly CATALOG = 152;
      static readonly CHAIN = 153;
      static readonly CHARACTERISTICS = 154;
      static readonly CHECKPOINT = 155;
      static readonly CLASS = 156;
      static readonly CLOSE = 157;
      static readonly CLUSTER = 158;
      static readonly COMMENT = 159;
      static readonly COMMENTS = 160;
      static readonly COMMIT = 161;
      static readonly COMMITTED = 162;
      static readonly CONFIGURATION = 163;
      static readonly CONNECTION = 164;
      static readonly CONSTRAINTS = 165;
      static readonly CONTENT_P = 166;
      static readonly CONTINUE_P = 167;
      static readonly CONVERSION_P = 168;
      static readonly COPY = 169;
      static readonly COST = 170;
      static readonly CSV = 171;
      static readonly CURSOR = 172;
      static readonly CYCLE = 173;
      static readonly DATA_P = 174;
      static readonly DATABASE = 175;
      static readonly DAY_P = 176;
      static readonly DEALLOCATE = 177;
      static readonly DECLARE = 178;
      static readonly DEFAULTS = 179;
      static readonly DEFERRED = 180;
      static readonly DEFINER = 181;
      static readonly DELETE_P = 182;
      static readonly DELIMITER = 183;
      static readonly DELIMITERS = 184;
      static readonly DICTIONARY = 185;
      static readonly DISABLE_P = 186;
      static readonly DISCARD = 187;
      static readonly DOCUMENT_P = 188;
      static readonly DOMAIN_P = 189;
      static readonly DOUBLE_P = 190;
      static readonly DROP = 191;
      static readonly EACH = 192;
      static readonly ENABLE_P = 193;
      static readonly ENCODING = 194;
      static readonly ENCRYPTED = 195;
      static readonly ENUM_P = 196;
      static readonly ESCAPE = 197;
      static readonly EVENT = 198;
      static readonly EXCLUDE = 199;
      static readonly EXCLUDING = 200;
      static readonly EXCLUSIVE = 201;
      static readonly EXECUTE = 202;
      static readonly EXPLAIN = 203;
      static readonly EXTENSION = 204;
      static readonly EXTERNAL = 205;
      static readonly FAMILY = 206;
      static readonly FIRST_P = 207;
      static readonly FOLLOWING = 208;
      static readonly FORCE = 209;
      static readonly FORWARD = 210;
      static readonly FUNCTION = 211;
      static readonly FUNCTIONS = 212;
      static readonly GLOBAL = 213;
      static readonly GRANTED = 214;
      static readonly HANDLER = 215;
      static readonly HEADER_P = 216;
      static readonly HOLD = 217;
      static readonly HOUR_P = 218;
      static readonly IDENTITY_P = 219;
      static readonly IF_P = 220;
      static readonly IMMEDIATE = 221;
      static readonly IMMUTABLE = 222;
      static readonly IMPLICIT_P = 223;
      static readonly INCLUDING = 224;
      static readonly INCREMENT = 225;
      static readonly INDEX = 226;
      static readonly INDEXES = 227;
      static readonly INHERIT = 228;
      static readonly INHERITS = 229;
      static readonly INLINE_P = 230;
      static readonly INSENSITIVE = 231;
      static readonly INSERT = 232;
      static readonly INSTEAD = 233;
      static readonly INVOKER = 234;
      static readonly ISOLATION = 235;
      static readonly KEY = 236;
      static readonly LABEL = 237;
      static readonly LANGUAGE = 238;
      static readonly LARGE_P = 239;
      static readonly LAST_P = 240;
      static readonly LEAKPROOF = 241;
      static readonly LEVEL = 242;
      static readonly LISTEN = 243;
      static readonly LOAD = 244;
      static readonly LOCAL = 245;
      static readonly LOCATION = 246;
      static readonly LOCK_P = 247;
      static readonly MAPPING = 248;
      static readonly MATCH = 249;
      static readonly MATCHED = 250;
      static readonly MATERIALIZED = 251;
      static readonly MAXVALUE = 252;
      static readonly MERGE = 253;
      static readonly MINUTE_P = 254;
      static readonly MINVALUE = 255;
      static readonly MODE = 256;
      static readonly MONTH_P = 257;
      static readonly MOVE = 258;
      static readonly NAME_P = 259;
      static readonly NAMES = 260;
      static readonly NEXT = 261;
      static readonly NO = 262;
      static readonly NOTHING = 263;
      static readonly NOTIFY = 264;
      static readonly NOWAIT = 265;
      static readonly NULLS_P = 266;
      static readonly OBJECT_P = 267;
      static readonly OF = 268;
      static readonly OFF = 269;
      static readonly OIDS = 270;
      static readonly OPERATOR = 271;
      static readonly OPTION = 272;
      static readonly OPTIONS = 273;
      static readonly OWNED = 274;
      static readonly OWNER = 275;
      static readonly PARSER = 276;
      static readonly PARTIAL = 277;
      static readonly PARTITION = 278;
      static readonly PASSING = 279;
      static readonly PASSWORD = 280;
      static readonly PLANS = 281;
      static readonly PRECEDING = 282;
      static readonly PREPARE = 283;
      static readonly PREPARED = 284;
      static readonly PRESERVE = 285;
      static readonly PRIOR = 286;
      static readonly PRIVILEGES = 287;
      static readonly PROCEDURAL = 288;
      static readonly PROCEDURE = 289;
      static readonly PROGRAM = 290;
      static readonly QUOTE = 291;
      static readonly RANGE = 292;
      static readonly READ = 293;
      static readonly REASSIGN = 294;
      static readonly RECHECK = 295;
      static readonly RECURSIVE = 296;
      static readonly REF = 297;
      static readonly REFRESH = 298;
      static readonly REINDEX = 299;
      static readonly RELATIVE_P = 300;
      static readonly RELEASE = 301;
      static readonly RENAME = 302;
      static readonly REPEATABLE = 303;
      static readonly REPLACE = 304;
      static readonly REPLICA = 305;
      static readonly RESET = 306;
      static readonly RESTART = 307;
      static readonly RESTRICT = 308;
      static readonly RETURNS = 309;
      static readonly REVOKE = 310;
      static readonly ROLE = 311;
      static readonly ROLLBACK = 312;
      static readonly ROWS = 313;
      static readonly RULE = 314;
      static readonly SAVEPOINT = 315;
      static readonly SCHEMA = 316;
      static readonly SCROLL = 317;
      static readonly SEARCH = 318;
      static readonly SECOND_P = 319;
      static readonly SECURITY = 320;
      static readonly SEQUENCE = 321;
      static readonly SEQUENCES = 322;
      static readonly SERIALIZABLE = 323;
      static readonly SERVER = 324;
      static readonly SESSION = 325;
      static readonly SET = 326;
      static readonly SHARE = 327;
      static readonly SHOW = 328;
      static readonly SIMPLE = 329;
      static readonly SNAPSHOT = 330;
      static readonly STABLE = 331;
      static readonly STANDALONE_P = 332;
      static readonly START = 333;
      static readonly STATEMENT = 334;
      static readonly STATISTICS = 335;
      static readonly STDIN = 336;
      static readonly STDOUT = 337;
      static readonly STORAGE = 338;
      static readonly STRICT_P = 339;
      static readonly STRIP_P = 340;
      static readonly SYSID = 341;
      static readonly SYSTEM_P = 342;
      static readonly TABLES = 343;
      static readonly TABLESPACE = 344;
      static readonly TEMP = 345;
      static readonly TEMPLATE = 346;
      static readonly TEMPORARY = 347;
      static readonly TEXT_P = 348;
      static readonly TRANSACTION = 349;
      static readonly TRIGGER = 350;
      static readonly TRUNCATE = 351;
      static readonly TRUSTED = 352;
      static readonly TYPE_P = 353;
      static readonly TYPES_P = 354;
      static readonly UNBOUNDED = 355;
      static readonly UNCOMMITTED = 356;
      static readonly UNENCRYPTED = 357;
      static readonly UNKNOWN = 358;
      static readonly UNLISTEN = 359;
      static readonly UNLOGGED = 360;
      static readonly UNTIL = 361;
      static readonly UPDATE = 362;
      static readonly VACUUM = 363;
      static readonly VALID = 364;
      static readonly VALIDATE = 365;
      static readonly VALIDATOR = 366;
      static readonly VARYING = 367;
      static readonly VERSION_P = 368;
      static readonly VIEW = 369;
      static readonly VOLATILE = 370;
      static readonly WHITESPACE_P = 371;
      static readonly WITHOUT = 372;
      static readonly WORK = 373;
      static readonly WRAPPER = 374;
      static readonly WRITE = 375;
      static readonly XML_P = 376;
      static readonly YEAR_P = 377;
      static readonly YES_P = 378;
      static readonly ZONE = 379;
      static readonly BETWEEN = 380;
      static readonly BIGINT = 381;
      static readonly BIT = 382;
      static readonly BOOLEAN_P = 383;
      static readonly CHAR_P = 384;
      static readonly CHARACTER = 385;
      static readonly COALESCE = 386;
      static readonly DEC = 387;
      static readonly DECIMAL_P = 388;
      static readonly EXISTS = 389;
      static readonly EXTRACT = 390;
      static readonly FLOAT_P = 391;
      static readonly GREATEST = 392;
      static readonly INOUT = 393;
      static readonly INT_P = 394;
      static readonly INTEGER = 395;
      static readonly INTERVAL = 396;
      static readonly LEAST = 397;
      static readonly NATIONAL = 398;
      static readonly NCHAR = 399;
      static readonly NONE = 400;
      static readonly NULLIF = 401;
      static readonly NUMERIC = 402;
      static readonly OVERLAY = 403;
      static readonly POSITION = 404;
      static readonly PRECISION = 405;
      static readonly REAL = 406;
      static readonly ROW = 407;
      static readonly SETOF = 408;
      static readonly SMALLINT = 409;
      static readonly SUBSTRING = 410;
      static readonly TIME = 411;
      static readonly TIMESTAMP = 412;
      static readonly TREAT = 413;
      static readonly TRIM = 414;
      static readonly VALUES = 415;
      static readonly VARCHAR = 416;
      static readonly XMLATTRIBUTES = 417;
      static readonly XMLCOMMENT = 418;
      static readonly XMLAGG = 419;
      static readonly XML_IS_WELL_FORMED = 420;
      static readonly XML_IS_WELL_FORMED_DOCUMENT = 421;
      static readonly XML_IS_WELL_FORMED_CONTENT = 422;
      static readonly XPATH = 423;
      static readonly XPATH_EXISTS = 424;
      static readonly XMLCONCAT = 425;
      static readonly XMLELEMENT = 426;
      static readonly XMLEXISTS = 427;
      static readonly XMLFOREST = 428;
      static readonly XMLPARSE = 429;
      static readonly XMLPI = 430;
      static readonly XMLROOT = 431;
      static readonly XMLSERIALIZE = 432;
      static readonly CALL = 433;
      static readonly CURRENT_P = 434;
      static readonly ATTACH = 435;
      static readonly DETACH = 436;
      static readonly EXPRESSION = 437;
      static readonly GENERATED = 438;
      static readonly LOGGED = 439;
      static readonly STORED = 440;
      static readonly INCLUDE = 441;
      static readonly ROUTINE = 442;
      static readonly TRANSFORM = 443;
      static readonly IMPORT_P = 444;
      static readonly POLICY = 445;
      static readonly METHOD = 446;
      static readonly REFERENCING = 447;
      static readonly NEW = 448;
      static readonly OLD = 449;
      static readonly VALUE_P = 450;
      static readonly SUBSCRIPTION = 451;
      static readonly PUBLICATION = 452;
      static readonly OUT_P = 453;
      static readonly END_P = 454;
      static readonly ROUTINES = 455;
      static readonly SCHEMAS = 456;
      static readonly PROCEDURES = 457;
      static readonly INPUT_P = 458;
      static readonly SUPPORT = 459;
      static readonly PARALLEL = 460;
      static readonly SQL_P = 461;
      static readonly DEPENDS = 462;
      static readonly OVERRIDING = 463;
      static readonly CONFLICT = 464;
      static readonly SKIP_P = 465;
      static readonly LOCKED = 466;
      static readonly TIES = 467;
      static readonly ROLLUP = 468;
      static readonly CUBE = 469;
      static readonly GROUPING = 470;
      static readonly SETS = 471;
      static readonly TABLESAMPLE = 472;
      static readonly ORDINALITY = 473;
      static readonly XMLTABLE = 474;
      static readonly COLUMNS = 475;
      static readonly XMLNAMESPACES = 476;
      static readonly ROWTYPE = 477;
      static readonly NORMALIZED = 478;
      static readonly WITHIN = 479;
      static readonly FILTER = 480;
      static readonly GROUPS = 481;
      static readonly OTHERS = 482;
      static readonly NFC = 483;
      static readonly NFD = 484;
      static readonly NFKC = 485;
      static readonly NFKD = 486;
      static readonly UESCAPE = 487;
      static readonly VIEWS = 488;
      static readonly NORMALIZE = 489;
      static readonly DUMP = 490;
      static readonly PRINT_STRICT_PARAMS = 491;
      static readonly VARIABLE_CONFLICT = 492;
      static readonly ERROR = 493;
      static readonly USE_VARIABLE = 494;
      static readonly USE_COLUMN = 495;
      static readonly ALIAS = 496;
      static readonly CONSTANT = 497;
      static readonly PERFORM = 498;
      static readonly GET = 499;
      static readonly DIAGNOSTICS = 500;
      static readonly STACKED = 501;
      static readonly ELSIF = 502;
      static readonly WHILE = 503;
      static readonly REVERSE = 504;
      static readonly FOREACH = 505;
      static readonly SLICE = 506;
      static readonly EXIT = 507;
      static readonly RETURN = 508;
      static readonly QUERY = 509;
      static readonly RAISE = 510;
      static readonly SQLSTATE = 511;
      static readonly DEBUG = 512;
      static readonly LOG = 513;
      static readonly INFO = 514;
      static readonly NOTICE = 515;
      static readonly WARNING = 516;
      static readonly EXCEPTION = 517;
      static readonly ASSERT = 518;
      static readonly LOOP = 519;
      static readonly OPEN = 520;
      static readonly ABS = 521;
      static readonly CBRT = 522;
      static readonly CEIL = 523;
      static readonly CEILING = 524;
      static readonly DEGREES = 525;
      static readonly DIV = 526;
      static readonly EXP = 527;
      static readonly FACTORIAL = 528;
      static readonly FLOOR = 529;
      static readonly GCD = 530;
      static readonly LCM = 531;
      static readonly LN = 532;
      static readonly LOG10 = 533;
      static readonly MIN_SCALE = 534;
      static readonly MOD = 535;
      static readonly PI = 536;
      static readonly POWER = 537;
      static readonly RADIANS = 538;
      static readonly ROUND = 539;
      static readonly SCALE = 540;
      static readonly SIGN = 541;
      static readonly SQRT = 542;
      static readonly TRIM_SCALE = 543;
      static readonly TRUNC = 544;
      static readonly WIDTH_BUCKET = 545;
      static readonly RANDOM = 546;
      static readonly SETSEED = 547;
      static readonly ACOS = 548;
      static readonly ACOSD = 549;
      static readonly ASIN = 550;
      static readonly ASIND = 551;
      static readonly ATAN = 552;
      static readonly ATAND = 553;
      static readonly ATAN2 = 554;
      static readonly ATAN2D = 555;
      static readonly COS = 556;
      static readonly COSD = 557;
      static readonly COT = 558;
      static readonly COTD = 559;
      static readonly SIN = 560;
      static readonly SIND = 561;
      static readonly TAN = 562;
      static readonly TAND = 563;
      static readonly SINH = 564;
      static readonly COSH = 565;
      static readonly TANH = 566;
      static readonly ASINH = 567;
      static readonly ACOSH = 568;
      static readonly ATANH = 569;
      static readonly BIT_LENGTH = 570;
      static readonly CHAR_LENGTH = 571;
      static readonly CHARACTER_LENGTH = 572;
      static readonly LOWER = 573;
      static readonly OCTET_LENGTH = 574;
      static readonly UPPER = 575;
      static readonly ASCII = 576;
      static readonly BTRIM = 577;
      static readonly CHR = 578;
      static readonly CONCAT = 579;
      static readonly CONCAT_WS = 580;
      static readonly FORMAT = 581;
      static readonly INITCAP = 582;
      static readonly LENGTH = 583;
      static readonly LPAD = 584;
      static readonly LTRIM = 585;
      static readonly MD5 = 586;
      static readonly PARSE_IDENT = 587;
      static readonly PG_CLIENT_ENCODING = 588;
      static readonly QUOTE_IDENT = 589;
      static readonly QUOTE_LITERAL = 590;
      static readonly QUOTE_NULLABLE = 591;
      static readonly REGEXP_COUNT = 592;
      static readonly REGEXP_INSTR = 593;
      static readonly REGEXP_LIKE = 594;
      static readonly REGEXP_MATCH = 595;
      static readonly REGEXP_MATCHES = 596;
      static readonly REGEXP_REPLACE = 597;
      static readonly REGEXP_SPLIT_TO_ARRAY = 598;
      static readonly REGEXP_SPLIT_TO_TABLE = 599;
      static readonly REGEXP_SUBSTR = 600;
      static readonly REPEAT = 601;
      static readonly RPAD = 602;
      static readonly RTRIM = 603;
      static readonly SPLIT_PART = 604;
      static readonly STARTS_WITH = 605;
      static readonly STRING_TO_ARRAY = 606;
      static readonly STRING_TO_TABLE = 607;
      static readonly STRPOS = 608;
      static readonly SUBSTR = 609;
      static readonly TO_ASCII = 610;
      static readonly TO_HEX = 611;
      static readonly TRANSLATE = 612;
      static readonly UNISTR = 613;
      static readonly AGE = 614;
      static readonly CLOCK_TIMESTAMP = 615;
      static readonly DATE_BIN = 616;
      static readonly DATE_PART = 617;
      static readonly DATE_TRUNC = 618;
      static readonly ISFINITE = 619;
      static readonly JUSTIFY_DAYS = 620;
      static readonly JUSTIFY_HOURS = 621;
      static readonly JUSTIFY_INTERVAL = 622;
      static readonly MAKE_DATE = 623;
      static readonly MAKE_INTERVAL = 624;
      static readonly MAKE_TIME = 625;
      static readonly MAKE_TIMESTAMP = 626;
      static readonly MAKE_TIMESTAMPTZ = 627;
      static readonly NOW = 628;
      static readonly STATEMENT_TIMESTAMP = 629;
      static readonly TIMEOFDAY = 630;
      static readonly TRANSACTION_TIMESTAMP = 631;
      static readonly TO_TIMESTAMP = 632;
      static readonly TO_CHAR = 633;
      static readonly TO_DATE = 634;
      static readonly TO_NUMBER = 635;
      static readonly Identifier = 636;
      static readonly QuotedIdentifier = 637;
      static readonly UnterminatedQuotedIdentifier = 638;
      static readonly InvalidQuotedIdentifier = 639;
      static readonly InvalidUnterminatedQuotedIdentifier = 640;
      static readonly UnicodeQuotedIdentifier = 641;
      static readonly UnterminatedUnicodeQuotedIdentifier = 642;
      static readonly InvalidUnicodeQuotedIdentifier = 643;
      static readonly InvalidUnterminatedUnicodeQuotedIdentifier = 644;
      static readonly StringConstant = 645;
      static readonly UnterminatedStringConstant = 646;
      static readonly UnicodeEscapeStringConstant = 647;
      static readonly UnterminatedUnicodeEscapeStringConstant = 648;
      static readonly BeginDollarStringConstant = 649;
      static readonly BinaryStringConstant = 650;
      static readonly UnterminatedBinaryStringConstant = 651;
      static readonly InvalidBinaryStringConstant = 652;
      static readonly InvalidUnterminatedBinaryStringConstant = 653;
      static readonly HexadecimalStringConstant = 654;
      static readonly UnterminatedHexadecimalStringConstant = 655;
      static readonly InvalidHexadecimalStringConstant = 656;
      static readonly InvalidUnterminatedHexadecimalStringConstant = 657;
      static readonly Integral = 658;
      static readonly NumericFail = 659;
      static readonly Numeric = 660;
      static readonly PLSQLVARIABLENAME = 661;
      static readonly PLSQLIDENTIFIER = 662;
      static readonly Whitespace = 663;
      static readonly Newline = 664;
      static readonly LineComment = 665;
      static readonly BlockComment = 666;
      static readonly UnterminatedBlockComment = 667;
      static readonly MetaCommand = 668;
      static readonly EndMetaCommand = 669;
      static readonly ErrorCharacter = 670;
      static readonly EscapeStringConstant = 671;
      static readonly UnterminatedEscapeStringConstant = 672;
      static readonly InvalidEscapeStringConstant = 673;
      static readonly InvalidUnterminatedEscapeStringConstant = 674;
      static readonly AfterEscapeStringConstantMode_NotContinued = 675;
      static readonly AfterEscapeStringConstantWithNewlineMode_NotContinued = 676;
      static readonly DollarText = 677;
      static readonly EndDollarStringConstant = 678;
      static readonly AfterEscapeStringConstantWithNewlineMode_Continued = 679;
      static readonly RULE_root = 0;
      static readonly RULE_plsqlroot = 1;
      static readonly RULE_stmtblock = 2;
      static readonly RULE_stmtmulti = 3;
      static readonly RULE_stmt = 4;
      static readonly RULE_plsqlconsolecommand = 5;
      static readonly RULE_callstmt = 6;
      static readonly RULE_createrolestmt = 7;
      static readonly RULE_opt_with = 8;
      static readonly RULE_optrolelist = 9;
      static readonly RULE_alteroptrolelist = 10;
      static readonly RULE_alteroptroleelem = 11;
      static readonly RULE_createoptroleelem = 12;
      static readonly RULE_createuserstmt = 13;
      static readonly RULE_alterrolestmt = 14;
      static readonly RULE_opt_in_database = 15;
      static readonly RULE_alterrolesetstmt = 16;
      static readonly RULE_droprolestmt = 17;
      static readonly RULE_creategroupstmt = 18;
      static readonly RULE_altergroupstmt = 19;
      static readonly RULE_add_drop = 20;
      static readonly RULE_createschemastmt = 21;
      static readonly RULE_optschemaname = 22;
      static readonly RULE_optschemaeltlist = 23;
      static readonly RULE_schema_stmt = 24;
      static readonly RULE_variablesetstmt = 25;
      static readonly RULE_set_rest = 26;
      static readonly RULE_generic_set = 27;
      static readonly RULE_set_rest_more = 28;
      static readonly RULE_var_name = 29;
      static readonly RULE_var_list = 30;
      static readonly RULE_var_value = 31;
      static readonly RULE_iso_level = 32;
      static readonly RULE_opt_boolean_or_string = 33;
      static readonly RULE_zone_value = 34;
      static readonly RULE_opt_encoding = 35;
      static readonly RULE_nonreservedword_or_sconst = 36;
      static readonly RULE_variableresetstmt = 37;
      static readonly RULE_reset_rest = 38;
      static readonly RULE_generic_reset = 39;
      static readonly RULE_setresetclause = 40;
      static readonly RULE_functionsetresetclause = 41;
      static readonly RULE_variableshowstmt = 42;
      static readonly RULE_constraintssetstmt = 43;
      static readonly RULE_constraints_set_list = 44;
      static readonly RULE_constraints_set_mode = 45;
      static readonly RULE_checkpointstmt = 46;
      static readonly RULE_discardstmt = 47;
      static readonly RULE_altertablestmt = 48;
      static readonly RULE_alter_table_cmds = 49;
      static readonly RULE_partition_cmd = 50;
      static readonly RULE_index_partition_cmd = 51;
      static readonly RULE_alter_table_cmd = 52;
      static readonly RULE_alter_column_default = 53;
      static readonly RULE_opt_drop_behavior = 54;
      static readonly RULE_opt_collate_clause = 55;
      static readonly RULE_alter_using = 56;
      static readonly RULE_replica_identity = 57;
      static readonly RULE_reloptions = 58;
      static readonly RULE_opt_reloptions = 59;
      static readonly RULE_reloption_list = 60;
      static readonly RULE_reloption_elem = 61;
      static readonly RULE_alter_identity_column_option_list = 62;
      static readonly RULE_alter_identity_column_option = 63;
      static readonly RULE_partitionboundspec = 64;
      static readonly RULE_hash_partbound_elem = 65;
      static readonly RULE_hash_partbound = 66;
      static readonly RULE_altercompositetypestmt = 67;
      static readonly RULE_alter_type_cmds = 68;
      static readonly RULE_alter_type_cmd = 69;
      static readonly RULE_closeportalstmt = 70;
      static readonly RULE_copystmt = 71;
      static readonly RULE_copy_from = 72;
      static readonly RULE_opt_program = 73;
      static readonly RULE_copy_file_name = 74;
      static readonly RULE_copy_options = 75;
      static readonly RULE_copy_opt_list = 76;
      static readonly RULE_copy_opt_item = 77;
      static readonly RULE_opt_binary = 78;
      static readonly RULE_copy_delimiter = 79;
      static readonly RULE_opt_using = 80;
      static readonly RULE_copy_generic_opt_list = 81;
      static readonly RULE_copy_generic_opt_elem = 82;
      static readonly RULE_copy_generic_opt_arg = 83;
      static readonly RULE_copy_generic_opt_arg_list = 84;
      static readonly RULE_copy_generic_opt_arg_list_item = 85;
      static readonly RULE_createstmt = 86;
      static readonly RULE_opttemp = 87;
      static readonly RULE_opttableelementlist = 88;
      static readonly RULE_opttypedtableelementlist = 89;
      static readonly RULE_tableelementlist = 90;
      static readonly RULE_typedtableelementlist = 91;
      static readonly RULE_tableelement = 92;
      static readonly RULE_typedtableelement = 93;
      static readonly RULE_columnDef = 94;
      static readonly RULE_columnOptions = 95;
      static readonly RULE_colquallist = 96;
      static readonly RULE_colconstraint = 97;
      static readonly RULE_colconstraintelem = 98;
      static readonly RULE_generated_when = 99;
      static readonly RULE_constraintattr = 100;
      static readonly RULE_tablelikeclause = 101;
      static readonly RULE_tablelikeoptionlist = 102;
      static readonly RULE_tablelikeoption = 103;
      static readonly RULE_tableconstraint = 104;
      static readonly RULE_constraintelem = 105;
      static readonly RULE_opt_no_inherit = 106;
      static readonly RULE_opt_column_list = 107;
      static readonly RULE_columnlist = 108;
      static readonly RULE_columnElem = 109;
      static readonly RULE_opt_c_include = 110;
      static readonly RULE_key_match = 111;
      static readonly RULE_exclusionconstraintlist = 112;
      static readonly RULE_exclusionconstraintelem = 113;
      static readonly RULE_exclusionwhereclause = 114;
      static readonly RULE_key_actions = 115;
      static readonly RULE_key_update = 116;
      static readonly RULE_key_delete = 117;
      static readonly RULE_key_action = 118;
      static readonly RULE_optinherit = 119;
      static readonly RULE_optpartitionspec = 120;
      static readonly RULE_partitionspec = 121;
      static readonly RULE_part_params = 122;
      static readonly RULE_part_elem = 123;
      static readonly RULE_table_access_method_clause = 124;
      static readonly RULE_optwith = 125;
      static readonly RULE_oncommitoption = 126;
      static readonly RULE_opttablespace = 127;
      static readonly RULE_optconstablespace = 128;
      static readonly RULE_existingindex = 129;
      static readonly RULE_createstatsstmt = 130;
      static readonly RULE_alterstatsstmt = 131;
      static readonly RULE_createasstmt = 132;
      static readonly RULE_create_as_target = 133;
      static readonly RULE_opt_with_data = 134;
      static readonly RULE_creatematviewstmt = 135;
      static readonly RULE_create_mv_target = 136;
      static readonly RULE_optnolog = 137;
      static readonly RULE_refreshmatviewstmt = 138;
      static readonly RULE_createseqstmt = 139;
      static readonly RULE_alterseqstmt = 140;
      static readonly RULE_optseqoptlist = 141;
      static readonly RULE_optparenthesizedseqoptlist = 142;
      static readonly RULE_seqoptlist = 143;
      static readonly RULE_seqoptelem = 144;
      static readonly RULE_opt_by = 145;
      static readonly RULE_numericonly = 146;
      static readonly RULE_numericonly_list = 147;
      static readonly RULE_createplangstmt = 148;
      static readonly RULE_opt_trusted = 149;
      static readonly RULE_handler_name = 150;
      static readonly RULE_opt_inline_handler = 151;
      static readonly RULE_validator_clause = 152;
      static readonly RULE_opt_validator = 153;
      static readonly RULE_opt_procedural = 154;
      static readonly RULE_createtablespacestmt = 155;
      static readonly RULE_opttablespaceowner = 156;
      static readonly RULE_droptablespacestmt = 157;
      static readonly RULE_createextensionstmt = 158;
      static readonly RULE_create_extension_opt_list = 159;
      static readonly RULE_create_extension_opt_item = 160;
      static readonly RULE_alterextensionstmt = 161;
      static readonly RULE_alter_extension_opt_list = 162;
      static readonly RULE_alter_extension_opt_item = 163;
      static readonly RULE_alterextensioncontentsstmt = 164;
      static readonly RULE_createfdwstmt = 165;
      static readonly RULE_fdw_option = 166;
      static readonly RULE_fdw_options = 167;
      static readonly RULE_opt_fdw_options = 168;
      static readonly RULE_alterfdwstmt = 169;
      static readonly RULE_create_generic_options = 170;
      static readonly RULE_generic_option_list = 171;
      static readonly RULE_alter_generic_options = 172;
      static readonly RULE_alter_generic_option_list = 173;
      static readonly RULE_alter_generic_option_elem = 174;
      static readonly RULE_generic_option_elem = 175;
      static readonly RULE_generic_option_name = 176;
      static readonly RULE_generic_option_arg = 177;
      static readonly RULE_createforeignserverstmt = 178;
      static readonly RULE_opt_type = 179;
      static readonly RULE_foreign_server_version = 180;
      static readonly RULE_opt_foreign_server_version = 181;
      static readonly RULE_alterforeignserverstmt = 182;
      static readonly RULE_createforeigntablestmt = 183;
      static readonly RULE_importforeignschemastmt = 184;
      static readonly RULE_import_qualification_type = 185;
      static readonly RULE_import_qualification = 186;
      static readonly RULE_createusermappingstmt = 187;
      static readonly RULE_auth_ident = 188;
      static readonly RULE_dropusermappingstmt = 189;
      static readonly RULE_alterusermappingstmt = 190;
      static readonly RULE_createpolicystmt = 191;
      static readonly RULE_alterpolicystmt = 192;
      static readonly RULE_rowsecurityoptionalexpr = 193;
      static readonly RULE_rowsecurityoptionalwithcheck = 194;
      static readonly RULE_rowsecuritydefaulttorole = 195;
      static readonly RULE_rowsecurityoptionaltorole = 196;
      static readonly RULE_rowsecuritydefaultpermissive = 197;
      static readonly RULE_rowsecuritydefaultforcmd = 198;
      static readonly RULE_row_security_cmd = 199;
      static readonly RULE_createamstmt = 200;
      static readonly RULE_am_type = 201;
      static readonly RULE_createtrigstmt = 202;
      static readonly RULE_triggeractiontime = 203;
      static readonly RULE_triggerevents = 204;
      static readonly RULE_triggeroneevent = 205;
      static readonly RULE_triggerreferencing = 206;
      static readonly RULE_triggertransitions = 207;
      static readonly RULE_triggertransition = 208;
      static readonly RULE_transitionoldornew = 209;
      static readonly RULE_transitionrowortable = 210;
      static readonly RULE_transitionrelname = 211;
      static readonly RULE_triggerforspec = 212;
      static readonly RULE_triggerforopteach = 213;
      static readonly RULE_triggerfortype = 214;
      static readonly RULE_triggerwhen = 215;
      static readonly RULE_function_or_procedure = 216;
      static readonly RULE_triggerfuncargs = 217;
      static readonly RULE_triggerfuncarg = 218;
      static readonly RULE_optconstrfromtable = 219;
      static readonly RULE_constraintattributespec = 220;
      static readonly RULE_constraintattributeElem = 221;
      static readonly RULE_createeventtrigstmt = 222;
      static readonly RULE_event_trigger_when_list = 223;
      static readonly RULE_event_trigger_when_item = 224;
      static readonly RULE_event_trigger_value_list = 225;
      static readonly RULE_altereventtrigstmt = 226;
      static readonly RULE_enable_trigger = 227;
      static readonly RULE_createassertionstmt = 228;
      static readonly RULE_definestmt = 229;
      static readonly RULE_definition = 230;
      static readonly RULE_def_list = 231;
      static readonly RULE_def_elem = 232;
      static readonly RULE_def_arg = 233;
      static readonly RULE_old_aggr_definition = 234;
      static readonly RULE_old_aggr_list = 235;
      static readonly RULE_old_aggr_elem = 236;
      static readonly RULE_opt_enum_val_list = 237;
      static readonly RULE_enum_val_list = 238;
      static readonly RULE_alterenumstmt = 239;
      static readonly RULE_opt_if_not_exists = 240;
      static readonly RULE_createopclassstmt = 241;
      static readonly RULE_opclass_item_list = 242;
      static readonly RULE_opclass_item = 243;
      static readonly RULE_opt_default = 244;
      static readonly RULE_opt_opfamily = 245;
      static readonly RULE_opclass_purpose = 246;
      static readonly RULE_opt_recheck = 247;
      static readonly RULE_createopfamilystmt = 248;
      static readonly RULE_alteropfamilystmt = 249;
      static readonly RULE_opclass_drop_list = 250;
      static readonly RULE_opclass_drop = 251;
      static readonly RULE_dropopclassstmt = 252;
      static readonly RULE_dropopfamilystmt = 253;
      static readonly RULE_dropownedstmt = 254;
      static readonly RULE_reassignownedstmt = 255;
      static readonly RULE_dropstmt = 256;
      static readonly RULE_object_type_any_name = 257;
      static readonly RULE_object_type_name = 258;
      static readonly RULE_drop_type_name = 259;
      static readonly RULE_object_type_name_on_any_name = 260;
      static readonly RULE_any_name_list = 261;
      static readonly RULE_any_name = 262;
      static readonly RULE_attrs = 263;
      static readonly RULE_type_name_list = 264;
      static readonly RULE_truncatestmt = 265;
      static readonly RULE_opt_restart_seqs = 266;
      static readonly RULE_commentstmt = 267;
      static readonly RULE_comment_text = 268;
      static readonly RULE_seclabelstmt = 269;
      static readonly RULE_opt_provider = 270;
      static readonly RULE_security_label = 271;
      static readonly RULE_fetchstmt = 272;
      static readonly RULE_fetch_args = 273;
      static readonly RULE_from_in = 274;
      static readonly RULE_opt_from_in = 275;
      static readonly RULE_grantstmt = 276;
      static readonly RULE_revokestmt = 277;
      static readonly RULE_privileges = 278;
      static readonly RULE_privilege_list = 279;
      static readonly RULE_privilege = 280;
      static readonly RULE_privilege_target = 281;
      static readonly RULE_grantee_list = 282;
      static readonly RULE_grantee = 283;
      static readonly RULE_opt_grant_grant_option = 284;
      static readonly RULE_grantrolestmt = 285;
      static readonly RULE_revokerolestmt = 286;
      static readonly RULE_opt_grant_admin_option = 287;
      static readonly RULE_opt_granted_by = 288;
      static readonly RULE_alterdefaultprivilegesstmt = 289;
      static readonly RULE_defacloptionlist = 290;
      static readonly RULE_defacloption = 291;
      static readonly RULE_defaclaction = 292;
      static readonly RULE_defacl_privilege_target = 293;
      static readonly RULE_indexstmt = 294;
      static readonly RULE_opt_unique = 295;
      static readonly RULE_opt_concurrently = 296;
      static readonly RULE_opt_index_name = 297;
      static readonly RULE_access_method_clause = 298;
      static readonly RULE_index_params = 299;
      static readonly RULE_index_elem_options = 300;
      static readonly RULE_index_elem = 301;
      static readonly RULE_opt_include = 302;
      static readonly RULE_index_including_params = 303;
      static readonly RULE_opt_collate = 304;
      static readonly RULE_opt_class = 305;
      static readonly RULE_opt_asc_desc = 306;
      static readonly RULE_opt_nulls_order = 307;
      static readonly RULE_createfunctionstmt = 308;
      static readonly RULE_opt_or_replace = 309;
      static readonly RULE_func_args = 310;
      static readonly RULE_func_args_list = 311;
      static readonly RULE_function_with_argtypes_list = 312;
      static readonly RULE_function_with_argtypes = 313;
      static readonly RULE_func_args_with_defaults = 314;
      static readonly RULE_func_args_with_defaults_list = 315;
      static readonly RULE_func_arg = 316;
      static readonly RULE_arg_class = 317;
      static readonly RULE_param_name = 318;
      static readonly RULE_func_return = 319;
      static readonly RULE_func_type = 320;
      static readonly RULE_func_arg_with_default = 321;
      static readonly RULE_aggr_arg = 322;
      static readonly RULE_aggr_args = 323;
      static readonly RULE_aggr_args_list = 324;
      static readonly RULE_aggregate_with_argtypes = 325;
      static readonly RULE_aggregate_with_argtypes_list = 326;
      static readonly RULE_createfunc_opt_list = 327;
      static readonly RULE_common_func_opt_item = 328;
      static readonly RULE_createfunc_opt_item = 329;
      static readonly RULE_func_as = 330;
      static readonly RULE_transform_type_list = 331;
      static readonly RULE_opt_definition = 332;
      static readonly RULE_table_func_column = 333;
      static readonly RULE_table_func_column_list = 334;
      static readonly RULE_alterfunctionstmt = 335;
      static readonly RULE_alterfunc_opt_list = 336;
      static readonly RULE_opt_restrict = 337;
      static readonly RULE_removefuncstmt = 338;
      static readonly RULE_removeaggrstmt = 339;
      static readonly RULE_removeoperstmt = 340;
      static readonly RULE_oper_argtypes = 341;
      static readonly RULE_any_operator = 342;
      static readonly RULE_operator_with_argtypes_list = 343;
      static readonly RULE_operator_with_argtypes = 344;
      static readonly RULE_dostmt = 345;
      static readonly RULE_dostmt_opt_list = 346;
      static readonly RULE_dostmt_opt_item = 347;
      static readonly RULE_createcaststmt = 348;
      static readonly RULE_cast_context = 349;
      static readonly RULE_dropcaststmt = 350;
      static readonly RULE_opt_if_exists = 351;
      static readonly RULE_createtransformstmt = 352;
      static readonly RULE_transform_element_list = 353;
      static readonly RULE_droptransformstmt = 354;
      static readonly RULE_reindexstmt = 355;
      static readonly RULE_reindex_target_type = 356;
      static readonly RULE_reindex_target_multitable = 357;
      static readonly RULE_reindex_option_list = 358;
      static readonly RULE_reindex_option_elem = 359;
      static readonly RULE_altertblspcstmt = 360;
      static readonly RULE_renamestmt = 361;
      static readonly RULE_opt_column = 362;
      static readonly RULE_opt_set_data = 363;
      static readonly RULE_alterobjectdependsstmt = 364;
      static readonly RULE_opt_no = 365;
      static readonly RULE_alterobjectschemastmt = 366;
      static readonly RULE_alteroperatorstmt = 367;
      static readonly RULE_operator_def_list = 368;
      static readonly RULE_operator_def_elem = 369;
      static readonly RULE_operator_def_arg = 370;
      static readonly RULE_altertypestmt = 371;
      static readonly RULE_alterownerstmt = 372;
      static readonly RULE_createpublicationstmt = 373;
      static readonly RULE_opt_publication_for_tables = 374;
      static readonly RULE_publication_for_tables = 375;
      static readonly RULE_alterpublicationstmt = 376;
      static readonly RULE_createsubscriptionstmt = 377;
      static readonly RULE_publication_name_list = 378;
      static readonly RULE_publication_name_item = 379;
      static readonly RULE_altersubscriptionstmt = 380;
      static readonly RULE_dropsubscriptionstmt = 381;
      static readonly RULE_rulestmt = 382;
      static readonly RULE_ruleactionlist = 383;
      static readonly RULE_ruleactionmulti = 384;
      static readonly RULE_ruleactionstmt = 385;
      static readonly RULE_ruleactionstmtOrEmpty = 386;
      static readonly RULE_event = 387;
      static readonly RULE_opt_instead = 388;
      static readonly RULE_notifystmt = 389;
      static readonly RULE_notify_payload = 390;
      static readonly RULE_listenstmt = 391;
      static readonly RULE_unlistenstmt = 392;
      static readonly RULE_transactionstmt = 393;
      static readonly RULE_opt_transaction = 394;
      static readonly RULE_transaction_mode_item = 395;
      static readonly RULE_transaction_mode_list = 396;
      static readonly RULE_transaction_mode_list_or_empty = 397;
      static readonly RULE_opt_transaction_chain = 398;
      static readonly RULE_viewstmt = 399;
      static readonly RULE_opt_check_option = 400;
      static readonly RULE_loadstmt = 401;
      static readonly RULE_createdbstmt = 402;
      static readonly RULE_createdb_opt_list = 403;
      static readonly RULE_createdb_opt_items = 404;
      static readonly RULE_createdb_opt_item = 405;
      static readonly RULE_createdb_opt_name = 406;
      static readonly RULE_opt_equal = 407;
      static readonly RULE_alterdatabasestmt = 408;
      static readonly RULE_alterdatabasesetstmt = 409;
      static readonly RULE_dropdbstmt = 410;
      static readonly RULE_drop_option_list = 411;
      static readonly RULE_drop_option = 412;
      static readonly RULE_altercollationstmt = 413;
      static readonly RULE_altersystemstmt = 414;
      static readonly RULE_createdomainstmt = 415;
      static readonly RULE_alterdomainstmt = 416;
      static readonly RULE_opt_as = 417;
      static readonly RULE_altertsdictionarystmt = 418;
      static readonly RULE_altertsconfigurationstmt = 419;
      static readonly RULE_any_with = 420;
      static readonly RULE_createconversionstmt = 421;
      static readonly RULE_clusterstmt = 422;
      static readonly RULE_cluster_index_specification = 423;
      static readonly RULE_vacuumstmt = 424;
      static readonly RULE_analyzestmt = 425;
      static readonly RULE_vac_analyze_option_list = 426;
      static readonly RULE_analyze_keyword = 427;
      static readonly RULE_vac_analyze_option_elem = 428;
      static readonly RULE_vac_analyze_option_name = 429;
      static readonly RULE_vac_analyze_option_arg = 430;
      static readonly RULE_opt_analyze = 431;
      static readonly RULE_opt_verbose = 432;
      static readonly RULE_opt_full = 433;
      static readonly RULE_opt_freeze = 434;
      static readonly RULE_opt_name_list = 435;
      static readonly RULE_vacuum_relation = 436;
      static readonly RULE_vacuum_relation_list = 437;
      static readonly RULE_opt_vacuum_relation_list = 438;
      static readonly RULE_explainstmt = 439;
      static readonly RULE_explainablestmt = 440;
      static readonly RULE_explain_option_list = 441;
      static readonly RULE_explain_option_elem = 442;
      static readonly RULE_explain_option_name = 443;
      static readonly RULE_explain_option_arg = 444;
      static readonly RULE_preparestmt = 445;
      static readonly RULE_prep_type_clause = 446;
      static readonly RULE_preparablestmt = 447;
      static readonly RULE_executestmt = 448;
      static readonly RULE_execute_param_clause = 449;
      static readonly RULE_deallocatestmt = 450;
      static readonly RULE_insertstmt = 451;
      static readonly RULE_insert_target = 452;
      static readonly RULE_insert_rest = 453;
      static readonly RULE_override_kind = 454;
      static readonly RULE_insert_column_list = 455;
      static readonly RULE_insert_column_item = 456;
      static readonly RULE_opt_on_conflict = 457;
      static readonly RULE_opt_conf_expr = 458;
      static readonly RULE_returning_clause = 459;
      static readonly RULE_mergestmt = 460;
      static readonly RULE_merge_insert_clause = 461;
      static readonly RULE_merge_update_clause = 462;
      static readonly RULE_merge_delete_clause = 463;
      static readonly RULE_deletestmt = 464;
      static readonly RULE_using_clause = 465;
      static readonly RULE_lockstmt = 466;
      static readonly RULE_opt_lock = 467;
      static readonly RULE_lock_type = 468;
      static readonly RULE_opt_nowait = 469;
      static readonly RULE_opt_nowait_or_skip = 470;
      static readonly RULE_updatestmt = 471;
      static readonly RULE_set_clause_list = 472;
      static readonly RULE_set_clause = 473;
      static readonly RULE_set_target = 474;
      static readonly RULE_set_target_list = 475;
      static readonly RULE_declarecursorstmt = 476;
      static readonly RULE_cursor_name = 477;
      static readonly RULE_cursor_options = 478;
      static readonly RULE_opt_hold = 479;
      static readonly RULE_selectstmt = 480;
      static readonly RULE_select_with_parens = 481;
      static readonly RULE_select_no_parens = 482;
      static readonly RULE_select_clause = 483;
      static readonly RULE_simple_select_intersect = 484;
      static readonly RULE_simple_select_pramary = 485;
      static readonly RULE_with_clause = 486;
      static readonly RULE_cte_list = 487;
      static readonly RULE_common_table_expr = 488;
      static readonly RULE_opt_materialized = 489;
      static readonly RULE_opt_with_clause = 490;
      static readonly RULE_into_clause = 491;
      static readonly RULE_opt_strict = 492;
      static readonly RULE_opttempTableName = 493;
      static readonly RULE_opt_table = 494;
      static readonly RULE_all_or_distinct = 495;
      static readonly RULE_distinct_clause = 496;
      static readonly RULE_opt_all_clause = 497;
      static readonly RULE_opt_sort_clause = 498;
      static readonly RULE_sort_clause = 499;
      static readonly RULE_sortby_list = 500;
      static readonly RULE_sortby = 501;
      static readonly RULE_select_limit = 502;
      static readonly RULE_opt_select_limit = 503;
      static readonly RULE_limit_clause = 504;
      static readonly RULE_offset_clause = 505;
      static readonly RULE_select_limit_value = 506;
      static readonly RULE_select_offset_value = 507;
      static readonly RULE_select_fetch_first_value = 508;
      static readonly RULE_i_or_f_const = 509;
      static readonly RULE_row_or_rows = 510;
      static readonly RULE_first_or_next = 511;
      static readonly RULE_group_clause = 512;
      static readonly RULE_group_by_list = 513;
      static readonly RULE_group_by_item = 514;
      static readonly RULE_empty_grouping_set = 515;
      static readonly RULE_rollup_clause = 516;
      static readonly RULE_cube_clause = 517;
      static readonly RULE_grouping_sets_clause = 518;
      static readonly RULE_having_clause = 519;
      static readonly RULE_for_locking_clause = 520;
      static readonly RULE_opt_for_locking_clause = 521;
      static readonly RULE_for_locking_items = 522;
      static readonly RULE_for_locking_item = 523;
      static readonly RULE_for_locking_strength = 524;
      static readonly RULE_locked_rels_list = 525;
      static readonly RULE_values_clause = 526;
      static readonly RULE_from_clause = 527;
      static readonly RULE_from_list = 528;
      static readonly RULE_non_ansi_join = 529;
      static readonly RULE_table_ref = 530;
      static readonly RULE_alias_clause = 531;
      static readonly RULE_opt_alias_clause = 532;
      static readonly RULE_table_alias_clause = 533;
      static readonly RULE_func_alias_clause = 534;
      static readonly RULE_join_type = 535;
      static readonly RULE_join_qual = 536;
      static readonly RULE_relation_expr = 537;
      static readonly RULE_relation_expr_list = 538;
      static readonly RULE_relation_expr_opt_alias = 539;
      static readonly RULE_tablesample_clause = 540;
      static readonly RULE_opt_repeatable_clause = 541;
      static readonly RULE_func_table = 542;
      static readonly RULE_rowsfrom_item = 543;
      static readonly RULE_rowsfrom_list = 544;
      static readonly RULE_opt_col_def_list = 545;
      static readonly RULE_opt_ordinality = 546;
      static readonly RULE_where_clause = 547;
      static readonly RULE_where_or_current_clause = 548;
      static readonly RULE_opttablefuncelementlist = 549;
      static readonly RULE_tablefuncelementlist = 550;
      static readonly RULE_tablefuncelement = 551;
      static readonly RULE_xmltable = 552;
      static readonly RULE_xmltable_column_list = 553;
      static readonly RULE_xmltable_column_el = 554;
      static readonly RULE_xmltable_column_option_list = 555;
      static readonly RULE_xmltable_column_option_el = 556;
      static readonly RULE_xml_namespace_list = 557;
      static readonly RULE_xml_namespace_el = 558;
      static readonly RULE_typename = 559;
      static readonly RULE_opt_array_bounds = 560;
      static readonly RULE_simpletypename = 561;
      static readonly RULE_consttypename = 562;
      static readonly RULE_generictype = 563;
      static readonly RULE_opt_type_modifiers = 564;
      static readonly RULE_numeric = 565;
      static readonly RULE_opt_float = 566;
      static readonly RULE_bit = 567;
      static readonly RULE_constbit = 568;
      static readonly RULE_bitwithlength = 569;
      static readonly RULE_bitwithoutlength = 570;
      static readonly RULE_character = 571;
      static readonly RULE_constcharacter = 572;
      static readonly RULE_character_c = 573;
      static readonly RULE_opt_varying = 574;
      static readonly RULE_constdatetime = 575;
      static readonly RULE_constinterval = 576;
      static readonly RULE_opt_timezone = 577;
      static readonly RULE_opt_interval = 578;
      static readonly RULE_interval_second = 579;
      static readonly RULE_opt_escape = 580;
      static readonly RULE_a_expr = 581;
      static readonly RULE_a_expr_qual = 582;
      static readonly RULE_a_expr_lessless = 583;
      static readonly RULE_a_expr_or = 584;
      static readonly RULE_a_expr_and = 585;
      static readonly RULE_a_expr_between = 586;
      static readonly RULE_a_expr_in = 587;
      static readonly RULE_a_expr_unary_not = 588;
      static readonly RULE_a_expr_isnull = 589;
      static readonly RULE_a_expr_is_not = 590;
      static readonly RULE_a_expr_compare = 591;
      static readonly RULE_a_expr_like = 592;
      static readonly RULE_a_expr_qual_op = 593;
      static readonly RULE_a_expr_unary_qualop = 594;
      static readonly RULE_a_expr_add = 595;
      static readonly RULE_a_expr_mul = 596;
      static readonly RULE_a_expr_caret = 597;
      static readonly RULE_a_expr_unary_sign = 598;
      static readonly RULE_a_expr_at_time_zone = 599;
      static readonly RULE_a_expr_collate = 600;
      static readonly RULE_a_expr_typecast = 601;
      static readonly RULE_b_expr = 602;
      static readonly RULE_c_expr = 603;
      static readonly RULE_plsqlvariablename = 604;
      static readonly RULE_func_application = 605;
      static readonly RULE_func_expr = 606;
      static readonly RULE_func_expr_windowless = 607;
      static readonly RULE_func_expr_common_subexpr = 608;
      static readonly RULE_xml_root_version = 609;
      static readonly RULE_opt_xml_root_standalone = 610;
      static readonly RULE_xml_attributes = 611;
      static readonly RULE_xml_attribute_list = 612;
      static readonly RULE_xml_attribute_el = 613;
      static readonly RULE_document_or_content = 614;
      static readonly RULE_xml_whitespace_option = 615;
      static readonly RULE_xmlexists_argument = 616;
      static readonly RULE_xml_passing_mech = 617;
      static readonly RULE_within_group_clause = 618;
      static readonly RULE_filter_clause = 619;
      static readonly RULE_window_clause = 620;
      static readonly RULE_window_definition_list = 621;
      static readonly RULE_window_definition = 622;
      static readonly RULE_over_clause = 623;
      static readonly RULE_window_specification = 624;
      static readonly RULE_opt_existing_window_name = 625;
      static readonly RULE_opt_partition_clause = 626;
      static readonly RULE_opt_frame_clause = 627;
      static readonly RULE_frame_extent = 628;
      static readonly RULE_frame_bound = 629;
      static readonly RULE_opt_window_exclusion_clause = 630;
      static readonly RULE_row = 631;
      static readonly RULE_explicit_row = 632;
      static readonly RULE_implicit_row = 633;
      static readonly RULE_sub_type = 634;
      static readonly RULE_all_op = 635;
      static readonly RULE_mathop = 636;
      static readonly RULE_qual_op = 637;
      static readonly RULE_qual_all_op = 638;
      static readonly RULE_subquery_Op = 639;
      static readonly RULE_expr_list = 640;
      static readonly RULE_func_arg_list = 641;
      static readonly RULE_func_arg_expr = 642;
      static readonly RULE_type_list = 643;
      static readonly RULE_array_expr = 644;
      static readonly RULE_array_expr_list = 645;
      static readonly RULE_extract_list = 646;
      static readonly RULE_extract_arg = 647;
      static readonly RULE_unicode_normal_form = 648;
      static readonly RULE_overlay_list = 649;
      static readonly RULE_position_list = 650;
      static readonly RULE_substr_list = 651;
      static readonly RULE_trim_list = 652;
      static readonly RULE_in_expr = 653;
      static readonly RULE_case_expr = 654;
      static readonly RULE_when_clause_list = 655;
      static readonly RULE_when_clause = 656;
      static readonly RULE_case_default = 657;
      static readonly RULE_case_arg = 658;
      static readonly RULE_columnref = 659;
      static readonly RULE_indirection_el = 660;
      static readonly RULE_opt_slice_bound = 661;
      static readonly RULE_indirection = 662;
      static readonly RULE_opt_indirection = 663;
      static readonly RULE_opt_target_list = 664;
      static readonly RULE_target_list = 665;
      static readonly RULE_target_el = 666;
      static readonly RULE_qualified_name_list = 667;
      static readonly RULE_qualified_name = 668;
      static readonly RULE_name_list = 669;
      static readonly RULE_name = 670;
      static readonly RULE_attr_name = 671;
      static readonly RULE_file_name = 672;
      static readonly RULE_func_name = 673;
      static readonly RULE_aexprconst = 674;
      static readonly RULE_xconst = 675;
      static readonly RULE_bconst = 676;
      static readonly RULE_fconst = 677;
      static readonly RULE_iconst = 678;
      static readonly RULE_sconst = 679;
      static readonly RULE_anysconst = 680;
      static readonly RULE_opt_uescape = 681;
      static readonly RULE_signediconst = 682;
      static readonly RULE_roleid = 683;
      static readonly RULE_rolespec = 684;
      static readonly RULE_role_list = 685;
      static readonly RULE_colid = 686;
      static readonly RULE_table_alias = 687;
      static readonly RULE_type_function_name = 688;
      static readonly RULE_nonreservedword = 689;
      static readonly RULE_collabel = 690;
      static readonly RULE_identifier = 691;
      static readonly RULE_plsqlidentifier = 692;
      static readonly RULE_unreserved_keyword = 693;
      static readonly RULE_col_name_keyword = 694;
      static readonly RULE_type_func_name_keyword = 695;
      static readonly RULE_reserved_keyword = 696;
      static readonly RULE_builtin_function_name = 697;
      static readonly RULE_pl_function = 698;
      static readonly RULE_comp_options = 699;
      static readonly RULE_comp_option = 700;
      static readonly RULE_sharp = 701;
      static readonly RULE_option_value = 702;
      static readonly RULE_opt_semi = 703;
      static readonly RULE_pl_block = 704;
      static readonly RULE_decl_sect = 705;
      static readonly RULE_decl_start = 706;
      static readonly RULE_decl_stmts = 707;
      static readonly RULE_label_decl = 708;
      static readonly RULE_decl_stmt = 709;
      static readonly RULE_decl_statement = 710;
      static readonly RULE_opt_scrollable = 711;
      static readonly RULE_decl_cursor_query = 712;
      static readonly RULE_decl_cursor_args = 713;
      static readonly RULE_decl_cursor_arglist = 714;
      static readonly RULE_decl_cursor_arg = 715;
      static readonly RULE_decl_is_for = 716;
      static readonly RULE_decl_aliasitem = 717;
      static readonly RULE_decl_varname = 718;
      static readonly RULE_decl_const = 719;
      static readonly RULE_decl_datatype = 720;
      static readonly RULE_decl_collate = 721;
      static readonly RULE_decl_notnull = 722;
      static readonly RULE_decl_defval = 723;
      static readonly RULE_decl_defkey = 724;
      static readonly RULE_assign_operator = 725;
      static readonly RULE_proc_sect = 726;
      static readonly RULE_proc_stmt = 727;
      static readonly RULE_stmt_perform = 728;
      static readonly RULE_stmt_call = 729;
      static readonly RULE_opt_expr_list = 730;
      static readonly RULE_stmt_assign = 731;
      static readonly RULE_stmt_getdiag = 732;
      static readonly RULE_getdiag_area_opt = 733;
      static readonly RULE_getdiag_list = 734;
      static readonly RULE_getdiag_list_item = 735;
      static readonly RULE_getdiag_item = 736;
      static readonly RULE_getdiag_target = 737;
      static readonly RULE_assign_var = 738;
      static readonly RULE_stmt_if = 739;
      static readonly RULE_stmt_elsifs = 740;
      static readonly RULE_stmt_else = 741;
      static readonly RULE_stmt_case = 742;
      static readonly RULE_opt_expr_until_when = 743;
      static readonly RULE_case_when_list = 744;
      static readonly RULE_case_when = 745;
      static readonly RULE_opt_case_else = 746;
      static readonly RULE_stmt_loop = 747;
      static readonly RULE_stmt_while = 748;
      static readonly RULE_stmt_for = 749;
      static readonly RULE_for_control = 750;
      static readonly RULE_opt_for_using_expression = 751;
      static readonly RULE_opt_cursor_parameters = 752;
      static readonly RULE_opt_reverse = 753;
      static readonly RULE_opt_by_expression = 754;
      static readonly RULE_for_variable = 755;
      static readonly RULE_stmt_foreach_a = 756;
      static readonly RULE_foreach_slice = 757;
      static readonly RULE_stmt_exit = 758;
      static readonly RULE_exit_type = 759;
      static readonly RULE_stmt_return = 760;
      static readonly RULE_opt_return_result = 761;
      static readonly RULE_stmt_raise = 762;
      static readonly RULE_opt_stmt_raise_level = 763;
      static readonly RULE_opt_raise_list = 764;
      static readonly RULE_opt_raise_using = 765;
      static readonly RULE_opt_raise_using_elem = 766;
      static readonly RULE_opt_raise_using_elem_list = 767;
      static readonly RULE_stmt_assert = 768;
      static readonly RULE_opt_stmt_assert_message = 769;
      static readonly RULE_loop_body = 770;
      static readonly RULE_stmt_execsql = 771;
      static readonly RULE_stmt_dynexecute = 772;
      static readonly RULE_opt_execute_using = 773;
      static readonly RULE_opt_execute_using_list = 774;
      static readonly RULE_opt_execute_into = 775;
      static readonly RULE_stmt_open = 776;
      static readonly RULE_opt_open_bound_list_item = 777;
      static readonly RULE_opt_open_bound_list = 778;
      static readonly RULE_opt_open_using = 779;
      static readonly RULE_opt_scroll_option = 780;
      static readonly RULE_opt_scroll_option_no = 781;
      static readonly RULE_stmt_fetch = 782;
      static readonly RULE_into_target = 783;
      static readonly RULE_opt_cursor_from = 784;
      static readonly RULE_opt_fetch_direction = 785;
      static readonly RULE_stmt_move = 786;
      static readonly RULE_stmt_close = 787;
      static readonly RULE_stmt_null = 788;
      static readonly RULE_stmt_commit = 789;
      static readonly RULE_stmt_rollback = 790;
      static readonly RULE_plsql_opt_transaction_chain = 791;
      static readonly RULE_stmt_set = 792;
      static readonly RULE_cursor_variable = 793;
      static readonly RULE_exception_sect = 794;
      static readonly RULE_proc_exceptions = 795;
      static readonly RULE_proc_exception = 796;
      static readonly RULE_proc_conditions = 797;
      static readonly RULE_proc_condition = 798;
      static readonly RULE_opt_block_label = 799;
      static readonly RULE_opt_loop_label = 800;
      static readonly RULE_opt_label = 801;
      static readonly RULE_opt_exitcond = 802;
      static readonly RULE_any_identifier = 803;
      static readonly RULE_plsql_unreserved_keyword = 804;
      static readonly RULE_sql_expression = 805;
      static readonly RULE_expr_until_then = 806;
      static readonly RULE_expr_until_semi = 807;
      static readonly RULE_expr_until_rightbracket = 808;
      static readonly RULE_expr_until_loop = 809;
      static readonly RULE_make_execsql_stmt = 810;
      static readonly RULE_opt_returning_clause_into = 811;
      static readonly literalNames: (string | null)[];
      static readonly symbolicNames: (string | null)[];
      static readonly ruleNames: string[];
      get grammarFileName(): string;
      get literalNames(): (string | null)[];
      get symbolicNames(): (string | null)[];
      get ruleNames(): string[];
      get serializedATN(): number[];
      protected createFailedPredicateException(predicate?: string, message?: string): antlr.FailedPredicateException;
      constructor(input: antlr.TokenStream);
      root(): RootContext;
      plsqlroot(): PlsqlrootContext;
      stmtblock(): StmtblockContext;
      stmtmulti(): StmtmultiContext;
      stmt(): StmtContext;
      plsqlconsolecommand(): PlsqlconsolecommandContext;
      callstmt(): CallstmtContext;
      createrolestmt(): CreaterolestmtContext;
      opt_with(): Opt_withContext;
      optrolelist(): OptrolelistContext;
      alteroptrolelist(): AlteroptrolelistContext;
      alteroptroleelem(): AlteroptroleelemContext;
      createoptroleelem(): CreateoptroleelemContext;
      createuserstmt(): CreateuserstmtContext;
      alterrolestmt(): AlterrolestmtContext;
      opt_in_database(): Opt_in_databaseContext;
      alterrolesetstmt(): AlterrolesetstmtContext;
      droprolestmt(): DroprolestmtContext;
      creategroupstmt(): CreategroupstmtContext;
      altergroupstmt(): AltergroupstmtContext;
      add_drop(): Add_dropContext;
      createschemastmt(): CreateschemastmtContext;
      optschemaname(): OptschemanameContext;
      optschemaeltlist(): OptschemaeltlistContext;
      schema_stmt(): Schema_stmtContext;
      variablesetstmt(): VariablesetstmtContext;
      set_rest(): Set_restContext;
      generic_set(): Generic_setContext;
      set_rest_more(): Set_rest_moreContext;
      var_name(): Var_nameContext;
      var_list(): Var_listContext;
      var_value(): Var_valueContext;
      iso_level(): Iso_levelContext;
      opt_boolean_or_string(): Opt_boolean_or_stringContext;
      zone_value(): Zone_valueContext;
      opt_encoding(): Opt_encodingContext;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext;
      variableresetstmt(): VariableresetstmtContext;
      reset_rest(): Reset_restContext;
      generic_reset(): Generic_resetContext;
      setresetclause(): SetresetclauseContext;
      functionsetresetclause(): FunctionsetresetclauseContext;
      variableshowstmt(): VariableshowstmtContext;
      constraintssetstmt(): ConstraintssetstmtContext;
      constraints_set_list(): Constraints_set_listContext;
      constraints_set_mode(): Constraints_set_modeContext;
      checkpointstmt(): CheckpointstmtContext;
      discardstmt(): DiscardstmtContext;
      altertablestmt(): AltertablestmtContext;
      alter_table_cmds(): Alter_table_cmdsContext;
      partition_cmd(): Partition_cmdContext;
      index_partition_cmd(): Index_partition_cmdContext;
      alter_table_cmd(): Alter_table_cmdContext;
      alter_column_default(): Alter_column_defaultContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      opt_collate_clause(): Opt_collate_clauseContext;
      alter_using(): Alter_usingContext;
      replica_identity(): Replica_identityContext;
      reloptions(): ReloptionsContext;
      opt_reloptions(): Opt_reloptionsContext;
      reloption_list(): Reloption_listContext;
      reloption_elem(): Reloption_elemContext;
      alter_identity_column_option_list(): Alter_identity_column_option_listContext;
      alter_identity_column_option(): Alter_identity_column_optionContext;
      partitionboundspec(): PartitionboundspecContext;
      hash_partbound_elem(): Hash_partbound_elemContext;
      hash_partbound(): Hash_partboundContext;
      altercompositetypestmt(): AltercompositetypestmtContext;
      alter_type_cmds(): Alter_type_cmdsContext;
      alter_type_cmd(): Alter_type_cmdContext;
      closeportalstmt(): CloseportalstmtContext;
      copystmt(): CopystmtContext;
      copy_from(): Copy_fromContext;
      opt_program(): Opt_programContext;
      copy_file_name(): Copy_file_nameContext;
      copy_options(): Copy_optionsContext;
      copy_opt_list(): Copy_opt_listContext;
      copy_opt_item(): Copy_opt_itemContext;
      opt_binary(): Opt_binaryContext;
      copy_delimiter(): Copy_delimiterContext;
      opt_using(): Opt_usingContext;
      copy_generic_opt_list(): Copy_generic_opt_listContext;
      copy_generic_opt_elem(): Copy_generic_opt_elemContext;
      copy_generic_opt_arg(): Copy_generic_opt_argContext;
      copy_generic_opt_arg_list(): Copy_generic_opt_arg_listContext;
      copy_generic_opt_arg_list_item(): Copy_generic_opt_arg_list_itemContext;
      createstmt(): CreatestmtContext;
      opttemp(): OpttempContext;
      opttableelementlist(): OpttableelementlistContext;
      opttypedtableelementlist(): OpttypedtableelementlistContext;
      tableelementlist(): TableelementlistContext;
      typedtableelementlist(): TypedtableelementlistContext;
      tableelement(): TableelementContext;
      typedtableelement(): TypedtableelementContext;
      columnDef(): ColumnDefContext;
      columnOptions(): ColumnOptionsContext;
      colquallist(): ColquallistContext;
      colconstraint(): ColconstraintContext;
      colconstraintelem(): ColconstraintelemContext;
      generated_when(): Generated_whenContext;
      constraintattr(): ConstraintattrContext;
      tablelikeclause(): TablelikeclauseContext;
      tablelikeoptionlist(): TablelikeoptionlistContext;
      tablelikeoption(): TablelikeoptionContext;
      tableconstraint(): TableconstraintContext;
      constraintelem(): ConstraintelemContext;
      opt_no_inherit(): Opt_no_inheritContext;
      opt_column_list(): Opt_column_listContext;
      columnlist(): ColumnlistContext;
      columnElem(): ColumnElemContext;
      opt_c_include(): Opt_c_includeContext;
      key_match(): Key_matchContext;
      exclusionconstraintlist(): ExclusionconstraintlistContext;
      exclusionconstraintelem(): ExclusionconstraintelemContext;
      exclusionwhereclause(): ExclusionwhereclauseContext;
      key_actions(): Key_actionsContext;
      key_update(): Key_updateContext;
      key_delete(): Key_deleteContext;
      key_action(): Key_actionContext;
      optinherit(): OptinheritContext;
      optpartitionspec(): OptpartitionspecContext;
      partitionspec(): PartitionspecContext;
      part_params(): Part_paramsContext;
      part_elem(): Part_elemContext;
      table_access_method_clause(): Table_access_method_clauseContext;
      optwith(): OptwithContext;
      oncommitoption(): OncommitoptionContext;
      opttablespace(): OpttablespaceContext;
      optconstablespace(): OptconstablespaceContext;
      existingindex(): ExistingindexContext;
      createstatsstmt(): CreatestatsstmtContext;
      alterstatsstmt(): AlterstatsstmtContext;
      createasstmt(): CreateasstmtContext;
      create_as_target(): Create_as_targetContext;
      opt_with_data(): Opt_with_dataContext;
      creatematviewstmt(): CreatematviewstmtContext;
      create_mv_target(): Create_mv_targetContext;
      optnolog(): OptnologContext;
      refreshmatviewstmt(): RefreshmatviewstmtContext;
      createseqstmt(): CreateseqstmtContext;
      alterseqstmt(): AlterseqstmtContext;
      optseqoptlist(): OptseqoptlistContext;
      optparenthesizedseqoptlist(): OptparenthesizedseqoptlistContext;
      seqoptlist(): SeqoptlistContext;
      seqoptelem(): SeqoptelemContext;
      opt_by(): Opt_byContext;
      numericonly(): NumericonlyContext;
      numericonly_list(): Numericonly_listContext;
      createplangstmt(): CreateplangstmtContext;
      opt_trusted(): Opt_trustedContext;
      handler_name(): Handler_nameContext;
      opt_inline_handler(): Opt_inline_handlerContext;
      validator_clause(): Validator_clauseContext;
      opt_validator(): Opt_validatorContext;
      opt_procedural(): Opt_proceduralContext;
      createtablespacestmt(): CreatetablespacestmtContext;
      opttablespaceowner(): OpttablespaceownerContext;
      droptablespacestmt(): DroptablespacestmtContext;
      createextensionstmt(): CreateextensionstmtContext;
      create_extension_opt_list(): Create_extension_opt_listContext;
      create_extension_opt_item(): Create_extension_opt_itemContext;
      alterextensionstmt(): AlterextensionstmtContext;
      alter_extension_opt_list(): Alter_extension_opt_listContext;
      alter_extension_opt_item(): Alter_extension_opt_itemContext;
      alterextensioncontentsstmt(): AlterextensioncontentsstmtContext;
      createfdwstmt(): CreatefdwstmtContext;
      fdw_option(): Fdw_optionContext;
      fdw_options(): Fdw_optionsContext;
      opt_fdw_options(): Opt_fdw_optionsContext;
      alterfdwstmt(): AlterfdwstmtContext;
      create_generic_options(): Create_generic_optionsContext;
      generic_option_list(): Generic_option_listContext;
      alter_generic_options(): Alter_generic_optionsContext;
      alter_generic_option_list(): Alter_generic_option_listContext;
      alter_generic_option_elem(): Alter_generic_option_elemContext;
      generic_option_elem(): Generic_option_elemContext;
      generic_option_name(): Generic_option_nameContext;
      generic_option_arg(): Generic_option_argContext;
      createforeignserverstmt(): CreateforeignserverstmtContext;
      opt_type(): Opt_typeContext;
      foreign_server_version(): Foreign_server_versionContext;
      opt_foreign_server_version(): Opt_foreign_server_versionContext;
      alterforeignserverstmt(): AlterforeignserverstmtContext;
      createforeigntablestmt(): CreateforeigntablestmtContext;
      importforeignschemastmt(): ImportforeignschemastmtContext;
      import_qualification_type(): Import_qualification_typeContext;
      import_qualification(): Import_qualificationContext;
      createusermappingstmt(): CreateusermappingstmtContext;
      auth_ident(): Auth_identContext;
      dropusermappingstmt(): DropusermappingstmtContext;
      alterusermappingstmt(): AlterusermappingstmtContext;
      createpolicystmt(): CreatepolicystmtContext;
      alterpolicystmt(): AlterpolicystmtContext;
      rowsecurityoptionalexpr(): RowsecurityoptionalexprContext;
      rowsecurityoptionalwithcheck(): RowsecurityoptionalwithcheckContext;
      rowsecuritydefaulttorole(): RowsecuritydefaulttoroleContext;
      rowsecurityoptionaltorole(): RowsecurityoptionaltoroleContext;
      rowsecuritydefaultpermissive(): RowsecuritydefaultpermissiveContext;
      rowsecuritydefaultforcmd(): RowsecuritydefaultforcmdContext;
      row_security_cmd(): Row_security_cmdContext;
      createamstmt(): CreateamstmtContext;
      am_type(): Am_typeContext;
      createtrigstmt(): CreatetrigstmtContext;
      triggeractiontime(): TriggeractiontimeContext;
      triggerevents(): TriggereventsContext;
      triggeroneevent(): TriggeroneeventContext;
      triggerreferencing(): TriggerreferencingContext;
      triggertransitions(): TriggertransitionsContext;
      triggertransition(): TriggertransitionContext;
      transitionoldornew(): TransitionoldornewContext;
      transitionrowortable(): TransitionrowortableContext;
      transitionrelname(): TransitionrelnameContext;
      triggerforspec(): TriggerforspecContext;
      triggerforopteach(): TriggerforopteachContext;
      triggerfortype(): TriggerfortypeContext;
      triggerwhen(): TriggerwhenContext;
      function_or_procedure(): Function_or_procedureContext;
      triggerfuncargs(): TriggerfuncargsContext;
      triggerfuncarg(): TriggerfuncargContext;
      optconstrfromtable(): OptconstrfromtableContext;
      constraintattributespec(): ConstraintattributespecContext;
      constraintattributeElem(): ConstraintattributeElemContext;
      createeventtrigstmt(): CreateeventtrigstmtContext;
      event_trigger_when_list(): Event_trigger_when_listContext;
      event_trigger_when_item(): Event_trigger_when_itemContext;
      event_trigger_value_list(): Event_trigger_value_listContext;
      altereventtrigstmt(): AltereventtrigstmtContext;
      enable_trigger(): Enable_triggerContext;
      createassertionstmt(): CreateassertionstmtContext;
      definestmt(): DefinestmtContext;
      definition(): DefinitionContext;
      def_list(): Def_listContext;
      def_elem(): Def_elemContext;
      def_arg(): Def_argContext;
      old_aggr_definition(): Old_aggr_definitionContext;
      old_aggr_list(): Old_aggr_listContext;
      old_aggr_elem(): Old_aggr_elemContext;
      opt_enum_val_list(): Opt_enum_val_listContext;
      enum_val_list(): Enum_val_listContext;
      alterenumstmt(): AlterenumstmtContext;
      opt_if_not_exists(): Opt_if_not_existsContext;
      createopclassstmt(): CreateopclassstmtContext;
      opclass_item_list(): Opclass_item_listContext;
      opclass_item(): Opclass_itemContext;
      opt_default(): Opt_defaultContext;
      opt_opfamily(): Opt_opfamilyContext;
      opclass_purpose(): Opclass_purposeContext;
      opt_recheck(): Opt_recheckContext;
      createopfamilystmt(): CreateopfamilystmtContext;
      alteropfamilystmt(): AlteropfamilystmtContext;
      opclass_drop_list(): Opclass_drop_listContext;
      opclass_drop(): Opclass_dropContext;
      dropopclassstmt(): DropopclassstmtContext;
      dropopfamilystmt(): DropopfamilystmtContext;
      dropownedstmt(): DropownedstmtContext;
      reassignownedstmt(): ReassignownedstmtContext;
      dropstmt(): DropstmtContext;
      object_type_any_name(): Object_type_any_nameContext;
      object_type_name(): Object_type_nameContext;
      drop_type_name(): Drop_type_nameContext;
      object_type_name_on_any_name(): Object_type_name_on_any_nameContext;
      any_name_list(): Any_name_listContext;
      any_name(): Any_nameContext;
      attrs(): AttrsContext;
      type_name_list(): Type_name_listContext;
      truncatestmt(): TruncatestmtContext;
      opt_restart_seqs(): Opt_restart_seqsContext;
      commentstmt(): CommentstmtContext;
      comment_text(): Comment_textContext;
      seclabelstmt(): SeclabelstmtContext;
      opt_provider(): Opt_providerContext;
      security_label(): Security_labelContext;
      fetchstmt(): FetchstmtContext;
      fetch_args(): Fetch_argsContext;
      from_in(): From_inContext;
      opt_from_in(): Opt_from_inContext;
      grantstmt(): GrantstmtContext;
      revokestmt(): RevokestmtContext;
      privileges(): PrivilegesContext;
      privilege_list(): Privilege_listContext;
      privilege(): PrivilegeContext;
      privilege_target(): Privilege_targetContext;
      grantee_list(): Grantee_listContext;
      grantee(): GranteeContext;
      opt_grant_grant_option(): Opt_grant_grant_optionContext;
      grantrolestmt(): GrantrolestmtContext;
      revokerolestmt(): RevokerolestmtContext;
      opt_grant_admin_option(): Opt_grant_admin_optionContext;
      opt_granted_by(): Opt_granted_byContext;
      alterdefaultprivilegesstmt(): AlterdefaultprivilegesstmtContext;
      defacloptionlist(): DefacloptionlistContext;
      defacloption(): DefacloptionContext;
      defaclaction(): DefaclactionContext;
      defacl_privilege_target(): Defacl_privilege_targetContext;
      indexstmt(): IndexstmtContext;
      opt_unique(): Opt_uniqueContext;
      opt_concurrently(): Opt_concurrentlyContext;
      opt_index_name(): Opt_index_nameContext;
      access_method_clause(): Access_method_clauseContext;
      index_params(): Index_paramsContext;
      index_elem_options(): Index_elem_optionsContext;
      index_elem(): Index_elemContext;
      opt_include(): Opt_includeContext;
      index_including_params(): Index_including_paramsContext;
      opt_collate(): Opt_collateContext;
      opt_class(): Opt_classContext;
      opt_asc_desc(): Opt_asc_descContext;
      opt_nulls_order(): Opt_nulls_orderContext;
      createfunctionstmt(): CreatefunctionstmtContext;
      opt_or_replace(): Opt_or_replaceContext;
      func_args(): Func_argsContext;
      func_args_list(): Func_args_listContext;
      function_with_argtypes_list(): Function_with_argtypes_listContext;
      function_with_argtypes(): Function_with_argtypesContext;
      func_args_with_defaults(): Func_args_with_defaultsContext;
      func_args_with_defaults_list(): Func_args_with_defaults_listContext;
      func_arg(): Func_argContext;
      arg_class(): Arg_classContext;
      param_name(): Param_nameContext;
      func_return(): Func_returnContext;
      func_type(): Func_typeContext;
      func_arg_with_default(): Func_arg_with_defaultContext;
      aggr_arg(): Aggr_argContext;
      aggr_args(): Aggr_argsContext;
      aggr_args_list(): Aggr_args_listContext;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext;
      aggregate_with_argtypes_list(): Aggregate_with_argtypes_listContext;
      createfunc_opt_list(): Createfunc_opt_listContext;
      common_func_opt_item(): Common_func_opt_itemContext;
      createfunc_opt_item(): Createfunc_opt_itemContext;
      func_as(): Func_asContext;
      transform_type_list(): Transform_type_listContext;
      opt_definition(): Opt_definitionContext;
      table_func_column(): Table_func_columnContext;
      table_func_column_list(): Table_func_column_listContext;
      alterfunctionstmt(): AlterfunctionstmtContext;
      alterfunc_opt_list(): Alterfunc_opt_listContext;
      opt_restrict(): Opt_restrictContext;
      removefuncstmt(): RemovefuncstmtContext;
      removeaggrstmt(): RemoveaggrstmtContext;
      removeoperstmt(): RemoveoperstmtContext;
      oper_argtypes(): Oper_argtypesContext;
      any_operator(): Any_operatorContext;
      operator_with_argtypes_list(): Operator_with_argtypes_listContext;
      operator_with_argtypes(): Operator_with_argtypesContext;
      dostmt(): DostmtContext;
      dostmt_opt_list(): Dostmt_opt_listContext;
      dostmt_opt_item(): Dostmt_opt_itemContext;
      createcaststmt(): CreatecaststmtContext;
      cast_context(): Cast_contextContext;
      dropcaststmt(): DropcaststmtContext;
      opt_if_exists(): Opt_if_existsContext;
      createtransformstmt(): CreatetransformstmtContext;
      transform_element_list(): Transform_element_listContext;
      droptransformstmt(): DroptransformstmtContext;
      reindexstmt(): ReindexstmtContext;
      reindex_target_type(): Reindex_target_typeContext;
      reindex_target_multitable(): Reindex_target_multitableContext;
      reindex_option_list(): Reindex_option_listContext;
      reindex_option_elem(): Reindex_option_elemContext;
      altertblspcstmt(): AltertblspcstmtContext;
      renamestmt(): RenamestmtContext;
      opt_column(): Opt_columnContext;
      opt_set_data(): Opt_set_dataContext;
      alterobjectdependsstmt(): AlterobjectdependsstmtContext;
      opt_no(): Opt_noContext;
      alterobjectschemastmt(): AlterobjectschemastmtContext;
      alteroperatorstmt(): AlteroperatorstmtContext;
      operator_def_list(): Operator_def_listContext;
      operator_def_elem(): Operator_def_elemContext;
      operator_def_arg(): Operator_def_argContext;
      altertypestmt(): AltertypestmtContext;
      alterownerstmt(): AlterownerstmtContext;
      createpublicationstmt(): CreatepublicationstmtContext;
      opt_publication_for_tables(): Opt_publication_for_tablesContext;
      publication_for_tables(): Publication_for_tablesContext;
      alterpublicationstmt(): AlterpublicationstmtContext;
      createsubscriptionstmt(): CreatesubscriptionstmtContext;
      publication_name_list(): Publication_name_listContext;
      publication_name_item(): Publication_name_itemContext;
      altersubscriptionstmt(): AltersubscriptionstmtContext;
      dropsubscriptionstmt(): DropsubscriptionstmtContext;
      rulestmt(): RulestmtContext;
      ruleactionlist(): RuleactionlistContext;
      ruleactionmulti(): RuleactionmultiContext;
      ruleactionstmt(): RuleactionstmtContext;
      ruleactionstmtOrEmpty(): RuleactionstmtOrEmptyContext;
      event(): EventContext;
      opt_instead(): Opt_insteadContext;
      notifystmt(): NotifystmtContext;
      notify_payload(): Notify_payloadContext;
      listenstmt(): ListenstmtContext;
      unlistenstmt(): UnlistenstmtContext;
      transactionstmt(): TransactionstmtContext;
      opt_transaction(): Opt_transactionContext;
      transaction_mode_item(): Transaction_mode_itemContext;
      transaction_mode_list(): Transaction_mode_listContext;
      transaction_mode_list_or_empty(): Transaction_mode_list_or_emptyContext;
      opt_transaction_chain(): Opt_transaction_chainContext;
      viewstmt(): ViewstmtContext;
      opt_check_option(): Opt_check_optionContext;
      loadstmt(): LoadstmtContext;
      createdbstmt(): CreatedbstmtContext;
      createdb_opt_list(): Createdb_opt_listContext;
      createdb_opt_items(): Createdb_opt_itemsContext;
      createdb_opt_item(): Createdb_opt_itemContext;
      createdb_opt_name(): Createdb_opt_nameContext;
      opt_equal(): Opt_equalContext;
      alterdatabasestmt(): AlterdatabasestmtContext;
      alterdatabasesetstmt(): AlterdatabasesetstmtContext;
      dropdbstmt(): DropdbstmtContext;
      drop_option_list(): Drop_option_listContext;
      drop_option(): Drop_optionContext;
      altercollationstmt(): AltercollationstmtContext;
      altersystemstmt(): AltersystemstmtContext;
      createdomainstmt(): CreatedomainstmtContext;
      alterdomainstmt(): AlterdomainstmtContext;
      opt_as(): Opt_asContext;
      altertsdictionarystmt(): AltertsdictionarystmtContext;
      altertsconfigurationstmt(): AltertsconfigurationstmtContext;
      any_with(): Any_withContext;
      createconversionstmt(): CreateconversionstmtContext;
      clusterstmt(): ClusterstmtContext;
      cluster_index_specification(): Cluster_index_specificationContext;
      vacuumstmt(): VacuumstmtContext;
      analyzestmt(): AnalyzestmtContext;
      vac_analyze_option_list(): Vac_analyze_option_listContext;
      analyze_keyword(): Analyze_keywordContext;
      vac_analyze_option_elem(): Vac_analyze_option_elemContext;
      vac_analyze_option_name(): Vac_analyze_option_nameContext;
      vac_analyze_option_arg(): Vac_analyze_option_argContext;
      opt_analyze(): Opt_analyzeContext;
      opt_verbose(): Opt_verboseContext;
      opt_full(): Opt_fullContext;
      opt_freeze(): Opt_freezeContext;
      opt_name_list(): Opt_name_listContext;
      vacuum_relation(): Vacuum_relationContext;
      vacuum_relation_list(): Vacuum_relation_listContext;
      opt_vacuum_relation_list(): Opt_vacuum_relation_listContext;
      explainstmt(): ExplainstmtContext;
      explainablestmt(): ExplainablestmtContext;
      explain_option_list(): Explain_option_listContext;
      explain_option_elem(): Explain_option_elemContext;
      explain_option_name(): Explain_option_nameContext;
      explain_option_arg(): Explain_option_argContext;
      preparestmt(): PreparestmtContext;
      prep_type_clause(): Prep_type_clauseContext;
      preparablestmt(): PreparablestmtContext;
      executestmt(): ExecutestmtContext;
      execute_param_clause(): Execute_param_clauseContext;
      deallocatestmt(): DeallocatestmtContext;
      insertstmt(): InsertstmtContext;
      insert_target(): Insert_targetContext;
      insert_rest(): Insert_restContext;
      override_kind(): Override_kindContext;
      insert_column_list(): Insert_column_listContext;
      insert_column_item(): Insert_column_itemContext;
      opt_on_conflict(): Opt_on_conflictContext;
      opt_conf_expr(): Opt_conf_exprContext;
      returning_clause(): Returning_clauseContext;
      mergestmt(): MergestmtContext;
      merge_insert_clause(): Merge_insert_clauseContext;
      merge_update_clause(): Merge_update_clauseContext;
      merge_delete_clause(): Merge_delete_clauseContext;
      deletestmt(): DeletestmtContext;
      using_clause(): Using_clauseContext;
      lockstmt(): LockstmtContext;
      opt_lock(): Opt_lockContext;
      lock_type(): Lock_typeContext;
      opt_nowait(): Opt_nowaitContext;
      opt_nowait_or_skip(): Opt_nowait_or_skipContext;
      updatestmt(): UpdatestmtContext;
      set_clause_list(): Set_clause_listContext;
      set_clause(): Set_clauseContext;
      set_target(): Set_targetContext;
      set_target_list(): Set_target_listContext;
      declarecursorstmt(): DeclarecursorstmtContext;
      cursor_name(): Cursor_nameContext;
      cursor_options(): Cursor_optionsContext;
      opt_hold(): Opt_holdContext;
      selectstmt(): SelectstmtContext;
      select_with_parens(): Select_with_parensContext;
      select_no_parens(): Select_no_parensContext;
      select_clause(): Select_clauseContext;
      simple_select_intersect(): Simple_select_intersectContext;
      simple_select_pramary(): Simple_select_pramaryContext;
      with_clause(): With_clauseContext;
      cte_list(): Cte_listContext;
      common_table_expr(): Common_table_exprContext;
      opt_materialized(): Opt_materializedContext;
      opt_with_clause(): Opt_with_clauseContext;
      into_clause(): Into_clauseContext;
      opt_strict(): Opt_strictContext;
      opttempTableName(): OpttempTableNameContext;
      opt_table(): Opt_tableContext;
      all_or_distinct(): All_or_distinctContext;
      distinct_clause(): Distinct_clauseContext;
      opt_all_clause(): Opt_all_clauseContext;
      opt_sort_clause(): Opt_sort_clauseContext;
      sort_clause(): Sort_clauseContext;
      sortby_list(): Sortby_listContext;
      sortby(): SortbyContext;
      select_limit(): Select_limitContext;
      opt_select_limit(): Opt_select_limitContext;
      limit_clause(): Limit_clauseContext;
      offset_clause(): Offset_clauseContext;
      select_limit_value(): Select_limit_valueContext;
      select_offset_value(): Select_offset_valueContext;
      select_fetch_first_value(): Select_fetch_first_valueContext;
      i_or_f_const(): I_or_f_constContext;
      row_or_rows(): Row_or_rowsContext;
      first_or_next(): First_or_nextContext;
      group_clause(): Group_clauseContext;
      group_by_list(): Group_by_listContext;
      group_by_item(): Group_by_itemContext;
      empty_grouping_set(): Empty_grouping_setContext;
      rollup_clause(): Rollup_clauseContext;
      cube_clause(): Cube_clauseContext;
      grouping_sets_clause(): Grouping_sets_clauseContext;
      having_clause(): Having_clauseContext;
      for_locking_clause(): For_locking_clauseContext;
      opt_for_locking_clause(): Opt_for_locking_clauseContext;
      for_locking_items(): For_locking_itemsContext;
      for_locking_item(): For_locking_itemContext;
      for_locking_strength(): For_locking_strengthContext;
      locked_rels_list(): Locked_rels_listContext;
      values_clause(): Values_clauseContext;
      from_clause(): From_clauseContext;
      from_list(): From_listContext;
      non_ansi_join(): Non_ansi_joinContext;
      table_ref(): Table_refContext;
      alias_clause(): Alias_clauseContext;
      opt_alias_clause(): Opt_alias_clauseContext;
      table_alias_clause(): Table_alias_clauseContext;
      func_alias_clause(): Func_alias_clauseContext;
      join_type(): Join_typeContext;
      join_qual(): Join_qualContext;
      relation_expr(): Relation_exprContext;
      relation_expr_list(): Relation_expr_listContext;
      relation_expr_opt_alias(): Relation_expr_opt_aliasContext;
      tablesample_clause(): Tablesample_clauseContext;
      opt_repeatable_clause(): Opt_repeatable_clauseContext;
      func_table(): Func_tableContext;
      rowsfrom_item(): Rowsfrom_itemContext;
      rowsfrom_list(): Rowsfrom_listContext;
      opt_col_def_list(): Opt_col_def_listContext;
      opt_ordinality(): Opt_ordinalityContext;
      where_clause(): Where_clauseContext;
      where_or_current_clause(): Where_or_current_clauseContext;
      opttablefuncelementlist(): OpttablefuncelementlistContext;
      tablefuncelementlist(): TablefuncelementlistContext;
      tablefuncelement(): TablefuncelementContext;
      xmltable(): XmltableContext;
      xmltable_column_list(): Xmltable_column_listContext;
      xmltable_column_el(): Xmltable_column_elContext;
      xmltable_column_option_list(): Xmltable_column_option_listContext;
      xmltable_column_option_el(): Xmltable_column_option_elContext;
      xml_namespace_list(): Xml_namespace_listContext;
      xml_namespace_el(): Xml_namespace_elContext;
      typename(): TypenameContext;
      opt_array_bounds(): Opt_array_boundsContext;
      simpletypename(): SimpletypenameContext;
      consttypename(): ConsttypenameContext;
      generictype(): GenerictypeContext;
      opt_type_modifiers(): Opt_type_modifiersContext;
      numeric(): NumericContext;
      opt_float(): Opt_floatContext;
      bit(): BitContext;
      constbit(): ConstbitContext;
      bitwithlength(): BitwithlengthContext;
      bitwithoutlength(): BitwithoutlengthContext;
      character(): CharacterContext;
      constcharacter(): ConstcharacterContext;
      character_c(): Character_cContext;
      opt_varying(): Opt_varyingContext;
      constdatetime(): ConstdatetimeContext;
      constinterval(): ConstintervalContext;
      opt_timezone(): Opt_timezoneContext;
      opt_interval(): Opt_intervalContext;
      interval_second(): Interval_secondContext;
      opt_escape(): Opt_escapeContext;
      a_expr(): A_exprContext;
      a_expr_qual(): A_expr_qualContext;
      a_expr_lessless(): A_expr_lesslessContext;
      a_expr_or(): A_expr_orContext;
      a_expr_and(): A_expr_andContext;
      a_expr_between(): A_expr_betweenContext;
      a_expr_in(): A_expr_inContext;
      a_expr_unary_not(): A_expr_unary_notContext;
      a_expr_isnull(): A_expr_isnullContext;
      a_expr_is_not(): A_expr_is_notContext;
      a_expr_compare(): A_expr_compareContext;
      a_expr_like(): A_expr_likeContext;
      a_expr_qual_op(): A_expr_qual_opContext;
      a_expr_unary_qualop(): A_expr_unary_qualopContext;
      a_expr_add(): A_expr_addContext;
      a_expr_mul(): A_expr_mulContext;
      a_expr_caret(): A_expr_caretContext;
      a_expr_unary_sign(): A_expr_unary_signContext;
      a_expr_at_time_zone(): A_expr_at_time_zoneContext;
      a_expr_collate(): A_expr_collateContext;
      a_expr_typecast(): A_expr_typecastContext;
      b_expr(): B_exprContext;
      b_expr(_p: number): B_exprContext;
      c_expr(): C_exprContext;
      plsqlvariablename(): PlsqlvariablenameContext;
      func_application(): Func_applicationContext;
      func_expr(): Func_exprContext;
      func_expr_windowless(): Func_expr_windowlessContext;
      func_expr_common_subexpr(): Func_expr_common_subexprContext;
      xml_root_version(): Xml_root_versionContext;
      opt_xml_root_standalone(): Opt_xml_root_standaloneContext;
      xml_attributes(): Xml_attributesContext;
      xml_attribute_list(): Xml_attribute_listContext;
      xml_attribute_el(): Xml_attribute_elContext;
      document_or_content(): Document_or_contentContext;
      xml_whitespace_option(): Xml_whitespace_optionContext;
      xmlexists_argument(): Xmlexists_argumentContext;
      xml_passing_mech(): Xml_passing_mechContext;
      within_group_clause(): Within_group_clauseContext;
      filter_clause(): Filter_clauseContext;
      window_clause(): Window_clauseContext;
      window_definition_list(): Window_definition_listContext;
      window_definition(): Window_definitionContext;
      over_clause(): Over_clauseContext;
      window_specification(): Window_specificationContext;
      opt_existing_window_name(): Opt_existing_window_nameContext;
      opt_partition_clause(): Opt_partition_clauseContext;
      opt_frame_clause(): Opt_frame_clauseContext;
      frame_extent(): Frame_extentContext;
      frame_bound(): Frame_boundContext;
      opt_window_exclusion_clause(): Opt_window_exclusion_clauseContext;
      row(): RowContext;
      explicit_row(): Explicit_rowContext;
      implicit_row(): Implicit_rowContext;
      sub_type(): Sub_typeContext;
      all_op(): All_opContext;
      mathop(): MathopContext;
      qual_op(): Qual_opContext;
      qual_all_op(): Qual_all_opContext;
      subquery_Op(): Subquery_OpContext;
      expr_list(): Expr_listContext;
      func_arg_list(): Func_arg_listContext;
      func_arg_expr(): Func_arg_exprContext;
      type_list(): Type_listContext;
      array_expr(): Array_exprContext;
      array_expr_list(): Array_expr_listContext;
      extract_list(): Extract_listContext;
      extract_arg(): Extract_argContext;
      unicode_normal_form(): Unicode_normal_formContext;
      overlay_list(): Overlay_listContext;
      position_list(): Position_listContext;
      substr_list(): Substr_listContext;
      trim_list(): Trim_listContext;
      in_expr(): In_exprContext;
      case_expr(): Case_exprContext;
      when_clause_list(): When_clause_listContext;
      when_clause(): When_clauseContext;
      case_default(): Case_defaultContext;
      case_arg(): Case_argContext;
      columnref(): ColumnrefContext;
      indirection_el(): Indirection_elContext;
      opt_slice_bound(): Opt_slice_boundContext;
      indirection(): IndirectionContext;
      opt_indirection(): Opt_indirectionContext;
      opt_target_list(): Opt_target_listContext;
      target_list(): Target_listContext;
      target_el(): Target_elContext;
      qualified_name_list(): Qualified_name_listContext;
      qualified_name(): Qualified_nameContext;
      name_list(): Name_listContext;
      name(): NameContext;
      attr_name(): Attr_nameContext;
      file_name(): File_nameContext;
      func_name(): Func_nameContext;
      aexprconst(): AexprconstContext;
      xconst(): XconstContext;
      bconst(): BconstContext;
      fconst(): FconstContext;
      iconst(): IconstContext;
      sconst(): SconstContext;
      anysconst(): AnysconstContext;
      opt_uescape(): Opt_uescapeContext;
      signediconst(): SignediconstContext;
      roleid(): RoleidContext;
      rolespec(): RolespecContext;
      role_list(): Role_listContext;
      colid(): ColidContext;
      table_alias(): Table_aliasContext;
      type_function_name(): Type_function_nameContext;
      nonreservedword(): NonreservedwordContext;
      collabel(): CollabelContext;
      identifier(): IdentifierContext;
      plsqlidentifier(): PlsqlidentifierContext;
      unreserved_keyword(): Unreserved_keywordContext;
      col_name_keyword(): Col_name_keywordContext;
      type_func_name_keyword(): Type_func_name_keywordContext;
      reserved_keyword(): Reserved_keywordContext;
      builtin_function_name(): Builtin_function_nameContext;
      pl_function(): Pl_functionContext;
      comp_options(): Comp_optionsContext;
      comp_option(): Comp_optionContext;
      sharp(): SharpContext;
      option_value(): Option_valueContext;
      opt_semi(): Opt_semiContext;
      pl_block(): Pl_blockContext;
      decl_sect(): Decl_sectContext;
      decl_start(): Decl_startContext;
      decl_stmts(): Decl_stmtsContext;
      label_decl(): Label_declContext;
      decl_stmt(): Decl_stmtContext;
      decl_statement(): Decl_statementContext;
      opt_scrollable(): Opt_scrollableContext;
      decl_cursor_query(): Decl_cursor_queryContext;
      decl_cursor_args(): Decl_cursor_argsContext;
      decl_cursor_arglist(): Decl_cursor_arglistContext;
      decl_cursor_arg(): Decl_cursor_argContext;
      decl_is_for(): Decl_is_forContext;
      decl_aliasitem(): Decl_aliasitemContext;
      decl_varname(): Decl_varnameContext;
      decl_const(): Decl_constContext;
      decl_datatype(): Decl_datatypeContext;
      decl_collate(): Decl_collateContext;
      decl_notnull(): Decl_notnullContext;
      decl_defval(): Decl_defvalContext;
      decl_defkey(): Decl_defkeyContext;
      assign_operator(): Assign_operatorContext;
      proc_sect(): Proc_sectContext;
      proc_stmt(): Proc_stmtContext;
      stmt_perform(): Stmt_performContext;
      stmt_call(): Stmt_callContext;
      opt_expr_list(): Opt_expr_listContext;
      stmt_assign(): Stmt_assignContext;
      stmt_getdiag(): Stmt_getdiagContext;
      getdiag_area_opt(): Getdiag_area_optContext;
      getdiag_list(): Getdiag_listContext;
      getdiag_list_item(): Getdiag_list_itemContext;
      getdiag_item(): Getdiag_itemContext;
      getdiag_target(): Getdiag_targetContext;
      assign_var(): Assign_varContext;
      stmt_if(): Stmt_ifContext;
      stmt_elsifs(): Stmt_elsifsContext;
      stmt_else(): Stmt_elseContext;
      stmt_case(): Stmt_caseContext;
      opt_expr_until_when(): Opt_expr_until_whenContext;
      case_when_list(): Case_when_listContext;
      case_when(): Case_whenContext;
      opt_case_else(): Opt_case_elseContext;
      stmt_loop(): Stmt_loopContext;
      stmt_while(): Stmt_whileContext;
      stmt_for(): Stmt_forContext;
      for_control(): For_controlContext;
      opt_for_using_expression(): Opt_for_using_expressionContext;
      opt_cursor_parameters(): Opt_cursor_parametersContext;
      opt_reverse(): Opt_reverseContext;
      opt_by_expression(): Opt_by_expressionContext;
      for_variable(): For_variableContext;
      stmt_foreach_a(): Stmt_foreach_aContext;
      foreach_slice(): Foreach_sliceContext;
      stmt_exit(): Stmt_exitContext;
      exit_type(): Exit_typeContext;
      stmt_return(): Stmt_returnContext;
      opt_return_result(): Opt_return_resultContext;
      stmt_raise(): Stmt_raiseContext;
      opt_stmt_raise_level(): Opt_stmt_raise_levelContext;
      opt_raise_list(): Opt_raise_listContext;
      opt_raise_using(): Opt_raise_usingContext;
      opt_raise_using_elem(): Opt_raise_using_elemContext;
      opt_raise_using_elem_list(): Opt_raise_using_elem_listContext;
      stmt_assert(): Stmt_assertContext;
      opt_stmt_assert_message(): Opt_stmt_assert_messageContext;
      loop_body(): Loop_bodyContext;
      stmt_execsql(): Stmt_execsqlContext;
      stmt_dynexecute(): Stmt_dynexecuteContext;
      opt_execute_using(): Opt_execute_usingContext;
      opt_execute_using_list(): Opt_execute_using_listContext;
      opt_execute_into(): Opt_execute_intoContext;
      stmt_open(): Stmt_openContext;
      opt_open_bound_list_item(): Opt_open_bound_list_itemContext;
      opt_open_bound_list(): Opt_open_bound_listContext;
      opt_open_using(): Opt_open_usingContext;
      opt_scroll_option(): Opt_scroll_optionContext;
      opt_scroll_option_no(): Opt_scroll_option_noContext;
      stmt_fetch(): Stmt_fetchContext;
      into_target(): Into_targetContext;
      opt_cursor_from(): Opt_cursor_fromContext;
      opt_fetch_direction(): Opt_fetch_directionContext;
      stmt_move(): Stmt_moveContext;
      stmt_close(): Stmt_closeContext;
      stmt_null(): Stmt_nullContext;
      stmt_commit(): Stmt_commitContext;
      stmt_rollback(): Stmt_rollbackContext;
      plsql_opt_transaction_chain(): Plsql_opt_transaction_chainContext;
      stmt_set(): Stmt_setContext;
      cursor_variable(): Cursor_variableContext;
      exception_sect(): Exception_sectContext;
      proc_exceptions(): Proc_exceptionsContext;
      proc_exception(): Proc_exceptionContext;
      proc_conditions(): Proc_conditionsContext;
      proc_condition(): Proc_conditionContext;
      opt_block_label(): Opt_block_labelContext;
      opt_loop_label(): Opt_loop_labelContext;
      opt_label(): Opt_labelContext;
      opt_exitcond(): Opt_exitcondContext;
      any_identifier(): Any_identifierContext;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext;
      sql_expression(): Sql_expressionContext;
      expr_until_then(): Expr_until_thenContext;
      expr_until_semi(): Expr_until_semiContext;
      expr_until_rightbracket(): Expr_until_rightbracketContext;
      expr_until_loop(): Expr_until_loopContext;
      make_execsql_stmt(): Make_execsql_stmtContext;
      opt_returning_clause_into(): Opt_returning_clause_intoContext;
      sempred(localContext: antlr.RuleContext | null, ruleIndex: number, predIndex: number): boolean;
      private b_expr_sempred;
      static readonly _serializedATN: number[];
      private static __ATN;
      static get _ATN(): antlr.ATN;
      private static readonly vocabulary;
      get vocabulary(): antlr.Vocabulary;
      private static readonly decisionsToDFA;
  }
  export class RootContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      stmtblock(): StmtblockContext;
      EOF(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PlsqlrootContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      pl_function(): Pl_functionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class StmtblockContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      stmtmulti(): StmtmultiContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class StmtmultiContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      stmt(): StmtContext[];
      stmt(i: number): StmtContext | null;
      SEMI(): antlr.TerminalNode[];
      SEMI(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class StmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      altereventtrigstmt(): AltereventtrigstmtContext | null;
      altercollationstmt(): AltercollationstmtContext | null;
      alterdatabasestmt(): AlterdatabasestmtContext | null;
      alterdatabasesetstmt(): AlterdatabasesetstmtContext | null;
      alterdefaultprivilegesstmt(): AlterdefaultprivilegesstmtContext | null;
      alterdomainstmt(): AlterdomainstmtContext | null;
      alterenumstmt(): AlterenumstmtContext | null;
      alterextensionstmt(): AlterextensionstmtContext | null;
      alterextensioncontentsstmt(): AlterextensioncontentsstmtContext | null;
      alterfdwstmt(): AlterfdwstmtContext | null;
      alterforeignserverstmt(): AlterforeignserverstmtContext | null;
      alterfunctionstmt(): AlterfunctionstmtContext | null;
      altergroupstmt(): AltergroupstmtContext | null;
      alterobjectdependsstmt(): AlterobjectdependsstmtContext | null;
      alterobjectschemastmt(): AlterobjectschemastmtContext | null;
      alterownerstmt(): AlterownerstmtContext | null;
      alteroperatorstmt(): AlteroperatorstmtContext | null;
      altertypestmt(): AltertypestmtContext | null;
      alterpolicystmt(): AlterpolicystmtContext | null;
      alterseqstmt(): AlterseqstmtContext | null;
      altersystemstmt(): AltersystemstmtContext | null;
      altertablestmt(): AltertablestmtContext | null;
      altertblspcstmt(): AltertblspcstmtContext | null;
      altercompositetypestmt(): AltercompositetypestmtContext | null;
      alterpublicationstmt(): AlterpublicationstmtContext | null;
      alterrolesetstmt(): AlterrolesetstmtContext | null;
      alterrolestmt(): AlterrolestmtContext | null;
      altersubscriptionstmt(): AltersubscriptionstmtContext | null;
      alterstatsstmt(): AlterstatsstmtContext | null;
      altertsconfigurationstmt(): AltertsconfigurationstmtContext | null;
      altertsdictionarystmt(): AltertsdictionarystmtContext | null;
      alterusermappingstmt(): AlterusermappingstmtContext | null;
      analyzestmt(): AnalyzestmtContext | null;
      callstmt(): CallstmtContext | null;
      checkpointstmt(): CheckpointstmtContext | null;
      closeportalstmt(): CloseportalstmtContext | null;
      clusterstmt(): ClusterstmtContext | null;
      commentstmt(): CommentstmtContext | null;
      constraintssetstmt(): ConstraintssetstmtContext | null;
      copystmt(): CopystmtContext | null;
      createamstmt(): CreateamstmtContext | null;
      createasstmt(): CreateasstmtContext | null;
      createassertionstmt(): CreateassertionstmtContext | null;
      createcaststmt(): CreatecaststmtContext | null;
      createconversionstmt(): CreateconversionstmtContext | null;
      createdomainstmt(): CreatedomainstmtContext | null;
      createextensionstmt(): CreateextensionstmtContext | null;
      createfdwstmt(): CreatefdwstmtContext | null;
      createforeignserverstmt(): CreateforeignserverstmtContext | null;
      createforeigntablestmt(): CreateforeigntablestmtContext | null;
      createfunctionstmt(): CreatefunctionstmtContext | null;
      creategroupstmt(): CreategroupstmtContext | null;
      creatematviewstmt(): CreatematviewstmtContext | null;
      createopclassstmt(): CreateopclassstmtContext | null;
      createopfamilystmt(): CreateopfamilystmtContext | null;
      createpublicationstmt(): CreatepublicationstmtContext | null;
      alteropfamilystmt(): AlteropfamilystmtContext | null;
      createpolicystmt(): CreatepolicystmtContext | null;
      createplangstmt(): CreateplangstmtContext | null;
      createschemastmt(): CreateschemastmtContext | null;
      createseqstmt(): CreateseqstmtContext | null;
      createstmt(): CreatestmtContext | null;
      createsubscriptionstmt(): CreatesubscriptionstmtContext | null;
      createstatsstmt(): CreatestatsstmtContext | null;
      createtablespacestmt(): CreatetablespacestmtContext | null;
      createtransformstmt(): CreatetransformstmtContext | null;
      createtrigstmt(): CreatetrigstmtContext | null;
      createeventtrigstmt(): CreateeventtrigstmtContext | null;
      createrolestmt(): CreaterolestmtContext | null;
      createuserstmt(): CreateuserstmtContext | null;
      createusermappingstmt(): CreateusermappingstmtContext | null;
      createdbstmt(): CreatedbstmtContext | null;
      deallocatestmt(): DeallocatestmtContext | null;
      declarecursorstmt(): DeclarecursorstmtContext | null;
      definestmt(): DefinestmtContext | null;
      deletestmt(): DeletestmtContext | null;
      discardstmt(): DiscardstmtContext | null;
      dostmt(): DostmtContext | null;
      dropcaststmt(): DropcaststmtContext | null;
      dropopclassstmt(): DropopclassstmtContext | null;
      dropopfamilystmt(): DropopfamilystmtContext | null;
      dropownedstmt(): DropownedstmtContext | null;
      dropstmt(): DropstmtContext | null;
      dropsubscriptionstmt(): DropsubscriptionstmtContext | null;
      droptablespacestmt(): DroptablespacestmtContext | null;
      droptransformstmt(): DroptransformstmtContext | null;
      droprolestmt(): DroprolestmtContext | null;
      dropusermappingstmt(): DropusermappingstmtContext | null;
      dropdbstmt(): DropdbstmtContext | null;
      executestmt(): ExecutestmtContext | null;
      explainstmt(): ExplainstmtContext | null;
      fetchstmt(): FetchstmtContext | null;
      grantstmt(): GrantstmtContext | null;
      grantrolestmt(): GrantrolestmtContext | null;
      importforeignschemastmt(): ImportforeignschemastmtContext | null;
      indexstmt(): IndexstmtContext | null;
      insertstmt(): InsertstmtContext | null;
      mergestmt(): MergestmtContext | null;
      listenstmt(): ListenstmtContext | null;
      refreshmatviewstmt(): RefreshmatviewstmtContext | null;
      loadstmt(): LoadstmtContext | null;
      lockstmt(): LockstmtContext | null;
      notifystmt(): NotifystmtContext | null;
      preparestmt(): PreparestmtContext | null;
      reassignownedstmt(): ReassignownedstmtContext | null;
      reindexstmt(): ReindexstmtContext | null;
      removeaggrstmt(): RemoveaggrstmtContext | null;
      removefuncstmt(): RemovefuncstmtContext | null;
      removeoperstmt(): RemoveoperstmtContext | null;
      renamestmt(): RenamestmtContext | null;
      revokestmt(): RevokestmtContext | null;
      revokerolestmt(): RevokerolestmtContext | null;
      rulestmt(): RulestmtContext | null;
      seclabelstmt(): SeclabelstmtContext | null;
      selectstmt(): SelectstmtContext | null;
      transactionstmt(): TransactionstmtContext | null;
      truncatestmt(): TruncatestmtContext | null;
      unlistenstmt(): UnlistenstmtContext | null;
      updatestmt(): UpdatestmtContext | null;
      vacuumstmt(): VacuumstmtContext | null;
      variableresetstmt(): VariableresetstmtContext | null;
      variablesetstmt(): VariablesetstmtContext | null;
      variableshowstmt(): VariableshowstmtContext | null;
      viewstmt(): ViewstmtContext | null;
      plsqlconsolecommand(): PlsqlconsolecommandContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PlsqlconsolecommandContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MetaCommand(): antlr.TerminalNode;
      EndMetaCommand(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CallstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CALL(): antlr.TerminalNode;
      func_application(): Func_applicationContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreaterolestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      ROLE(): antlr.TerminalNode;
      roleid(): RoleidContext;
      opt_with(): Opt_withContext;
      optrolelist(): OptrolelistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_withContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptrolelistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createoptroleelem(): CreateoptroleelemContext[];
      createoptroleelem(i: number): CreateoptroleelemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlteroptrolelistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alteroptroleelem(): AlteroptroleelemContext[];
      alteroptroleelem(i: number): AlteroptroleelemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlteroptroleelemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PASSWORD(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      NULL_P(): antlr.TerminalNode | null;
      ENCRYPTED(): antlr.TerminalNode | null;
      UNENCRYPTED(): antlr.TerminalNode | null;
      INHERIT(): antlr.TerminalNode | null;
      CONNECTION(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      signediconst(): SignediconstContext | null;
      VALID(): antlr.TerminalNode | null;
      UNTIL(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      role_list(): Role_listContext | null;
      identifier(): IdentifierContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateoptroleelemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alteroptroleelem(): AlteroptroleelemContext | null;
      SYSID(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      ADMIN(): antlr.TerminalNode | null;
      role_list(): Role_listContext | null;
      ROLE(): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      GROUP_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateuserstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      roleid(): RoleidContext;
      opt_with(): Opt_withContext;
      optrolelist(): OptrolelistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterrolestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      rolespec(): RolespecContext;
      opt_with(): Opt_withContext;
      alteroptrolelist(): AlteroptrolelistContext;
      ROLE(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_in_databaseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IN_P(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterrolesetstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      rolespec(): RolespecContext;
      opt_in_database(): Opt_in_databaseContext;
      setresetclause(): SetresetclauseContext;
      ROLE(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DroprolestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      role_list(): Role_listContext;
      ROLE(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      GROUP_P(): antlr.TerminalNode | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreategroupstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      GROUP_P(): antlr.TerminalNode;
      roleid(): RoleidContext;
      opt_with(): Opt_withContext;
      optrolelist(): OptrolelistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltergroupstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      GROUP_P(): antlr.TerminalNode;
      rolespec(): RolespecContext;
      add_drop(): Add_dropContext;
      USER(): antlr.TerminalNode;
      role_list(): Role_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Add_dropContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ADD_P(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateschemastmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      SCHEMA(): antlr.TerminalNode;
      optschemaeltlist(): OptschemaeltlistContext;
      optschemaname(): OptschemanameContext | null;
      AUTHORIZATION(): antlr.TerminalNode | null;
      rolespec(): RolespecContext | null;
      colid(): ColidContext | null;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptschemanameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptschemaeltlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      schema_stmt(): Schema_stmtContext[];
      schema_stmt(i: number): Schema_stmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Schema_stmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createstmt(): CreatestmtContext | null;
      indexstmt(): IndexstmtContext | null;
      createseqstmt(): CreateseqstmtContext | null;
      createtrigstmt(): CreatetrigstmtContext | null;
      grantstmt(): GrantstmtContext | null;
      viewstmt(): ViewstmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class VariablesetstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      set_rest(): Set_restContext;
      LOCAL(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Set_restContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRANSACTION(): antlr.TerminalNode | null;
      transaction_mode_list(): Transaction_mode_listContext | null;
      SESSION(): antlr.TerminalNode | null;
      CHARACTERISTICS(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      set_rest_more(): Set_rest_moreContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generic_setContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      var_name(): Var_nameContext;
      var_list(): Var_listContext;
      TO(): antlr.TerminalNode | null;
      EQUAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Set_rest_moreContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      generic_set(): Generic_setContext | null;
      var_name(): Var_nameContext | null;
      FROM(): antlr.TerminalNode | null;
      CURRENT_P(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      ZONE(): antlr.TerminalNode | null;
      zone_value(): Zone_valueContext | null;
      CATALOG(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      SCHEMA(): antlr.TerminalNode | null;
      NAMES(): antlr.TerminalNode | null;
      opt_encoding(): Opt_encodingContext | null;
      ROLE(): antlr.TerminalNode | null;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext | null;
      SESSION(): antlr.TerminalNode | null;
      AUTHORIZATION(): antlr.TerminalNode | null;
      XML_P(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      document_or_content(): Document_or_contentContext | null;
      TRANSACTION(): antlr.TerminalNode | null;
      SNAPSHOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Var_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext[];
      colid(i: number): ColidContext | null;
      DOT(): antlr.TerminalNode[];
      DOT(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Var_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      var_value(): Var_valueContext[];
      var_value(i: number): Var_valueContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Var_valueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_boolean_or_string(): Opt_boolean_or_stringContext | null;
      numericonly(): NumericonlyContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Iso_levelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      READ(): antlr.TerminalNode | null;
      UNCOMMITTED(): antlr.TerminalNode | null;
      COMMITTED(): antlr.TerminalNode | null;
      REPEATABLE(): antlr.TerminalNode | null;
      SERIALIZABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_boolean_or_stringContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRUE_P(): antlr.TerminalNode | null;
      FALSE_P(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Zone_valueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      identifier(): IdentifierContext | null;
      constinterval(): ConstintervalContext | null;
      opt_interval(): Opt_intervalContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      numericonly(): NumericonlyContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_encodingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Nonreservedword_or_sconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nonreservedword(): NonreservedwordContext | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class VariableresetstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESET(): antlr.TerminalNode;
      reset_rest(): Reset_restContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reset_restContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      generic_reset(): Generic_resetContext | null;
      TIME(): antlr.TerminalNode | null;
      ZONE(): antlr.TerminalNode | null;
      TRANSACTION(): antlr.TerminalNode | null;
      ISOLATION(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      AUTHORIZATION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generic_resetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      var_name(): Var_nameContext | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SetresetclauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode | null;
      set_rest(): Set_restContext | null;
      variableresetstmt(): VariableresetstmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class FunctionsetresetclauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode | null;
      set_rest_more(): Set_rest_moreContext | null;
      variableresetstmt(): VariableresetstmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class VariableshowstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SHOW(): antlr.TerminalNode;
      var_name(): Var_nameContext | null;
      TIME(): antlr.TerminalNode | null;
      ZONE(): antlr.TerminalNode | null;
      TRANSACTION(): antlr.TerminalNode | null;
      ISOLATION(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      AUTHORIZATION(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstraintssetstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode;
      CONSTRAINTS(): antlr.TerminalNode;
      constraints_set_list(): Constraints_set_listContext;
      constraints_set_mode(): Constraints_set_modeContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Constraints_set_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      qualified_name_list(): Qualified_name_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Constraints_set_modeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEFERRED(): antlr.TerminalNode | null;
      IMMEDIATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CheckpointstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHECKPOINT(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DiscardstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DISCARD(): antlr.TerminalNode;
      ALL(): antlr.TerminalNode | null;
      TEMP(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      PLANS(): antlr.TerminalNode | null;
      SEQUENCES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltertablestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode | null;
      relation_expr(): Relation_exprContext | null;
      alter_table_cmds(): Alter_table_cmdsContext | null;
      partition_cmd(): Partition_cmdContext | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode[];
      TABLESPACE(i: number): antlr.TerminalNode | null;
      name(): NameContext[];
      name(i: number): NameContext | null;
      SET(): antlr.TerminalNode | null;
      opt_nowait(): Opt_nowaitContext | null;
      OWNED(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      role_list(): Role_listContext | null;
      INDEX(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      index_partition_cmd(): Index_partition_cmdContext | null;
      SEQUENCE(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_table_cmdsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alter_table_cmd(): Alter_table_cmdContext[];
      alter_table_cmd(i: number): Alter_table_cmdContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Partition_cmdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ATTACH(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      partitionboundspec(): PartitionboundspecContext | null;
      DETACH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Index_partition_cmdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ATTACH(): antlr.TerminalNode;
      PARTITION(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_table_cmdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ADD_P(): antlr.TerminalNode | null;
      columnDef(): ColumnDefContext | null;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      COLUMN(): antlr.TerminalNode | null;
      ALTER(): antlr.TerminalNode | null;
      opt_column(): Opt_columnContext | null;
      colid(): ColidContext[];
      colid(i: number): ColidContext | null;
      alter_column_default(): Alter_column_defaultContext | null;
      DROP(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      EXPRESSION(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      signediconst(): SignediconstContext | null;
      iconst(): IconstContext | null;
      reloptions(): ReloptionsContext | null;
      RESET(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      GENERATED(): antlr.TerminalNode | null;
      generated_when(): Generated_whenContext | null;
      AS(): antlr.TerminalNode | null;
      IDENTITY_P(): antlr.TerminalNode | null;
      optparenthesizedseqoptlist(): OptparenthesizedseqoptlistContext | null;
      alter_identity_column_option_list(): Alter_identity_column_option_listContext | null;
      opt_drop_behavior(): Opt_drop_behaviorContext | null;
      opt_set_data(): Opt_set_dataContext | null;
      TYPE_P(): antlr.TerminalNode | null;
      typename(): TypenameContext | null;
      opt_collate_clause(): Opt_collate_clauseContext | null;
      alter_using(): Alter_usingContext | null;
      alter_generic_options(): Alter_generic_optionsContext | null;
      tableconstraint(): TableconstraintContext | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      name(): NameContext | null;
      constraintattributespec(): ConstraintattributespecContext | null;
      VALIDATE(): antlr.TerminalNode | null;
      WITHOUT(): antlr.TerminalNode | null;
      OIDS(): antlr.TerminalNode | null;
      CLUSTER(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      LOGGED(): antlr.TerminalNode | null;
      UNLOGGED(): antlr.TerminalNode | null;
      ENABLE_P(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      ALWAYS(): antlr.TerminalNode | null;
      REPLICA(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      DISABLE_P(): antlr.TerminalNode | null;
      RULE(): antlr.TerminalNode | null;
      INHERIT(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      NO(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      OWNER(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      rolespec(): RolespecContext | null;
      TABLESPACE(): antlr.TerminalNode | null;
      replica_identity(): Replica_identityContext | null;
      ROW(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      SECURITY(): antlr.TerminalNode | null;
      FORCE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_column_defaultContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode;
      a_expr(): A_exprContext | null;
      DROP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_drop_behaviorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CASCADE(): antlr.TerminalNode | null;
      RESTRICT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_collate_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COLLATE(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_usingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Replica_identityContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOTHING(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ReloptionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      reloption_list(): Reloption_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_reloptionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      reloptions(): ReloptionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reloption_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      reloption_elem(): Reloption_elemContext[];
      reloption_elem(i: number): Reloption_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reloption_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext[];
      collabel(i: number): CollabelContext | null;
      EQUAL(): antlr.TerminalNode | null;
      def_arg(): Def_argContext | null;
      DOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_identity_column_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alter_identity_column_option(): Alter_identity_column_optionContext[];
      alter_identity_column_option(i: number): Alter_identity_column_optionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_identity_column_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESTART(): antlr.TerminalNode | null;
      opt_with(): Opt_withContext | null;
      numericonly(): NumericonlyContext | null;
      SET(): antlr.TerminalNode | null;
      seqoptelem(): SeqoptelemContext | null;
      GENERATED(): antlr.TerminalNode | null;
      generated_when(): Generated_whenContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PartitionboundspecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      VALUES(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode[];
      OPEN_PAREN(i: number): antlr.TerminalNode | null;
      hash_partbound(): Hash_partboundContext | null;
      CLOSE_PAREN(): antlr.TerminalNode[];
      CLOSE_PAREN(i: number): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext[];
      expr_list(i: number): Expr_listContext | null;
      FROM(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Hash_partbound_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nonreservedword(): NonreservedwordContext;
      iconst(): IconstContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Hash_partboundContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      hash_partbound_elem(): Hash_partbound_elemContext[];
      hash_partbound_elem(i: number): Hash_partbound_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltercompositetypestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TYPE_P(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      alter_type_cmds(): Alter_type_cmdsContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_type_cmdsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alter_type_cmd(): Alter_type_cmdContext[];
      alter_type_cmd(i: number): Alter_type_cmdContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_type_cmdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ADD_P(): antlr.TerminalNode | null;
      ATTRIBUTE(): antlr.TerminalNode;
      tablefuncelement(): TablefuncelementContext | null;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      DROP(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      ALTER(): antlr.TerminalNode | null;
      opt_set_data(): Opt_set_dataContext | null;
      TYPE_P(): antlr.TerminalNode | null;
      typename(): TypenameContext | null;
      opt_collate_clause(): Opt_collate_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CloseportalstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CLOSE(): antlr.TerminalNode;
      cursor_name(): Cursor_nameContext | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CopystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COPY(): antlr.TerminalNode;
      opt_binary(): Opt_binaryContext | null;
      qualified_name(): Qualified_nameContext | null;
      opt_column_list(): Opt_column_listContext | null;
      copy_from(): Copy_fromContext | null;
      opt_program(): Opt_programContext;
      copy_file_name(): Copy_file_nameContext;
      copy_delimiter(): Copy_delimiterContext | null;
      opt_with(): Opt_withContext;
      copy_options(): Copy_optionsContext;
      where_clause(): Where_clauseContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      preparablestmt(): PreparablestmtContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_fromContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_programContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PROGRAM(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_file_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      STDIN(): antlr.TerminalNode | null;
      STDOUT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      copy_opt_list(): Copy_opt_listContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      copy_generic_opt_list(): Copy_generic_opt_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      copy_opt_item(): Copy_opt_itemContext[];
      copy_opt_item(i: number): Copy_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BINARY(): antlr.TerminalNode | null;
      FREEZE(): antlr.TerminalNode | null;
      DELIMITER(): antlr.TerminalNode | null;
      opt_as(): Opt_asContext | null;
      sconst(): SconstContext | null;
      NULL_P(): antlr.TerminalNode | null;
      CSV(): antlr.TerminalNode | null;
      HEADER_P(): antlr.TerminalNode | null;
      QUOTE(): antlr.TerminalNode | null;
      ESCAPE(): antlr.TerminalNode | null;
      FORCE(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      STAR(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      ENCODING(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_binaryContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BINARY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_delimiterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_using(): Opt_usingContext | null;
      DELIMITERS(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_usingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_generic_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      copy_generic_opt_elem(): Copy_generic_opt_elemContext[];
      copy_generic_opt_elem(i: number): Copy_generic_opt_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_generic_opt_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext;
      copy_generic_opt_arg(): Copy_generic_opt_argContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_generic_opt_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_boolean_or_string(): Opt_boolean_or_stringContext | null;
      numericonly(): NumericonlyContext | null;
      STAR(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      copy_generic_opt_arg_list(): Copy_generic_opt_arg_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_generic_opt_arg_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      copy_generic_opt_arg_list_item(): Copy_generic_opt_arg_list_itemContext[];
      copy_generic_opt_arg_list_item(i: number): Copy_generic_opt_arg_list_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Copy_generic_opt_arg_list_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_boolean_or_string(): Opt_boolean_or_stringContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opttemp(): OpttempContext;
      TABLE(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext[];
      qualified_name(i: number): Qualified_nameContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      opttableelementlist(): OpttableelementlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      optinherit(): OptinheritContext | null;
      optpartitionspec(): OptpartitionspecContext | null;
      table_access_method_clause(): Table_access_method_clauseContext | null;
      optwith(): OptwithContext | null;
      oncommitoption(): OncommitoptionContext | null;
      opttablespace(): OpttablespaceContext | null;
      OF(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      opttypedtableelementlist(): OpttypedtableelementlistContext | null;
      PARTITION(): antlr.TerminalNode | null;
      partitionboundspec(): PartitionboundspecContext | null;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttempContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TEMPORARY(): antlr.TerminalNode | null;
      TEMP(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      UNLOGGED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttableelementlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableelementlist(): TableelementlistContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttypedtableelementlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      typedtableelementlist(): TypedtableelementlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TableelementlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableelement(): TableelementContext[];
      tableelement(i: number): TableelementContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TypedtableelementlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      typedtableelement(): TypedtableelementContext[];
      typedtableelement(i: number): TypedtableelementContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TableelementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tableconstraint(): TableconstraintContext | null;
      tablelikeclause(): TablelikeclauseContext | null;
      columnDef(): ColumnDefContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TypedtableelementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnOptions(): ColumnOptionsContext | null;
      tableconstraint(): TableconstraintContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColumnDefContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      typename(): TypenameContext;
      create_generic_options(): Create_generic_optionsContext;
      colquallist(): ColquallistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColumnOptionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      colquallist(): ColquallistContext;
      WITH(): antlr.TerminalNode | null;
      OPTIONS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColquallistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colconstraint(): ColconstraintContext[];
      colconstraint(i: number): ColconstraintContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColconstraintContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CONSTRAINT(): antlr.TerminalNode | null;
      name(): NameContext | null;
      colconstraintelem(): ColconstraintelemContext | null;
      constraintattr(): ConstraintattrContext | null;
      COLLATE(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColconstraintelemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOT(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      UNIQUE(): antlr.TerminalNode | null;
      opt_definition(): Opt_definitionContext | null;
      optconstablespace(): OptconstablespaceContext | null;
      PRIMARY(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      opt_no_inherit(): Opt_no_inheritContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      b_expr(): B_exprContext | null;
      GENERATED(): antlr.TerminalNode | null;
      generated_when(): Generated_whenContext | null;
      AS(): antlr.TerminalNode | null;
      IDENTITY_P(): antlr.TerminalNode | null;
      optparenthesizedseqoptlist(): OptparenthesizedseqoptlistContext | null;
      STORED(): antlr.TerminalNode | null;
      REFERENCES(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      opt_column_list(): Opt_column_listContext | null;
      key_match(): Key_matchContext | null;
      key_actions(): Key_actionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generated_whenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALWAYS(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstraintattrContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEFERRABLE(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      INITIALLY(): antlr.TerminalNode | null;
      DEFERRED(): antlr.TerminalNode | null;
      IMMEDIATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TablelikeclauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIKE(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      tablelikeoptionlist(): TablelikeoptionlistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TablelikeoptionlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tablelikeoption(): TablelikeoptionContext[];
      tablelikeoption(i: number): TablelikeoptionContext | null;
      INCLUDING(): antlr.TerminalNode[];
      INCLUDING(i: number): antlr.TerminalNode | null;
      EXCLUDING(): antlr.TerminalNode[];
      EXCLUDING(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TablelikeoptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMENTS(): antlr.TerminalNode | null;
      CONSTRAINTS(): antlr.TerminalNode | null;
      DEFAULTS(): antlr.TerminalNode | null;
      IDENTITY_P(): antlr.TerminalNode | null;
      GENERATED(): antlr.TerminalNode | null;
      INDEXES(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TableconstraintContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CONSTRAINT(): antlr.TerminalNode | null;
      name(): NameContext | null;
      constraintelem(): ConstraintelemContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstraintelemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CHECK(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      constraintattributespec(): ConstraintattributespecContext | null;
      UNIQUE(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      opt_c_include(): Opt_c_includeContext | null;
      opt_definition(): Opt_definitionContext | null;
      optconstablespace(): OptconstablespaceContext | null;
      existingindex(): ExistingindexContext | null;
      PRIMARY(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      EXCLUDE(): antlr.TerminalNode | null;
      access_method_clause(): Access_method_clauseContext | null;
      exclusionconstraintlist(): ExclusionconstraintlistContext | null;
      exclusionwhereclause(): ExclusionwhereclauseContext | null;
      FOREIGN(): antlr.TerminalNode | null;
      REFERENCES(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      opt_column_list(): Opt_column_listContext | null;
      key_match(): Key_matchContext | null;
      key_actions(): Key_actionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_no_inheritContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NO(): antlr.TerminalNode | null;
      INHERIT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_column_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColumnlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      columnElem(): ColumnElemContext[];
      columnElem(i: number): ColumnElemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColumnElemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_c_includeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INCLUDE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Key_matchContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MATCH(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      PARTIAL(): antlr.TerminalNode | null;
      SIMPLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExclusionconstraintlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      exclusionconstraintelem(): ExclusionconstraintelemContext[];
      exclusionconstraintelem(i: number): ExclusionconstraintelemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExclusionconstraintelemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      index_elem(): Index_elemContext;
      WITH(): antlr.TerminalNode;
      any_operator(): Any_operatorContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExclusionwhereclauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHERE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Key_actionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      key_update(): Key_updateContext | null;
      key_delete(): Key_deleteContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Key_updateContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode;
      UPDATE(): antlr.TerminalNode;
      key_action(): Key_actionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Key_deleteContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode;
      DELETE_P(): antlr.TerminalNode;
      key_action(): Key_actionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Key_actionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NO(): antlr.TerminalNode | null;
      ACTION(): antlr.TerminalNode | null;
      RESTRICT(): antlr.TerminalNode | null;
      CASCADE(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptinheritContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INHERITS(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      qualified_name_list(): Qualified_name_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptpartitionspecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      partitionspec(): PartitionspecContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PartitionspecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      colid(): ColidContext;
      OPEN_PAREN(): antlr.TerminalNode;
      part_params(): Part_paramsContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Part_paramsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      part_elem(): Part_elemContext[];
      part_elem(i: number): Part_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Part_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      opt_collate(): Opt_collateContext;
      opt_class(): Opt_classContext;
      func_expr_windowless(): Func_expr_windowlessContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Table_access_method_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptwithContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      reloptions(): ReloptionsContext | null;
      WITHOUT(): antlr.TerminalNode | null;
      OIDS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OncommitoptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode | null;
      COMMIT(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      DELETE_P(): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode | null;
      PRESERVE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttablespaceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLESPACE(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptconstablespaceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExistingindexContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode;
      INDEX(): antlr.TerminalNode;
      name(): NameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatestatsstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      STATISTICS(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      opt_name_list(): Opt_name_listContext;
      ON(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      FROM(): antlr.TerminalNode;
      from_list(): From_listContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterstatsstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      STATISTICS(): antlr.TerminalNode[];
      STATISTICS(i: number): antlr.TerminalNode | null;
      any_name(): Any_nameContext;
      SET(): antlr.TerminalNode;
      signediconst(): SignediconstContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateasstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opttemp(): OpttempContext;
      TABLE(): antlr.TerminalNode;
      create_as_target(): Create_as_targetContext;
      AS(): antlr.TerminalNode;
      selectstmt(): SelectstmtContext;
      opt_with_data(): Opt_with_dataContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Create_as_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name(): Qualified_nameContext;
      opt_column_list(): Opt_column_listContext;
      table_access_method_clause(): Table_access_method_clauseContext;
      optwith(): OptwithContext;
      oncommitoption(): OncommitoptionContext;
      opttablespace(): OpttablespaceContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_with_dataContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatematviewstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      optnolog(): OptnologContext;
      MATERIALIZED(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      create_mv_target(): Create_mv_targetContext;
      AS(): antlr.TerminalNode;
      selectstmt(): SelectstmtContext;
      opt_with_data(): Opt_with_dataContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Create_mv_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name(): Qualified_nameContext;
      opt_column_list(): Opt_column_listContext;
      table_access_method_clause(): Table_access_method_clauseContext;
      opt_reloptions(): Opt_reloptionsContext;
      opttablespace(): OpttablespaceContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptnologContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNLOGGED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RefreshmatviewstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REFRESH(): antlr.TerminalNode;
      MATERIALIZED(): antlr.TerminalNode;
      VIEW(): antlr.TerminalNode;
      opt_concurrently(): Opt_concurrentlyContext;
      qualified_name(): Qualified_nameContext;
      opt_with_data(): Opt_with_dataContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateseqstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opttemp(): OpttempContext;
      SEQUENCE(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      optseqoptlist(): OptseqoptlistContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterseqstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      SEQUENCE(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      seqoptlist(): SeqoptlistContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptseqoptlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      seqoptlist(): SeqoptlistContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptparenthesizedseqoptlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      seqoptlist(): SeqoptlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SeqoptlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      seqoptelem(): SeqoptelemContext[];
      seqoptelem(i: number): SeqoptelemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SeqoptelemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode | null;
      simpletypename(): SimpletypenameContext | null;
      CACHE(): antlr.TerminalNode | null;
      numericonly(): NumericonlyContext | null;
      CYCLE(): antlr.TerminalNode | null;
      INCREMENT(): antlr.TerminalNode | null;
      opt_by(): Opt_byContext | null;
      MAXVALUE(): antlr.TerminalNode | null;
      MINVALUE(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      OWNED(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      SEQUENCE(): antlr.TerminalNode | null;
      NAME_P(): antlr.TerminalNode | null;
      START(): antlr.TerminalNode | null;
      opt_with(): Opt_withContext | null;
      RESTART(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_byContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class NumericonlyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fconst(): FconstContext | null;
      PLUS(): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode | null;
      signediconst(): SignediconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Numericonly_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      numericonly(): NumericonlyContext[];
      numericonly(i: number): NumericonlyContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateplangstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_or_replace(): Opt_or_replaceContext;
      opt_trusted(): Opt_trustedContext;
      opt_procedural(): Opt_proceduralContext;
      LANGUAGE(): antlr.TerminalNode;
      name(): NameContext;
      HANDLER(): antlr.TerminalNode | null;
      handler_name(): Handler_nameContext | null;
      opt_inline_handler(): Opt_inline_handlerContext | null;
      opt_validator(): Opt_validatorContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_trustedContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRUSTED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Handler_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      name(): NameContext;
      attrs(): AttrsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_inline_handlerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INLINE_P(): antlr.TerminalNode | null;
      handler_name(): Handler_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Validator_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VALIDATOR(): antlr.TerminalNode;
      handler_name(): Handler_nameContext | null;
      NO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_validatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      validator_clause(): Validator_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_proceduralContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PROCEDURAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatetablespacestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      name(): NameContext;
      opttablespaceowner(): OpttablespaceownerContext;
      LOCATION(): antlr.TerminalNode;
      sconst(): SconstContext;
      opt_reloptions(): Opt_reloptionsContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttablespaceownerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OWNER(): antlr.TerminalNode | null;
      rolespec(): RolespecContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DroptablespacestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      name(): NameContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateextensionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      EXTENSION(): antlr.TerminalNode;
      name(): NameContext;
      opt_with(): Opt_withContext;
      create_extension_opt_list(): Create_extension_opt_listContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Create_extension_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      create_extension_opt_item(): Create_extension_opt_itemContext[];
      create_extension_opt_item(i: number): Create_extension_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Create_extension_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SCHEMA(): antlr.TerminalNode | null;
      name(): NameContext | null;
      VERSION_P(): antlr.TerminalNode | null;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext | null;
      FROM(): antlr.TerminalNode | null;
      CASCADE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterextensionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      EXTENSION(): antlr.TerminalNode;
      name(): NameContext;
      UPDATE(): antlr.TerminalNode;
      alter_extension_opt_list(): Alter_extension_opt_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_extension_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alter_extension_opt_item(): Alter_extension_opt_itemContext[];
      alter_extension_opt_item(i: number): Alter_extension_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_extension_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TO(): antlr.TerminalNode;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterextensioncontentsstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      EXTENSION(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      add_drop(): Add_dropContext;
      object_type_name(): Object_type_nameContext | null;
      object_type_any_name(): Object_type_any_nameContext | null;
      any_name(): Any_nameContext | null;
      AGGREGATE(): antlr.TerminalNode | null;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext | null;
      CAST(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      AS(): antlr.TerminalNode | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      operator_with_argtypes(): Operator_with_argtypesContext | null;
      CLASS(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      FAMILY(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      TRANSFORM(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      LANGUAGE(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatefdwstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      FOREIGN(): antlr.TerminalNode;
      DATA_P(): antlr.TerminalNode;
      WRAPPER(): antlr.TerminalNode;
      name(): NameContext;
      opt_fdw_options(): Opt_fdw_optionsContext;
      create_generic_options(): Create_generic_optionsContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Fdw_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HANDLER(): antlr.TerminalNode | null;
      handler_name(): Handler_nameContext | null;
      NO(): antlr.TerminalNode | null;
      VALIDATOR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Fdw_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fdw_option(): Fdw_optionContext[];
      fdw_option(i: number): Fdw_optionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_fdw_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      fdw_options(): Fdw_optionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterfdwstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      FOREIGN(): antlr.TerminalNode;
      DATA_P(): antlr.TerminalNode;
      WRAPPER(): antlr.TerminalNode;
      name(): NameContext;
      opt_fdw_options(): Opt_fdw_optionsContext | null;
      alter_generic_options(): Alter_generic_optionsContext | null;
      fdw_options(): Fdw_optionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Create_generic_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPTIONS(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      generic_option_list(): Generic_option_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generic_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      generic_option_elem(): Generic_option_elemContext[];
      generic_option_elem(i: number): Generic_option_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_generic_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPTIONS(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      alter_generic_option_list(): Alter_generic_option_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_generic_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alter_generic_option_elem(): Alter_generic_option_elemContext[];
      alter_generic_option_elem(i: number): Alter_generic_option_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alter_generic_option_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      generic_option_elem(): Generic_option_elemContext | null;
      SET(): antlr.TerminalNode | null;
      ADD_P(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      generic_option_name(): Generic_option_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generic_option_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      generic_option_name(): Generic_option_nameContext;
      generic_option_arg(): Generic_option_argContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generic_option_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Generic_option_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateforeignserverstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      SERVER(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      opt_type(): Opt_typeContext;
      opt_foreign_server_version(): Opt_foreign_server_versionContext;
      FOREIGN(): antlr.TerminalNode;
      DATA_P(): antlr.TerminalNode;
      WRAPPER(): antlr.TerminalNode;
      create_generic_options(): Create_generic_optionsContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TYPE_P(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Foreign_server_versionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VERSION_P(): antlr.TerminalNode;
      sconst(): SconstContext | null;
      NULL_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_foreign_server_versionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      foreign_server_version(): Foreign_server_versionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterforeignserverstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      SERVER(): antlr.TerminalNode;
      name(): NameContext;
      alter_generic_options(): Alter_generic_optionsContext | null;
      foreign_server_version(): Foreign_server_versionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateforeigntablestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      FOREIGN(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext[];
      qualified_name(i: number): Qualified_nameContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      opttableelementlist(): OpttableelementlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      optinherit(): OptinheritContext | null;
      SERVER(): antlr.TerminalNode;
      name(): NameContext;
      create_generic_options(): Create_generic_optionsContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      opttypedtableelementlist(): OpttypedtableelementlistContext | null;
      partitionboundspec(): PartitionboundspecContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ImportforeignschemastmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IMPORT_P(): antlr.TerminalNode;
      FOREIGN(): antlr.TerminalNode;
      SCHEMA(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      import_qualification(): Import_qualificationContext;
      FROM(): antlr.TerminalNode;
      SERVER(): antlr.TerminalNode;
      INTO(): antlr.TerminalNode;
      create_generic_options(): Create_generic_optionsContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Import_qualification_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIMIT(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      EXCEPT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Import_qualificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      import_qualification_type(): Import_qualification_typeContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      relation_expr_list(): Relation_expr_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateusermappingstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      MAPPING(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      auth_ident(): Auth_identContext;
      SERVER(): antlr.TerminalNode;
      name(): NameContext;
      create_generic_options(): Create_generic_optionsContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Auth_identContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      rolespec(): RolespecContext | null;
      USER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropusermappingstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      MAPPING(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      auth_ident(): Auth_identContext;
      SERVER(): antlr.TerminalNode;
      name(): NameContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterusermappingstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      USER(): antlr.TerminalNode;
      MAPPING(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      auth_ident(): Auth_identContext;
      SERVER(): antlr.TerminalNode;
      name(): NameContext;
      alter_generic_options(): Alter_generic_optionsContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatepolicystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      POLICY(): antlr.TerminalNode;
      name(): NameContext;
      ON(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      rowsecuritydefaultpermissive(): RowsecuritydefaultpermissiveContext;
      rowsecuritydefaultforcmd(): RowsecuritydefaultforcmdContext;
      rowsecuritydefaulttorole(): RowsecuritydefaulttoroleContext;
      rowsecurityoptionalexpr(): RowsecurityoptionalexprContext;
      rowsecurityoptionalwithcheck(): RowsecurityoptionalwithcheckContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterpolicystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      POLICY(): antlr.TerminalNode;
      name(): NameContext;
      ON(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      rowsecurityoptionaltorole(): RowsecurityoptionaltoroleContext;
      rowsecurityoptionalexpr(): RowsecurityoptionalexprContext;
      rowsecurityoptionalwithcheck(): RowsecurityoptionalwithcheckContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowsecurityoptionalexprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowsecurityoptionalwithcheckContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowsecuritydefaulttoroleContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TO(): antlr.TerminalNode | null;
      role_list(): Role_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowsecurityoptionaltoroleContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TO(): antlr.TerminalNode | null;
      role_list(): Role_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowsecuritydefaultpermissiveContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode | null;
      identifier(): IdentifierContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowsecuritydefaultforcmdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      row_security_cmd(): Row_security_cmdContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Row_security_cmdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      SELECT(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      DELETE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateamstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      ACCESS(): antlr.TerminalNode;
      METHOD(): antlr.TerminalNode;
      name(): NameContext;
      TYPE_P(): antlr.TerminalNode;
      am_type(): Am_typeContext;
      HANDLER(): antlr.TerminalNode;
      handler_name(): Handler_nameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Am_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INDEX(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatetrigstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      TRIGGER(): antlr.TerminalNode;
      name(): NameContext;
      triggeractiontime(): TriggeractiontimeContext | null;
      triggerevents(): TriggereventsContext;
      ON(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      triggerreferencing(): TriggerreferencingContext | null;
      triggerforspec(): TriggerforspecContext | null;
      triggerwhen(): TriggerwhenContext;
      EXECUTE(): antlr.TerminalNode;
      function_or_procedure(): Function_or_procedureContext;
      func_name(): Func_nameContext;
      OPEN_PAREN(): antlr.TerminalNode;
      triggerfuncargs(): TriggerfuncargsContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      CONSTRAINT(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      optconstrfromtable(): OptconstrfromtableContext | null;
      constraintattributespec(): ConstraintattributespecContext | null;
      FOR(): antlr.TerminalNode | null;
      EACH(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggeractiontimeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BEFORE(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      INSTEAD(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggereventsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      triggeroneevent(): TriggeroneeventContext[];
      triggeroneevent(i: number): TriggeroneeventContext | null;
      OR(): antlr.TerminalNode[];
      OR(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggeroneeventContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INSERT(): antlr.TerminalNode | null;
      DELETE_P(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      TRUNCATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerreferencingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REFERENCING(): antlr.TerminalNode | null;
      triggertransitions(): TriggertransitionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggertransitionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      triggertransition(): TriggertransitionContext[];
      triggertransition(i: number): TriggertransitionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggertransitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      transitionoldornew(): TransitionoldornewContext;
      transitionrowortable(): TransitionrowortableContext;
      opt_as(): Opt_asContext;
      transitionrelname(): TransitionrelnameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TransitionoldornewContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NEW(): antlr.TerminalNode | null;
      OLD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TransitionrowortableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLE(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TransitionrelnameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerforspecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      triggerforopteach(): TriggerforopteachContext | null;
      triggerfortype(): TriggerfortypeContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerforopteachContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EACH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerfortypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROW(): antlr.TerminalNode | null;
      STATEMENT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerwhenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Function_or_procedureContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerfuncargsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      triggerfuncarg(): TriggerfuncargContext[];
      triggerfuncarg(i: number): TriggerfuncargContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TriggerfuncargContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      iconst(): IconstContext | null;
      fconst(): FconstContext | null;
      sconst(): SconstContext | null;
      collabel(): CollabelContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OptconstrfromtableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstraintattributespecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      constraintattributeElem(): ConstraintattributeElemContext[];
      constraintattributeElem(i: number): ConstraintattributeElemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstraintattributeElemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOT(): antlr.TerminalNode | null;
      DEFERRABLE(): antlr.TerminalNode | null;
      INITIALLY(): antlr.TerminalNode | null;
      IMMEDIATE(): antlr.TerminalNode | null;
      DEFERRED(): antlr.TerminalNode | null;
      VALID(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      INHERIT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateeventtrigstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      EVENT(): antlr.TerminalNode;
      TRIGGER(): antlr.TerminalNode;
      name(): NameContext;
      ON(): antlr.TerminalNode;
      collabel(): CollabelContext;
      EXECUTE(): antlr.TerminalNode;
      function_or_procedure(): Function_or_procedureContext;
      func_name(): Func_nameContext;
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      WHEN(): antlr.TerminalNode | null;
      event_trigger_when_list(): Event_trigger_when_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Event_trigger_when_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      event_trigger_when_item(): Event_trigger_when_itemContext[];
      event_trigger_when_item(i: number): Event_trigger_when_itemContext | null;
      AND(): antlr.TerminalNode[];
      AND(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Event_trigger_when_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      IN_P(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      event_trigger_value_list(): Event_trigger_value_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Event_trigger_value_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext[];
      sconst(i: number): SconstContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltereventtrigstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      EVENT(): antlr.TerminalNode;
      TRIGGER(): antlr.TerminalNode;
      name(): NameContext;
      enable_trigger(): Enable_triggerContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Enable_triggerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ENABLE_P(): antlr.TerminalNode | null;
      REPLICA(): antlr.TerminalNode | null;
      ALWAYS(): antlr.TerminalNode | null;
      DISABLE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateassertionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      ASSERTION(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      CHECK(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      constraintattributespec(): ConstraintattributespecContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DefinestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_or_replace(): Opt_or_replaceContext | null;
      AGGREGATE(): antlr.TerminalNode | null;
      func_name(): Func_nameContext | null;
      aggr_args(): Aggr_argsContext | null;
      definition(): DefinitionContext | null;
      old_aggr_definition(): Old_aggr_definitionContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      any_operator(): Any_operatorContext | null;
      TYPE_P(): antlr.TerminalNode | null;
      any_name(): Any_nameContext[];
      any_name(i: number): Any_nameContext | null;
      AS(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      opttablefuncelementlist(): OpttablefuncelementlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      ENUM_P(): antlr.TerminalNode | null;
      opt_enum_val_list(): Opt_enum_val_listContext | null;
      RANGE(): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      TEMPLATE(): antlr.TerminalNode | null;
      CONFIGURATION(): antlr.TerminalNode | null;
      COLLATION(): antlr.TerminalNode | null;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DefinitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      def_list(): Def_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Def_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      def_elem(): Def_elemContext[];
      def_elem(i: number): Def_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Def_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext;
      EQUAL(): antlr.TerminalNode | null;
      def_arg(): Def_argContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Def_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_type(): Func_typeContext | null;
      reserved_keyword(): Reserved_keywordContext | null;
      qual_all_op(): Qual_all_opContext | null;
      numericonly(): NumericonlyContext | null;
      sconst(): SconstContext | null;
      NONE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Old_aggr_definitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      old_aggr_list(): Old_aggr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Old_aggr_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      old_aggr_elem(): Old_aggr_elemContext[];
      old_aggr_elem(i: number): Old_aggr_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Old_aggr_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      EQUAL(): antlr.TerminalNode;
      def_arg(): Def_argContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_enum_val_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      enum_val_list(): Enum_val_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Enum_val_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext[];
      sconst(i: number): SconstContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterenumstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TYPE_P(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      ADD_P(): antlr.TerminalNode | null;
      VALUE_P(): antlr.TerminalNode;
      opt_if_not_exists(): Opt_if_not_existsContext | null;
      sconst(): SconstContext[];
      sconst(i: number): SconstContext | null;
      BEFORE(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      RENAME(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_if_not_existsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateopclassstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      CLASS(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      opt_default(): Opt_defaultContext;
      FOR(): antlr.TerminalNode;
      TYPE_P(): antlr.TerminalNode;
      typename(): TypenameContext;
      USING(): antlr.TerminalNode;
      name(): NameContext;
      opt_opfamily(): Opt_opfamilyContext;
      AS(): antlr.TerminalNode;
      opclass_item_list(): Opclass_item_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opclass_item_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opclass_item(): Opclass_itemContext[];
      opclass_item(i: number): Opclass_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opclass_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPERATOR(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      any_operator(): Any_operatorContext | null;
      opclass_purpose(): Opclass_purposeContext | null;
      opt_recheck(): Opt_recheckContext | null;
      operator_with_argtypes(): Operator_with_argtypesContext | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      type_list(): Type_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      typename(): TypenameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_defaultContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_opfamilyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FAMILY(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opclass_purposeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      ORDER(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_recheckContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RECHECK(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateopfamilystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      FAMILY(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      USING(): antlr.TerminalNode;
      name(): NameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlteropfamilystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      FAMILY(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      USING(): antlr.TerminalNode;
      name(): NameContext;
      ADD_P(): antlr.TerminalNode | null;
      opclass_item_list(): Opclass_item_listContext | null;
      DROP(): antlr.TerminalNode | null;
      opclass_drop_list(): Opclass_drop_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opclass_drop_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opclass_drop(): Opclass_dropContext[];
      opclass_drop(i: number): Opclass_dropContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opclass_dropContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPERATOR(): antlr.TerminalNode | null;
      iconst(): IconstContext;
      OPEN_PAREN(): antlr.TerminalNode;
      type_list(): Type_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropopclassstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      CLASS(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      USING(): antlr.TerminalNode;
      name(): NameContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropopfamilystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      FAMILY(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      USING(): antlr.TerminalNode;
      name(): NameContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropownedstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      OWNED(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      role_list(): Role_listContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ReassignownedstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REASSIGN(): antlr.TerminalNode;
      OWNED(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      role_list(): Role_listContext;
      TO(): antlr.TerminalNode;
      rolespec(): RolespecContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      object_type_any_name(): Object_type_any_nameContext | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      any_name_list(): Any_name_listContext | null;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      drop_type_name(): Drop_type_nameContext | null;
      name_list(): Name_listContext | null;
      object_type_name_on_any_name(): Object_type_name_on_any_nameContext | null;
      name(): NameContext | null;
      ON(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      TYPE_P(): antlr.TerminalNode | null;
      type_name_list(): Type_name_listContext | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      CONCURRENTLY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Object_type_any_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLE(): antlr.TerminalNode | null;
      SEQUENCE(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      COLLATION(): antlr.TerminalNode | null;
      CONVERSION_P(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      TEMPLATE(): antlr.TerminalNode | null;
      CONFIGURATION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Object_type_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      drop_type_name(): Drop_type_nameContext | null;
      DATABASE(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      SUBSCRIPTION(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Drop_type_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ACCESS(): antlr.TerminalNode | null;
      METHOD(): antlr.TerminalNode | null;
      EVENT(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      EXTENSION(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      WRAPPER(): antlr.TerminalNode | null;
      opt_procedural(): Opt_proceduralContext | null;
      LANGUAGE(): antlr.TerminalNode | null;
      PUBLICATION(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      SERVER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Object_type_name_on_any_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      POLICY(): antlr.TerminalNode | null;
      RULE(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Any_name_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_name(): Any_nameContext[];
      any_name(i: number): Any_nameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Any_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      attrs(): AttrsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AttrsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DOT(): antlr.TerminalNode[];
      DOT(i: number): antlr.TerminalNode | null;
      attr_name(): Attr_nameContext[];
      attr_name(i: number): Attr_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Type_name_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TruncatestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TRUNCATE(): antlr.TerminalNode;
      opt_table(): Opt_tableContext;
      relation_expr_list(): Relation_expr_listContext;
      opt_restart_seqs(): Opt_restart_seqsContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_restart_seqsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CONTINUE_P(): antlr.TerminalNode | null;
      IDENTITY_P(): antlr.TerminalNode | null;
      RESTART(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CommentstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMENT(): antlr.TerminalNode;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      object_type_any_name(): Object_type_any_nameContext | null;
      any_name(): Any_nameContext | null;
      IS(): antlr.TerminalNode;
      comment_text(): Comment_textContext;
      COLUMN(): antlr.TerminalNode | null;
      object_type_name(): Object_type_nameContext | null;
      name(): NameContext | null;
      TYPE_P(): antlr.TerminalNode | null;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      AGGREGATE(): antlr.TerminalNode | null;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      operator_with_argtypes(): Operator_with_argtypesContext | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      object_type_name_on_any_name(): Object_type_name_on_any_nameContext | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      TRANSFORM(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      LANGUAGE(): antlr.TerminalNode | null;
      CLASS(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      FAMILY(): antlr.TerminalNode | null;
      LARGE_P(): antlr.TerminalNode | null;
      OBJECT_P(): antlr.TerminalNode | null;
      numericonly(): NumericonlyContext | null;
      CAST(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Comment_textContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      NULL_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SeclabelstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SECURITY(): antlr.TerminalNode;
      LABEL(): antlr.TerminalNode;
      opt_provider(): Opt_providerContext;
      ON(): antlr.TerminalNode;
      object_type_any_name(): Object_type_any_nameContext | null;
      any_name(): Any_nameContext | null;
      IS(): antlr.TerminalNode;
      security_label(): Security_labelContext;
      COLUMN(): antlr.TerminalNode | null;
      object_type_name(): Object_type_nameContext | null;
      name(): NameContext | null;
      TYPE_P(): antlr.TerminalNode | null;
      typename(): TypenameContext | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      AGGREGATE(): antlr.TerminalNode | null;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      LARGE_P(): antlr.TerminalNode | null;
      OBJECT_P(): antlr.TerminalNode | null;
      numericonly(): NumericonlyContext | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_providerContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode | null;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Security_labelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      NULL_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class FetchstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FETCH(): antlr.TerminalNode | null;
      fetch_args(): Fetch_argsContext;
      MOVE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Fetch_argsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      cursor_name(): Cursor_nameContext;
      from_in(): From_inContext | null;
      NEXT(): antlr.TerminalNode | null;
      opt_from_in(): Opt_from_inContext | null;
      PRIOR(): antlr.TerminalNode | null;
      FIRST_P(): antlr.TerminalNode | null;
      LAST_P(): antlr.TerminalNode | null;
      ABSOLUTE_P(): antlr.TerminalNode | null;
      signediconst(): SignediconstContext | null;
      RELATIVE_P(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      FORWARD(): antlr.TerminalNode | null;
      BACKWARD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class From_inContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_from_inContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      from_in(): From_inContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class GrantstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GRANT(): antlr.TerminalNode;
      privileges(): PrivilegesContext;
      ON(): antlr.TerminalNode;
      privilege_target(): Privilege_targetContext;
      TO(): antlr.TerminalNode;
      grantee_list(): Grantee_listContext;
      opt_grant_grant_option(): Opt_grant_grant_optionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RevokestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REVOKE(): antlr.TerminalNode;
      privileges(): PrivilegesContext;
      ON(): antlr.TerminalNode;
      privilege_target(): Privilege_targetContext;
      FROM(): antlr.TerminalNode;
      grantee_list(): Grantee_listContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      GRANT(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PrivilegesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      privilege_list(): Privilege_listContext | null;
      ALL(): antlr.TerminalNode | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Privilege_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      privilege(): PrivilegeContext[];
      privilege(i: number): PrivilegeContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PrivilegeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SELECT(): antlr.TerminalNode | null;
      opt_column_list(): Opt_column_listContext;
      REFERENCES(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Privilege_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name_list(): Qualified_name_listContext | null;
      TABLE(): antlr.TerminalNode | null;
      SEQUENCE(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      WRAPPER(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      SERVER(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes_list(): Function_with_argtypes_listContext | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      any_name_list(): Any_name_listContext | null;
      LANGUAGE(): antlr.TerminalNode | null;
      LARGE_P(): antlr.TerminalNode | null;
      OBJECT_P(): antlr.TerminalNode | null;
      numericonly_list(): Numericonly_listContext | null;
      SCHEMA(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      SEQUENCES(): antlr.TerminalNode | null;
      FUNCTIONS(): antlr.TerminalNode | null;
      PROCEDURES(): antlr.TerminalNode | null;
      ROUTINES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Grantee_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      grantee(): GranteeContext[];
      grantee(i: number): GranteeContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class GranteeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      rolespec(): RolespecContext;
      GROUP_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_grant_grant_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      GRANT(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class GrantrolestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GRANT(): antlr.TerminalNode;
      privilege_list(): Privilege_listContext;
      TO(): antlr.TerminalNode;
      role_list(): Role_listContext;
      opt_grant_admin_option(): Opt_grant_admin_optionContext;
      opt_granted_by(): Opt_granted_byContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RevokerolestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REVOKE(): antlr.TerminalNode;
      privilege_list(): Privilege_listContext;
      FROM(): antlr.TerminalNode;
      role_list(): Role_listContext;
      opt_granted_by(): Opt_granted_byContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      ADMIN(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_grant_admin_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      ADMIN(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_granted_byContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GRANTED(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      rolespec(): RolespecContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterdefaultprivilegesstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      DEFAULT(): antlr.TerminalNode;
      PRIVILEGES(): antlr.TerminalNode;
      defacloptionlist(): DefacloptionlistContext;
      defaclaction(): DefaclactionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DefacloptionlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      defacloption(): DefacloptionContext[];
      defacloption(i: number): DefacloptionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DefacloptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IN_P(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      FOR(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      role_list(): Role_listContext | null;
      USER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DefaclactionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GRANT(): antlr.TerminalNode | null;
      privileges(): PrivilegesContext;
      ON(): antlr.TerminalNode;
      defacl_privilege_target(): Defacl_privilege_targetContext;
      TO(): antlr.TerminalNode | null;
      grantee_list(): Grantee_listContext;
      opt_grant_grant_option(): Opt_grant_grant_optionContext | null;
      REVOKE(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      opt_drop_behavior(): Opt_drop_behaviorContext | null;
      OPTION(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Defacl_privilege_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLES(): antlr.TerminalNode | null;
      FUNCTIONS(): antlr.TerminalNode | null;
      ROUTINES(): antlr.TerminalNode | null;
      SEQUENCES(): antlr.TerminalNode | null;
      TYPES_P(): antlr.TerminalNode | null;
      SCHEMAS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class IndexstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_unique(): Opt_uniqueContext;
      INDEX(): antlr.TerminalNode;
      opt_concurrently(): Opt_concurrentlyContext;
      opt_index_name(): Opt_index_nameContext | null;
      ON(): antlr.TerminalNode;
      relation_expr(): Relation_exprContext;
      access_method_clause(): Access_method_clauseContext;
      OPEN_PAREN(): antlr.TerminalNode;
      index_params(): Index_paramsContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      opt_include(): Opt_includeContext;
      opt_reloptions(): Opt_reloptionsContext;
      opttablespace(): OpttablespaceContext;
      where_clause(): Where_clauseContext;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_uniqueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNIQUE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_concurrentlyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CONCURRENTLY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_index_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Access_method_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Index_paramsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      index_elem(): Index_elemContext[];
      index_elem(i: number): Index_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Index_elem_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_collate(): Opt_collateContext;
      opt_class(): Opt_classContext | null;
      opt_asc_desc(): Opt_asc_descContext;
      opt_nulls_order(): Opt_nulls_orderContext;
      any_name(): Any_nameContext | null;
      reloptions(): ReloptionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Index_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      index_elem_options(): Index_elem_optionsContext;
      func_expr_windowless(): Func_expr_windowlessContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_includeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INCLUDE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      index_including_params(): Index_including_paramsContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Index_including_paramsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      index_elem(): Index_elemContext[];
      index_elem(i: number): Index_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_collateContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COLLATE(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_classContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_asc_descContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ASC(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_nulls_orderContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NULLS_P(): antlr.TerminalNode | null;
      FIRST_P(): antlr.TerminalNode | null;
      LAST_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatefunctionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_or_replace(): Opt_or_replaceContext;
      func_name(): Func_nameContext;
      func_args_with_defaults(): Func_args_with_defaultsContext;
      createfunc_opt_list(): Createfunc_opt_listContext;
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      RETURNS(): antlr.TerminalNode | null;
      func_return(): Func_returnContext | null;
      TABLE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      table_func_column_list(): Table_func_column_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_or_replaceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OR(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_argsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      func_args_list(): Func_args_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_args_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_arg(): Func_argContext[];
      func_arg(i: number): Func_argContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Function_with_argtypes_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      function_with_argtypes(): Function_with_argtypesContext[];
      function_with_argtypes(i: number): Function_with_argtypesContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Function_with_argtypesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_name(): Func_nameContext | null;
      func_args(): Func_argsContext | null;
      type_func_name_keyword(): Type_func_name_keywordContext | null;
      colid(): ColidContext | null;
      indirection(): IndirectionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_args_with_defaultsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      func_args_with_defaults_list(): Func_args_with_defaults_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_args_with_defaults_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_arg_with_default(): Func_arg_with_defaultContext[];
      func_arg_with_default(i: number): Func_arg_with_defaultContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      arg_class(): Arg_classContext | null;
      func_type(): Func_typeContext;
      param_name(): Param_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Arg_classContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IN_P(): antlr.TerminalNode | null;
      OUT_P(): antlr.TerminalNode | null;
      INOUT(): antlr.TerminalNode | null;
      VARIADIC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Param_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      type_function_name(): Type_function_nameContext | null;
      builtin_function_name(): Builtin_function_nameContext | null;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_returnContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_type(): Func_typeContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      typename(): TypenameContext | null;
      attrs(): AttrsContext | null;
      PERCENT(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      builtin_function_name(): Builtin_function_nameContext | null;
      type_function_name(): Type_function_nameContext | null;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      SETOF(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_arg_with_defaultContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_arg(): Func_argContext;
      a_expr(): A_exprContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      EQUAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Aggr_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_arg(): Func_argContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Aggr_argsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      STAR(): antlr.TerminalNode | null;
      aggr_args_list(): Aggr_args_listContext[];
      aggr_args_list(i: number): Aggr_args_listContext | null;
      ORDER(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Aggr_args_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      aggr_arg(): Aggr_argContext[];
      aggr_arg(i: number): Aggr_argContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Aggregate_with_argtypesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_name(): Func_nameContext;
      aggr_args(): Aggr_argsContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Aggregate_with_argtypes_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      aggregate_with_argtypes(): Aggregate_with_argtypesContext[];
      aggregate_with_argtypes(i: number): Aggregate_with_argtypesContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Createfunc_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createfunc_opt_item(): Createfunc_opt_itemContext[];
      createfunc_opt_item(i: number): Createfunc_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Common_func_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CALLED(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode[];
      NULL_P(i: number): antlr.TerminalNode | null;
      INPUT_P(): antlr.TerminalNode | null;
      RETURNS(): antlr.TerminalNode | null;
      STRICT_P(): antlr.TerminalNode | null;
      IMMUTABLE(): antlr.TerminalNode | null;
      STABLE(): antlr.TerminalNode | null;
      VOLATILE(): antlr.TerminalNode | null;
      EXTERNAL(): antlr.TerminalNode | null;
      SECURITY(): antlr.TerminalNode | null;
      DEFINER(): antlr.TerminalNode | null;
      INVOKER(): antlr.TerminalNode | null;
      LEAKPROOF(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      COST(): antlr.TerminalNode | null;
      numericonly(): NumericonlyContext | null;
      ROWS(): antlr.TerminalNode | null;
      SUPPORT(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      functionsetresetclause(): FunctionsetresetclauseContext | null;
      PARALLEL(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Createfunc_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode | null;
      func_as(): Func_asContext | null;
      LANGUAGE(): antlr.TerminalNode | null;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext | null;
      TRANSFORM(): antlr.TerminalNode | null;
      transform_type_list(): Transform_type_listContext | null;
      WINDOW(): antlr.TerminalNode | null;
      common_func_opt_item(): Common_func_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_asContext extends antlr.ParserRuleContext {
      Definition: antlr.ParserRuleContext;
      _def?: SconstContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext[];
      sconst(i: number): SconstContext | null;
      COMMA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Transform_type_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode[];
      FOR(i: number): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode[];
      TYPE_P(i: number): antlr.TerminalNode | null;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_definitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      definition(): DefinitionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Table_func_columnContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      param_name(): Param_nameContext;
      func_type(): Func_typeContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Table_func_column_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      table_func_column(): Table_func_columnContext[];
      table_func_column(i: number): Table_func_columnContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterfunctionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      function_with_argtypes(): Function_with_argtypesContext;
      alterfunc_opt_list(): Alterfunc_opt_listContext;
      opt_restrict(): Opt_restrictContext;
      FUNCTION(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alterfunc_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      common_func_opt_item(): Common_func_opt_itemContext[];
      common_func_opt_item(i: number): Common_func_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_restrictContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RESTRICT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RemovefuncstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes_list(): Function_with_argtypes_listContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RemoveaggrstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      AGGREGATE(): antlr.TerminalNode;
      aggregate_with_argtypes_list(): Aggregate_with_argtypes_listContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RemoveoperstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      operator_with_argtypes_list(): Operator_with_argtypes_listContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Oper_argtypesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      CLOSE_PAREN(): antlr.TerminalNode;
      COMMA(): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Any_operatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      all_op(): All_opContext;
      colid(): ColidContext[];
      colid(i: number): ColidContext | null;
      DOT(): antlr.TerminalNode[];
      DOT(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Operator_with_argtypes_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      operator_with_argtypes(): Operator_with_argtypesContext[];
      operator_with_argtypes(i: number): Operator_with_argtypesContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Operator_with_argtypesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_operator(): Any_operatorContext;
      oper_argtypes(): Oper_argtypesContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DostmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DO(): antlr.TerminalNode;
      dostmt_opt_list(): Dostmt_opt_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Dostmt_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      dostmt_opt_item(): Dostmt_opt_itemContext[];
      dostmt_opt_item(i: number): Dostmt_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Dostmt_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      LANGUAGE(): antlr.TerminalNode | null;
      nonreservedword_or_sconst(): Nonreservedword_or_sconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatecaststmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      CAST(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      AS(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      WITH(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      cast_context(): Cast_contextContext;
      WITHOUT(): antlr.TerminalNode | null;
      INOUT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cast_contextContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode | null;
      IMPLICIT_P(): antlr.TerminalNode | null;
      ASSIGNMENT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropcaststmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      CAST(): antlr.TerminalNode;
      opt_if_exists(): Opt_if_existsContext;
      OPEN_PAREN(): antlr.TerminalNode;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      AS(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_if_existsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatetransformstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_or_replace(): Opt_or_replaceContext;
      TRANSFORM(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode;
      typename(): TypenameContext;
      LANGUAGE(): antlr.TerminalNode;
      name(): NameContext;
      OPEN_PAREN(): antlr.TerminalNode;
      transform_element_list(): Transform_element_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Transform_element_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      SQL_P(): antlr.TerminalNode[];
      SQL_P(i: number): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode[];
      WITH(i: number): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode[];
      FUNCTION(i: number): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext[];
      function_with_argtypes(i: number): Function_with_argtypesContext | null;
      COMMA(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DroptransformstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      TRANSFORM(): antlr.TerminalNode;
      opt_if_exists(): Opt_if_existsContext;
      FOR(): antlr.TerminalNode;
      typename(): TypenameContext;
      LANGUAGE(): antlr.TerminalNode;
      name(): NameContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ReindexstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REINDEX(): antlr.TerminalNode;
      reindex_target_type(): Reindex_target_typeContext | null;
      opt_concurrently(): Opt_concurrentlyContext;
      qualified_name(): Qualified_nameContext | null;
      reindex_target_multitable(): Reindex_target_multitableContext | null;
      name(): NameContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      reindex_option_list(): Reindex_option_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reindex_target_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INDEX(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      SYSTEM_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reindex_target_multitableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SCHEMA(): antlr.TerminalNode | null;
      SYSTEM_P(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reindex_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      reindex_option_elem(): Reindex_option_elemContext[];
      reindex_option_elem(i: number): Reindex_option_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reindex_option_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VERBOSE(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      CONCURRENTLY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltertblspcstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TABLESPACE(): antlr.TerminalNode;
      name(): NameContext;
      SET(): antlr.TerminalNode | null;
      reloptions(): ReloptionsContext;
      RESET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RenamestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      AGGREGATE(): antlr.TerminalNode | null;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext | null;
      RENAME(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      COLLATION(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      CONVERSION_P(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      WRAPPER(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      GROUP_P(): antlr.TerminalNode | null;
      roleid(): RoleidContext[];
      roleid(i: number): RoleidContext | null;
      opt_procedural(): Opt_proceduralContext | null;
      LANGUAGE(): antlr.TerminalNode | null;
      OPERATOR(): antlr.TerminalNode | null;
      CLASS(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      FAMILY(): antlr.TerminalNode | null;
      POLICY(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      PUBLICATION(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      SERVER(): antlr.TerminalNode | null;
      SUBSCRIPTION(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      relation_expr(): Relation_exprContext | null;
      SEQUENCE(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      opt_column(): Opt_columnContext | null;
      RULE(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      EVENT(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      TEMPLATE(): antlr.TerminalNode | null;
      CONFIGURATION(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      ATTRIBUTE(): antlr.TerminalNode | null;
      opt_drop_behavior(): Opt_drop_behaviorContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_columnContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COLUMN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_set_dataContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterobjectdependsstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      opt_no(): Opt_noContext;
      DEPENDS(): antlr.TerminalNode;
      ON(): antlr.TerminalNode[];
      ON(i: number): antlr.TerminalNode | null;
      EXTENSION(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_noContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterobjectschemastmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      AGGREGATE(): antlr.TerminalNode | null;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext | null;
      SET(): antlr.TerminalNode;
      SCHEMA(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      COLLATION(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      CONVERSION_P(): antlr.TerminalNode | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      EXTENSION(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      operator_with_argtypes(): Operator_with_argtypesContext | null;
      CLASS(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      FAMILY(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      relation_expr(): Relation_exprContext | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      TEMPLATE(): antlr.TerminalNode | null;
      CONFIGURATION(): antlr.TerminalNode | null;
      SEQUENCE(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      VIEW(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlteroperatorstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      OPERATOR(): antlr.TerminalNode;
      operator_with_argtypes(): Operator_with_argtypesContext;
      SET(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      operator_def_list(): Operator_def_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Operator_def_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      operator_def_elem(): Operator_def_elemContext[];
      operator_def_elem(i: number): Operator_def_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Operator_def_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext;
      EQUAL(): antlr.TerminalNode;
      NONE(): antlr.TerminalNode | null;
      operator_def_arg(): Operator_def_argContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Operator_def_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_type(): Func_typeContext | null;
      reserved_keyword(): Reserved_keywordContext | null;
      qual_all_op(): Qual_all_opContext | null;
      numericonly(): NumericonlyContext | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltertypestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TYPE_P(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      SET(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      operator_def_list(): Operator_def_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterownerstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      AGGREGATE(): antlr.TerminalNode | null;
      aggregate_with_argtypes(): Aggregate_with_argtypesContext | null;
      OWNER(): antlr.TerminalNode;
      TO(): antlr.TerminalNode;
      rolespec(): RolespecContext;
      COLLATION(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      CONVERSION_P(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      name(): NameContext | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      function_with_argtypes(): Function_with_argtypesContext | null;
      opt_procedural(): Opt_proceduralContext | null;
      LANGUAGE(): antlr.TerminalNode | null;
      LARGE_P(): antlr.TerminalNode | null;
      OBJECT_P(): antlr.TerminalNode | null;
      numericonly(): NumericonlyContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      operator_with_argtypes(): Operator_with_argtypesContext | null;
      CLASS(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      FAMILY(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      CONFIGURATION(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      WRAPPER(): antlr.TerminalNode | null;
      SERVER(): antlr.TerminalNode | null;
      EVENT(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      PUBLICATION(): antlr.TerminalNode | null;
      SUBSCRIPTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatepublicationstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      PUBLICATION(): antlr.TerminalNode;
      name(): NameContext;
      opt_publication_for_tables(): Opt_publication_for_tablesContext;
      opt_definition(): Opt_definitionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_publication_for_tablesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      publication_for_tables(): Publication_for_tablesContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Publication_for_tablesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode;
      TABLE(): antlr.TerminalNode | null;
      relation_expr_list(): Relation_expr_listContext | null;
      ALL(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterpublicationstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      PUBLICATION(): antlr.TerminalNode;
      name(): NameContext;
      SET(): antlr.TerminalNode | null;
      definition(): DefinitionContext | null;
      ADD_P(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      relation_expr_list(): Relation_expr_listContext | null;
      DROP(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatesubscriptionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      SUBSCRIPTION(): antlr.TerminalNode;
      name(): NameContext;
      CONNECTION(): antlr.TerminalNode;
      sconst(): SconstContext;
      PUBLICATION(): antlr.TerminalNode;
      publication_name_list(): Publication_name_listContext;
      opt_definition(): Opt_definitionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Publication_name_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      publication_name_item(): Publication_name_itemContext[];
      publication_name_item(i: number): Publication_name_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Publication_name_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltersubscriptionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      SUBSCRIPTION(): antlr.TerminalNode;
      name(): NameContext;
      SET(): antlr.TerminalNode | null;
      definition(): DefinitionContext | null;
      CONNECTION(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      REFRESH(): antlr.TerminalNode | null;
      PUBLICATION(): antlr.TerminalNode | null;
      opt_definition(): Opt_definitionContext | null;
      publication_name_list(): Publication_name_listContext | null;
      ENABLE_P(): antlr.TerminalNode | null;
      DISABLE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropsubscriptionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      SUBSCRIPTION(): antlr.TerminalNode;
      name(): NameContext;
      opt_drop_behavior(): Opt_drop_behaviorContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RulestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_or_replace(): Opt_or_replaceContext;
      RULE(): antlr.TerminalNode;
      name(): NameContext;
      AS(): antlr.TerminalNode;
      ON(): antlr.TerminalNode;
      event(): EventContext;
      TO(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext;
      where_clause(): Where_clauseContext;
      DO(): antlr.TerminalNode;
      opt_instead(): Opt_insteadContext;
      ruleactionlist(): RuleactionlistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RuleactionlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOTHING(): antlr.TerminalNode | null;
      ruleactionstmt(): RuleactionstmtContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      ruleactionmulti(): RuleactionmultiContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RuleactionmultiContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ruleactionstmtOrEmpty(): RuleactionstmtOrEmptyContext[];
      ruleactionstmtOrEmpty(i: number): RuleactionstmtOrEmptyContext | null;
      SEMI(): antlr.TerminalNode[];
      SEMI(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RuleactionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectstmt(): SelectstmtContext | null;
      insertstmt(): InsertstmtContext | null;
      updatestmt(): UpdatestmtContext | null;
      deletestmt(): DeletestmtContext | null;
      notifystmt(): NotifystmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RuleactionstmtOrEmptyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ruleactionstmt(): RuleactionstmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class EventContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SELECT(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      DELETE_P(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_insteadContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INSTEAD(): antlr.TerminalNode | null;
      ALSO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class NotifystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOTIFY(): antlr.TerminalNode;
      colid(): ColidContext;
      notify_payload(): Notify_payloadContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Notify_payloadContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMA(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ListenstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LISTEN(): antlr.TerminalNode;
      colid(): ColidContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class UnlistenstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNLISTEN(): antlr.TerminalNode;
      colid(): ColidContext | null;
      STAR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TransactionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ABORT_P(): antlr.TerminalNode | null;
      opt_transaction(): Opt_transactionContext | null;
      opt_transaction_chain(): Opt_transaction_chainContext | null;
      BEGIN_P(): antlr.TerminalNode | null;
      transaction_mode_list_or_empty(): Transaction_mode_list_or_emptyContext | null;
      START(): antlr.TerminalNode | null;
      TRANSACTION(): antlr.TerminalNode | null;
      COMMIT(): antlr.TerminalNode | null;
      END_P(): antlr.TerminalNode | null;
      ROLLBACK(): antlr.TerminalNode | null;
      SAVEPOINT(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      RELEASE(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      PREPARE(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      PREPARED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_transactionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WORK(): antlr.TerminalNode | null;
      TRANSACTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Transaction_mode_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ISOLATION(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      iso_level(): Iso_levelContext | null;
      READ(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      WRITE(): antlr.TerminalNode | null;
      DEFERRABLE(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Transaction_mode_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      transaction_mode_item(): Transaction_mode_itemContext[];
      transaction_mode_item(i: number): Transaction_mode_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Transaction_mode_list_or_emptyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      transaction_mode_list(): Transaction_mode_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_transaction_chainContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AND(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ViewstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opttemp(): OpttempContext;
      AS(): antlr.TerminalNode;
      selectstmt(): SelectstmtContext;
      opt_check_option(): Opt_check_optionContext;
      VIEW(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      opt_column_list(): Opt_column_listContext | null;
      opt_reloptions(): Opt_reloptionsContext | null;
      RECURSIVE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      columnlist(): ColumnlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      OR(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_check_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      CASCADED(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class LoadstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOAD(): antlr.TerminalNode;
      file_name(): File_nameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatedbstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode;
      name(): NameContext;
      opt_with(): Opt_withContext;
      createdb_opt_list(): Createdb_opt_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Createdb_opt_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createdb_opt_items(): Createdb_opt_itemsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Createdb_opt_itemsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createdb_opt_item(): Createdb_opt_itemContext[];
      createdb_opt_item(i: number): Createdb_opt_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Createdb_opt_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      createdb_opt_name(): Createdb_opt_nameContext;
      opt_equal(): Opt_equalContext;
      signediconst(): SignediconstContext | null;
      opt_boolean_or_string(): Opt_boolean_or_stringContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Createdb_opt_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      CONNECTION(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      ENCODING(): antlr.TerminalNode | null;
      LOCATION(): antlr.TerminalNode | null;
      OWNER(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      TEMPLATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_equalContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EQUAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterdatabasestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode;
      name(): NameContext[];
      name(i: number): NameContext | null;
      WITH(): antlr.TerminalNode | null;
      createdb_opt_list(): Createdb_opt_listContext | null;
      SET(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterdatabasesetstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode;
      name(): NameContext;
      setresetclause(): SetresetclauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DropdbstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DROP(): antlr.TerminalNode;
      DATABASE(): antlr.TerminalNode;
      name(): NameContext;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      opt_with(): Opt_withContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      drop_option_list(): Drop_option_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Drop_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      drop_option(): Drop_optionContext[];
      drop_option(i: number): Drop_optionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Drop_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FORCE(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltercollationstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      COLLATION(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      REFRESH(): antlr.TerminalNode;
      VERSION_P(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltersystemstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      SYSTEM_P(): antlr.TerminalNode;
      generic_set(): Generic_setContext;
      SET(): antlr.TerminalNode | null;
      RESET(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreatedomainstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      DOMAIN_P(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      opt_as(): Opt_asContext;
      typename(): TypenameContext;
      colquallist(): ColquallistContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AlterdomainstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      DOMAIN_P(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      alter_column_default(): Alter_column_defaultContext | null;
      DROP(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      ADD_P(): antlr.TerminalNode | null;
      tableconstraint(): TableconstraintContext | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      name(): NameContext | null;
      opt_drop_behavior(): Opt_drop_behaviorContext | null;
      VALIDATE(): antlr.TerminalNode | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_asContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltertsdictionarystmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode;
      TEXT_P(): antlr.TerminalNode;
      SEARCH(): antlr.TerminalNode;
      DICTIONARY(): antlr.TerminalNode;
      any_name(): Any_nameContext;
      definition(): DefinitionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AltertsconfigurationstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALTER(): antlr.TerminalNode[];
      ALTER(i: number): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode;
      SEARCH(): antlr.TerminalNode;
      CONFIGURATION(): antlr.TerminalNode;
      any_name(): Any_nameContext[];
      any_name(i: number): Any_nameContext | null;
      ADD_P(): antlr.TerminalNode | null;
      MAPPING(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      any_with(): Any_withContext | null;
      any_name_list(): Any_name_listContext | null;
      REPLACE(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      IF_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Any_withContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CreateconversionstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CREATE(): antlr.TerminalNode;
      opt_default(): Opt_defaultContext;
      CONVERSION_P(): antlr.TerminalNode;
      any_name(): Any_nameContext[];
      any_name(i: number): Any_nameContext | null;
      FOR(): antlr.TerminalNode;
      sconst(): SconstContext[];
      sconst(i: number): SconstContext | null;
      TO(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ClusterstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CLUSTER(): antlr.TerminalNode;
      opt_verbose(): Opt_verboseContext;
      qualified_name(): Qualified_nameContext | null;
      cluster_index_specification(): Cluster_index_specificationContext | null;
      name(): NameContext | null;
      ON(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cluster_index_specificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class VacuumstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VACUUM(): antlr.TerminalNode;
      opt_full(): Opt_fullContext | null;
      opt_freeze(): Opt_freezeContext | null;
      opt_verbose(): Opt_verboseContext | null;
      opt_analyze(): Opt_analyzeContext | null;
      opt_vacuum_relation_list(): Opt_vacuum_relation_listContext;
      OPEN_PAREN(): antlr.TerminalNode | null;
      vac_analyze_option_list(): Vac_analyze_option_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AnalyzestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      analyze_keyword(): Analyze_keywordContext;
      opt_verbose(): Opt_verboseContext | null;
      opt_vacuum_relation_list(): Opt_vacuum_relation_listContext;
      OPEN_PAREN(): antlr.TerminalNode | null;
      vac_analyze_option_list(): Vac_analyze_option_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Vac_analyze_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      vac_analyze_option_elem(): Vac_analyze_option_elemContext[];
      vac_analyze_option_elem(i: number): Vac_analyze_option_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Analyze_keywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ANALYZE(): antlr.TerminalNode | null;
      ANALYSE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Vac_analyze_option_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      vac_analyze_option_name(): Vac_analyze_option_nameContext;
      vac_analyze_option_arg(): Vac_analyze_option_argContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Vac_analyze_option_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nonreservedword(): NonreservedwordContext | null;
      analyze_keyword(): Analyze_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Vac_analyze_option_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_boolean_or_string(): Opt_boolean_or_stringContext | null;
      numericonly(): NumericonlyContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_analyzeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      analyze_keyword(): Analyze_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_verboseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VERBOSE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_fullContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FULL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_freezeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FREEZE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_name_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Vacuum_relationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name(): Qualified_nameContext;
      opt_name_list(): Opt_name_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Vacuum_relation_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      vacuum_relation(): Vacuum_relationContext[];
      vacuum_relation(i: number): Vacuum_relationContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_vacuum_relation_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      vacuum_relation_list(): Vacuum_relation_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExplainstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXPLAIN(): antlr.TerminalNode;
      explainablestmt(): ExplainablestmtContext;
      analyze_keyword(): Analyze_keywordContext | null;
      opt_verbose(): Opt_verboseContext | null;
      VERBOSE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      explain_option_list(): Explain_option_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExplainablestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectstmt(): SelectstmtContext | null;
      insertstmt(): InsertstmtContext | null;
      updatestmt(): UpdatestmtContext | null;
      deletestmt(): DeletestmtContext | null;
      declarecursorstmt(): DeclarecursorstmtContext | null;
      createasstmt(): CreateasstmtContext | null;
      creatematviewstmt(): CreatematviewstmtContext | null;
      refreshmatviewstmt(): RefreshmatviewstmtContext | null;
      executestmt(): ExecutestmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Explain_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      explain_option_elem(): Explain_option_elemContext[];
      explain_option_elem(i: number): Explain_option_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Explain_option_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      explain_option_name(): Explain_option_nameContext;
      explain_option_arg(): Explain_option_argContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Explain_option_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nonreservedword(): NonreservedwordContext | null;
      analyze_keyword(): Analyze_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Explain_option_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_boolean_or_string(): Opt_boolean_or_stringContext | null;
      numericonly(): NumericonlyContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PreparestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PREPARE(): antlr.TerminalNode;
      name(): NameContext;
      prep_type_clause(): Prep_type_clauseContext;
      AS(): antlr.TerminalNode;
      preparablestmt(): PreparablestmtContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Prep_type_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      type_list(): Type_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PreparablestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectstmt(): SelectstmtContext | null;
      insertstmt(): InsertstmtContext | null;
      updatestmt(): UpdatestmtContext | null;
      deletestmt(): DeletestmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ExecutestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXECUTE(): antlr.TerminalNode;
      name(): NameContext;
      execute_param_clause(): Execute_param_clauseContext;
      CREATE(): antlr.TerminalNode | null;
      opttemp(): OpttempContext | null;
      TABLE(): antlr.TerminalNode | null;
      create_as_target(): Create_as_targetContext | null;
      AS(): antlr.TerminalNode | null;
      opt_with_data(): Opt_with_dataContext | null;
      IF_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Execute_param_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DeallocatestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEALLOCATE(): antlr.TerminalNode;
      name(): NameContext | null;
      PREPARE(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class InsertstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_with_clause(): Opt_with_clauseContext;
      INSERT(): antlr.TerminalNode;
      INTO(): antlr.TerminalNode;
      insert_target(): Insert_targetContext;
      insert_rest(): Insert_restContext;
      opt_on_conflict(): Opt_on_conflictContext;
      returning_clause(): Returning_clauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Insert_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name(): Qualified_nameContext;
      AS(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Insert_restContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectstmt(): SelectstmtContext | null;
      OVERRIDING(): antlr.TerminalNode | null;
      override_kind(): Override_kindContext | null;
      VALUE_P(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      insert_column_list(): Insert_column_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      VALUES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Override_kindContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USER(): antlr.TerminalNode | null;
      SYSTEM_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Insert_column_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      insert_column_item(): Insert_column_itemContext[];
      insert_column_item(i: number): Insert_column_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Insert_column_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      opt_indirection(): Opt_indirectionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_on_conflictContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ON(): antlr.TerminalNode | null;
      CONFLICT(): antlr.TerminalNode | null;
      opt_conf_expr(): Opt_conf_exprContext | null;
      DO(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      set_clause_list(): Set_clause_listContext | null;
      where_clause(): Where_clauseContext | null;
      NOTHING(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_conf_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      index_params(): Index_paramsContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      where_clause(): Where_clauseContext | null;
      ON(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      name(): NameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Returning_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RETURNING(): antlr.TerminalNode | null;
      target_list(): Target_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class MergestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MERGE(): antlr.TerminalNode;
      qualified_name(): Qualified_nameContext[];
      qualified_name(i: number): Qualified_nameContext | null;
      USING(): antlr.TerminalNode;
      ON(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      select_with_parens(): Select_with_parensContext | null;
      merge_insert_clause(): Merge_insert_clauseContext | null;
      merge_update_clause(): Merge_update_clauseContext | null;
      INTO(): antlr.TerminalNode | null;
      alias_clause(): Alias_clauseContext[];
      alias_clause(i: number): Alias_clauseContext | null;
      merge_delete_clause(): Merge_delete_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Merge_insert_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      NOT(): antlr.TerminalNode;
      MATCHED(): antlr.TerminalNode;
      INSERT(): antlr.TerminalNode;
      values_clause(): Values_clauseContext;
      AND(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      THEN(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      insert_column_list(): Insert_column_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Merge_update_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      MATCHED(): antlr.TerminalNode;
      UPDATE(): antlr.TerminalNode;
      SET(): antlr.TerminalNode;
      set_clause_list(): Set_clause_listContext;
      AND(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      THEN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Merge_delete_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      MATCHED(): antlr.TerminalNode;
      DELETE_P(): antlr.TerminalNode;
      THEN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DeletestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_with_clause(): Opt_with_clauseContext;
      DELETE_P(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      relation_expr_opt_alias(): Relation_expr_opt_aliasContext;
      using_clause(): Using_clauseContext;
      where_or_current_clause(): Where_or_current_clauseContext;
      returning_clause(): Returning_clauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Using_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      from_list(): From_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class LockstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOCK_P(): antlr.TerminalNode;
      opt_table(): Opt_tableContext;
      relation_expr_list(): Relation_expr_listContext;
      opt_lock(): Opt_lockContext;
      opt_nowait(): Opt_nowaitContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_lockContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IN_P(): antlr.TerminalNode | null;
      lock_type(): Lock_typeContext | null;
      MODE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Lock_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ACCESS(): antlr.TerminalNode | null;
      SHARE(): antlr.TerminalNode | null;
      EXCLUSIVE(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_nowaitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOWAIT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_nowait_or_skipContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOWAIT(): antlr.TerminalNode | null;
      SKIP_P(): antlr.TerminalNode | null;
      LOCKED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class UpdatestmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_with_clause(): Opt_with_clauseContext;
      UPDATE(): antlr.TerminalNode;
      relation_expr_opt_alias(): Relation_expr_opt_aliasContext;
      SET(): antlr.TerminalNode;
      set_clause_list(): Set_clause_listContext;
      from_clause(): From_clauseContext;
      where_or_current_clause(): Where_or_current_clauseContext;
      returning_clause(): Returning_clauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Set_clause_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      set_clause(): Set_clauseContext[];
      set_clause(i: number): Set_clauseContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Set_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      set_target(): Set_targetContext | null;
      EQUAL(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      OPEN_PAREN(): antlr.TerminalNode | null;
      set_target_list(): Set_target_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Set_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      opt_indirection(): Opt_indirectionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Set_target_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      set_target(): Set_targetContext[];
      set_target(i: number): Set_targetContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class DeclarecursorstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECLARE(): antlr.TerminalNode;
      cursor_name(): Cursor_nameContext;
      cursor_options(): Cursor_optionsContext;
      CURSOR(): antlr.TerminalNode;
      opt_hold(): Opt_holdContext;
      FOR(): antlr.TerminalNode;
      selectstmt(): SelectstmtContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cursor_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      name(): NameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cursor_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NO(): antlr.TerminalNode[];
      NO(i: number): antlr.TerminalNode | null;
      SCROLL(): antlr.TerminalNode[];
      SCROLL(i: number): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode[];
      BINARY(i: number): antlr.TerminalNode | null;
      INSENSITIVE(): antlr.TerminalNode[];
      INSENSITIVE(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_holdContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      HOLD(): antlr.TerminalNode | null;
      WITHOUT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SelectstmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      select_no_parens(): Select_no_parensContext | null;
      select_with_parens(): Select_with_parensContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_with_parensContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      select_no_parens(): Select_no_parensContext | null;
      CLOSE_PAREN(): antlr.TerminalNode;
      select_with_parens(): Select_with_parensContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_no_parensContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      select_clause(): Select_clauseContext;
      opt_sort_clause(): Opt_sort_clauseContext;
      for_locking_clause(): For_locking_clauseContext | null;
      opt_select_limit(): Opt_select_limitContext | null;
      select_limit(): Select_limitContext | null;
      opt_for_locking_clause(): Opt_for_locking_clauseContext | null;
      with_clause(): With_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      simple_select_intersect(): Simple_select_intersectContext[];
      simple_select_intersect(i: number): Simple_select_intersectContext | null;
      all_or_distinct(): All_or_distinctContext[];
      all_or_distinct(i: number): All_or_distinctContext | null;
      UNION(): antlr.TerminalNode[];
      UNION(i: number): antlr.TerminalNode | null;
      EXCEPT(): antlr.TerminalNode[];
      EXCEPT(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Simple_select_intersectContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      simple_select_pramary(): Simple_select_pramaryContext[];
      simple_select_pramary(i: number): Simple_select_pramaryContext | null;
      INTERSECT(): antlr.TerminalNode[];
      INTERSECT(i: number): antlr.TerminalNode | null;
      all_or_distinct(): All_or_distinctContext[];
      all_or_distinct(i: number): All_or_distinctContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Simple_select_pramaryContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SELECT(): antlr.TerminalNode | null;
      into_clause(): Into_clauseContext[];
      into_clause(i: number): Into_clauseContext | null;
      from_clause(): From_clauseContext | null;
      where_clause(): Where_clauseContext | null;
      group_clause(): Group_clauseContext | null;
      having_clause(): Having_clauseContext | null;
      window_clause(): Window_clauseContext | null;
      opt_all_clause(): Opt_all_clauseContext | null;
      opt_target_list(): Opt_target_listContext | null;
      distinct_clause(): Distinct_clauseContext | null;
      target_list(): Target_listContext | null;
      values_clause(): Values_clauseContext | null;
      TABLE(): antlr.TerminalNode | null;
      relation_expr(): Relation_exprContext | null;
      select_with_parens(): Select_with_parensContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class With_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode;
      cte_list(): Cte_listContext;
      RECURSIVE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cte_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      common_table_expr(): Common_table_exprContext[];
      common_table_expr(i: number): Common_table_exprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Common_table_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      name(): NameContext;
      opt_name_list(): Opt_name_listContext;
      AS(): antlr.TerminalNode;
      opt_materialized(): Opt_materializedContext;
      OPEN_PAREN(): antlr.TerminalNode;
      preparablestmt(): PreparablestmtContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_materializedContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MATERIALIZED(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_with_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      with_clause(): With_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Into_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INTO(): antlr.TerminalNode | null;
      opt_strict(): Opt_strictContext | null;
      opttempTableName(): OpttempTableNameContext | null;
      into_target(): Into_targetContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_strictContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      STRICT_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttempTableNameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_table(): Opt_tableContext | null;
      qualified_name(): Qualified_nameContext;
      TEMPORARY(): antlr.TerminalNode | null;
      TEMP(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      UNLOGGED(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_tableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class All_or_distinctContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Distinct_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DISTINCT(): antlr.TerminalNode;
      ON(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_all_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_sort_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sort_clause(): Sort_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Sort_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ORDER(): antlr.TerminalNode;
      BY(): antlr.TerminalNode;
      sortby_list(): Sortby_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Sortby_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sortby(): SortbyContext[];
      sortby(i: number): SortbyContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SortbyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext;
      opt_nulls_order(): Opt_nulls_orderContext;
      USING(): antlr.TerminalNode | null;
      qual_all_op(): Qual_all_opContext | null;
      opt_asc_desc(): Opt_asc_descContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_limitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      limit_clause(): Limit_clauseContext | null;
      offset_clause(): Offset_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_select_limitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      select_limit(): Select_limitContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Limit_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LIMIT(): antlr.TerminalNode | null;
      select_limit_value(): Select_limit_valueContext | null;
      COMMA(): antlr.TerminalNode | null;
      select_offset_value(): Select_offset_valueContext | null;
      FETCH(): antlr.TerminalNode | null;
      first_or_next(): First_or_nextContext | null;
      select_fetch_first_value(): Select_fetch_first_valueContext | null;
      row_or_rows(): Row_or_rowsContext | null;
      ONLY(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      TIES(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Offset_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OFFSET(): antlr.TerminalNode;
      select_offset_value(): Select_offset_valueContext | null;
      select_fetch_first_value(): Select_fetch_first_valueContext | null;
      row_or_rows(): Row_or_rowsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_limit_valueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_offset_valueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Select_fetch_first_valueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      c_expr(): C_exprContext | null;
      PLUS(): antlr.TerminalNode | null;
      i_or_f_const(): I_or_f_constContext | null;
      MINUS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class I_or_f_constContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      iconst(): IconstContext | null;
      fconst(): FconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Row_or_rowsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROW(): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class First_or_nextContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FIRST_P(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Group_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GROUP_P(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      group_by_list(): Group_by_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Group_by_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      group_by_item(): Group_by_itemContext[];
      group_by_item(i: number): Group_by_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Group_by_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext | null;
      empty_grouping_set(): Empty_grouping_setContext | null;
      cube_clause(): Cube_clauseContext | null;
      rollup_clause(): Rollup_clauseContext | null;
      grouping_sets_clause(): Grouping_sets_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Empty_grouping_setContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Rollup_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROLLUP(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cube_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CUBE(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Grouping_sets_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GROUPING(): antlr.TerminalNode;
      SETS(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      group_by_list(): Group_by_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Having_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HAVING(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class For_locking_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      for_locking_items(): For_locking_itemsContext | null;
      FOR(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_for_locking_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      for_locking_clause(): For_locking_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class For_locking_itemsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      for_locking_item(): For_locking_itemContext[];
      for_locking_item(i: number): For_locking_itemContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class For_locking_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      for_locking_strength(): For_locking_strengthContext;
      locked_rels_list(): Locked_rels_listContext;
      opt_nowait_or_skip(): Opt_nowait_or_skipContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class For_locking_strengthContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FOR(): antlr.TerminalNode;
      UPDATE(): antlr.TerminalNode | null;
      SHARE(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Locked_rels_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OF(): antlr.TerminalNode | null;
      qualified_name_list(): Qualified_name_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Values_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VALUES(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode[];
      OPEN_PAREN(i: number): antlr.TerminalNode | null;
      expr_list(): Expr_listContext[];
      expr_list(i: number): Expr_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode[];
      CLOSE_PAREN(i: number): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class From_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      from_list(): From_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class From_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      non_ansi_join(): Non_ansi_joinContext | null;
      table_ref(): Table_refContext[];
      table_ref(i: number): Table_refContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Non_ansi_joinContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      table_ref(): Table_refContext[];
      table_ref(i: number): Table_refContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Table_refContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      relation_expr(): Relation_exprContext | null;
      opt_alias_clause(): Opt_alias_clauseContext | null;
      func_table(): Func_tableContext | null;
      func_alias_clause(): Func_alias_clauseContext | null;
      xmltable(): XmltableContext | null;
      select_with_parens(): Select_with_parensContext | null;
      LATERAL_P(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      table_ref(): Table_refContext[];
      table_ref(i: number): Table_refContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      CROSS(): antlr.TerminalNode[];
      CROSS(i: number): antlr.TerminalNode | null;
      JOIN(): antlr.TerminalNode[];
      JOIN(i: number): antlr.TerminalNode | null;
      NATURAL(): antlr.TerminalNode[];
      NATURAL(i: number): antlr.TerminalNode | null;
      join_qual(): Join_qualContext[];
      join_qual(i: number): Join_qualContext | null;
      tablesample_clause(): Tablesample_clauseContext | null;
      join_type(): Join_typeContext[];
      join_type(i: number): Join_typeContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Alias_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      AS(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_alias_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      table_alias_clause(): Table_alias_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Table_alias_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      table_alias(): Table_aliasContext;
      AS(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_alias_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      alias_clause(): Alias_clauseContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      tablefuncelementlist(): TablefuncelementlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Join_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FULL(): antlr.TerminalNode | null;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      INNER_P(): antlr.TerminalNode | null;
      OUTER_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Join_qualContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      name_list(): Name_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Relation_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name(): Qualified_nameContext | null;
      STAR(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Relation_expr_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      relation_expr(): Relation_exprContext[];
      relation_expr(i: number): Relation_exprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Relation_expr_opt_aliasContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      relation_expr(): Relation_exprContext;
      colid(): ColidContext | null;
      AS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Tablesample_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      TABLESAMPLE(): antlr.TerminalNode;
      func_name(): Func_nameContext;
      OPEN_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      opt_repeatable_clause(): Opt_repeatable_clauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_repeatable_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REPEATABLE(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_tableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_expr_windowless(): Func_expr_windowlessContext | null;
      opt_ordinality(): Opt_ordinalityContext;
      ROWS(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      rowsfrom_list(): Rowsfrom_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Rowsfrom_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_expr_windowless(): Func_expr_windowlessContext;
      opt_col_def_list(): Opt_col_def_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Rowsfrom_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      rowsfrom_item(): Rowsfrom_itemContext[];
      rowsfrom_item(i: number): Rowsfrom_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_col_def_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AS(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      tablefuncelementlist(): TablefuncelementlistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_ordinalityContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      ORDINALITY(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Where_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHERE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Where_or_current_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHERE(): antlr.TerminalNode | null;
      CURRENT_P(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      cursor_name(): Cursor_nameContext | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class OpttablefuncelementlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tablefuncelementlist(): TablefuncelementlistContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TablefuncelementlistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      tablefuncelement(): TablefuncelementContext[];
      tablefuncelement(i: number): TablefuncelementContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TablefuncelementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      typename(): TypenameContext;
      opt_collate_clause(): Opt_collate_clauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class XmltableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XMLTABLE(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode[];
      OPEN_PAREN(i: number): antlr.TerminalNode | null;
      CLOSE_PAREN(): antlr.TerminalNode[];
      CLOSE_PAREN(i: number): antlr.TerminalNode | null;
      c_expr(): C_exprContext | null;
      xmlexists_argument(): Xmlexists_argumentContext | null;
      COLUMNS(): antlr.TerminalNode | null;
      xmltable_column_list(): Xmltable_column_listContext | null;
      XMLNAMESPACES(): antlr.TerminalNode | null;
      xml_namespace_list(): Xml_namespace_listContext | null;
      COMMA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xmltable_column_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      xmltable_column_el(): Xmltable_column_elContext[];
      xmltable_column_el(i: number): Xmltable_column_elContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xmltable_column_elContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      typename(): TypenameContext | null;
      FOR(): antlr.TerminalNode | null;
      ORDINALITY(): antlr.TerminalNode | null;
      xmltable_column_option_list(): Xmltable_column_option_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xmltable_column_option_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      xmltable_column_option_el(): Xmltable_column_option_elContext[];
      xmltable_column_option_el(i: number): Xmltable_column_option_elContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xmltable_column_option_elContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEFAULT(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      identifier(): IdentifierContext | null;
      NOT(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_namespace_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      xml_namespace_el(): Xml_namespace_elContext[];
      xml_namespace_el(i: number): Xml_namespace_elContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_namespace_elContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      b_expr(): B_exprContext;
      AS(): antlr.TerminalNode | null;
      collabel(): CollabelContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class TypenameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      simpletypename(): SimpletypenameContext | null;
      opt_array_bounds(): Opt_array_boundsContext | null;
      ARRAY(): antlr.TerminalNode | null;
      SETOF(): antlr.TerminalNode | null;
      OPEN_BRACKET(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_BRACKET(): antlr.TerminalNode | null;
      qualified_name(): Qualified_nameContext | null;
      PERCENT(): antlr.TerminalNode | null;
      ROWTYPE(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_array_boundsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_BRACKET(): antlr.TerminalNode[];
      OPEN_BRACKET(i: number): antlr.TerminalNode | null;
      CLOSE_BRACKET(): antlr.TerminalNode[];
      CLOSE_BRACKET(i: number): antlr.TerminalNode | null;
      iconst(): IconstContext[];
      iconst(i: number): IconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SimpletypenameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      generictype(): GenerictypeContext | null;
      numeric(): NumericContext | null;
      bit(): BitContext | null;
      character(): CharacterContext | null;
      constdatetime(): ConstdatetimeContext | null;
      constinterval(): ConstintervalContext | null;
      opt_interval(): Opt_intervalContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConsttypenameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      numeric(): NumericContext | null;
      constbit(): ConstbitContext | null;
      constcharacter(): ConstcharacterContext | null;
      constdatetime(): ConstdatetimeContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class GenerictypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_type_modifiers(): Opt_type_modifiersContext;
      builtin_function_name(): Builtin_function_nameContext | null;
      type_function_name(): Type_function_nameContext | null;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      attrs(): AttrsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_type_modifiersContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class NumericContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INT_P(): antlr.TerminalNode | null;
      INTEGER(): antlr.TerminalNode | null;
      SMALLINT(): antlr.TerminalNode | null;
      BIGINT(): antlr.TerminalNode | null;
      REAL(): antlr.TerminalNode | null;
      FLOAT_P(): antlr.TerminalNode | null;
      opt_float(): Opt_floatContext | null;
      DOUBLE_P(): antlr.TerminalNode | null;
      PRECISION(): antlr.TerminalNode | null;
      DECIMAL_P(): antlr.TerminalNode | null;
      opt_type_modifiers(): Opt_type_modifiersContext | null;
      DEC(): antlr.TerminalNode | null;
      NUMERIC(): antlr.TerminalNode | null;
      BOOLEAN_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_floatContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class BitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      bitwithlength(): BitwithlengthContext | null;
      bitwithoutlength(): BitwithoutlengthContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstbitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      bitwithlength(): BitwithlengthContext | null;
      bitwithoutlength(): BitwithoutlengthContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class BitwithlengthContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BIT(): antlr.TerminalNode;
      opt_varying(): Opt_varyingContext;
      OPEN_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class BitwithoutlengthContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BIT(): antlr.TerminalNode;
      opt_varying(): Opt_varyingContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CharacterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      character_c(): Character_cContext;
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstcharacterContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      character_c(): Character_cContext;
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Character_cContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_varying(): Opt_varyingContext | null;
      CHARACTER(): antlr.TerminalNode | null;
      CHAR_P(): antlr.TerminalNode | null;
      NCHAR(): antlr.TerminalNode | null;
      VARCHAR(): antlr.TerminalNode | null;
      NATIONAL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_varyingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VARYING(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstdatetimeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_timezone(): Opt_timezoneContext;
      TIMESTAMP(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ConstintervalContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INTERVAL(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_timezoneContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITH(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      ZONE(): antlr.TerminalNode | null;
      WITHOUT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_intervalContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      YEAR_P(): antlr.TerminalNode | null;
      MONTH_P(): antlr.TerminalNode | null;
      DAY_P(): antlr.TerminalNode | null;
      HOUR_P(): antlr.TerminalNode | null;
      MINUTE_P(): antlr.TerminalNode | null;
      interval_second(): Interval_secondContext | null;
      TO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Interval_secondContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SECOND_P(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_escapeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ESCAPE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_qual(): A_expr_qualContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_qualContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_lessless(): A_expr_lesslessContext;
      qual_op(): Qual_opContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_lesslessContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_or(): A_expr_orContext[];
      a_expr_or(i: number): A_expr_orContext | null;
      LESS_LESS(): antlr.TerminalNode[];
      LESS_LESS(i: number): antlr.TerminalNode | null;
      GREATER_GREATER(): antlr.TerminalNode[];
      GREATER_GREATER(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_orContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_and(): A_expr_andContext[];
      a_expr_and(i: number): A_expr_andContext | null;
      OR(): antlr.TerminalNode[];
      OR(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_andContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_between(): A_expr_betweenContext[];
      a_expr_between(i: number): A_expr_betweenContext | null;
      AND(): antlr.TerminalNode[];
      AND(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_betweenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_in(): A_expr_inContext[];
      a_expr_in(i: number): A_expr_inContext | null;
      BETWEEN(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      SYMMETRIC(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_inContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_unary_not(): A_expr_unary_notContext;
      IN_P(): antlr.TerminalNode | null;
      in_expr(): In_exprContext | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_unary_notContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_isnull(): A_expr_isnullContext;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_isnullContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_is_not(): A_expr_is_notContext;
      ISNULL(): antlr.TerminalNode | null;
      NOTNULL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_is_notContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_compare(): A_expr_compareContext;
      IS(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      TRUE_P(): antlr.TerminalNode | null;
      FALSE_P(): antlr.TerminalNode | null;
      UNKNOWN(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      OF(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      type_list(): Type_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      DOCUMENT_P(): antlr.TerminalNode | null;
      NORMALIZED(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      unicode_normal_form(): Unicode_normal_formContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_compareContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_like(): A_expr_likeContext[];
      a_expr_like(i: number): A_expr_likeContext | null;
      subquery_Op(): Subquery_OpContext | null;
      sub_type(): Sub_typeContext | null;
      LT(): antlr.TerminalNode | null;
      GT(): antlr.TerminalNode | null;
      EQUAL(): antlr.TerminalNode | null;
      LESS_EQUALS(): antlr.TerminalNode | null;
      GREATER_EQUALS(): antlr.TerminalNode | null;
      NOT_EQUALS(): antlr.TerminalNode | null;
      select_with_parens(): Select_with_parensContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_likeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_qual_op(): A_expr_qual_opContext[];
      a_expr_qual_op(i: number): A_expr_qual_opContext | null;
      opt_escape(): Opt_escapeContext | null;
      LIKE(): antlr.TerminalNode | null;
      ILIKE(): antlr.TerminalNode | null;
      SIMILAR(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_qual_opContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_unary_qualop(): A_expr_unary_qualopContext[];
      a_expr_unary_qualop(i: number): A_expr_unary_qualopContext | null;
      qual_op(): Qual_opContext[];
      qual_op(i: number): Qual_opContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_unary_qualopContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_add(): A_expr_addContext;
      qual_op(): Qual_opContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_addContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_mul(): A_expr_mulContext[];
      a_expr_mul(i: number): A_expr_mulContext | null;
      MINUS(): antlr.TerminalNode[];
      MINUS(i: number): antlr.TerminalNode | null;
      PLUS(): antlr.TerminalNode[];
      PLUS(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_mulContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_caret(): A_expr_caretContext[];
      a_expr_caret(i: number): A_expr_caretContext | null;
      STAR(): antlr.TerminalNode[];
      STAR(i: number): antlr.TerminalNode | null;
      SLASH(): antlr.TerminalNode[];
      SLASH(i: number): antlr.TerminalNode | null;
      PERCENT(): antlr.TerminalNode[];
      PERCENT(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_caretContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_unary_sign(): A_expr_unary_signContext;
      CARET(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_unary_signContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_at_time_zone(): A_expr_at_time_zoneContext;
      MINUS(): antlr.TerminalNode | null;
      PLUS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_at_time_zoneContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_collate(): A_expr_collateContext;
      AT(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      ZONE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_collateContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr_typecast(): A_expr_typecastContext;
      COLLATE(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class A_expr_typecastContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      c_expr(): C_exprContext;
      TYPECAST(): antlr.TerminalNode[];
      TYPECAST(i: number): antlr.TerminalNode | null;
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class B_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      c_expr(): C_exprContext | null;
      b_expr(): B_exprContext[];
      b_expr(i: number): B_exprContext | null;
      PLUS(): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode | null;
      qual_op(): Qual_opContext | null;
      CARET(): antlr.TerminalNode | null;
      STAR(): antlr.TerminalNode | null;
      SLASH(): antlr.TerminalNode | null;
      PERCENT(): antlr.TerminalNode | null;
      LT(): antlr.TerminalNode | null;
      GT(): antlr.TerminalNode | null;
      EQUAL(): antlr.TerminalNode | null;
      LESS_EQUALS(): antlr.TerminalNode | null;
      GREATER_EQUALS(): antlr.TerminalNode | null;
      NOT_EQUALS(): antlr.TerminalNode | null;
      TYPECAST(): antlr.TerminalNode | null;
      typename(): TypenameContext | null;
      IS(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      type_list(): Type_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      DOCUMENT_P(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class C_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: C_exprContext): void;
  }
  export class C_expr_existsContext extends C_exprContext {
      constructor(ctx: C_exprContext);
      EXISTS(): antlr.TerminalNode;
      select_with_parens(): Select_with_parensContext;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class C_expr_caseContext extends C_exprContext {
      constructor(ctx: C_exprContext);
      case_expr(): Case_exprContext;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class C_expr_exprContext extends C_exprContext {
      _a_expr_in_parens?: A_exprContext;
      constructor(ctx: C_exprContext);
      ARRAY(): antlr.TerminalNode | null;
      select_with_parens(): Select_with_parensContext | null;
      array_expr(): Array_exprContext | null;
      PARAM(): antlr.TerminalNode | null;
      opt_indirection(): Opt_indirectionContext | null;
      GROUPING(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      UNIQUE(): antlr.TerminalNode | null;
      columnref(): ColumnrefContext | null;
      aexprconst(): AexprconstContext | null;
      plsqlvariablename(): PlsqlvariablenameContext | null;
      a_expr(): A_exprContext | null;
      func_expr(): Func_exprContext | null;
      indirection(): IndirectionContext | null;
      explicit_row(): Explicit_rowContext | null;
      implicit_row(): Implicit_rowContext | null;
      row(): RowContext[];
      row(i: number): RowContext | null;
      OVERLAPS(): antlr.TerminalNode | null;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PlsqlvariablenameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PLSQLVARIABLENAME(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_applicationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_name(): Func_nameContext;
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      func_arg_list(): Func_arg_listContext | null;
      opt_sort_clause(): Opt_sort_clauseContext | null;
      VARIADIC(): antlr.TerminalNode | null;
      func_arg_expr(): Func_arg_exprContext | null;
      STAR(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_application(): Func_applicationContext | null;
      within_group_clause(): Within_group_clauseContext | null;
      filter_clause(): Filter_clauseContext | null;
      over_clause(): Over_clauseContext | null;
      func_expr_common_subexpr(): Func_expr_common_subexprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_expr_windowlessContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_application(): Func_applicationContext | null;
      func_expr_common_subexpr(): Func_expr_common_subexprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_expr_common_subexprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COLLATION(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      CURRENT_DATE(): antlr.TerminalNode | null;
      CURRENT_TIME(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      CURRENT_TIMESTAMP(): antlr.TerminalNode | null;
      LOCALTIME(): antlr.TerminalNode | null;
      LOCALTIMESTAMP(): antlr.TerminalNode | null;
      CURRENT_ROLE(): antlr.TerminalNode | null;
      CURRENT_USER(): antlr.TerminalNode | null;
      SESSION_USER(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      CURRENT_CATALOG(): antlr.TerminalNode | null;
      CURRENT_SCHEMA(): antlr.TerminalNode | null;
      CAST(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      typename(): TypenameContext | null;
      EXTRACT(): antlr.TerminalNode | null;
      extract_list(): Extract_listContext | null;
      NORMALIZE(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode | null;
      unicode_normal_form(): Unicode_normal_formContext | null;
      OVERLAY(): antlr.TerminalNode | null;
      overlay_list(): Overlay_listContext | null;
      POSITION(): antlr.TerminalNode | null;
      position_list(): Position_listContext | null;
      SUBSTRING(): antlr.TerminalNode | null;
      substr_list(): Substr_listContext | null;
      TREAT(): antlr.TerminalNode | null;
      TRIM(): antlr.TerminalNode | null;
      trim_list(): Trim_listContext | null;
      BOTH(): antlr.TerminalNode | null;
      LEADING(): antlr.TerminalNode | null;
      TRAILING(): antlr.TerminalNode | null;
      NULLIF(): antlr.TerminalNode | null;
      COALESCE(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      GREATEST(): antlr.TerminalNode | null;
      LEAST(): antlr.TerminalNode | null;
      XMLCONCAT(): antlr.TerminalNode | null;
      XMLELEMENT(): antlr.TerminalNode | null;
      NAME_P(): antlr.TerminalNode | null;
      collabel(): CollabelContext | null;
      xml_attributes(): Xml_attributesContext | null;
      XMLEXISTS(): antlr.TerminalNode | null;
      c_expr(): C_exprContext | null;
      xmlexists_argument(): Xmlexists_argumentContext | null;
      XMLFOREST(): antlr.TerminalNode | null;
      xml_attribute_list(): Xml_attribute_listContext | null;
      XMLPARSE(): antlr.TerminalNode | null;
      document_or_content(): Document_or_contentContext | null;
      xml_whitespace_option(): Xml_whitespace_optionContext | null;
      XMLPI(): antlr.TerminalNode | null;
      XMLROOT(): antlr.TerminalNode | null;
      XML_P(): antlr.TerminalNode | null;
      xml_root_version(): Xml_root_versionContext | null;
      opt_xml_root_standalone(): Opt_xml_root_standaloneContext | null;
      XMLSERIALIZE(): antlr.TerminalNode | null;
      simpletypename(): SimpletypenameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_root_versionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      VERSION_P(): antlr.TerminalNode;
      a_expr(): A_exprContext | null;
      NO(): antlr.TerminalNode | null;
      VALUE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_xml_root_standaloneContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMA(): antlr.TerminalNode | null;
      STANDALONE_P(): antlr.TerminalNode | null;
      YES_P(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      VALUE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_attributesContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XMLATTRIBUTES(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      xml_attribute_list(): Xml_attribute_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_attribute_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      xml_attribute_el(): Xml_attribute_elContext[];
      xml_attribute_el(i: number): Xml_attribute_elContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_attribute_elContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext;
      AS(): antlr.TerminalNode | null;
      collabel(): CollabelContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Document_or_contentContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DOCUMENT_P(): antlr.TerminalNode | null;
      CONTENT_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_whitespace_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PRESERVE(): antlr.TerminalNode | null;
      WHITESPACE_P(): antlr.TerminalNode | null;
      STRIP_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xmlexists_argumentContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PASSING(): antlr.TerminalNode;
      c_expr(): C_exprContext;
      xml_passing_mech(): Xml_passing_mechContext[];
      xml_passing_mech(i: number): Xml_passing_mechContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Xml_passing_mechContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BY(): antlr.TerminalNode;
      REF(): antlr.TerminalNode | null;
      VALUE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Within_group_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WITHIN(): antlr.TerminalNode | null;
      GROUP_P(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      sort_clause(): Sort_clauseContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Filter_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FILTER(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Window_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WINDOW(): antlr.TerminalNode | null;
      window_definition_list(): Window_definition_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Window_definition_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      window_definition(): Window_definitionContext[];
      window_definition(i: number): Window_definitionContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Window_definitionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      AS(): antlr.TerminalNode;
      window_specification(): Window_specificationContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Over_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OVER(): antlr.TerminalNode | null;
      window_specification(): Window_specificationContext | null;
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Window_specificationContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      opt_existing_window_name(): Opt_existing_window_nameContext;
      opt_partition_clause(): Opt_partition_clauseContext;
      opt_sort_clause(): Opt_sort_clauseContext;
      opt_frame_clause(): Opt_frame_clauseContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_existing_window_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_partition_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARTITION(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_frame_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RANGE(): antlr.TerminalNode | null;
      frame_extent(): Frame_extentContext | null;
      opt_window_exclusion_clause(): Opt_window_exclusion_clauseContext | null;
      ROWS(): antlr.TerminalNode | null;
      GROUPS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Frame_extentContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      frame_bound(): Frame_boundContext[];
      frame_bound(i: number): Frame_boundContext | null;
      BETWEEN(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Frame_boundContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UNBOUNDED(): antlr.TerminalNode | null;
      PRECEDING(): antlr.TerminalNode | null;
      FOLLOWING(): antlr.TerminalNode | null;
      CURRENT_P(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_window_exclusion_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXCLUDE(): antlr.TerminalNode | null;
      CURRENT_P(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      GROUP_P(): antlr.TerminalNode | null;
      TIES(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      OTHERS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RowContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROW(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext | null;
      COMMA(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Explicit_rowContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROW(): antlr.TerminalNode;
      OPEN_PAREN(): antlr.TerminalNode;
      CLOSE_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Implicit_rowContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      COMMA(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Sub_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ANY(): antlr.TerminalNode | null;
      SOME(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class All_opContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      Operator(): antlr.TerminalNode | null;
      mathop(): MathopContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class MathopContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PLUS(): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode | null;
      STAR(): antlr.TerminalNode | null;
      SLASH(): antlr.TerminalNode | null;
      PERCENT(): antlr.TerminalNode | null;
      CARET(): antlr.TerminalNode | null;
      LT(): antlr.TerminalNode | null;
      GT(): antlr.TerminalNode | null;
      EQUAL(): antlr.TerminalNode | null;
      LESS_EQUALS(): antlr.TerminalNode | null;
      GREATER_EQUALS(): antlr.TerminalNode | null;
      NOT_EQUALS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Qual_opContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      Operator(): antlr.TerminalNode | null;
      OPERATOR(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      any_operator(): Any_operatorContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Qual_all_opContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      all_op(): All_opContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      any_operator(): Any_operatorContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Subquery_OpContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      all_op(): All_opContext | null;
      OPERATOR(): antlr.TerminalNode | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      any_operator(): Any_operatorContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      LIKE(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      ILIKE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Expr_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_arg_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      func_arg_expr(): Func_arg_exprContext[];
      func_arg_expr(i: number): Func_arg_exprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_arg_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext;
      param_name(): Param_nameContext | null;
      COLON_EQUALS(): antlr.TerminalNode | null;
      EQUALS_GREATER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Type_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      typename(): TypenameContext[];
      typename(i: number): TypenameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Array_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_BRACKET(): antlr.TerminalNode;
      CLOSE_BRACKET(): antlr.TerminalNode;
      expr_list(): Expr_listContext | null;
      array_expr_list(): Array_expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Array_expr_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      array_expr(): Array_exprContext[];
      array_expr(i: number): Array_exprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Extract_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      extract_arg(): Extract_argContext | null;
      FROM(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Extract_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      YEAR_P(): antlr.TerminalNode | null;
      MONTH_P(): antlr.TerminalNode | null;
      DAY_P(): antlr.TerminalNode | null;
      HOUR_P(): antlr.TerminalNode | null;
      MINUTE_P(): antlr.TerminalNode | null;
      SECOND_P(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Unicode_normal_formContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NFC(): antlr.TerminalNode | null;
      NFD(): antlr.TerminalNode | null;
      NFKC(): antlr.TerminalNode | null;
      NFKD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Overlay_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      PLACING(): antlr.TerminalNode;
      FROM(): antlr.TerminalNode;
      FOR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Position_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      b_expr(): B_exprContext[];
      b_expr(i: number): B_exprContext | null;
      IN_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Substr_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      FROM(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      SIMILAR(): antlr.TerminalNode | null;
      ESCAPE(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Trim_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext | null;
      FROM(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class In_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: In_exprContext): void;
  }
  export class In_expr_listContext extends In_exprContext {
      constructor(ctx: In_exprContext);
      OPEN_PAREN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class In_expr_selectContext extends In_exprContext {
      constructor(ctx: In_exprContext);
      select_with_parens(): Select_with_parensContext;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Case_exprContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CASE(): antlr.TerminalNode;
      case_arg(): Case_argContext;
      when_clause_list(): When_clause_listContext;
      case_default(): Case_defaultContext;
      END_P(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class When_clause_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      when_clause(): When_clauseContext[];
      when_clause(i: number): When_clauseContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class When_clauseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      THEN(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Case_defaultContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ELSE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Case_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColumnrefContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      indirection(): IndirectionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Indirection_elContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DOT(): antlr.TerminalNode | null;
      attr_name(): Attr_nameContext | null;
      STAR(): antlr.TerminalNode | null;
      OPEN_BRACKET(): antlr.TerminalNode | null;
      CLOSE_BRACKET(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      opt_slice_bound(): Opt_slice_boundContext[];
      opt_slice_bound(i: number): Opt_slice_boundContext | null;
      COLON(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_slice_boundContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class IndirectionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      indirection_el(): Indirection_elContext[];
      indirection_el(i: number): Indirection_elContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_indirectionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      indirection_el(): Indirection_elContext[];
      indirection_el(i: number): Indirection_elContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_target_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      target_list(): Target_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Target_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      target_el(): Target_elContext[];
      target_el(i: number): Target_elContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Target_elContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      get ruleIndex(): number;
      copyFrom(ctx: Target_elContext): void;
  }
  export class Target_labelContext extends Target_elContext {
      constructor(ctx: Target_elContext);
      a_expr(): A_exprContext;
      AS(): antlr.TerminalNode | null;
      collabel(): CollabelContext | null;
      identifier(): IdentifierContext | null;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Target_starContext extends Target_elContext {
      constructor(ctx: Target_elContext);
      STAR(): antlr.TerminalNode;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Qualified_name_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      qualified_name(): Qualified_nameContext[];
      qualified_name(i: number): Qualified_nameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Qualified_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      indirection(): IndirectionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Name_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      name(): NameContext[];
      name(i: number): NameContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class NameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Attr_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      collabel(): CollabelContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class File_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Func_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      builtin_function_name(): Builtin_function_nameContext | null;
      type_function_name(): Type_function_nameContext | null;
      colid(): ColidContext | null;
      indirection(): IndirectionContext | null;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AexprconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      iconst(): IconstContext | null;
      fconst(): FconstContext | null;
      sconst(): SconstContext | null;
      bconst(): BconstContext | null;
      xconst(): XconstContext | null;
      func_name(): Func_nameContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      func_arg_list(): Func_arg_listContext | null;
      opt_sort_clause(): Opt_sort_clauseContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      consttypename(): ConsttypenameContext | null;
      constinterval(): ConstintervalContext | null;
      opt_interval(): Opt_intervalContext | null;
      TRUE_P(): antlr.TerminalNode | null;
      FALSE_P(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class XconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      HexadecimalStringConstant(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class BconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BinaryStringConstant(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class FconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      Numeric(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class IconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      Integral(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      anysconst(): AnysconstContext;
      opt_uescape(): Opt_uescapeContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class AnysconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      StringConstant(): antlr.TerminalNode | null;
      UnicodeEscapeStringConstant(): antlr.TerminalNode | null;
      BeginDollarStringConstant(): antlr.TerminalNode | null;
      EndDollarStringConstant(): antlr.TerminalNode | null;
      DollarText(): antlr.TerminalNode[];
      DollarText(i: number): antlr.TerminalNode | null;
      EscapeStringConstant(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_uescapeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      UESCAPE(): antlr.TerminalNode | null;
      anysconst(): AnysconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SignediconstContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      iconst(): IconstContext;
      PLUS(): antlr.TerminalNode | null;
      MINUS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RoleidContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      rolespec(): RolespecContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class RolespecContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      nonreservedword(): NonreservedwordContext | null;
      CURRENT_USER(): antlr.TerminalNode | null;
      SESSION_USER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Role_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      rolespec(): RolespecContext[];
      rolespec(i: number): RolespecContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class ColidContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      unreserved_keyword(): Unreserved_keywordContext | null;
      col_name_keyword(): Col_name_keywordContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      LEFT(): antlr.TerminalNode | null;
      RIGHT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Table_aliasContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      unreserved_keyword(): Unreserved_keywordContext | null;
      col_name_keyword(): Col_name_keywordContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Type_function_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      unreserved_keyword(): Unreserved_keywordContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      type_func_name_keyword(): Type_func_name_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class NonreservedwordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      unreserved_keyword(): Unreserved_keywordContext | null;
      col_name_keyword(): Col_name_keywordContext | null;
      type_func_name_keyword(): Type_func_name_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class CollabelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      unreserved_keyword(): Unreserved_keywordContext | null;
      col_name_keyword(): Col_name_keywordContext | null;
      type_func_name_keyword(): Type_func_name_keywordContext | null;
      reserved_keyword(): Reserved_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class IdentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      Identifier(): antlr.TerminalNode | null;
      opt_uescape(): Opt_uescapeContext | null;
      QuotedIdentifier(): antlr.TerminalNode | null;
      UnicodeQuotedIdentifier(): antlr.TerminalNode | null;
      plsqlvariablename(): PlsqlvariablenameContext | null;
      plsqlidentifier(): PlsqlidentifierContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class PlsqlidentifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PLSQLIDENTIFIER(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Unreserved_keywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ABORT_P(): antlr.TerminalNode | null;
      ABSOLUTE_P(): antlr.TerminalNode | null;
      ACCESS(): antlr.TerminalNode | null;
      ACTION(): antlr.TerminalNode | null;
      ADD_P(): antlr.TerminalNode | null;
      ADMIN(): antlr.TerminalNode | null;
      AFTER(): antlr.TerminalNode | null;
      AGGREGATE(): antlr.TerminalNode | null;
      ALSO(): antlr.TerminalNode | null;
      ALTER(): antlr.TerminalNode | null;
      ALWAYS(): antlr.TerminalNode | null;
      ASSERTION(): antlr.TerminalNode | null;
      ASSIGNMENT(): antlr.TerminalNode | null;
      AT(): antlr.TerminalNode | null;
      ATTACH(): antlr.TerminalNode | null;
      ATTRIBUTE(): antlr.TerminalNode | null;
      BACKWARD(): antlr.TerminalNode | null;
      BEFORE(): antlr.TerminalNode | null;
      BEGIN_P(): antlr.TerminalNode | null;
      BY(): antlr.TerminalNode | null;
      CACHE(): antlr.TerminalNode | null;
      CALL(): antlr.TerminalNode | null;
      CALLED(): antlr.TerminalNode | null;
      CASCADE(): antlr.TerminalNode | null;
      CASCADED(): antlr.TerminalNode | null;
      CATALOG(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      CHARACTERISTICS(): antlr.TerminalNode | null;
      CHECKPOINT(): antlr.TerminalNode | null;
      CLASS(): antlr.TerminalNode | null;
      CLOSE(): antlr.TerminalNode | null;
      CLUSTER(): antlr.TerminalNode | null;
      COLUMNS(): antlr.TerminalNode | null;
      COMMENT(): antlr.TerminalNode | null;
      COMMENTS(): antlr.TerminalNode | null;
      COMMIT(): antlr.TerminalNode | null;
      COMMITTED(): antlr.TerminalNode | null;
      CONFIGURATION(): antlr.TerminalNode | null;
      CONFLICT(): antlr.TerminalNode | null;
      CONNECTION(): antlr.TerminalNode | null;
      CONSTRAINTS(): antlr.TerminalNode | null;
      CONTENT_P(): antlr.TerminalNode | null;
      CONTINUE_P(): antlr.TerminalNode | null;
      CONVERSION_P(): antlr.TerminalNode | null;
      COPY(): antlr.TerminalNode | null;
      COST(): antlr.TerminalNode | null;
      CSV(): antlr.TerminalNode | null;
      CUBE(): antlr.TerminalNode | null;
      CURRENT_P(): antlr.TerminalNode | null;
      CURSOR(): antlr.TerminalNode | null;
      CYCLE(): antlr.TerminalNode | null;
      DATA_P(): antlr.TerminalNode | null;
      DATABASE(): antlr.TerminalNode | null;
      DAY_P(): antlr.TerminalNode | null;
      DEALLOCATE(): antlr.TerminalNode | null;
      DECLARE(): antlr.TerminalNode | null;
      DEFAULTS(): antlr.TerminalNode | null;
      DEFERRED(): antlr.TerminalNode | null;
      DEFINER(): antlr.TerminalNode | null;
      DELETE_P(): antlr.TerminalNode | null;
      DELIMITER(): antlr.TerminalNode | null;
      DELIMITERS(): antlr.TerminalNode | null;
      DEPENDS(): antlr.TerminalNode | null;
      DETACH(): antlr.TerminalNode | null;
      DICTIONARY(): antlr.TerminalNode | null;
      DISABLE_P(): antlr.TerminalNode | null;
      DISCARD(): antlr.TerminalNode | null;
      DOCUMENT_P(): antlr.TerminalNode | null;
      DOMAIN_P(): antlr.TerminalNode | null;
      DOUBLE_P(): antlr.TerminalNode | null;
      DROP(): antlr.TerminalNode | null;
      EACH(): antlr.TerminalNode | null;
      ENABLE_P(): antlr.TerminalNode | null;
      ENCODING(): antlr.TerminalNode | null;
      ENCRYPTED(): antlr.TerminalNode | null;
      ENUM_P(): antlr.TerminalNode | null;
      ESCAPE(): antlr.TerminalNode | null;
      EVENT(): antlr.TerminalNode | null;
      EXCLUDE(): antlr.TerminalNode | null;
      EXCLUDING(): antlr.TerminalNode | null;
      EXCLUSIVE(): antlr.TerminalNode | null;
      EXECUTE(): antlr.TerminalNode | null;
      EXPLAIN(): antlr.TerminalNode | null;
      EXPRESSION(): antlr.TerminalNode | null;
      EXTENSION(): antlr.TerminalNode | null;
      EXTERNAL(): antlr.TerminalNode | null;
      FAMILY(): antlr.TerminalNode | null;
      FILTER(): antlr.TerminalNode | null;
      FIRST_P(): antlr.TerminalNode | null;
      FOLLOWING(): antlr.TerminalNode | null;
      FORCE(): antlr.TerminalNode | null;
      FORWARD(): antlr.TerminalNode | null;
      FUNCTION(): antlr.TerminalNode | null;
      FUNCTIONS(): antlr.TerminalNode | null;
      GENERATED(): antlr.TerminalNode | null;
      GLOBAL(): antlr.TerminalNode | null;
      GRANTED(): antlr.TerminalNode | null;
      GROUPS(): antlr.TerminalNode | null;
      HANDLER(): antlr.TerminalNode | null;
      HEADER_P(): antlr.TerminalNode | null;
      HOLD(): antlr.TerminalNode | null;
      HOUR_P(): antlr.TerminalNode | null;
      IDENTITY_P(): antlr.TerminalNode | null;
      IF_P(): antlr.TerminalNode | null;
      IMMEDIATE(): antlr.TerminalNode | null;
      IMMUTABLE(): antlr.TerminalNode | null;
      IMPLICIT_P(): antlr.TerminalNode | null;
      IMPORT_P(): antlr.TerminalNode | null;
      INCLUDE(): antlr.TerminalNode | null;
      INCLUDING(): antlr.TerminalNode | null;
      INCREMENT(): antlr.TerminalNode | null;
      INDEX(): antlr.TerminalNode | null;
      INDEXES(): antlr.TerminalNode | null;
      INHERIT(): antlr.TerminalNode | null;
      INHERITS(): antlr.TerminalNode | null;
      INLINE_P(): antlr.TerminalNode | null;
      INPUT_P(): antlr.TerminalNode | null;
      INSENSITIVE(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      INSTEAD(): antlr.TerminalNode | null;
      INVOKER(): antlr.TerminalNode | null;
      ISOLATION(): antlr.TerminalNode | null;
      KEY(): antlr.TerminalNode | null;
      LABEL(): antlr.TerminalNode | null;
      LANGUAGE(): antlr.TerminalNode | null;
      LARGE_P(): antlr.TerminalNode | null;
      LAST_P(): antlr.TerminalNode | null;
      LEAKPROOF(): antlr.TerminalNode | null;
      LEVEL(): antlr.TerminalNode | null;
      LISTEN(): antlr.TerminalNode | null;
      LOAD(): antlr.TerminalNode | null;
      LOCAL(): antlr.TerminalNode | null;
      LOCATION(): antlr.TerminalNode | null;
      LOCK_P(): antlr.TerminalNode | null;
      LOCKED(): antlr.TerminalNode | null;
      LOGGED(): antlr.TerminalNode | null;
      MAPPING(): antlr.TerminalNode | null;
      MATCH(): antlr.TerminalNode | null;
      MATERIALIZED(): antlr.TerminalNode | null;
      MAXVALUE(): antlr.TerminalNode | null;
      METHOD(): antlr.TerminalNode | null;
      MINUTE_P(): antlr.TerminalNode | null;
      MINVALUE(): antlr.TerminalNode | null;
      MODE(): antlr.TerminalNode | null;
      MONTH_P(): antlr.TerminalNode | null;
      MOVE(): antlr.TerminalNode | null;
      NAME_P(): antlr.TerminalNode | null;
      NAMES(): antlr.TerminalNode | null;
      NEW(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      NFC(): antlr.TerminalNode | null;
      NFD(): antlr.TerminalNode | null;
      NFKC(): antlr.TerminalNode | null;
      NFKD(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      NORMALIZED(): antlr.TerminalNode | null;
      NOTHING(): antlr.TerminalNode | null;
      NOTIFY(): antlr.TerminalNode | null;
      NOWAIT(): antlr.TerminalNode | null;
      NULLS_P(): antlr.TerminalNode | null;
      OBJECT_P(): antlr.TerminalNode | null;
      OF(): antlr.TerminalNode | null;
      OFF(): antlr.TerminalNode | null;
      OIDS(): antlr.TerminalNode | null;
      OLD(): antlr.TerminalNode | null;
      OPERATOR(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      OPTIONS(): antlr.TerminalNode | null;
      ORDINALITY(): antlr.TerminalNode | null;
      OTHERS(): antlr.TerminalNode | null;
      OVER(): antlr.TerminalNode | null;
      OVERRIDING(): antlr.TerminalNode | null;
      OWNED(): antlr.TerminalNode | null;
      OWNER(): antlr.TerminalNode | null;
      PARALLEL(): antlr.TerminalNode | null;
      PARSER(): antlr.TerminalNode | null;
      PARTIAL(): antlr.TerminalNode | null;
      PARTITION(): antlr.TerminalNode | null;
      PASSING(): antlr.TerminalNode | null;
      PASSWORD(): antlr.TerminalNode | null;
      PLANS(): antlr.TerminalNode | null;
      POLICY(): antlr.TerminalNode | null;
      PRECEDING(): antlr.TerminalNode | null;
      PREPARE(): antlr.TerminalNode | null;
      PREPARED(): antlr.TerminalNode | null;
      PRESERVE(): antlr.TerminalNode | null;
      PRIOR(): antlr.TerminalNode | null;
      PRIVILEGES(): antlr.TerminalNode | null;
      PROCEDURAL(): antlr.TerminalNode | null;
      PROCEDURE(): antlr.TerminalNode | null;
      PROCEDURES(): antlr.TerminalNode | null;
      PROGRAM(): antlr.TerminalNode | null;
      PUBLICATION(): antlr.TerminalNode | null;
      QUOTE(): antlr.TerminalNode | null;
      RANGE(): antlr.TerminalNode | null;
      READ(): antlr.TerminalNode | null;
      REASSIGN(): antlr.TerminalNode | null;
      RECHECK(): antlr.TerminalNode | null;
      RECURSIVE(): antlr.TerminalNode | null;
      REF(): antlr.TerminalNode | null;
      REFERENCING(): antlr.TerminalNode | null;
      REFRESH(): antlr.TerminalNode | null;
      REINDEX(): antlr.TerminalNode | null;
      RELATIVE_P(): antlr.TerminalNode | null;
      RELEASE(): antlr.TerminalNode | null;
      RENAME(): antlr.TerminalNode | null;
      REPEATABLE(): antlr.TerminalNode | null;
      REPLICA(): antlr.TerminalNode | null;
      RESET(): antlr.TerminalNode | null;
      RESTART(): antlr.TerminalNode | null;
      RESTRICT(): antlr.TerminalNode | null;
      RETURNS(): antlr.TerminalNode | null;
      REVOKE(): antlr.TerminalNode | null;
      ROLE(): antlr.TerminalNode | null;
      ROLLBACK(): antlr.TerminalNode | null;
      ROLLUP(): antlr.TerminalNode | null;
      ROUTINE(): antlr.TerminalNode | null;
      ROUTINES(): antlr.TerminalNode | null;
      ROWS(): antlr.TerminalNode | null;
      RULE(): antlr.TerminalNode | null;
      SAVEPOINT(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      SCHEMAS(): antlr.TerminalNode | null;
      SCROLL(): antlr.TerminalNode | null;
      SEARCH(): antlr.TerminalNode | null;
      SECOND_P(): antlr.TerminalNode | null;
      SECURITY(): antlr.TerminalNode | null;
      SEQUENCE(): antlr.TerminalNode | null;
      SEQUENCES(): antlr.TerminalNode | null;
      SERIALIZABLE(): antlr.TerminalNode | null;
      SERVER(): antlr.TerminalNode | null;
      SESSION(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      SETS(): antlr.TerminalNode | null;
      SHARE(): antlr.TerminalNode | null;
      SHOW(): antlr.TerminalNode | null;
      SIMPLE(): antlr.TerminalNode | null;
      SKIP_P(): antlr.TerminalNode | null;
      SNAPSHOT(): antlr.TerminalNode | null;
      SQL_P(): antlr.TerminalNode | null;
      STABLE(): antlr.TerminalNode | null;
      STANDALONE_P(): antlr.TerminalNode | null;
      START(): antlr.TerminalNode | null;
      STATEMENT(): antlr.TerminalNode | null;
      STATISTICS(): antlr.TerminalNode | null;
      STDIN(): antlr.TerminalNode | null;
      STDOUT(): antlr.TerminalNode | null;
      STORAGE(): antlr.TerminalNode | null;
      STORED(): antlr.TerminalNode | null;
      STRICT_P(): antlr.TerminalNode | null;
      STRIP_P(): antlr.TerminalNode | null;
      SUBSCRIPTION(): antlr.TerminalNode | null;
      SUPPORT(): antlr.TerminalNode | null;
      SYSID(): antlr.TerminalNode | null;
      SYSTEM_P(): antlr.TerminalNode | null;
      TABLES(): antlr.TerminalNode | null;
      TABLESPACE(): antlr.TerminalNode | null;
      TEMP(): antlr.TerminalNode | null;
      TEMPLATE(): antlr.TerminalNode | null;
      TEMPORARY(): antlr.TerminalNode | null;
      TEXT_P(): antlr.TerminalNode | null;
      TIES(): antlr.TerminalNode | null;
      TRANSACTION(): antlr.TerminalNode | null;
      TRANSFORM(): antlr.TerminalNode | null;
      TRIGGER(): antlr.TerminalNode | null;
      TRUNCATE(): antlr.TerminalNode | null;
      TRUSTED(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      TYPES_P(): antlr.TerminalNode | null;
      UESCAPE(): antlr.TerminalNode | null;
      UNBOUNDED(): antlr.TerminalNode | null;
      UNCOMMITTED(): antlr.TerminalNode | null;
      UNENCRYPTED(): antlr.TerminalNode | null;
      UNKNOWN(): antlr.TerminalNode | null;
      UNLISTEN(): antlr.TerminalNode | null;
      UNLOGGED(): antlr.TerminalNode | null;
      UNTIL(): antlr.TerminalNode | null;
      UPDATE(): antlr.TerminalNode | null;
      VACUUM(): antlr.TerminalNode | null;
      VALID(): antlr.TerminalNode | null;
      VALIDATE(): antlr.TerminalNode | null;
      VALIDATOR(): antlr.TerminalNode | null;
      VALUE_P(): antlr.TerminalNode | null;
      VARYING(): antlr.TerminalNode | null;
      VERSION_P(): antlr.TerminalNode | null;
      VIEW(): antlr.TerminalNode | null;
      VIEWS(): antlr.TerminalNode | null;
      VOLATILE(): antlr.TerminalNode | null;
      WHITESPACE_P(): antlr.TerminalNode | null;
      WITHIN(): antlr.TerminalNode | null;
      WITHOUT(): antlr.TerminalNode | null;
      WORK(): antlr.TerminalNode | null;
      WRAPPER(): antlr.TerminalNode | null;
      WRITE(): antlr.TerminalNode | null;
      XML_P(): antlr.TerminalNode | null;
      YEAR_P(): antlr.TerminalNode | null;
      YES_P(): antlr.TerminalNode | null;
      ZONE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Col_name_keywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BETWEEN(): antlr.TerminalNode | null;
      BIGINT(): antlr.TerminalNode | null;
      bit(): BitContext | null;
      BOOLEAN_P(): antlr.TerminalNode | null;
      CHAR_P(): antlr.TerminalNode | null;
      character(): CharacterContext | null;
      COALESCE(): antlr.TerminalNode | null;
      DEC(): antlr.TerminalNode | null;
      DECIMAL_P(): antlr.TerminalNode | null;
      EXISTS(): antlr.TerminalNode | null;
      EXTRACT(): antlr.TerminalNode | null;
      FLOAT_P(): antlr.TerminalNode | null;
      GREATEST(): antlr.TerminalNode | null;
      GROUPING(): antlr.TerminalNode | null;
      INOUT(): antlr.TerminalNode | null;
      INT_P(): antlr.TerminalNode | null;
      INTEGER(): antlr.TerminalNode | null;
      INTERVAL(): antlr.TerminalNode | null;
      LEAST(): antlr.TerminalNode | null;
      NATIONAL(): antlr.TerminalNode | null;
      NCHAR(): antlr.TerminalNode | null;
      NONE(): antlr.TerminalNode | null;
      NORMALIZE(): antlr.TerminalNode | null;
      NULLIF(): antlr.TerminalNode | null;
      numeric(): NumericContext | null;
      OUT_P(): antlr.TerminalNode | null;
      OVERLAY(): antlr.TerminalNode | null;
      POSITION(): antlr.TerminalNode | null;
      PRECISION(): antlr.TerminalNode | null;
      REAL(): antlr.TerminalNode | null;
      ROW(): antlr.TerminalNode | null;
      SETOF(): antlr.TerminalNode | null;
      SMALLINT(): antlr.TerminalNode | null;
      SUBSTRING(): antlr.TerminalNode | null;
      TIME(): antlr.TerminalNode | null;
      TIMESTAMP(): antlr.TerminalNode | null;
      TREAT(): antlr.TerminalNode | null;
      TRIM(): antlr.TerminalNode | null;
      VALUES(): antlr.TerminalNode | null;
      VARCHAR(): antlr.TerminalNode | null;
      XMLATTRIBUTES(): antlr.TerminalNode | null;
      XMLCONCAT(): antlr.TerminalNode | null;
      XMLELEMENT(): antlr.TerminalNode | null;
      XMLEXISTS(): antlr.TerminalNode | null;
      XMLFOREST(): antlr.TerminalNode | null;
      XMLNAMESPACES(): antlr.TerminalNode | null;
      XMLPARSE(): antlr.TerminalNode | null;
      XMLPI(): antlr.TerminalNode | null;
      XMLROOT(): antlr.TerminalNode | null;
      XMLSERIALIZE(): antlr.TerminalNode | null;
      XMLTABLE(): antlr.TerminalNode | null;
      builtin_function_name(): Builtin_function_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Type_func_name_keywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AUTHORIZATION(): antlr.TerminalNode | null;
      BINARY(): antlr.TerminalNode | null;
      COLLATION(): antlr.TerminalNode | null;
      CONCURRENTLY(): antlr.TerminalNode | null;
      CROSS(): antlr.TerminalNode | null;
      CURRENT_SCHEMA(): antlr.TerminalNode | null;
      FREEZE(): antlr.TerminalNode | null;
      FULL(): antlr.TerminalNode | null;
      ILIKE(): antlr.TerminalNode | null;
      INNER_P(): antlr.TerminalNode | null;
      IS(): antlr.TerminalNode | null;
      ISNULL(): antlr.TerminalNode | null;
      JOIN(): antlr.TerminalNode | null;
      LIKE(): antlr.TerminalNode | null;
      NATURAL(): antlr.TerminalNode | null;
      NOTNULL(): antlr.TerminalNode | null;
      OUTER_P(): antlr.TerminalNode | null;
      OVERLAPS(): antlr.TerminalNode | null;
      SIMILAR(): antlr.TerminalNode | null;
      TABLESAMPLE(): antlr.TerminalNode | null;
      VERBOSE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Reserved_keywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ALL(): antlr.TerminalNode | null;
      ANALYSE(): antlr.TerminalNode | null;
      ANALYZE(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      ANY(): antlr.TerminalNode | null;
      ARRAY(): antlr.TerminalNode | null;
      AS(): antlr.TerminalNode | null;
      ASC(): antlr.TerminalNode | null;
      ASYMMETRIC(): antlr.TerminalNode | null;
      BOTH(): antlr.TerminalNode | null;
      CASE(): antlr.TerminalNode | null;
      CAST(): antlr.TerminalNode | null;
      CHECK(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      COLUMN(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      CREATE(): antlr.TerminalNode | null;
      CURRENT_CATALOG(): antlr.TerminalNode | null;
      CURRENT_DATE(): antlr.TerminalNode | null;
      CURRENT_ROLE(): antlr.TerminalNode | null;
      CURRENT_TIME(): antlr.TerminalNode | null;
      CURRENT_TIMESTAMP(): antlr.TerminalNode | null;
      CURRENT_USER(): antlr.TerminalNode | null;
      DEFERRABLE(): antlr.TerminalNode | null;
      DESC(): antlr.TerminalNode | null;
      DISTINCT(): antlr.TerminalNode | null;
      DO(): antlr.TerminalNode | null;
      ELSE(): antlr.TerminalNode | null;
      END_P(): antlr.TerminalNode | null;
      EXCEPT(): antlr.TerminalNode | null;
      FALSE_P(): antlr.TerminalNode | null;
      FETCH(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      FOREIGN(): antlr.TerminalNode | null;
      FROM(): antlr.TerminalNode | null;
      GRANT(): antlr.TerminalNode | null;
      GROUP_P(): antlr.TerminalNode | null;
      HAVING(): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      INITIALLY(): antlr.TerminalNode | null;
      INTERSECT(): antlr.TerminalNode | null;
      LATERAL_P(): antlr.TerminalNode | null;
      LEADING(): antlr.TerminalNode | null;
      LIMIT(): antlr.TerminalNode | null;
      LOCALTIME(): antlr.TerminalNode | null;
      LOCALTIMESTAMP(): antlr.TerminalNode | null;
      NOT(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      OFFSET(): antlr.TerminalNode | null;
      ON(): antlr.TerminalNode | null;
      ONLY(): antlr.TerminalNode | null;
      OR(): antlr.TerminalNode | null;
      ORDER(): antlr.TerminalNode | null;
      PLACING(): antlr.TerminalNode | null;
      PRIMARY(): antlr.TerminalNode | null;
      REFERENCES(): antlr.TerminalNode | null;
      RETURNING(): antlr.TerminalNode | null;
      SELECT(): antlr.TerminalNode | null;
      SESSION_USER(): antlr.TerminalNode | null;
      SOME(): antlr.TerminalNode | null;
      SYMMETRIC(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      THEN(): antlr.TerminalNode | null;
      TO(): antlr.TerminalNode | null;
      TRAILING(): antlr.TerminalNode | null;
      TRUE_P(): antlr.TerminalNode | null;
      UNION(): antlr.TerminalNode | null;
      UNIQUE(): antlr.TerminalNode | null;
      USER(): antlr.TerminalNode | null;
      USING(): antlr.TerminalNode | null;
      VARIADIC(): antlr.TerminalNode | null;
      WHEN(): antlr.TerminalNode | null;
      WHERE(): antlr.TerminalNode | null;
      WINDOW(): antlr.TerminalNode | null;
      WITH(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Builtin_function_nameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      XMLCOMMENT(): antlr.TerminalNode | null;
      XML_IS_WELL_FORMED(): antlr.TerminalNode | null;
      XML_IS_WELL_FORMED_DOCUMENT(): antlr.TerminalNode | null;
      XML_IS_WELL_FORMED_CONTENT(): antlr.TerminalNode | null;
      XMLAGG(): antlr.TerminalNode | null;
      XPATH(): antlr.TerminalNode | null;
      XPATH_EXISTS(): antlr.TerminalNode | null;
      ABS(): antlr.TerminalNode | null;
      CBRT(): antlr.TerminalNode | null;
      CEIL(): antlr.TerminalNode | null;
      CEILING(): antlr.TerminalNode | null;
      DEGREES(): antlr.TerminalNode | null;
      DIV(): antlr.TerminalNode | null;
      EXP(): antlr.TerminalNode | null;
      FACTORIAL(): antlr.TerminalNode | null;
      FLOOR(): antlr.TerminalNode | null;
      GCD(): antlr.TerminalNode | null;
      LCM(): antlr.TerminalNode | null;
      LN(): antlr.TerminalNode | null;
      LOG(): antlr.TerminalNode | null;
      LOG10(): antlr.TerminalNode | null;
      MIN_SCALE(): antlr.TerminalNode | null;
      MOD(): antlr.TerminalNode | null;
      PI(): antlr.TerminalNode | null;
      POWER(): antlr.TerminalNode | null;
      RADIANS(): antlr.TerminalNode | null;
      ROUND(): antlr.TerminalNode | null;
      SCALE(): antlr.TerminalNode | null;
      SIGN(): antlr.TerminalNode | null;
      SQRT(): antlr.TerminalNode | null;
      TRIM_SCALE(): antlr.TerminalNode | null;
      TRUNC(): antlr.TerminalNode | null;
      WIDTH_BUCKET(): antlr.TerminalNode | null;
      RANDOM(): antlr.TerminalNode | null;
      SETSEED(): antlr.TerminalNode | null;
      ACOS(): antlr.TerminalNode | null;
      ACOSD(): antlr.TerminalNode | null;
      ACOSH(): antlr.TerminalNode | null;
      ASIN(): antlr.TerminalNode | null;
      ASIND(): antlr.TerminalNode | null;
      ASINH(): antlr.TerminalNode | null;
      ATAN(): antlr.TerminalNode | null;
      ATAND(): antlr.TerminalNode | null;
      ATANH(): antlr.TerminalNode | null;
      ATAN2(): antlr.TerminalNode | null;
      ATAN2D(): antlr.TerminalNode | null;
      COS(): antlr.TerminalNode | null;
      COSD(): antlr.TerminalNode | null;
      COSH(): antlr.TerminalNode | null;
      COT(): antlr.TerminalNode | null;
      COTD(): antlr.TerminalNode | null;
      SIN(): antlr.TerminalNode | null;
      SIND(): antlr.TerminalNode | null;
      SINH(): antlr.TerminalNode | null;
      TAN(): antlr.TerminalNode | null;
      TAND(): antlr.TerminalNode | null;
      TANH(): antlr.TerminalNode | null;
      BIT_LENGTH(): antlr.TerminalNode | null;
      CHAR_LENGTH(): antlr.TerminalNode | null;
      CHARACTER_LENGTH(): antlr.TerminalNode | null;
      LOWER(): antlr.TerminalNode | null;
      OCTET_LENGTH(): antlr.TerminalNode | null;
      UPPER(): antlr.TerminalNode | null;
      ASCII(): antlr.TerminalNode | null;
      BTRIM(): antlr.TerminalNode | null;
      CHR(): antlr.TerminalNode | null;
      CONCAT(): antlr.TerminalNode | null;
      CONCAT_WS(): antlr.TerminalNode | null;
      FORMAT(): antlr.TerminalNode | null;
      INITCAP(): antlr.TerminalNode | null;
      LENGTH(): antlr.TerminalNode | null;
      LPAD(): antlr.TerminalNode | null;
      LTRIM(): antlr.TerminalNode | null;
      MD5(): antlr.TerminalNode | null;
      PARSE_IDENT(): antlr.TerminalNode | null;
      PG_CLIENT_ENCODING(): antlr.TerminalNode | null;
      QUOTE_IDENT(): antlr.TerminalNode | null;
      QUOTE_LITERAL(): antlr.TerminalNode | null;
      QUOTE_NULLABLE(): antlr.TerminalNode | null;
      REGEXP_COUNT(): antlr.TerminalNode | null;
      REGEXP_INSTR(): antlr.TerminalNode | null;
      REGEXP_LIKE(): antlr.TerminalNode | null;
      REGEXP_MATCH(): antlr.TerminalNode | null;
      REGEXP_MATCHES(): antlr.TerminalNode | null;
      REGEXP_REPLACE(): antlr.TerminalNode | null;
      REGEXP_SPLIT_TO_ARRAY(): antlr.TerminalNode | null;
      REGEXP_SPLIT_TO_TABLE(): antlr.TerminalNode | null;
      REGEXP_SUBSTR(): antlr.TerminalNode | null;
      REPEAT(): antlr.TerminalNode | null;
      REPLACE(): antlr.TerminalNode | null;
      REVERSE(): antlr.TerminalNode | null;
      RPAD(): antlr.TerminalNode | null;
      RTRIM(): antlr.TerminalNode | null;
      SPLIT_PART(): antlr.TerminalNode | null;
      STARTS_WITH(): antlr.TerminalNode | null;
      STRING_TO_ARRAY(): antlr.TerminalNode | null;
      STRING_TO_TABLE(): antlr.TerminalNode | null;
      STRPOS(): antlr.TerminalNode | null;
      SUBSTR(): antlr.TerminalNode | null;
      TO_ASCII(): antlr.TerminalNode | null;
      TO_HEX(): antlr.TerminalNode | null;
      TRANSLATE(): antlr.TerminalNode | null;
      UNISTR(): antlr.TerminalNode | null;
      AGE(): antlr.TerminalNode | null;
      DATE_BIN(): antlr.TerminalNode | null;
      DATE_PART(): antlr.TerminalNode | null;
      DATE_TRUNC(): antlr.TerminalNode | null;
      ISFINITE(): antlr.TerminalNode | null;
      JUSTIFY_DAYS(): antlr.TerminalNode | null;
      JUSTIFY_HOURS(): antlr.TerminalNode | null;
      JUSTIFY_INTERVAL(): antlr.TerminalNode | null;
      MAKE_DATE(): antlr.TerminalNode | null;
      MAKE_INTERVAL(): antlr.TerminalNode | null;
      MAKE_TIME(): antlr.TerminalNode | null;
      MAKE_TIMESTAMP(): antlr.TerminalNode | null;
      MAKE_TIMESTAMPTZ(): antlr.TerminalNode | null;
      CLOCK_TIMESTAMP(): antlr.TerminalNode | null;
      NOW(): antlr.TerminalNode | null;
      STATEMENT_TIMESTAMP(): antlr.TerminalNode | null;
      TIMEOFDAY(): antlr.TerminalNode | null;
      TRANSACTION_TIMESTAMP(): antlr.TerminalNode | null;
      TO_TIMESTAMP(): antlr.TerminalNode | null;
      TO_CHAR(): antlr.TerminalNode | null;
      TO_DATE(): antlr.TerminalNode | null;
      TO_NUMBER(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Pl_functionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      comp_options(): Comp_optionsContext;
      pl_block(): Pl_blockContext;
      opt_semi(): Opt_semiContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Comp_optionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      comp_option(): Comp_optionContext[];
      comp_option(i: number): Comp_optionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Comp_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sharp(): SharpContext;
      OPTION(): antlr.TerminalNode | null;
      DUMP(): antlr.TerminalNode | null;
      PRINT_STRICT_PARAMS(): antlr.TerminalNode | null;
      option_value(): Option_valueContext | null;
      VARIABLE_CONFLICT(): antlr.TerminalNode | null;
      ERROR(): antlr.TerminalNode | null;
      USE_VARIABLE(): antlr.TerminalNode | null;
      USE_COLUMN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class SharpContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      Operator(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Option_valueContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sconst(): SconstContext | null;
      reserved_keyword(): Reserved_keywordContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      unreserved_keyword(): Unreserved_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_semiContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SEMI(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Pl_blockContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_sect(): Decl_sectContext;
      BEGIN_P(): antlr.TerminalNode;
      proc_sect(): Proc_sectContext;
      exception_sect(): Exception_sectContext;
      END_P(): antlr.TerminalNode;
      opt_label(): Opt_labelContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_sectContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_block_label(): Opt_block_labelContext;
      decl_start(): Decl_startContext | null;
      decl_stmts(): Decl_stmtsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_startContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DECLARE(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_stmtsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_stmt(): Decl_stmtContext[];
      decl_stmt(i: number): Decl_stmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Label_declContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LESS_LESS(): antlr.TerminalNode;
      any_identifier(): Any_identifierContext;
      GREATER_GREATER(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_stmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_statement(): Decl_statementContext | null;
      DECLARE(): antlr.TerminalNode | null;
      label_decl(): Label_declContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_statementContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_varname(): Decl_varnameContext;
      SEMI(): antlr.TerminalNode;
      ALIAS(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      decl_aliasitem(): Decl_aliasitemContext | null;
      decl_const(): Decl_constContext | null;
      decl_datatype(): Decl_datatypeContext | null;
      decl_collate(): Decl_collateContext | null;
      decl_notnull(): Decl_notnullContext | null;
      decl_defval(): Decl_defvalContext | null;
      opt_scrollable(): Opt_scrollableContext | null;
      CURSOR(): antlr.TerminalNode | null;
      decl_cursor_args(): Decl_cursor_argsContext | null;
      decl_is_for(): Decl_is_forContext | null;
      decl_cursor_query(): Decl_cursor_queryContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_scrollableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NO(): antlr.TerminalNode | null;
      SCROLL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_cursor_queryContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      selectstmt(): SelectstmtContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_cursor_argsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      decl_cursor_arglist(): Decl_cursor_arglistContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_cursor_arglistContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_cursor_arg(): Decl_cursor_argContext[];
      decl_cursor_arg(i: number): Decl_cursor_argContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_cursor_argContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_varname(): Decl_varnameContext;
      decl_datatype(): Decl_datatypeContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_is_forContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IS(): antlr.TerminalNode | null;
      FOR(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_aliasitemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PARAM(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_varnameContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_identifier(): Any_identifierContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_constContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CONSTANT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_datatypeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      typename(): TypenameContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_collateContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COLLATE(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_notnullContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NOT(): antlr.TerminalNode | null;
      NULL_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_defvalContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      decl_defkey(): Decl_defkeyContext | null;
      sql_expression(): Sql_expressionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Decl_defkeyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      assign_operator(): Assign_operatorContext | null;
      DEFAULT(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Assign_operatorContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EQUAL(): antlr.TerminalNode | null;
      COLON_EQUALS(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Proc_sectContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      proc_stmt(): Proc_stmtContext[];
      proc_stmt(i: number): Proc_stmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Proc_stmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      pl_block(): Pl_blockContext | null;
      SEMI(): antlr.TerminalNode | null;
      stmt_return(): Stmt_returnContext | null;
      stmt_raise(): Stmt_raiseContext | null;
      stmt_assign(): Stmt_assignContext | null;
      stmt_if(): Stmt_ifContext | null;
      stmt_case(): Stmt_caseContext | null;
      stmt_loop(): Stmt_loopContext | null;
      stmt_while(): Stmt_whileContext | null;
      stmt_for(): Stmt_forContext | null;
      stmt_foreach_a(): Stmt_foreach_aContext | null;
      stmt_exit(): Stmt_exitContext | null;
      stmt_assert(): Stmt_assertContext | null;
      stmt_execsql(): Stmt_execsqlContext | null;
      stmt_dynexecute(): Stmt_dynexecuteContext | null;
      stmt_perform(): Stmt_performContext | null;
      stmt_call(): Stmt_callContext | null;
      stmt_getdiag(): Stmt_getdiagContext | null;
      stmt_open(): Stmt_openContext | null;
      stmt_fetch(): Stmt_fetchContext | null;
      stmt_move(): Stmt_moveContext | null;
      stmt_close(): Stmt_closeContext | null;
      stmt_null(): Stmt_nullContext | null;
      stmt_commit(): Stmt_commitContext | null;
      stmt_rollback(): Stmt_rollbackContext | null;
      stmt_set(): Stmt_setContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_performContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      PERFORM(): antlr.TerminalNode;
      expr_until_semi(): Expr_until_semiContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_callContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CALL(): antlr.TerminalNode | null;
      any_identifier(): Any_identifierContext;
      OPEN_PAREN(): antlr.TerminalNode;
      opt_expr_list(): Opt_expr_listContext;
      CLOSE_PAREN(): antlr.TerminalNode;
      SEMI(): antlr.TerminalNode;
      DO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_expr_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expr_list(): Expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_assignContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      assign_var(): Assign_varContext;
      assign_operator(): Assign_operatorContext;
      sql_expression(): Sql_expressionContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_getdiagContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      GET(): antlr.TerminalNode;
      getdiag_area_opt(): Getdiag_area_optContext;
      DIAGNOSTICS(): antlr.TerminalNode;
      getdiag_list(): Getdiag_listContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Getdiag_area_optContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CURRENT_P(): antlr.TerminalNode | null;
      STACKED(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Getdiag_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      getdiag_list_item(): Getdiag_list_itemContext[];
      getdiag_list_item(i: number): Getdiag_list_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Getdiag_list_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      getdiag_target(): Getdiag_targetContext;
      assign_operator(): Assign_operatorContext;
      getdiag_item(): Getdiag_itemContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Getdiag_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Getdiag_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      assign_var(): Assign_varContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Assign_varContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_name(): Any_nameContext | null;
      PARAM(): antlr.TerminalNode | null;
      OPEN_BRACKET(): antlr.TerminalNode[];
      OPEN_BRACKET(i: number): antlr.TerminalNode | null;
      expr_until_rightbracket(): Expr_until_rightbracketContext[];
      expr_until_rightbracket(i: number): Expr_until_rightbracketContext | null;
      CLOSE_BRACKET(): antlr.TerminalNode[];
      CLOSE_BRACKET(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_ifContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      IF_P(): antlr.TerminalNode[];
      IF_P(i: number): antlr.TerminalNode | null;
      expr_until_then(): Expr_until_thenContext;
      THEN(): antlr.TerminalNode;
      proc_sect(): Proc_sectContext;
      stmt_elsifs(): Stmt_elsifsContext;
      stmt_else(): Stmt_elseContext;
      END_P(): antlr.TerminalNode;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_elsifsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ELSIF(): antlr.TerminalNode[];
      ELSIF(i: number): antlr.TerminalNode | null;
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      THEN(): antlr.TerminalNode[];
      THEN(i: number): antlr.TerminalNode | null;
      proc_sect(): Proc_sectContext[];
      proc_sect(i: number): Proc_sectContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_elseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ELSE(): antlr.TerminalNode | null;
      proc_sect(): Proc_sectContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_caseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CASE(): antlr.TerminalNode[];
      CASE(i: number): antlr.TerminalNode | null;
      opt_expr_until_when(): Opt_expr_until_whenContext;
      case_when_list(): Case_when_listContext;
      opt_case_else(): Opt_case_elseContext;
      END_P(): antlr.TerminalNode;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_expr_until_whenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sql_expression(): Sql_expressionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Case_when_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      case_when(): Case_whenContext[];
      case_when(i: number): Case_whenContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Case_whenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      expr_list(): Expr_listContext;
      THEN(): antlr.TerminalNode;
      proc_sect(): Proc_sectContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_case_elseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ELSE(): antlr.TerminalNode | null;
      proc_sect(): Proc_sectContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_loopContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_loop_label(): Opt_loop_labelContext;
      loop_body(): Loop_bodyContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_whileContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_loop_label(): Opt_loop_labelContext;
      WHILE(): antlr.TerminalNode;
      expr_until_loop(): Expr_until_loopContext;
      loop_body(): Loop_bodyContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_forContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_loop_label(): Opt_loop_labelContext;
      FOR(): antlr.TerminalNode;
      for_control(): For_controlContext;
      loop_body(): Loop_bodyContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class For_controlContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      for_variable(): For_variableContext;
      IN_P(): antlr.TerminalNode;
      cursor_name(): Cursor_nameContext | null;
      opt_cursor_parameters(): Opt_cursor_parametersContext | null;
      selectstmt(): SelectstmtContext | null;
      explainstmt(): ExplainstmtContext | null;
      EXECUTE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      opt_for_using_expression(): Opt_for_using_expressionContext | null;
      opt_reverse(): Opt_reverseContext | null;
      DOT_DOT(): antlr.TerminalNode | null;
      opt_by_expression(): Opt_by_expressionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_for_using_expressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_cursor_parametersContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN_PAREN(): antlr.TerminalNode | null;
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_reverseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      REVERSE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_by_expressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      BY(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class For_variableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_name_list(): Any_name_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_foreach_aContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_loop_label(): Opt_loop_labelContext;
      FOREACH(): antlr.TerminalNode;
      for_variable(): For_variableContext;
      foreach_slice(): Foreach_sliceContext;
      IN_P(): antlr.TerminalNode;
      ARRAY(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      loop_body(): Loop_bodyContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Foreach_sliceContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SLICE(): antlr.TerminalNode | null;
      iconst(): IconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_exitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      exit_type(): Exit_typeContext;
      opt_label(): Opt_labelContext;
      opt_exitcond(): Opt_exitcondContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Exit_typeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXIT(): antlr.TerminalNode | null;
      CONTINUE_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_returnContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RETURN(): antlr.TerminalNode;
      SEMI(): antlr.TerminalNode;
      NEXT(): antlr.TerminalNode | null;
      sql_expression(): Sql_expressionContext | null;
      QUERY(): antlr.TerminalNode | null;
      opt_return_result(): Opt_return_resultContext | null;
      EXECUTE(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      opt_for_using_expression(): Opt_for_using_expressionContext | null;
      selectstmt(): SelectstmtContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_return_resultContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sql_expression(): Sql_expressionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_raiseContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      RAISE(): antlr.TerminalNode;
      opt_stmt_raise_level(): Opt_stmt_raise_levelContext | null;
      sconst(): SconstContext | null;
      opt_raise_list(): Opt_raise_listContext | null;
      opt_raise_using(): Opt_raise_usingContext | null;
      SEMI(): antlr.TerminalNode | null;
      identifier(): IdentifierContext | null;
      SQLSTATE(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_stmt_raise_levelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      DEBUG(): antlr.TerminalNode | null;
      LOG(): antlr.TerminalNode | null;
      INFO(): antlr.TerminalNode | null;
      NOTICE(): antlr.TerminalNode | null;
      WARNING(): antlr.TerminalNode | null;
      EXCEPTION(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_raise_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_raise_usingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      opt_raise_using_elem_list(): Opt_raise_using_elem_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_raise_using_elemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      identifier(): IdentifierContext;
      EQUAL(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_raise_using_elem_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_raise_using_elem(): Opt_raise_using_elemContext[];
      opt_raise_using_elem(i: number): Opt_raise_using_elemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_assertContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ASSERT(): antlr.TerminalNode;
      sql_expression(): Sql_expressionContext;
      opt_stmt_assert_message(): Opt_stmt_assert_messageContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_stmt_assert_messageContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMA(): antlr.TerminalNode | null;
      sql_expression(): Sql_expressionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Loop_bodyContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      LOOP(): antlr.TerminalNode[];
      LOOP(i: number): antlr.TerminalNode | null;
      proc_sect(): Proc_sectContext;
      END_P(): antlr.TerminalNode;
      opt_label(): Opt_labelContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_execsqlContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      make_execsql_stmt(): Make_execsql_stmtContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_dynexecuteContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXECUTE(): antlr.TerminalNode;
      a_expr(): A_exprContext;
      SEMI(): antlr.TerminalNode;
      opt_execute_into(): Opt_execute_intoContext | null;
      opt_execute_using(): Opt_execute_usingContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_execute_usingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      opt_execute_using_list(): Opt_execute_using_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_execute_using_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext[];
      a_expr(i: number): A_exprContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_execute_intoContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INTO(): antlr.TerminalNode | null;
      into_target(): Into_targetContext | null;
      STRICT_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_openContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      OPEN(): antlr.TerminalNode;
      SEMI(): antlr.TerminalNode;
      cursor_variable(): Cursor_variableContext | null;
      opt_scroll_option(): Opt_scroll_optionContext | null;
      FOR(): antlr.TerminalNode | null;
      colid(): ColidContext | null;
      selectstmt(): SelectstmtContext | null;
      EXECUTE(): antlr.TerminalNode | null;
      sql_expression(): Sql_expressionContext | null;
      opt_open_using(): Opt_open_usingContext | null;
      OPEN_PAREN(): antlr.TerminalNode | null;
      opt_open_bound_list(): Opt_open_bound_listContext | null;
      CLOSE_PAREN(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_open_bound_list_itemContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      COLON_EQUALS(): antlr.TerminalNode | null;
      a_expr(): A_exprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_open_bound_listContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_open_bound_list_item(): Opt_open_bound_list_itemContext[];
      opt_open_bound_list_item(i: number): Opt_open_bound_list_itemContext | null;
      COMMA(): antlr.TerminalNode[];
      COMMA(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_open_usingContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      USING(): antlr.TerminalNode | null;
      expr_list(): Expr_listContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_scroll_optionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_scroll_option_no(): Opt_scroll_option_noContext | null;
      SCROLL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_scroll_option_noContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_fetchContext extends antlr.ParserRuleContext {
      _direction?: Opt_fetch_directionContext;
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FETCH(): antlr.TerminalNode;
      opt_cursor_from(): Opt_cursor_fromContext;
      cursor_variable(): Cursor_variableContext;
      INTO(): antlr.TerminalNode;
      into_target(): Into_targetContext;
      SEMI(): antlr.TerminalNode;
      opt_fetch_direction(): Opt_fetch_directionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Into_targetContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      expr_list(): Expr_listContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_cursor_fromContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      FROM(): antlr.TerminalNode | null;
      IN_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_fetch_directionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NEXT(): antlr.TerminalNode | null;
      PRIOR(): antlr.TerminalNode | null;
      FIRST_P(): antlr.TerminalNode | null;
      LAST_P(): antlr.TerminalNode | null;
      ABSOLUTE_P(): antlr.TerminalNode | null;
      a_expr(): A_exprContext | null;
      RELATIVE_P(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      FORWARD(): antlr.TerminalNode | null;
      BACKWARD(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_moveContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      MOVE(): antlr.TerminalNode;
      opt_fetch_direction(): Opt_fetch_directionContext;
      cursor_variable(): Cursor_variableContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_closeContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      CLOSE(): antlr.TerminalNode;
      cursor_variable(): Cursor_variableContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_nullContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      NULL_P(): antlr.TerminalNode;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_commitContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      COMMIT(): antlr.TerminalNode;
      plsql_opt_transaction_chain(): Plsql_opt_transaction_chainContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_rollbackContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ROLLBACK(): antlr.TerminalNode;
      plsql_opt_transaction_chain(): Plsql_opt_transaction_chainContext;
      SEMI(): antlr.TerminalNode;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Plsql_opt_transaction_chainContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      AND(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Stmt_setContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      SET(): antlr.TerminalNode | null;
      any_name(): Any_nameContext | null;
      TO(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      SEMI(): antlr.TerminalNode;
      RESET(): antlr.TerminalNode | null;
      ALL(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Cursor_variableContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      PARAM(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Exception_sectContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      EXCEPTION(): antlr.TerminalNode | null;
      proc_exceptions(): Proc_exceptionsContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Proc_exceptionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      proc_exception(): Proc_exceptionContext[];
      proc_exception(i: number): Proc_exceptionContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Proc_exceptionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode;
      proc_conditions(): Proc_conditionsContext;
      THEN(): antlr.TerminalNode;
      proc_sect(): Proc_sectContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Proc_conditionsContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      proc_condition(): Proc_conditionContext[];
      proc_condition(i: number): Proc_conditionContext | null;
      OR(): antlr.TerminalNode[];
      OR(i: number): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Proc_conditionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_identifier(): Any_identifierContext | null;
      SQLSTATE(): antlr.TerminalNode | null;
      sconst(): SconstContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_block_labelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      label_decl(): Label_declContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_loop_labelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      label_decl(): Label_declContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_labelContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      any_identifier(): Any_identifierContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_exitcondContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      WHEN(): antlr.TerminalNode | null;
      expr_until_semi(): Expr_until_semiContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Any_identifierContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      colid(): ColidContext | null;
      plsql_unreserved_keyword(): Plsql_unreserved_keywordContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Plsql_unreserved_keywordContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      ABSOLUTE_P(): antlr.TerminalNode | null;
      ALIAS(): antlr.TerminalNode | null;
      AND(): antlr.TerminalNode | null;
      ARRAY(): antlr.TerminalNode | null;
      ASSERT(): antlr.TerminalNode | null;
      BACKWARD(): antlr.TerminalNode | null;
      CALL(): antlr.TerminalNode | null;
      CHAIN(): antlr.TerminalNode | null;
      CLOSE(): antlr.TerminalNode | null;
      COLLATE(): antlr.TerminalNode | null;
      COLUMN(): antlr.TerminalNode | null;
      COMMIT(): antlr.TerminalNode | null;
      CONSTANT(): antlr.TerminalNode | null;
      CONSTRAINT(): antlr.TerminalNode | null;
      CONTINUE_P(): antlr.TerminalNode | null;
      CURRENT_P(): antlr.TerminalNode | null;
      CURSOR(): antlr.TerminalNode | null;
      DEBUG(): antlr.TerminalNode | null;
      DEFAULT(): antlr.TerminalNode | null;
      DIAGNOSTICS(): antlr.TerminalNode | null;
      DO(): antlr.TerminalNode | null;
      DUMP(): antlr.TerminalNode | null;
      ELSIF(): antlr.TerminalNode | null;
      ERROR(): antlr.TerminalNode | null;
      EXCEPTION(): antlr.TerminalNode | null;
      EXIT(): antlr.TerminalNode | null;
      FETCH(): antlr.TerminalNode | null;
      FIRST_P(): antlr.TerminalNode | null;
      FORWARD(): antlr.TerminalNode | null;
      GET(): antlr.TerminalNode | null;
      INFO(): antlr.TerminalNode | null;
      INSERT(): antlr.TerminalNode | null;
      IS(): antlr.TerminalNode | null;
      LAST_P(): antlr.TerminalNode | null;
      MOVE(): antlr.TerminalNode | null;
      NEXT(): antlr.TerminalNode | null;
      NO(): antlr.TerminalNode | null;
      NOTICE(): antlr.TerminalNode | null;
      OPEN(): antlr.TerminalNode | null;
      OPTION(): antlr.TerminalNode | null;
      PERFORM(): antlr.TerminalNode | null;
      PRINT_STRICT_PARAMS(): antlr.TerminalNode | null;
      PRIOR(): antlr.TerminalNode | null;
      QUERY(): antlr.TerminalNode | null;
      RAISE(): antlr.TerminalNode | null;
      RELATIVE_P(): antlr.TerminalNode | null;
      RESET(): antlr.TerminalNode | null;
      RETURN(): antlr.TerminalNode | null;
      ROLLBACK(): antlr.TerminalNode | null;
      ROWTYPE(): antlr.TerminalNode | null;
      SCHEMA(): antlr.TerminalNode | null;
      SCROLL(): antlr.TerminalNode | null;
      SET(): antlr.TerminalNode | null;
      SLICE(): antlr.TerminalNode | null;
      SQLSTATE(): antlr.TerminalNode | null;
      STACKED(): antlr.TerminalNode | null;
      TABLE(): antlr.TerminalNode | null;
      TYPE_P(): antlr.TerminalNode | null;
      USE_COLUMN(): antlr.TerminalNode | null;
      USE_VARIABLE(): antlr.TerminalNode | null;
      VARIABLE_CONFLICT(): antlr.TerminalNode | null;
      WARNING(): antlr.TerminalNode | null;
      OUTER_P(): antlr.TerminalNode | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Sql_expressionContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      opt_target_list(): Opt_target_listContext;
      into_clause(): Into_clauseContext;
      from_clause(): From_clauseContext;
      where_clause(): Where_clauseContext;
      group_clause(): Group_clauseContext;
      having_clause(): Having_clauseContext;
      window_clause(): Window_clauseContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Expr_until_thenContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sql_expression(): Sql_expressionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Expr_until_semiContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      sql_expression(): Sql_expressionContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Expr_until_rightbracketContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Expr_until_loopContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      a_expr(): A_exprContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Make_execsql_stmtContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      stmt(): StmtContext;
      opt_returning_clause_into(): Opt_returning_clause_intoContext;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }
  export class Opt_returning_clause_intoContext extends antlr.ParserRuleContext {
      constructor(parent: antlr.ParserRuleContext | null, invokingState: number);
      INTO(): antlr.TerminalNode | null;
      opt_strict(): Opt_strictContext | null;
      into_target(): Into_targetContext | null;
      get ruleIndex(): number;
      accept<Result>(visitor: PostgreSqlParserVisitor<Result>): Result | null;
  }

}
declare module 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParserVisitor' {
  import { AbstractParseTreeVisitor } from "antlr4ng";
  import { RootContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PlsqlrootContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { StmtblockContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { StmtmultiContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { StmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PlsqlconsolecommandContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CallstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreaterolestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_withContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptrolelistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlteroptrolelistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlteroptroleelemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateoptroleelemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateuserstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterrolestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_in_databaseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterrolesetstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DroprolestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreategroupstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltergroupstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Add_dropContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateschemastmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptschemanameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptschemaeltlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Schema_stmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { VariablesetstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Set_restContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generic_setContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Set_rest_moreContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Var_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Var_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Var_valueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Iso_levelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_boolean_or_stringContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Zone_valueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_encodingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Nonreservedword_or_sconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { VariableresetstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reset_restContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generic_resetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SetresetclauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { FunctionsetresetclauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { VariableshowstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstraintssetstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Constraints_set_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Constraints_set_modeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CheckpointstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DiscardstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltertablestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_table_cmdsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Partition_cmdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Index_partition_cmdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_table_cmdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_column_defaultContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_drop_behaviorContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_collate_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_usingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Replica_identityContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ReloptionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_reloptionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reloption_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reloption_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_identity_column_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_identity_column_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PartitionboundspecContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Hash_partbound_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Hash_partboundContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltercompositetypestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_type_cmdsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_type_cmdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CloseportalstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CopystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_fromContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_programContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_file_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_binaryContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_delimiterContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_usingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_generic_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_generic_opt_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_generic_opt_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_generic_opt_arg_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Copy_generic_opt_arg_list_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttempContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttableelementlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttypedtableelementlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TableelementlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TypedtableelementlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TableelementContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TypedtableelementContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColumnDefContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColumnOptionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColquallistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColconstraintContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColconstraintelemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generated_whenContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstraintattrContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TablelikeclauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TablelikeoptionlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TablelikeoptionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TableconstraintContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstraintelemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_no_inheritContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_column_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColumnlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColumnElemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_c_includeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Key_matchContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExclusionconstraintlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExclusionconstraintelemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExclusionwhereclauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Key_actionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Key_updateContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Key_deleteContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Key_actionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptinheritContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptpartitionspecContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PartitionspecContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Part_paramsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Part_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Table_access_method_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptwithContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OncommitoptionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttablespaceContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptconstablespaceContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExistingindexContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatestatsstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterstatsstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateasstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Create_as_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_with_dataContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatematviewstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Create_mv_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptnologContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RefreshmatviewstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateseqstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterseqstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptseqoptlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptparenthesizedseqoptlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SeqoptlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SeqoptelemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_byContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { NumericonlyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Numericonly_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateplangstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_trustedContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Handler_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_inline_handlerContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Validator_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_validatorContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_proceduralContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatetablespacestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttablespaceownerContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DroptablespacestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateextensionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Create_extension_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Create_extension_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterextensionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_extension_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_extension_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterextensioncontentsstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatefdwstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Fdw_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Fdw_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_fdw_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterfdwstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Create_generic_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generic_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_generic_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_generic_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alter_generic_option_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generic_option_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generic_option_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Generic_option_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateforeignserverstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Foreign_server_versionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_foreign_server_versionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterforeignserverstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateforeigntablestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ImportforeignschemastmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Import_qualification_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Import_qualificationContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateusermappingstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Auth_identContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropusermappingstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterusermappingstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatepolicystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterpolicystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowsecurityoptionalexprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowsecurityoptionalwithcheckContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowsecuritydefaulttoroleContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowsecurityoptionaltoroleContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowsecuritydefaultpermissiveContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowsecuritydefaultforcmdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Row_security_cmdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateamstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Am_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatetrigstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggeractiontimeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggereventsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggeroneeventContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerreferencingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggertransitionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggertransitionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TransitionoldornewContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TransitionrowortableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TransitionrelnameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerforspecContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerforopteachContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerfortypeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerwhenContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Function_or_procedureContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerfuncargsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TriggerfuncargContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OptconstrfromtableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstraintattributespecContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstraintattributeElemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateeventtrigstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Event_trigger_when_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Event_trigger_when_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Event_trigger_value_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltereventtrigstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Enable_triggerContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateassertionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DefinestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DefinitionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Def_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Def_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Def_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Old_aggr_definitionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Old_aggr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Old_aggr_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_enum_val_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Enum_val_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterenumstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_if_not_existsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateopclassstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opclass_item_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opclass_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_defaultContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_opfamilyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opclass_purposeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_recheckContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateopfamilystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlteropfamilystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opclass_drop_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opclass_dropContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropopclassstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropopfamilystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropownedstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ReassignownedstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Object_type_any_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Object_type_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Drop_type_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Object_type_name_on_any_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Any_name_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Any_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AttrsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Type_name_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TruncatestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_restart_seqsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CommentstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Comment_textContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SeclabelstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_providerContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Security_labelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { FetchstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Fetch_argsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { From_inContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_from_inContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { GrantstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RevokestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PrivilegesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Privilege_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PrivilegeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Privilege_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Grantee_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { GranteeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_grant_grant_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { GrantrolestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RevokerolestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_grant_admin_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_granted_byContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterdefaultprivilegesstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DefacloptionlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DefacloptionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DefaclactionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Defacl_privilege_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { IndexstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_uniqueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_concurrentlyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_index_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Access_method_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Index_paramsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Index_elem_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Index_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_includeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Index_including_paramsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_collateContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_classContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_asc_descContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_nulls_orderContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatefunctionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_or_replaceContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_argsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_args_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Function_with_argtypes_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Function_with_argtypesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_args_with_defaultsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_args_with_defaults_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Arg_classContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Param_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_returnContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_arg_with_defaultContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Aggr_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Aggr_argsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Aggr_args_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Aggregate_with_argtypesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Aggregate_with_argtypes_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Createfunc_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Common_func_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Createfunc_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_asContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Transform_type_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_definitionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Table_func_columnContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Table_func_column_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterfunctionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alterfunc_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_restrictContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RemovefuncstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RemoveaggrstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RemoveoperstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Oper_argtypesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Any_operatorContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Operator_with_argtypes_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Operator_with_argtypesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DostmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Dostmt_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Dostmt_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatecaststmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cast_contextContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropcaststmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_if_existsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatetransformstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Transform_element_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DroptransformstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ReindexstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reindex_target_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reindex_target_multitableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reindex_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reindex_option_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltertblspcstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RenamestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_columnContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_set_dataContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterobjectdependsstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_noContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterobjectschemastmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlteroperatorstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Operator_def_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Operator_def_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Operator_def_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltertypestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterownerstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatepublicationstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_publication_for_tablesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Publication_for_tablesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterpublicationstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatesubscriptionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Publication_name_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Publication_name_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltersubscriptionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropsubscriptionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RulestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RuleactionlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RuleactionmultiContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RuleactionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RuleactionstmtOrEmptyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { EventContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_insteadContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { NotifystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Notify_payloadContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ListenstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { UnlistenstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TransactionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_transactionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Transaction_mode_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Transaction_mode_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Transaction_mode_list_or_emptyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_transaction_chainContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ViewstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_check_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { LoadstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatedbstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Createdb_opt_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Createdb_opt_itemsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Createdb_opt_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Createdb_opt_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_equalContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterdatabasestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterdatabasesetstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DropdbstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Drop_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Drop_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltercollationstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltersystemstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreatedomainstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AlterdomainstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_asContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltertsdictionarystmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AltertsconfigurationstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Any_withContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CreateconversionstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ClusterstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cluster_index_specificationContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { VacuumstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AnalyzestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Vac_analyze_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Analyze_keywordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Vac_analyze_option_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Vac_analyze_option_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Vac_analyze_option_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_analyzeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_verboseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_fullContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_freezeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_name_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Vacuum_relationContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Vacuum_relation_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_vacuum_relation_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExplainstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExplainablestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Explain_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Explain_option_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Explain_option_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Explain_option_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PreparestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Prep_type_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PreparablestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ExecutestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Execute_param_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DeallocatestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { InsertstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Insert_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Insert_restContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Override_kindContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Insert_column_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Insert_column_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_on_conflictContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_conf_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Returning_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { MergestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Merge_insert_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Merge_update_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Merge_delete_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DeletestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Using_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { LockstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_lockContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Lock_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_nowaitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_nowait_or_skipContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { UpdatestmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Set_clause_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Set_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Set_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Set_target_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { DeclarecursorstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cursor_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cursor_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_holdContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SelectstmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_with_parensContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_no_parensContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Simple_select_intersectContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Simple_select_pramaryContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { With_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cte_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Common_table_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_materializedContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_with_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Into_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_strictContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttempTableNameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_tableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { All_or_distinctContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Distinct_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_all_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_sort_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Sort_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Sortby_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SortbyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_limitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_select_limitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Limit_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Offset_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_limit_valueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_offset_valueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Select_fetch_first_valueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { I_or_f_constContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Row_or_rowsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { First_or_nextContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Group_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Group_by_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Group_by_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Empty_grouping_setContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Rollup_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cube_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Grouping_sets_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Having_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { For_locking_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_for_locking_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { For_locking_itemsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { For_locking_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { For_locking_strengthContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Locked_rels_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Values_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { From_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { From_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Non_ansi_joinContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Table_refContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Alias_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_alias_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Table_alias_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_alias_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Join_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Join_qualContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Relation_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Relation_expr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Relation_expr_opt_aliasContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Tablesample_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_repeatable_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_tableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Rowsfrom_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Rowsfrom_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_col_def_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_ordinalityContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Where_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Where_or_current_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { OpttablefuncelementlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TablefuncelementlistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TablefuncelementContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { XmltableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xmltable_column_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xmltable_column_elContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xmltable_column_option_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xmltable_column_option_elContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_namespace_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_namespace_elContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { TypenameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_array_boundsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SimpletypenameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConsttypenameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { GenerictypeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_type_modifiersContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { NumericContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_floatContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { BitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstbitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { BitwithlengthContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { BitwithoutlengthContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CharacterContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstcharacterContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Character_cContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_varyingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstdatetimeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ConstintervalContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_timezoneContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_intervalContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Interval_secondContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_escapeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_qualContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_lesslessContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_orContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_andContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_betweenContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_inContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_unary_notContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_isnullContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_is_notContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_compareContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_likeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_qual_opContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_unary_qualopContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_addContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_mulContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_caretContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_unary_signContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_at_time_zoneContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_collateContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { A_expr_typecastContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { B_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { C_expr_existsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { C_expr_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { C_expr_caseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PlsqlvariablenameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_applicationContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_expr_windowlessContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_expr_common_subexprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_root_versionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_xml_root_standaloneContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_attributesContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_attribute_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_attribute_elContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Document_or_contentContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_whitespace_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xmlexists_argumentContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Xml_passing_mechContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Within_group_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Filter_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Window_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Window_definition_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Window_definitionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Over_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Window_specificationContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_existing_window_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_partition_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_frame_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Frame_extentContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Frame_boundContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_window_exclusion_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RowContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Explicit_rowContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Implicit_rowContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Sub_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { All_opContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { MathopContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Qual_opContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Qual_all_opContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Subquery_OpContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Expr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_arg_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_arg_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Type_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Array_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Array_expr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Extract_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Extract_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Unicode_normal_formContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Overlay_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Position_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Substr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Trim_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { In_expr_selectContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { In_expr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Case_exprContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { When_clause_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { When_clauseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Case_defaultContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Case_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColumnrefContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Indirection_elContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_slice_boundContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { IndirectionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_indirectionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_target_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Target_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Target_labelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Target_starContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Qualified_name_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Qualified_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Name_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { NameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Attr_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { File_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Func_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AexprconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { XconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { BconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { FconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { IconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { AnysconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_uescapeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SignediconstContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RoleidContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { RolespecContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Role_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { ColidContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Table_aliasContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Type_function_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { NonreservedwordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { CollabelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { IdentifierContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { PlsqlidentifierContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Unreserved_keywordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Col_name_keywordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Type_func_name_keywordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Reserved_keywordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Builtin_function_nameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Pl_functionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Comp_optionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Comp_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { SharpContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Option_valueContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_semiContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Pl_blockContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_sectContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_startContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_stmtsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Label_declContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_stmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_statementContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_scrollableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_cursor_queryContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_cursor_argsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_cursor_arglistContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_cursor_argContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_is_forContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_aliasitemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_varnameContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_constContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_datatypeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_collateContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_notnullContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_defvalContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Decl_defkeyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Assign_operatorContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Proc_sectContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Proc_stmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_performContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_callContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_expr_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_assignContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_getdiagContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Getdiag_area_optContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Getdiag_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Getdiag_list_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Getdiag_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Getdiag_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Assign_varContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_ifContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_elsifsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_elseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_caseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_expr_until_whenContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Case_when_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Case_whenContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_case_elseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_loopContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_whileContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_forContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { For_controlContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_for_using_expressionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_cursor_parametersContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_reverseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_by_expressionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { For_variableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_foreach_aContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Foreach_sliceContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_exitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Exit_typeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_returnContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_return_resultContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_raiseContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_stmt_raise_levelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_raise_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_raise_usingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_raise_using_elemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_raise_using_elem_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_assertContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_stmt_assert_messageContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Loop_bodyContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_execsqlContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_dynexecuteContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_execute_usingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_execute_using_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_execute_intoContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_openContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_open_bound_list_itemContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_open_bound_listContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_open_usingContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_scroll_optionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_scroll_option_noContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_fetchContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Into_targetContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_cursor_fromContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_fetch_directionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_moveContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_closeContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_nullContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_commitContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_rollbackContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Plsql_opt_transaction_chainContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Stmt_setContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Cursor_variableContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Exception_sectContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Proc_exceptionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Proc_exceptionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Proc_conditionsContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Proc_conditionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_block_labelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_loop_labelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_labelContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_exitcondContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Any_identifierContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Plsql_unreserved_keywordContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Sql_expressionContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Expr_until_thenContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Expr_until_semiContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Expr_until_rightbracketContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Expr_until_loopContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Make_execsql_stmtContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  import { Opt_returning_clause_intoContext } from "websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index";
  /**
   * This interface defines a complete generic visitor for a parse tree produced
   * by `PostgreSqlParser`.
   *
   * @param <Result> The return type of the visit operation. Use `void` for
   * operations with no return type.
   */
  export class PostgreSqlParserVisitor<Result> extends AbstractParseTreeVisitor<Result> {
      /**
       * Visit a parse tree produced by `PostgreSqlParser.root`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoot?: (ctx: RootContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.plsqlroot`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPlsqlroot?: (ctx: PlsqlrootContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmtblock`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmtblock?: (ctx: StmtblockContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmtmulti`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmtmulti?: (ctx: StmtmultiContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt?: (ctx: StmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.plsqlconsolecommand`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPlsqlconsolecommand?: (ctx: PlsqlconsolecommandContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.callstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCallstmt?: (ctx: CallstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createrolestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreaterolestmt?: (ctx: CreaterolestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_with`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_with?: (ctx: Opt_withContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optrolelist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptrolelist?: (ctx: OptrolelistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alteroptrolelist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlteroptrolelist?: (ctx: AlteroptrolelistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alteroptroleelem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlteroptroleelem?: (ctx: AlteroptroleelemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createoptroleelem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateoptroleelem?: (ctx: CreateoptroleelemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createuserstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateuserstmt?: (ctx: CreateuserstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterrolestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterrolestmt?: (ctx: AlterrolestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_in_database`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_in_database?: (ctx: Opt_in_databaseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterrolesetstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterrolesetstmt?: (ctx: AlterrolesetstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.droprolestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDroprolestmt?: (ctx: DroprolestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.creategroupstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreategroupstmt?: (ctx: CreategroupstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altergroupstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltergroupstmt?: (ctx: AltergroupstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.add_drop`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAdd_drop?: (ctx: Add_dropContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createschemastmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateschemastmt?: (ctx: CreateschemastmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optschemaname`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptschemaname?: (ctx: OptschemanameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optschemaeltlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptschemaeltlist?: (ctx: OptschemaeltlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.schema_stmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSchema_stmt?: (ctx: Schema_stmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.variablesetstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVariablesetstmt?: (ctx: VariablesetstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.set_rest`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSet_rest?: (ctx: Set_restContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generic_set`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneric_set?: (ctx: Generic_setContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.set_rest_more`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSet_rest_more?: (ctx: Set_rest_moreContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.var_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVar_name?: (ctx: Var_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.var_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVar_list?: (ctx: Var_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.var_value`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVar_value?: (ctx: Var_valueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.iso_level`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIso_level?: (ctx: Iso_levelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_boolean_or_string`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_boolean_or_string?: (ctx: Opt_boolean_or_stringContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.zone_value`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitZone_value?: (ctx: Zone_valueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_encoding`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_encoding?: (ctx: Opt_encodingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.nonreservedword_or_sconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNonreservedword_or_sconst?: (ctx: Nonreservedword_or_sconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.variableresetstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVariableresetstmt?: (ctx: VariableresetstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reset_rest`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReset_rest?: (ctx: Reset_restContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generic_reset`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneric_reset?: (ctx: Generic_resetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.setresetclause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSetresetclause?: (ctx: SetresetclauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.functionsetresetclause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunctionsetresetclause?: (ctx: FunctionsetresetclauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.variableshowstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVariableshowstmt?: (ctx: VariableshowstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraintssetstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraintssetstmt?: (ctx: ConstraintssetstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraints_set_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraints_set_list?: (ctx: Constraints_set_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraints_set_mode`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraints_set_mode?: (ctx: Constraints_set_modeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.checkpointstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCheckpointstmt?: (ctx: CheckpointstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.discardstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDiscardstmt?: (ctx: DiscardstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altertablestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltertablestmt?: (ctx: AltertablestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_table_cmds`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_table_cmds?: (ctx: Alter_table_cmdsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.partition_cmd`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartition_cmd?: (ctx: Partition_cmdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.index_partition_cmd`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndex_partition_cmd?: (ctx: Index_partition_cmdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_table_cmd`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_table_cmd?: (ctx: Alter_table_cmdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_column_default`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_column_default?: (ctx: Alter_column_defaultContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_drop_behavior`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_drop_behavior?: (ctx: Opt_drop_behaviorContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_collate_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_collate_clause?: (ctx: Opt_collate_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_using`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_using?: (ctx: Alter_usingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.replica_identity`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReplica_identity?: (ctx: Replica_identityContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reloptions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReloptions?: (ctx: ReloptionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_reloptions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_reloptions?: (ctx: Opt_reloptionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reloption_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReloption_list?: (ctx: Reloption_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reloption_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReloption_elem?: (ctx: Reloption_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_identity_column_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_identity_column_option_list?: (ctx: Alter_identity_column_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_identity_column_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_identity_column_option?: (ctx: Alter_identity_column_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.partitionboundspec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionboundspec?: (ctx: PartitionboundspecContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.hash_partbound_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHash_partbound_elem?: (ctx: Hash_partbound_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.hash_partbound`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHash_partbound?: (ctx: Hash_partboundContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altercompositetypestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltercompositetypestmt?: (ctx: AltercompositetypestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_type_cmds`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_type_cmds?: (ctx: Alter_type_cmdsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_type_cmd`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_type_cmd?: (ctx: Alter_type_cmdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.closeportalstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCloseportalstmt?: (ctx: CloseportalstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopystmt?: (ctx: CopystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_from`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_from?: (ctx: Copy_fromContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_program`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_program?: (ctx: Opt_programContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_file_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_file_name?: (ctx: Copy_file_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_options?: (ctx: Copy_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_opt_list?: (ctx: Copy_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_opt_item?: (ctx: Copy_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_binary`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_binary?: (ctx: Opt_binaryContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_delimiter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_delimiter?: (ctx: Copy_delimiterContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_using`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_using?: (ctx: Opt_usingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_generic_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_generic_opt_list?: (ctx: Copy_generic_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_generic_opt_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_generic_opt_elem?: (ctx: Copy_generic_opt_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_generic_opt_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_generic_opt_arg?: (ctx: Copy_generic_opt_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_generic_opt_arg_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_generic_opt_arg_list?: (ctx: Copy_generic_opt_arg_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.copy_generic_opt_arg_list_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCopy_generic_opt_arg_list_item?: (ctx: Copy_generic_opt_arg_list_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatestmt?: (ctx: CreatestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttemp`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttemp?: (ctx: OpttempContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttableelementlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttableelementlist?: (ctx: OpttableelementlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttypedtableelementlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttypedtableelementlist?: (ctx: OpttypedtableelementlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tableelementlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableelementlist?: (ctx: TableelementlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.typedtableelementlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTypedtableelementlist?: (ctx: TypedtableelementlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tableelement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableelement?: (ctx: TableelementContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.typedtableelement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTypedtableelement?: (ctx: TypedtableelementContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.columnDef`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnDef?: (ctx: ColumnDefContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.columnOptions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnOptions?: (ctx: ColumnOptionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.colquallist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColquallist?: (ctx: ColquallistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.colconstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColconstraint?: (ctx: ColconstraintContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.colconstraintelem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColconstraintelem?: (ctx: ColconstraintelemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generated_when`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGenerated_when?: (ctx: Generated_whenContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraintattr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraintattr?: (ctx: ConstraintattrContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tablelikeclause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablelikeclause?: (ctx: TablelikeclauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tablelikeoptionlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablelikeoptionlist?: (ctx: TablelikeoptionlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tablelikeoption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablelikeoption?: (ctx: TablelikeoptionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tableconstraint`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTableconstraint?: (ctx: TableconstraintContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraintelem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraintelem?: (ctx: ConstraintelemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_no_inherit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_no_inherit?: (ctx: Opt_no_inheritContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_column_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_column_list?: (ctx: Opt_column_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.columnlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnlist?: (ctx: ColumnlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.columnElem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnElem?: (ctx: ColumnElemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_c_include`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_c_include?: (ctx: Opt_c_includeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.key_match`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKey_match?: (ctx: Key_matchContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.exclusionconstraintlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExclusionconstraintlist?: (ctx: ExclusionconstraintlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.exclusionconstraintelem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExclusionconstraintelem?: (ctx: ExclusionconstraintelemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.exclusionwhereclause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExclusionwhereclause?: (ctx: ExclusionwhereclauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.key_actions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKey_actions?: (ctx: Key_actionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.key_update`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKey_update?: (ctx: Key_updateContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.key_delete`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKey_delete?: (ctx: Key_deleteContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.key_action`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitKey_action?: (ctx: Key_actionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optinherit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptinherit?: (ctx: OptinheritContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optpartitionspec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptpartitionspec?: (ctx: OptpartitionspecContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.partitionspec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPartitionspec?: (ctx: PartitionspecContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.part_params`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPart_params?: (ctx: Part_paramsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.part_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPart_elem?: (ctx: Part_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.table_access_method_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTable_access_method_clause?: (ctx: Table_access_method_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optwith`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptwith?: (ctx: OptwithContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.oncommitoption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOncommitoption?: (ctx: OncommitoptionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttablespace`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttablespace?: (ctx: OpttablespaceContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optconstablespace`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptconstablespace?: (ctx: OptconstablespaceContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.existingindex`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExistingindex?: (ctx: ExistingindexContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createstatsstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatestatsstmt?: (ctx: CreatestatsstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterstatsstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterstatsstmt?: (ctx: AlterstatsstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createasstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateasstmt?: (ctx: CreateasstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.create_as_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreate_as_target?: (ctx: Create_as_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_with_data`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_with_data?: (ctx: Opt_with_dataContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.creatematviewstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatematviewstmt?: (ctx: CreatematviewstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.create_mv_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreate_mv_target?: (ctx: Create_mv_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optnolog`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptnolog?: (ctx: OptnologContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.refreshmatviewstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRefreshmatviewstmt?: (ctx: RefreshmatviewstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createseqstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateseqstmt?: (ctx: CreateseqstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterseqstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterseqstmt?: (ctx: AlterseqstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optseqoptlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptseqoptlist?: (ctx: OptseqoptlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optparenthesizedseqoptlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptparenthesizedseqoptlist?: (ctx: OptparenthesizedseqoptlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.seqoptlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSeqoptlist?: (ctx: SeqoptlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.seqoptelem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSeqoptelem?: (ctx: SeqoptelemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_by`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_by?: (ctx: Opt_byContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.numericonly`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNumericonly?: (ctx: NumericonlyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.numericonly_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNumericonly_list?: (ctx: Numericonly_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createplangstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateplangstmt?: (ctx: CreateplangstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_trusted`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_trusted?: (ctx: Opt_trustedContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.handler_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHandler_name?: (ctx: Handler_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_inline_handler`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_inline_handler?: (ctx: Opt_inline_handlerContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.validator_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitValidator_clause?: (ctx: Validator_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_validator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_validator?: (ctx: Opt_validatorContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_procedural`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_procedural?: (ctx: Opt_proceduralContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createtablespacestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatetablespacestmt?: (ctx: CreatetablespacestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttablespaceowner`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttablespaceowner?: (ctx: OpttablespaceownerContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.droptablespacestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDroptablespacestmt?: (ctx: DroptablespacestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createextensionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateextensionstmt?: (ctx: CreateextensionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.create_extension_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreate_extension_opt_list?: (ctx: Create_extension_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.create_extension_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreate_extension_opt_item?: (ctx: Create_extension_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterextensionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterextensionstmt?: (ctx: AlterextensionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_extension_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_extension_opt_list?: (ctx: Alter_extension_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_extension_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_extension_opt_item?: (ctx: Alter_extension_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterextensioncontentsstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterextensioncontentsstmt?: (ctx: AlterextensioncontentsstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createfdwstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatefdwstmt?: (ctx: CreatefdwstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.fdw_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFdw_option?: (ctx: Fdw_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.fdw_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFdw_options?: (ctx: Fdw_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_fdw_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_fdw_options?: (ctx: Opt_fdw_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterfdwstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterfdwstmt?: (ctx: AlterfdwstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.create_generic_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreate_generic_options?: (ctx: Create_generic_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generic_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneric_option_list?: (ctx: Generic_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_generic_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_generic_options?: (ctx: Alter_generic_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_generic_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_generic_option_list?: (ctx: Alter_generic_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alter_generic_option_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlter_generic_option_elem?: (ctx: Alter_generic_option_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generic_option_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneric_option_elem?: (ctx: Generic_option_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generic_option_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneric_option_name?: (ctx: Generic_option_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generic_option_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGeneric_option_arg?: (ctx: Generic_option_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createforeignserverstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateforeignserverstmt?: (ctx: CreateforeignserverstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_type?: (ctx: Opt_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.foreign_server_version`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitForeign_server_version?: (ctx: Foreign_server_versionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_foreign_server_version`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_foreign_server_version?: (ctx: Opt_foreign_server_versionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterforeignserverstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterforeignserverstmt?: (ctx: AlterforeignserverstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createforeigntablestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateforeigntablestmt?: (ctx: CreateforeigntablestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.importforeignschemastmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitImportforeignschemastmt?: (ctx: ImportforeignschemastmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.import_qualification_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitImport_qualification_type?: (ctx: Import_qualification_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.import_qualification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitImport_qualification?: (ctx: Import_qualificationContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createusermappingstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateusermappingstmt?: (ctx: CreateusermappingstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.auth_ident`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAuth_ident?: (ctx: Auth_identContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropusermappingstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropusermappingstmt?: (ctx: DropusermappingstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterusermappingstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterusermappingstmt?: (ctx: AlterusermappingstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createpolicystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatepolicystmt?: (ctx: CreatepolicystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterpolicystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterpolicystmt?: (ctx: AlterpolicystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsecurityoptionalexpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsecurityoptionalexpr?: (ctx: RowsecurityoptionalexprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsecurityoptionalwithcheck`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsecurityoptionalwithcheck?: (ctx: RowsecurityoptionalwithcheckContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsecuritydefaulttorole`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsecuritydefaulttorole?: (ctx: RowsecuritydefaulttoroleContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsecurityoptionaltorole`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsecurityoptionaltorole?: (ctx: RowsecurityoptionaltoroleContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsecuritydefaultpermissive`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsecuritydefaultpermissive?: (ctx: RowsecuritydefaultpermissiveContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsecuritydefaultforcmd`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsecuritydefaultforcmd?: (ctx: RowsecuritydefaultforcmdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.row_security_cmd`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRow_security_cmd?: (ctx: Row_security_cmdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createamstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateamstmt?: (ctx: CreateamstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.am_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAm_type?: (ctx: Am_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createtrigstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatetrigstmt?: (ctx: CreatetrigstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggeractiontime`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggeractiontime?: (ctx: TriggeractiontimeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerevents`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerevents?: (ctx: TriggereventsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggeroneevent`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggeroneevent?: (ctx: TriggeroneeventContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerreferencing`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerreferencing?: (ctx: TriggerreferencingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggertransitions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggertransitions?: (ctx: TriggertransitionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggertransition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggertransition?: (ctx: TriggertransitionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transitionoldornew`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransitionoldornew?: (ctx: TransitionoldornewContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transitionrowortable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransitionrowortable?: (ctx: TransitionrowortableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transitionrelname`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransitionrelname?: (ctx: TransitionrelnameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerforspec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerforspec?: (ctx: TriggerforspecContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerforopteach`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerforopteach?: (ctx: TriggerforopteachContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerfortype`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerfortype?: (ctx: TriggerfortypeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerwhen`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerwhen?: (ctx: TriggerwhenContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.function_or_procedure`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunction_or_procedure?: (ctx: Function_or_procedureContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerfuncargs`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerfuncargs?: (ctx: TriggerfuncargsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.triggerfuncarg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTriggerfuncarg?: (ctx: TriggerfuncargContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.optconstrfromtable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOptconstrfromtable?: (ctx: OptconstrfromtableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraintattributespec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraintattributespec?: (ctx: ConstraintattributespecContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constraintattributeElem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstraintattributeElem?: (ctx: ConstraintattributeElemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createeventtrigstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateeventtrigstmt?: (ctx: CreateeventtrigstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.event_trigger_when_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEvent_trigger_when_list?: (ctx: Event_trigger_when_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.event_trigger_when_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEvent_trigger_when_item?: (ctx: Event_trigger_when_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.event_trigger_value_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEvent_trigger_value_list?: (ctx: Event_trigger_value_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altereventtrigstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltereventtrigstmt?: (ctx: AltereventtrigstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.enable_trigger`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEnable_trigger?: (ctx: Enable_triggerContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createassertionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateassertionstmt?: (ctx: CreateassertionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.definestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefinestmt?: (ctx: DefinestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.definition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefinition?: (ctx: DefinitionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.def_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDef_list?: (ctx: Def_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.def_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDef_elem?: (ctx: Def_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.def_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDef_arg?: (ctx: Def_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.old_aggr_definition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOld_aggr_definition?: (ctx: Old_aggr_definitionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.old_aggr_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOld_aggr_list?: (ctx: Old_aggr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.old_aggr_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOld_aggr_elem?: (ctx: Old_aggr_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_enum_val_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_enum_val_list?: (ctx: Opt_enum_val_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.enum_val_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEnum_val_list?: (ctx: Enum_val_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterenumstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterenumstmt?: (ctx: AlterenumstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_if_not_exists`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_if_not_exists?: (ctx: Opt_if_not_existsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createopclassstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateopclassstmt?: (ctx: CreateopclassstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opclass_item_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpclass_item_list?: (ctx: Opclass_item_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opclass_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpclass_item?: (ctx: Opclass_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_default`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_default?: (ctx: Opt_defaultContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_opfamily`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_opfamily?: (ctx: Opt_opfamilyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opclass_purpose`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpclass_purpose?: (ctx: Opclass_purposeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_recheck`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_recheck?: (ctx: Opt_recheckContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createopfamilystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateopfamilystmt?: (ctx: CreateopfamilystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alteropfamilystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlteropfamilystmt?: (ctx: AlteropfamilystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opclass_drop_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpclass_drop_list?: (ctx: Opclass_drop_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opclass_drop`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpclass_drop?: (ctx: Opclass_dropContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropopclassstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropopclassstmt?: (ctx: DropopclassstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropopfamilystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropopfamilystmt?: (ctx: DropopfamilystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropownedstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropownedstmt?: (ctx: DropownedstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reassignownedstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReassignownedstmt?: (ctx: ReassignownedstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropstmt?: (ctx: DropstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.object_type_any_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitObject_type_any_name?: (ctx: Object_type_any_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.object_type_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitObject_type_name?: (ctx: Object_type_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.drop_type_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDrop_type_name?: (ctx: Drop_type_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.object_type_name_on_any_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitObject_type_name_on_any_name?: (ctx: Object_type_name_on_any_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.any_name_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAny_name_list?: (ctx: Any_name_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.any_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAny_name?: (ctx: Any_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.attrs`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAttrs?: (ctx: AttrsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.type_name_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitType_name_list?: (ctx: Type_name_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.truncatestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTruncatestmt?: (ctx: TruncatestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_restart_seqs`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_restart_seqs?: (ctx: Opt_restart_seqsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.commentstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCommentstmt?: (ctx: CommentstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.comment_text`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitComment_text?: (ctx: Comment_textContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.seclabelstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSeclabelstmt?: (ctx: SeclabelstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_provider`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_provider?: (ctx: Opt_providerContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.security_label`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSecurity_label?: (ctx: Security_labelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.fetchstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFetchstmt?: (ctx: FetchstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.fetch_args`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFetch_args?: (ctx: Fetch_argsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.from_in`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrom_in?: (ctx: From_inContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_from_in`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_from_in?: (ctx: Opt_from_inContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.grantstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrantstmt?: (ctx: GrantstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.revokestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRevokestmt?: (ctx: RevokestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.privileges`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivileges?: (ctx: PrivilegesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.privilege_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivilege_list?: (ctx: Privilege_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.privilege`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivilege?: (ctx: PrivilegeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.privilege_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrivilege_target?: (ctx: Privilege_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.grantee_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrantee_list?: (ctx: Grantee_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.grantee`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrantee?: (ctx: GranteeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_grant_grant_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_grant_grant_option?: (ctx: Opt_grant_grant_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.grantrolestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrantrolestmt?: (ctx: GrantrolestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.revokerolestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRevokerolestmt?: (ctx: RevokerolestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_grant_admin_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_grant_admin_option?: (ctx: Opt_grant_admin_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_granted_by`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_granted_by?: (ctx: Opt_granted_byContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterdefaultprivilegesstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterdefaultprivilegesstmt?: (ctx: AlterdefaultprivilegesstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.defacloptionlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefacloptionlist?: (ctx: DefacloptionlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.defacloption`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefacloption?: (ctx: DefacloptionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.defaclaction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefaclaction?: (ctx: DefaclactionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.defacl_privilege_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDefacl_privilege_target?: (ctx: Defacl_privilege_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.indexstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndexstmt?: (ctx: IndexstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_unique`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_unique?: (ctx: Opt_uniqueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_concurrently`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_concurrently?: (ctx: Opt_concurrentlyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_index_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_index_name?: (ctx: Opt_index_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.access_method_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAccess_method_clause?: (ctx: Access_method_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.index_params`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndex_params?: (ctx: Index_paramsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.index_elem_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndex_elem_options?: (ctx: Index_elem_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.index_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndex_elem?: (ctx: Index_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_include`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_include?: (ctx: Opt_includeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.index_including_params`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndex_including_params?: (ctx: Index_including_paramsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_collate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_collate?: (ctx: Opt_collateContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_class`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_class?: (ctx: Opt_classContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_asc_desc`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_asc_desc?: (ctx: Opt_asc_descContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_nulls_order`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_nulls_order?: (ctx: Opt_nulls_orderContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createfunctionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatefunctionstmt?: (ctx: CreatefunctionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_or_replace`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_or_replace?: (ctx: Opt_or_replaceContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_args`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_args?: (ctx: Func_argsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_args_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_args_list?: (ctx: Func_args_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.function_with_argtypes_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunction_with_argtypes_list?: (ctx: Function_with_argtypes_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.function_with_argtypes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunction_with_argtypes?: (ctx: Function_with_argtypesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_args_with_defaults`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_args_with_defaults?: (ctx: Func_args_with_defaultsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_args_with_defaults_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_args_with_defaults_list?: (ctx: Func_args_with_defaults_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_arg?: (ctx: Func_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.arg_class`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitArg_class?: (ctx: Arg_classContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.param_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitParam_name?: (ctx: Param_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_return`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_return?: (ctx: Func_returnContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_type?: (ctx: Func_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_arg_with_default`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_arg_with_default?: (ctx: Func_arg_with_defaultContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.aggr_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggr_arg?: (ctx: Aggr_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.aggr_args`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggr_args?: (ctx: Aggr_argsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.aggr_args_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggr_args_list?: (ctx: Aggr_args_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.aggregate_with_argtypes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggregate_with_argtypes?: (ctx: Aggregate_with_argtypesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.aggregate_with_argtypes_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAggregate_with_argtypes_list?: (ctx: Aggregate_with_argtypes_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createfunc_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatefunc_opt_list?: (ctx: Createfunc_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.common_func_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCommon_func_opt_item?: (ctx: Common_func_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createfunc_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatefunc_opt_item?: (ctx: Createfunc_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_as`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_as?: (ctx: Func_asContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transform_type_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransform_type_list?: (ctx: Transform_type_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_definition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_definition?: (ctx: Opt_definitionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.table_func_column`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTable_func_column?: (ctx: Table_func_columnContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.table_func_column_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTable_func_column_list?: (ctx: Table_func_column_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterfunctionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterfunctionstmt?: (ctx: AlterfunctionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterfunc_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterfunc_opt_list?: (ctx: Alterfunc_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_restrict`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_restrict?: (ctx: Opt_restrictContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.removefuncstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRemovefuncstmt?: (ctx: RemovefuncstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.removeaggrstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRemoveaggrstmt?: (ctx: RemoveaggrstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.removeoperstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRemoveoperstmt?: (ctx: RemoveoperstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.oper_argtypes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOper_argtypes?: (ctx: Oper_argtypesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.any_operator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAny_operator?: (ctx: Any_operatorContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.operator_with_argtypes_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOperator_with_argtypes_list?: (ctx: Operator_with_argtypes_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.operator_with_argtypes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOperator_with_argtypes?: (ctx: Operator_with_argtypesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dostmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDostmt?: (ctx: DostmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dostmt_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDostmt_opt_list?: (ctx: Dostmt_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dostmt_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDostmt_opt_item?: (ctx: Dostmt_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createcaststmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatecaststmt?: (ctx: CreatecaststmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cast_context`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCast_context?: (ctx: Cast_contextContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropcaststmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropcaststmt?: (ctx: DropcaststmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_if_exists`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_if_exists?: (ctx: Opt_if_existsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createtransformstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatetransformstmt?: (ctx: CreatetransformstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transform_element_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransform_element_list?: (ctx: Transform_element_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.droptransformstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDroptransformstmt?: (ctx: DroptransformstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reindexstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReindexstmt?: (ctx: ReindexstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reindex_target_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReindex_target_type?: (ctx: Reindex_target_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reindex_target_multitable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReindex_target_multitable?: (ctx: Reindex_target_multitableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reindex_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReindex_option_list?: (ctx: Reindex_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reindex_option_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReindex_option_elem?: (ctx: Reindex_option_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altertblspcstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltertblspcstmt?: (ctx: AltertblspcstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.renamestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRenamestmt?: (ctx: RenamestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_column`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_column?: (ctx: Opt_columnContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_set_data`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_set_data?: (ctx: Opt_set_dataContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterobjectdependsstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterobjectdependsstmt?: (ctx: AlterobjectdependsstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_no`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_no?: (ctx: Opt_noContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterobjectschemastmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterobjectschemastmt?: (ctx: AlterobjectschemastmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alteroperatorstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlteroperatorstmt?: (ctx: AlteroperatorstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.operator_def_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOperator_def_list?: (ctx: Operator_def_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.operator_def_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOperator_def_elem?: (ctx: Operator_def_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.operator_def_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOperator_def_arg?: (ctx: Operator_def_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altertypestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltertypestmt?: (ctx: AltertypestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterownerstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterownerstmt?: (ctx: AlterownerstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createpublicationstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatepublicationstmt?: (ctx: CreatepublicationstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_publication_for_tables`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_publication_for_tables?: (ctx: Opt_publication_for_tablesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.publication_for_tables`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPublication_for_tables?: (ctx: Publication_for_tablesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterpublicationstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterpublicationstmt?: (ctx: AlterpublicationstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createsubscriptionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatesubscriptionstmt?: (ctx: CreatesubscriptionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.publication_name_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPublication_name_list?: (ctx: Publication_name_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.publication_name_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPublication_name_item?: (ctx: Publication_name_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altersubscriptionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltersubscriptionstmt?: (ctx: AltersubscriptionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropsubscriptionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropsubscriptionstmt?: (ctx: DropsubscriptionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rulestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRulestmt?: (ctx: RulestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.ruleactionlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRuleactionlist?: (ctx: RuleactionlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.ruleactionmulti`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRuleactionmulti?: (ctx: RuleactionmultiContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.ruleactionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRuleactionstmt?: (ctx: RuleactionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.ruleactionstmtOrEmpty`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRuleactionstmtOrEmpty?: (ctx: RuleactionstmtOrEmptyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.event`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEvent?: (ctx: EventContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_instead`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_instead?: (ctx: Opt_insteadContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.notifystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNotifystmt?: (ctx: NotifystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.notify_payload`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNotify_payload?: (ctx: Notify_payloadContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.listenstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitListenstmt?: (ctx: ListenstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.unlistenstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnlistenstmt?: (ctx: UnlistenstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transactionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransactionstmt?: (ctx: TransactionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_transaction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_transaction?: (ctx: Opt_transactionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transaction_mode_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransaction_mode_item?: (ctx: Transaction_mode_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transaction_mode_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransaction_mode_list?: (ctx: Transaction_mode_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.transaction_mode_list_or_empty`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTransaction_mode_list_or_empty?: (ctx: Transaction_mode_list_or_emptyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_transaction_chain`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_transaction_chain?: (ctx: Opt_transaction_chainContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.viewstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitViewstmt?: (ctx: ViewstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_check_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_check_option?: (ctx: Opt_check_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.loadstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoadstmt?: (ctx: LoadstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createdbstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatedbstmt?: (ctx: CreatedbstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createdb_opt_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatedb_opt_list?: (ctx: Createdb_opt_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createdb_opt_items`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatedb_opt_items?: (ctx: Createdb_opt_itemsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createdb_opt_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatedb_opt_item?: (ctx: Createdb_opt_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createdb_opt_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatedb_opt_name?: (ctx: Createdb_opt_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_equal`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_equal?: (ctx: Opt_equalContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterdatabasestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterdatabasestmt?: (ctx: AlterdatabasestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterdatabasesetstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterdatabasesetstmt?: (ctx: AlterdatabasesetstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.dropdbstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDropdbstmt?: (ctx: DropdbstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.drop_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDrop_option_list?: (ctx: Drop_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.drop_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDrop_option?: (ctx: Drop_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altercollationstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltercollationstmt?: (ctx: AltercollationstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altersystemstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltersystemstmt?: (ctx: AltersystemstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createdomainstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreatedomainstmt?: (ctx: CreatedomainstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alterdomainstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlterdomainstmt?: (ctx: AlterdomainstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_as`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_as?: (ctx: Opt_asContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altertsdictionarystmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltertsdictionarystmt?: (ctx: AltertsdictionarystmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.altertsconfigurationstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAltertsconfigurationstmt?: (ctx: AltertsconfigurationstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.any_with`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAny_with?: (ctx: Any_withContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.createconversionstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCreateconversionstmt?: (ctx: CreateconversionstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.clusterstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitClusterstmt?: (ctx: ClusterstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cluster_index_specification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCluster_index_specification?: (ctx: Cluster_index_specificationContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vacuumstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVacuumstmt?: (ctx: VacuumstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.analyzestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAnalyzestmt?: (ctx: AnalyzestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vac_analyze_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVac_analyze_option_list?: (ctx: Vac_analyze_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.analyze_keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAnalyze_keyword?: (ctx: Analyze_keywordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vac_analyze_option_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVac_analyze_option_elem?: (ctx: Vac_analyze_option_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vac_analyze_option_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVac_analyze_option_name?: (ctx: Vac_analyze_option_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vac_analyze_option_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVac_analyze_option_arg?: (ctx: Vac_analyze_option_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_analyze`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_analyze?: (ctx: Opt_analyzeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_verbose`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_verbose?: (ctx: Opt_verboseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_full`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_full?: (ctx: Opt_fullContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_freeze`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_freeze?: (ctx: Opt_freezeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_name_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_name_list?: (ctx: Opt_name_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vacuum_relation`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVacuum_relation?: (ctx: Vacuum_relationContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.vacuum_relation_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitVacuum_relation_list?: (ctx: Vacuum_relation_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_vacuum_relation_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_vacuum_relation_list?: (ctx: Opt_vacuum_relation_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explainstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplainstmt?: (ctx: ExplainstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explainablestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplainablestmt?: (ctx: ExplainablestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explain_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplain_option_list?: (ctx: Explain_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explain_option_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplain_option_elem?: (ctx: Explain_option_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explain_option_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplain_option_name?: (ctx: Explain_option_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explain_option_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplain_option_arg?: (ctx: Explain_option_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.preparestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPreparestmt?: (ctx: PreparestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.prep_type_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPrep_type_clause?: (ctx: Prep_type_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.preparablestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPreparablestmt?: (ctx: PreparablestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.executestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExecutestmt?: (ctx: ExecutestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.execute_param_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExecute_param_clause?: (ctx: Execute_param_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.deallocatestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeallocatestmt?: (ctx: DeallocatestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.insertstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsertstmt?: (ctx: InsertstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.insert_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsert_target?: (ctx: Insert_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.insert_rest`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsert_rest?: (ctx: Insert_restContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.override_kind`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOverride_kind?: (ctx: Override_kindContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.insert_column_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsert_column_list?: (ctx: Insert_column_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.insert_column_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInsert_column_item?: (ctx: Insert_column_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_on_conflict`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_on_conflict?: (ctx: Opt_on_conflictContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_conf_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_conf_expr?: (ctx: Opt_conf_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.returning_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReturning_clause?: (ctx: Returning_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.mergestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMergestmt?: (ctx: MergestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.merge_insert_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMerge_insert_clause?: (ctx: Merge_insert_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.merge_update_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMerge_update_clause?: (ctx: Merge_update_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.merge_delete_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMerge_delete_clause?: (ctx: Merge_delete_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.deletestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeletestmt?: (ctx: DeletestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.using_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUsing_clause?: (ctx: Using_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.lockstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLockstmt?: (ctx: LockstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_lock`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_lock?: (ctx: Opt_lockContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.lock_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLock_type?: (ctx: Lock_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_nowait`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_nowait?: (ctx: Opt_nowaitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_nowait_or_skip`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_nowait_or_skip?: (ctx: Opt_nowait_or_skipContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.updatestmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUpdatestmt?: (ctx: UpdatestmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.set_clause_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSet_clause_list?: (ctx: Set_clause_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.set_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSet_clause?: (ctx: Set_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.set_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSet_target?: (ctx: Set_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.set_target_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSet_target_list?: (ctx: Set_target_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.declarecursorstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDeclarecursorstmt?: (ctx: DeclarecursorstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cursor_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCursor_name?: (ctx: Cursor_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cursor_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCursor_options?: (ctx: Cursor_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_hold`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_hold?: (ctx: Opt_holdContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.selectstmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelectstmt?: (ctx: SelectstmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_with_parens`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_with_parens?: (ctx: Select_with_parensContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_no_parens`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_no_parens?: (ctx: Select_no_parensContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_clause?: (ctx: Select_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.simple_select_intersect`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimple_select_intersect?: (ctx: Simple_select_intersectContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.simple_select_pramary`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimple_select_pramary?: (ctx: Simple_select_pramaryContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.with_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWith_clause?: (ctx: With_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cte_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCte_list?: (ctx: Cte_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.common_table_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCommon_table_expr?: (ctx: Common_table_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_materialized`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_materialized?: (ctx: Opt_materializedContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_with_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_with_clause?: (ctx: Opt_with_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.into_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInto_clause?: (ctx: Into_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_strict`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_strict?: (ctx: Opt_strictContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttempTableName`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttempTableName?: (ctx: OpttempTableNameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_table`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_table?: (ctx: Opt_tableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.all_or_distinct`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAll_or_distinct?: (ctx: All_or_distinctContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.distinct_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDistinct_clause?: (ctx: Distinct_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_all_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_all_clause?: (ctx: Opt_all_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_sort_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_sort_clause?: (ctx: Opt_sort_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sort_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSort_clause?: (ctx: Sort_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sortby_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSortby_list?: (ctx: Sortby_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sortby`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSortby?: (ctx: SortbyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_limit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_limit?: (ctx: Select_limitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_select_limit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_select_limit?: (ctx: Opt_select_limitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.limit_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLimit_clause?: (ctx: Limit_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.offset_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOffset_clause?: (ctx: Offset_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_limit_value`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_limit_value?: (ctx: Select_limit_valueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_offset_value`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_offset_value?: (ctx: Select_offset_valueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.select_fetch_first_value`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSelect_fetch_first_value?: (ctx: Select_fetch_first_valueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.i_or_f_const`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitI_or_f_const?: (ctx: I_or_f_constContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.row_or_rows`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRow_or_rows?: (ctx: Row_or_rowsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.first_or_next`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFirst_or_next?: (ctx: First_or_nextContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.group_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGroup_clause?: (ctx: Group_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.group_by_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGroup_by_list?: (ctx: Group_by_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.group_by_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGroup_by_item?: (ctx: Group_by_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.empty_grouping_set`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitEmpty_grouping_set?: (ctx: Empty_grouping_setContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rollup_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRollup_clause?: (ctx: Rollup_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cube_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCube_clause?: (ctx: Cube_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.grouping_sets_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGrouping_sets_clause?: (ctx: Grouping_sets_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.having_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitHaving_clause?: (ctx: Having_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.for_locking_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFor_locking_clause?: (ctx: For_locking_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_for_locking_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_for_locking_clause?: (ctx: Opt_for_locking_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.for_locking_items`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFor_locking_items?: (ctx: For_locking_itemsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.for_locking_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFor_locking_item?: (ctx: For_locking_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.for_locking_strength`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFor_locking_strength?: (ctx: For_locking_strengthContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.locked_rels_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLocked_rels_list?: (ctx: Locked_rels_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.values_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitValues_clause?: (ctx: Values_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.from_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrom_clause?: (ctx: From_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.from_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrom_list?: (ctx: From_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.non_ansi_join`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNon_ansi_join?: (ctx: Non_ansi_joinContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.table_ref`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTable_ref?: (ctx: Table_refContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.alias_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAlias_clause?: (ctx: Alias_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_alias_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_alias_clause?: (ctx: Opt_alias_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.table_alias_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTable_alias_clause?: (ctx: Table_alias_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_alias_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_alias_clause?: (ctx: Func_alias_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.join_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoin_type?: (ctx: Join_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.join_qual`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitJoin_qual?: (ctx: Join_qualContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.relation_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRelation_expr?: (ctx: Relation_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.relation_expr_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRelation_expr_list?: (ctx: Relation_expr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.relation_expr_opt_alias`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRelation_expr_opt_alias?: (ctx: Relation_expr_opt_aliasContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tablesample_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablesample_clause?: (ctx: Tablesample_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_repeatable_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_repeatable_clause?: (ctx: Opt_repeatable_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_table`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_table?: (ctx: Func_tableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsfrom_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsfrom_item?: (ctx: Rowsfrom_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rowsfrom_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRowsfrom_list?: (ctx: Rowsfrom_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_col_def_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_col_def_list?: (ctx: Opt_col_def_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_ordinality`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_ordinality?: (ctx: Opt_ordinalityContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.where_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWhere_clause?: (ctx: Where_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.where_or_current_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWhere_or_current_clause?: (ctx: Where_or_current_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opttablefuncelementlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpttablefuncelementlist?: (ctx: OpttablefuncelementlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tablefuncelementlist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablefuncelementlist?: (ctx: TablefuncelementlistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.tablefuncelement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTablefuncelement?: (ctx: TablefuncelementContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xmltable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXmltable?: (ctx: XmltableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xmltable_column_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXmltable_column_list?: (ctx: Xmltable_column_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xmltable_column_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXmltable_column_el?: (ctx: Xmltable_column_elContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xmltable_column_option_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXmltable_column_option_list?: (ctx: Xmltable_column_option_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xmltable_column_option_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXmltable_column_option_el?: (ctx: Xmltable_column_option_elContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_namespace_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_namespace_list?: (ctx: Xml_namespace_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_namespace_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_namespace_el?: (ctx: Xml_namespace_elContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.typename`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTypename?: (ctx: TypenameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_array_bounds`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_array_bounds?: (ctx: Opt_array_boundsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.simpletypename`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSimpletypename?: (ctx: SimpletypenameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.consttypename`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConsttypename?: (ctx: ConsttypenameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.generictype`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGenerictype?: (ctx: GenerictypeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_type_modifiers`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_type_modifiers?: (ctx: Opt_type_modifiersContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.numeric`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNumeric?: (ctx: NumericContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_float`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_float?: (ctx: Opt_floatContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.bit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBit?: (ctx: BitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constbit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstbit?: (ctx: ConstbitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.bitwithlength`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBitwithlength?: (ctx: BitwithlengthContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.bitwithoutlength`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBitwithoutlength?: (ctx: BitwithoutlengthContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.character`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCharacter?: (ctx: CharacterContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constcharacter`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstcharacter?: (ctx: ConstcharacterContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.character_c`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCharacter_c?: (ctx: Character_cContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_varying`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_varying?: (ctx: Opt_varyingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constdatetime`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstdatetime?: (ctx: ConstdatetimeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.constinterval`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitConstinterval?: (ctx: ConstintervalContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_timezone`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_timezone?: (ctx: Opt_timezoneContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_interval`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_interval?: (ctx: Opt_intervalContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.interval_second`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInterval_second?: (ctx: Interval_secondContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_escape`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_escape?: (ctx: Opt_escapeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr?: (ctx: A_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_qual`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_qual?: (ctx: A_expr_qualContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_lessless`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_lessless?: (ctx: A_expr_lesslessContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_or`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_or?: (ctx: A_expr_orContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_and`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_and?: (ctx: A_expr_andContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_between`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_between?: (ctx: A_expr_betweenContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_in`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_in?: (ctx: A_expr_inContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_unary_not`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_unary_not?: (ctx: A_expr_unary_notContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_isnull`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_isnull?: (ctx: A_expr_isnullContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_is_not`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_is_not?: (ctx: A_expr_is_notContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_compare`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_compare?: (ctx: A_expr_compareContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_like`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_like?: (ctx: A_expr_likeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_qual_op`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_qual_op?: (ctx: A_expr_qual_opContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_unary_qualop`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_unary_qualop?: (ctx: A_expr_unary_qualopContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_add`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_add?: (ctx: A_expr_addContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_mul`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_mul?: (ctx: A_expr_mulContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_caret`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_caret?: (ctx: A_expr_caretContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_unary_sign`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_unary_sign?: (ctx: A_expr_unary_signContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_at_time_zone`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_at_time_zone?: (ctx: A_expr_at_time_zoneContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_collate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_collate?: (ctx: A_expr_collateContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.a_expr_typecast`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitA_expr_typecast?: (ctx: A_expr_typecastContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.b_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitB_expr?: (ctx: B_exprContext) => Result;
      /**
       * Visit a parse tree produced by the `c_expr_exists`
       * labeled alternative in `PostgreSqlParser.c_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitC_expr_exists?: (ctx: C_expr_existsContext) => Result;
      /**
       * Visit a parse tree produced by the `c_expr_expr`
       * labeled alternative in `PostgreSqlParser.c_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitC_expr_expr?: (ctx: C_expr_exprContext) => Result;
      /**
       * Visit a parse tree produced by the `c_expr_case`
       * labeled alternative in `PostgreSqlParser.c_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitC_expr_case?: (ctx: C_expr_caseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.plsqlvariablename`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPlsqlvariablename?: (ctx: PlsqlvariablenameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_application`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_application?: (ctx: Func_applicationContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_expr?: (ctx: Func_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_expr_windowless`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_expr_windowless?: (ctx: Func_expr_windowlessContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_expr_common_subexpr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_expr_common_subexpr?: (ctx: Func_expr_common_subexprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_root_version`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_root_version?: (ctx: Xml_root_versionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_xml_root_standalone`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_xml_root_standalone?: (ctx: Opt_xml_root_standaloneContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_attributes`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_attributes?: (ctx: Xml_attributesContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_attribute_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_attribute_list?: (ctx: Xml_attribute_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_attribute_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_attribute_el?: (ctx: Xml_attribute_elContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.document_or_content`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDocument_or_content?: (ctx: Document_or_contentContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_whitespace_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_whitespace_option?: (ctx: Xml_whitespace_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xmlexists_argument`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXmlexists_argument?: (ctx: Xmlexists_argumentContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xml_passing_mech`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXml_passing_mech?: (ctx: Xml_passing_mechContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.within_group_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWithin_group_clause?: (ctx: Within_group_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.filter_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFilter_clause?: (ctx: Filter_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.window_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindow_clause?: (ctx: Window_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.window_definition_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindow_definition_list?: (ctx: Window_definition_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.window_definition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindow_definition?: (ctx: Window_definitionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.over_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOver_clause?: (ctx: Over_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.window_specification`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWindow_specification?: (ctx: Window_specificationContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_existing_window_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_existing_window_name?: (ctx: Opt_existing_window_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_partition_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_partition_clause?: (ctx: Opt_partition_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_frame_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_frame_clause?: (ctx: Opt_frame_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.frame_extent`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrame_extent?: (ctx: Frame_extentContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.frame_bound`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFrame_bound?: (ctx: Frame_boundContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_window_exclusion_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_window_exclusion_clause?: (ctx: Opt_window_exclusion_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.row`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRow?: (ctx: RowContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.explicit_row`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExplicit_row?: (ctx: Explicit_rowContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.implicit_row`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitImplicit_row?: (ctx: Implicit_rowContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sub_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSub_type?: (ctx: Sub_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.all_op`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAll_op?: (ctx: All_opContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.mathop`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMathop?: (ctx: MathopContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.qual_op`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQual_op?: (ctx: Qual_opContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.qual_all_op`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQual_all_op?: (ctx: Qual_all_opContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.subquery_Op`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubquery_Op?: (ctx: Subquery_OpContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.expr_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpr_list?: (ctx: Expr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_arg_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_arg_list?: (ctx: Func_arg_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_arg_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_arg_expr?: (ctx: Func_arg_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.type_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitType_list?: (ctx: Type_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.array_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitArray_expr?: (ctx: Array_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.array_expr_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitArray_expr_list?: (ctx: Array_expr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.extract_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExtract_list?: (ctx: Extract_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.extract_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExtract_arg?: (ctx: Extract_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.unicode_normal_form`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnicode_normal_form?: (ctx: Unicode_normal_formContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.overlay_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOverlay_list?: (ctx: Overlay_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.position_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPosition_list?: (ctx: Position_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.substr_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSubstr_list?: (ctx: Substr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.trim_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTrim_list?: (ctx: Trim_listContext) => Result;
      /**
       * Visit a parse tree produced by the `in_expr_select`
       * labeled alternative in `PostgreSqlParser.in_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIn_expr_select?: (ctx: In_expr_selectContext) => Result;
      /**
       * Visit a parse tree produced by the `in_expr_list`
       * labeled alternative in `PostgreSqlParser.in_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIn_expr_list?: (ctx: In_expr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.case_expr`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCase_expr?: (ctx: Case_exprContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.when_clause_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWhen_clause_list?: (ctx: When_clause_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.when_clause`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitWhen_clause?: (ctx: When_clauseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.case_default`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCase_default?: (ctx: Case_defaultContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.case_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCase_arg?: (ctx: Case_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.columnref`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColumnref?: (ctx: ColumnrefContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.indirection_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndirection_el?: (ctx: Indirection_elContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_slice_bound`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_slice_bound?: (ctx: Opt_slice_boundContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.indirection`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIndirection?: (ctx: IndirectionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_indirection`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_indirection?: (ctx: Opt_indirectionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_target_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_target_list?: (ctx: Opt_target_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.target_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTarget_list?: (ctx: Target_listContext) => Result;
      /**
       * Visit a parse tree produced by the `target_label`
       * labeled alternative in `PostgreSqlParser.target_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTarget_label?: (ctx: Target_labelContext) => Result;
      /**
       * Visit a parse tree produced by the `target_star`
       * labeled alternative in `PostgreSqlParser.target_el`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTarget_star?: (ctx: Target_starContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.qualified_name_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQualified_name_list?: (ctx: Qualified_name_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.qualified_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitQualified_name?: (ctx: Qualified_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.name_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitName_list?: (ctx: Name_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitName?: (ctx: NameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.attr_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAttr_name?: (ctx: Attr_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.file_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFile_name?: (ctx: File_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.func_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFunc_name?: (ctx: Func_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.aexprconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAexprconst?: (ctx: AexprconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.xconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitXconst?: (ctx: XconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.bconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBconst?: (ctx: BconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.fconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFconst?: (ctx: FconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.iconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIconst?: (ctx: IconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSconst?: (ctx: SconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.anysconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAnysconst?: (ctx: AnysconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_uescape`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_uescape?: (ctx: Opt_uescapeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.signediconst`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSignediconst?: (ctx: SignediconstContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.roleid`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRoleid?: (ctx: RoleidContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.rolespec`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRolespec?: (ctx: RolespecContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.role_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitRole_list?: (ctx: Role_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.colid`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitColid?: (ctx: ColidContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.table_alias`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitTable_alias?: (ctx: Table_aliasContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.type_function_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitType_function_name?: (ctx: Type_function_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.nonreservedword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitNonreservedword?: (ctx: NonreservedwordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.collabel`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCollabel?: (ctx: CollabelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.identifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitIdentifier?: (ctx: IdentifierContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.plsqlidentifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPlsqlidentifier?: (ctx: PlsqlidentifierContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.unreserved_keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitUnreserved_keyword?: (ctx: Unreserved_keywordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.col_name_keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCol_name_keyword?: (ctx: Col_name_keywordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.type_func_name_keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitType_func_name_keyword?: (ctx: Type_func_name_keywordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.reserved_keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitReserved_keyword?: (ctx: Reserved_keywordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.builtin_function_name`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitBuiltin_function_name?: (ctx: Builtin_function_nameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.pl_function`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPl_function?: (ctx: Pl_functionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.comp_options`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitComp_options?: (ctx: Comp_optionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.comp_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitComp_option?: (ctx: Comp_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sharp`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSharp?: (ctx: SharpContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.option_value`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOption_value?: (ctx: Option_valueContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_semi`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_semi?: (ctx: Opt_semiContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.pl_block`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPl_block?: (ctx: Pl_blockContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_sect`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_sect?: (ctx: Decl_sectContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_start`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_start?: (ctx: Decl_startContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_stmts`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_stmts?: (ctx: Decl_stmtsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.label_decl`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLabel_decl?: (ctx: Label_declContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_stmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_stmt?: (ctx: Decl_stmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_statement`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_statement?: (ctx: Decl_statementContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_scrollable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_scrollable?: (ctx: Opt_scrollableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_cursor_query`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_cursor_query?: (ctx: Decl_cursor_queryContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_cursor_args`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_cursor_args?: (ctx: Decl_cursor_argsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_cursor_arglist`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_cursor_arglist?: (ctx: Decl_cursor_arglistContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_cursor_arg`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_cursor_arg?: (ctx: Decl_cursor_argContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_is_for`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_is_for?: (ctx: Decl_is_forContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_aliasitem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_aliasitem?: (ctx: Decl_aliasitemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_varname`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_varname?: (ctx: Decl_varnameContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_const`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_const?: (ctx: Decl_constContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_datatype`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_datatype?: (ctx: Decl_datatypeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_collate`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_collate?: (ctx: Decl_collateContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_notnull`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_notnull?: (ctx: Decl_notnullContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_defval`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_defval?: (ctx: Decl_defvalContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.decl_defkey`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitDecl_defkey?: (ctx: Decl_defkeyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.assign_operator`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAssign_operator?: (ctx: Assign_operatorContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.proc_sect`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProc_sect?: (ctx: Proc_sectContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.proc_stmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProc_stmt?: (ctx: Proc_stmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_perform`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_perform?: (ctx: Stmt_performContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_call`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_call?: (ctx: Stmt_callContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_expr_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_expr_list?: (ctx: Opt_expr_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_assign`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_assign?: (ctx: Stmt_assignContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_getdiag`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_getdiag?: (ctx: Stmt_getdiagContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.getdiag_area_opt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGetdiag_area_opt?: (ctx: Getdiag_area_optContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.getdiag_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGetdiag_list?: (ctx: Getdiag_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.getdiag_list_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGetdiag_list_item?: (ctx: Getdiag_list_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.getdiag_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGetdiag_item?: (ctx: Getdiag_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.getdiag_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitGetdiag_target?: (ctx: Getdiag_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.assign_var`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAssign_var?: (ctx: Assign_varContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_if`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_if?: (ctx: Stmt_ifContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_elsifs`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_elsifs?: (ctx: Stmt_elsifsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_else`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_else?: (ctx: Stmt_elseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_case`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_case?: (ctx: Stmt_caseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_expr_until_when`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_expr_until_when?: (ctx: Opt_expr_until_whenContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.case_when_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCase_when_list?: (ctx: Case_when_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.case_when`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCase_when?: (ctx: Case_whenContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_case_else`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_case_else?: (ctx: Opt_case_elseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_loop`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_loop?: (ctx: Stmt_loopContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_while`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_while?: (ctx: Stmt_whileContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_for`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_for?: (ctx: Stmt_forContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.for_control`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFor_control?: (ctx: For_controlContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_for_using_expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_for_using_expression?: (ctx: Opt_for_using_expressionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_cursor_parameters`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_cursor_parameters?: (ctx: Opt_cursor_parametersContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_reverse`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_reverse?: (ctx: Opt_reverseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_by_expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_by_expression?: (ctx: Opt_by_expressionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.for_variable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitFor_variable?: (ctx: For_variableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_foreach_a`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_foreach_a?: (ctx: Stmt_foreach_aContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.foreach_slice`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitForeach_slice?: (ctx: Foreach_sliceContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_exit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_exit?: (ctx: Stmt_exitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.exit_type`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExit_type?: (ctx: Exit_typeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_return`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_return?: (ctx: Stmt_returnContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_return_result`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_return_result?: (ctx: Opt_return_resultContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_raise`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_raise?: (ctx: Stmt_raiseContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_stmt_raise_level`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_stmt_raise_level?: (ctx: Opt_stmt_raise_levelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_raise_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_raise_list?: (ctx: Opt_raise_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_raise_using`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_raise_using?: (ctx: Opt_raise_usingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_raise_using_elem`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_raise_using_elem?: (ctx: Opt_raise_using_elemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_raise_using_elem_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_raise_using_elem_list?: (ctx: Opt_raise_using_elem_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_assert`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_assert?: (ctx: Stmt_assertContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_stmt_assert_message`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_stmt_assert_message?: (ctx: Opt_stmt_assert_messageContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.loop_body`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitLoop_body?: (ctx: Loop_bodyContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_execsql`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_execsql?: (ctx: Stmt_execsqlContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_dynexecute`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_dynexecute?: (ctx: Stmt_dynexecuteContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_execute_using`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_execute_using?: (ctx: Opt_execute_usingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_execute_using_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_execute_using_list?: (ctx: Opt_execute_using_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_execute_into`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_execute_into?: (ctx: Opt_execute_intoContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_open`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_open?: (ctx: Stmt_openContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_open_bound_list_item`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_open_bound_list_item?: (ctx: Opt_open_bound_list_itemContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_open_bound_list`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_open_bound_list?: (ctx: Opt_open_bound_listContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_open_using`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_open_using?: (ctx: Opt_open_usingContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_scroll_option`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_scroll_option?: (ctx: Opt_scroll_optionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_scroll_option_no`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_scroll_option_no?: (ctx: Opt_scroll_option_noContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_fetch`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_fetch?: (ctx: Stmt_fetchContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.into_target`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitInto_target?: (ctx: Into_targetContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_cursor_from`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_cursor_from?: (ctx: Opt_cursor_fromContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_fetch_direction`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_fetch_direction?: (ctx: Opt_fetch_directionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_move`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_move?: (ctx: Stmt_moveContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_close`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_close?: (ctx: Stmt_closeContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_null`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_null?: (ctx: Stmt_nullContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_commit`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_commit?: (ctx: Stmt_commitContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_rollback`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_rollback?: (ctx: Stmt_rollbackContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.plsql_opt_transaction_chain`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPlsql_opt_transaction_chain?: (ctx: Plsql_opt_transaction_chainContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.stmt_set`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitStmt_set?: (ctx: Stmt_setContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.cursor_variable`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitCursor_variable?: (ctx: Cursor_variableContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.exception_sect`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitException_sect?: (ctx: Exception_sectContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.proc_exceptions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProc_exceptions?: (ctx: Proc_exceptionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.proc_exception`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProc_exception?: (ctx: Proc_exceptionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.proc_conditions`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProc_conditions?: (ctx: Proc_conditionsContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.proc_condition`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitProc_condition?: (ctx: Proc_conditionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_block_label`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_block_label?: (ctx: Opt_block_labelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_loop_label`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_loop_label?: (ctx: Opt_loop_labelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_label`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_label?: (ctx: Opt_labelContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_exitcond`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_exitcond?: (ctx: Opt_exitcondContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.any_identifier`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitAny_identifier?: (ctx: Any_identifierContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.plsql_unreserved_keyword`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitPlsql_unreserved_keyword?: (ctx: Plsql_unreserved_keywordContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.sql_expression`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitSql_expression?: (ctx: Sql_expressionContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.expr_until_then`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpr_until_then?: (ctx: Expr_until_thenContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.expr_until_semi`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpr_until_semi?: (ctx: Expr_until_semiContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.expr_until_rightbracket`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpr_until_rightbracket?: (ctx: Expr_until_rightbracketContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.expr_until_loop`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitExpr_until_loop?: (ctx: Expr_until_loopContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.make_execsql_stmt`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitMake_execsql_stmt?: (ctx: Make_execsql_stmtContext) => Result;
      /**
       * Visit a parse tree produced by `PostgreSqlParser.opt_returning_clause_into`.
       * @param ctx the parse tree
       * @return the visitor result
       */
      visitOpt_returning_clause_into?: (ctx: Opt_returning_clause_intoContext) => Result;
  }

}
declare module 'websql-autocomplete-2/parsers/postgresql/grammar/PostgreSqlLexerBase' {
  import { Lexer } from 'antlr4ng';
  abstract class PostgreSqlLexerBase extends Lexer {
      protected tags: string[];
      pushTag(): void;
      isTag(): boolean;
      popTag(): void;
      checkLA(c: number): boolean;
      charIsLetter(): boolean;
      HandleNumericFail(): void;
      HandleLessLessGreaterGreater(): void;
      UnterminatedBlockCommentDebugAssert(): void;
      CheckIfUtf32Letter(): boolean;
  }
  export default PostgreSqlLexerBase;

}
declare module 'websql-autocomplete-2/parsers/postgresql/grammar/PostgreSqlParserBase' {
  import { Parser, ParserRuleContext } from 'antlr4ng';
  import { Createfunc_opt_listContext, PostgreSqlParser, SconstContext } from 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index';
  abstract class PostgreSqlParserBase extends Parser {
      GetParsedSqlTree(script: string): ParserRuleContext;
      ParseRoutineBody(_localctx: Createfunc_opt_listContext): void;
      unquote(s: string): string;
      GetRoutineBodyString(rule: SconstContext): string;
      getPostgreSQLParser(script: string): PostgreSqlParser;
      private TrimQuotes;
  }
  export default PostgreSqlParserBase;

}
declare module 'websql-autocomplete-2/parsers/postgresql/postgreSqlParserData' {
  import { ParseTree, Token } from 'antlr4ng';
  import * as c3 from 'antlr4-c3';
  import { AutocompleteParseResult, ISymbolTableVisitor } from 'websql-autocomplete-2/types.js/index';
  import { PostgreSqlLexer } from 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlLexer.js/index';
  import { PostgreSqlParser, Relation_exprContext, Table_refContext } from 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParser.js/index';
  import { PostgreSqlParserVisitor } from 'websql-autocomplete-2/parsers/postgresql/generated/PostgreSqlParserVisitor.js/index';
  import { TableQueryPosition, TokenDictionary } from 'websql-autocomplete-2/lib/tables.js/index';
  class PostgreSqlSymbolTableVisitor extends PostgreSqlParserVisitor<{}> implements ISymbolTableVisitor {
      symbolTable: c3.SymbolTable;
      scope: c3.ScopedSymbol;
      constructor();
      visitRelation_expr: (context: Relation_exprContext) => {};
      visitTable_ref: (context: Table_refContext) => {};
  }
  function generateSuggestionsFromRules(rules: c3.CandidatesCollection['rules'], cursorTokenIndex: number, previousToken?: Token): Partial<AutocompleteParseResult> & {
      suggestColumns?: boolean;
  };
  function getParseTree(parser: PostgreSqlParser, type?: TableQueryPosition['type']): ParseTree;
  export const postgreSqlParserData: {
      Lexer: typeof PostgreSqlLexer;
      Parser: typeof PostgreSqlParser;
      SymbolTableVisitor: typeof PostgreSqlSymbolTableVisitor;
      tokenDictionary: TokenDictionary;
      ignoredTokens: Set<number>;
      preferredRules: Set<number>;
      explicitlyParseJoin: boolean;
      getParseTree: typeof getParseTree;
      generateSuggestionsFromRules: typeof generateSuggestionsFromRules;
  };
  export {};

}
declare module 'websql-autocomplete-2/types' {
  import { CharStream, CommonTokenStream, ParseTree, Token } from 'antlr4ng';
  import * as c3 from 'antlr4-c3';
  import { TokenPosition } from 'websql-autocomplete-2/lib/cursor';
  import { TableQueryPosition } from 'websql-autocomplete-2/lib/tables';
  export interface ParserSyntaxError extends TokenPosition {
      message: string;
  }
  export interface KeywordSuggestion {
      value: string;
  }
  export interface ColumnSuggestion {
      tables?: {
          name: string;
          alias?: string;
      }[];
  }
  export enum TableSuggestion {
      ALL = "ALL",
      TABLES = "TABLES",
      VIEWS = "VIEWS"
  }
  export interface EngineSuggestion {
      engines: string[];
      functionalEngines: string[];
  }
  export interface AutocompleteParseResult {
      errors: ParserSyntaxError[];
      suggestKeywords?: KeywordSuggestion[];
      suggestTables?: TableSuggestion;
      suggestTemplates?: boolean;
      suggestAggregateFunctions?: boolean;
      suggestFunctions?: boolean;
      suggestColumns?: ColumnSuggestion;
      suggestEngines?: EngineSuggestion;
  }
  export type LexerConstructor<T> = new (input: CharStream) => T;
  export type ParserConstructor<T> = new (input: CommonTokenStream) => T;
  export type SymbolTableVisitorConstructor<T> = new () => T;
  export interface ISymbolTableVisitor {
      symbolTable: c3.SymbolTable;
      scope: c3.ScopedSymbol;
  }
  export type GetParseTree<P> = (parser: P, type?: TableQueryPosition['type']) => ParseTree;
  export type GenerateSuggestionsFromRules = (rules: c3.CandidatesCollection['rules'], cursorTokenIndex: number, previousToken?: Token) => Partial<AutocompleteParseResult> & {
      suggestColumns?: boolean;
  };

}
declare module 'websql-autocomplete-2' {
  import main = require('websql-autocomplete-2/src/index');
  export = main;
}